***********************************************************************
**** This files creates enlistment variables (c and n) for 1969-2005 **
**** The resulting file is called enlistment69-05.dta				 **
**** Enlistment69-05.dta is used to create enlistment measures for   **
**** women. This file is executed first in draft_female.do 			 **
***********************************************************************
 

clear all
set mem 5g
set matsize 1000
cd /home/workgroups/firmiq/data/

use plikt/pliktverket_03_06.dta, clear
gen enlistyr=substr(m_ndatum,1,4)
destring enlistyr, replace
rename perslopnr lopnr
sort lopnr

**** CREATE COGNITIVE MEASURES
** Percentile rankings of cognitive skills by enlistment year

* Percentile rankings of cognitive skills by enlistment year

 	foreach x in g {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == 2003
	egen temp2=mean(temp1) if `x'!=. & enlistyr == 2003, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == 2003
	gen `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == 2003
	label var `x'_rank "perctile rank `x'      
	drop temp*
       }

foreach i of num 2004/2005 {
 	foreach x in g {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == `i'
	egen temp2=mean(temp1) if `x'!=. & enlistyr == `i', by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == `i'
	replace `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == `i'
        drop temp*
       }
 }

** Normally distributed cognitive skills by enlistment year

gen pctc = g_rank/100
bysort enlistyr: gen c=invnorm(pctc)

** New version of standardized cognitive skills (2014-02-11)
gen c_alt=. 
forvalues i=2003(1)2005 {
	egen my_`i'=mean(g) if enlistyr==`i'
	egen sdy_`i'=sd(g) if enlistyr==`i'
	gen z_`i'=(g-my_`i')/sdy_`i' if enlistyr==`i'
	replace c_alt=z_`i' if enlistyr==`i'
	drop *_`i'
}	


**** CREATE NONCOGNITIVE MEASURES
** Percentile rankings of cognitive skills by enlistment year

 	foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == 2003
	egen temp2=mean(temp1) if `x'!=. & enlistyr == 2003, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == 2003
	gen `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == 2003
	label var `x'_rank "perctile rank `x'      
	drop temp*
       }

foreach i of num 2004/2005 {
 	foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == `i'
	egen temp2=mean(temp1) if `x'!=. & enlistyr == `i', by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == `i'
	replace `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == `i'
        drop temp*
       }
 }

** Normally distributed noncognitive skills by enlistment year

gen pctn = pf_rank/100
bysort enlistyr: gen n=invnorm(pctn)

** Alternative standardization of noncognitive skills 
gen n_alt=. 
forvalues i=2003(1)2005 {
	egen my_`i'=mean(pf) if enlistyr==`i'
	egen sdy_`i'=sd(pf) if enlistyr==`i'
	gen z_`i'=(pf-my_`i')/sdy_`i' if enlistyr==`i'
	replace n_alt=z_`i' if enlistyr==`i'
	drop *_`i'
}	


* Clean up and save
rename g pg
rename c c_old
rename c_alt c
rename n n_old
rename n_alt n

keep lopnr enlistyr pg c pf n c_old n_old
sort lopnr enlistyr
duplicates drop lopnr, force
label var c "Cognitive skills by enlistment year"
label var n "Nonognitive skills by enlistment year"
label var c_old "Cognitive skills by enlistment year, sd=0.96"
label var n_old "Nonognitive skills by enlistment year, sd=0.96"

sort lopnr enlistyr
duplicates drop lopnr, force

save temp/enlistment2003-2005.dta, replace

*** Open main enlistment file
use modified/enlistment.dta, clear
keep lopnr enlistyr pg c pf n c_old n_old

append using temp/enlistment2003-2005.dta

*** Correct values for 2003

replace n=. if enlistyr==2003
replace c=. if enlistyr==2003

 	foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == 2003
	egen temp2=mean(temp1) if `x'!=. & enlistyr == 2003, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == 2003
	gen `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == 2003
	label var `x'_rank "perctile rank `x'      
	drop temp*
       }
	   
gen pctc = pg_rank/100
bysort enlistyr: replace c_old=invnorm(pctc) if enlistyr==2003

egen my_2003=mean(pg) if enlistyr==2003
egen sdy_2003=sd(pg) if enlistyr==2003
gen z_2003=(pg-my_2003)/sdy_2003 if enlistyr==2003
replace c=z_2003 if enlistyr==2003
drop *_2003

foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == 2003
	egen temp2=mean(temp1) if `x'!=. & enlistyr == 2003, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == 2003
	gen `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == 2003
	label var `x'_rank "perctile rank `x'      
	drop temp*
       }
gen pctn = pf_rank/100
bysort enlistyr: replace n_old=invnorm(pctn) if enlistyr==2003

egen my_2003=mean(pf) if enlistyr==2003
egen sdy_2003=sd(pf) if enlistyr==2003
gen z_2003=(pf-my_2003)/sdy_2003 if enlistyr==2003
replace n=z_2003 if enlistyr==2003
drop *_2003

keep lopnr enlistyr pg c pf n c_old n_old

sort lopnr enlistyr
duplicates drop lopnr, force
sort lopnr

save modified/enlistment69-05.dta, replace
