﻿

****** ENLISTMENT DATA ********


***** KRIGSARKIVET ******* 

**** LOAD DATA
clear all
set more off
set memory 5g
cd /home/workgroups/firmiq/data/

use krig/krigsarkivet.dta, clear

**** Fix variables

destring inst, replace
destring perslopnr, gen(lopnr)
destring perslopnr, replace 

** Basic human capital measures

replace pf = "." if pf == "A"
replace pf = "." if pf == "B"

rename pgrp pg

destring pg, replace
destring pf, replace
destring rpgi, replace

replace pg = . if pg == 0
replace pf = . if pf == 0

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)

** Detailed human capital measures for cognitive ability

*To get logic:
rename rpg1 logic
destring logic, replace
replace logic=. if logic==0
replace logic=. if logic>=41 

*To get verbal:
rename rpg2 verbal
destring verbal, replace
replace verbal=. if verbal==0
replace verbal=. if verbal>=41 

*To get spatial:
rename rpg3 spatial
destring spatial, replace
replace spatial=. if spatial==0
replace spatial=. if spatial>=41

*To get tech:
rename rpg4 tech
destring tech, replace
replace tech=. if tech==0
replace tech=. if tech>=41

gen sumprov = logic + verbal + spatial + tech

** Year of enlistment

destring inst, replace
gen enlistyr = floor(inst/10000)
replace enlistyr = enlistyr + 1900
drop if enlistyr == 1983

keep lopnr perslopnr inst pg pf logic verbal spatial tech enlistyr
save temp/krigsarkivet.dta, replace


***** PLIKTVERKET 83-97 *******

**** LOAD DATA
use plikt/pliktverket_83_97.dta, clear

**** Fix variables
gen lopnr = perslopnr

** Basic human capital measures

destring pg, replace
destring pf, replace
replace pg = . if pg == 0
replace pf = . if pf == 0
destring rpgi, replace

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)

** Detailed human capital measures for cognitive ability

*To get logic:
generate logic=rpgi/1000000
replace logic=floor(logic) 
replace logic=. if logic==0
replace logic=. if logic>=41 

*To get verbal:
generate slask1=logic*1000000
generate slask2=rpgi-slask1
generate verbal=floor(slask2/10000)
replace verbal=. if verbal==0
replace verbal=. if verbal>=41 

*To get spatial:
generate slask3=verbal*10000
generate slask4=rpgi-slask1-slask3
generate spatial=floor(slask4/100)
replace spatial=. if spatial==0
replace spatial=. if spatial>=41

*To get tech:
generate slask5=spatial*100
generate slask6=rpgi-slask1-slask3-slask5
generate tech=floor(slask6)
replace tech=. if tech==0
replace tech=. if tech>=41

drop slask1 slask2 slask3 slask4 slask5 slask6

gen sumprov =  logic + verbal + spatial + tech
replace sumprov=. if logic==.|verbal==.|spatial==.|tech==.

** Year of enlistment

gen yrslask = inst/10000
gen enlistyr = floor(yrslask)
replace enlistyr =. if enlistyr<=82|enlistyr>=98
replace enlistyr = enlistyr + 1900

keep lopnr perslopnr inst pg pf logic verbal spatial tech enlistyr
save temp/pliktverket_83_97.dta, replace


***** PLIKTVERKET 97-02 *******

**** LOAD DATA
use plikt/pliktverket_97_02.dta, clear

**** Fix variables

gen lopnr = perslopnr

** Basic human capital measures

replace gkap = . if gkap == 0
rename gkap pg

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)

** No detailed human capital measures for cognitive ability

** Year of enlistment

encode inskdat, gen(test)
gen enlistyr = 1997 if test >=1 & test <=106
replace enlistyr = 1998 if test >=107 & test <=324
replace enlistyr = 1999 if test >=325 & test <=538
replace enlistyr = 2000 if test >=539 & test <=751
replace enlistyr = 2001 if test >=752 & test <=960
replace enlistyr = 2002 if test >=961 & test <=1168
replace enlistyr = 2003 if test >=1169 & test <=1208
drop test

keep lopnr perslopnr pg pf enlistyr
save temp/pliktverket_97_02.dta, replace

**** ADD DATA SETS TO CREATE COG/NONCOG MEASURES

use temp/krigsarkivet.dta, clear
append using temp/pliktverket_83_97.dta
append using temp/pliktverket_97_02.dta

***********************************
**** CREATE COGNITIVE MEASURES ****
***********************************

** Percentile rankings of cognitive skills by enlistment year

 	foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == 1969
	egen temp2=mean(temp1) if `x'!=. & enlistyr == 1969, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == 1969
	gen `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == 1969
	label var `x'_rank "perctile rank `x'      
	drop temp*
       }

foreach i of num 1970/2003 {
 	foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == `i'
	egen temp2=mean(temp1) if `x'!=. & enlistyr == `i', by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == `i'
	replace `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == `i'
    drop temp*
       }
 }

** Normally distributed cognitive skills by enlistment year

gen pctc = pg_rank/100
bysort enlistyr: gen c=invnorm(pctc)

*** Percentile ranking of cognitive skills based on test cohorts / change assumed to take place 2000, but maybe already in 1997?

gen cohort_c =1 if enlistyr >= 1969 & enlistyr <= 1979
replace cohort_c =2 if enlistyr >= 1980 & enlistyr <= 1988
replace cohort_c =3 if enlistyr >= 1989 & enlistyr <= 1993
replace cohort_c =4 if enlistyr >= 1994 & enlistyr <= 1999
replace cohort_c =5 if enlistyr >= 2000 & enlistyr <= 2003

foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1969 & enlistyr <= 1979
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1969 & enlistyr <= 1979, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1969 & enlistyr <= 1979
	gen `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr >= 1969 & enlistyr <= 1979
	label var `x'_rank_cohort "perctile rank `x' based on test cohort     
	drop temp*
       }

foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1980 & enlistyr <= 1988
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1980 & enlistyr <= 1988, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1980 & enlistyr <= 1988
	replace `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr>= 1980 & enlistyr <= 1988
	label var `x'_rank_cohort "perctile rank `x' based on test cohort      
	drop temp*
       }

foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1989 & enlistyr <= 1993
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1989 & enlistyr <= 1993, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1989 & enlistyr <= 1993
	replace `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr >= 1989 & enlistyr <= 1993
	label var `x'_rank_cohort "perctile rank `x' based on test cohort      
	drop temp*
       }


foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1989 & enlistyr <= 1993
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1989 & enlistyr <= 1993, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1989 & enlistyr <= 1993
	replace `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr>= 1989 & enlistyr <= 1993
	label var `x'_rank_cohort "perctile rank `x' based on test cohort      
	drop temp*
       }


foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1994 & enlistyr <= 1999
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1994 & enlistyr <= 1999, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1994 & enlistyr <= 1999
	replace `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr>= 1994 & enlistyr <= 1999
	label var `x'_rank_cohort "perctile rank `x' based on test cohort      
	drop temp*
       }

foreach x in pg {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 2000 & enlistyr <= 2003
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 2000 & enlistyr <= 2003, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 2000 & enlistyr <= 2003
	replace `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr>= 2000 & enlistyr <= 2003
	label var `x'_rank_cohort "perctile rank `x' based on test cohort      
	drop temp*
       }

** Normally distributed cognitive skills by test cohort

gen pctc_cohort = pg_rank_cohort/100
bysort cohort_c: gen c_cohort=invnorm(pctc_cohort)

** Alternative standardization of cognitive skills  
gen c_alt=. 
forvalues i=1969(1)2003 {
	egen my_`i'=mean(pg) if enlistyr==`i'
	egen sdy_`i'=sd(pg) if enlistyr==`i'
	gen z_`i'=(pg-my_`i')/sdy_`i' if enlistyr==`i'
	replace c_alt=z_`i' if enlistyr==`i'
	drop *_`i'
}	

**************************************
**** CREATE NONCOGNITIVE MEASURES ****
**************************************

** Percentile rankings of noncognitive skills by enlistment year

 	foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == 1969
	egen temp2=mean(temp1) if `x'!=. & enlistyr == 1969, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == 1969
	gen `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == 1969
	label var `x'_rank "perctile rank `x'      
	drop temp*
       }

foreach i of num 1970/2003 {
 	foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr == `i'
	egen temp2=mean(temp1) if `x'!=. & enlistyr == `i', by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr == `i'
	replace `x'_rank=((temp2-0.5)/temp3)*100 if enlistyr == `i'
        drop temp*
       }
 }

** Normally distributed noncognitive skills by enlistment year

gen pctn = pf_rank/100
bysort enlistyr: gen n=invnorm(pctn)

*** Percentile ranking of noncognitive skills based on test cohorts / pf before 1972 assumed to be the same as for 1972 and onwards, is it true? 

gen cohort_n =1 if enlistyr >= 1969 & enlistyr <= 1994
replace cohort_n =2 if enlistyr >= 1995 & enlistyr <= 2003

foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1969 & enlistyr <= 1994
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1969 & enlistyr <= 1994, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1969 & enlistyr <= 1994
	gen `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr>= 1969 & enlistyr <= 1994
	label var `x'_rank_cohort "perctile rank `x' based on test cohort     
	drop temp*
       }

foreach x in pf {
        sort `x'
	egen temp1=seq() if `x'!=. & enlistyr >= 1995 & enlistyr <= 2003
	egen temp2=mean(temp1) if `x'!=. & enlistyr >= 1995 & enlistyr <= 2003, by(`x')
	egen temp3=count(lopnr) if `x'!=. & enlistyr >= 1995 & enlistyr <= 2003
	replace `x'_rank_cohort=((temp2-0.5)/temp3)*100 if enlistyr>= 1995 & enlistyr <= 2003
	label var `x'_rank_cohort "perctile rank `x' based on test cohort      
	drop temp*
       }

** Normally distributed noncognitive skills by test cohort

gen pctn_cohort = pf_rank_cohort/100
bysort cohort_n: gen n_cohort=invnorm(pctn_cohort)

** Alternative standardization of noncognitive skills 
gen n_alt=. 
forvalues i=1969(1)2003 {
	egen my_`i'=mean(pf) if enlistyr==`i'
	egen sdy_`i'=sd(pf) if enlistyr==`i'
	gen z_`i'=(pf-my_`i')/sdy_`i' if enlistyr==`i'
	replace n_alt=z_`i' if enlistyr==`i'
	drop *_`i'
}	

rename c c_old
rename c_alt c
rename n n_old
rename n_alt n

label var c "Cognitive skills by enlistment year"
label var n "Noncognitive skills by enlistment year"
label var c_cohort "Cognitive skills by test cohort"
label var n_cohort "Noncognitive skills by test cohort"
label var c_old "Cognitive skills by enlistment year, sd=0.96"
label var n_old "Noncognitive skills by enlistment year, sd=0.96"

*** Remove second draft

keep lopnr perslopnr inst c_old n_old pg pf pg_rank pctc c pg_rank_cohort pctc_cohort c_cohort pf_rank pctn n pf_rank_cohort pctn_cohort n_cohort logic verbal spatial tech enlistyr

order lopnr perslopnr inst pg pf pg_rank pctc c pg_rank_cohort pctc_cohort c_cohort c_old pf_rank pctn n pf_rank_cohort pctn_cohort n_cohort n_old logic verbal spatial tech enlistyr

sort lopnr inst
gen two = 1 if lopnr == lopnr[_n-1]
drop if two == 1
drop two

sort lopnr enlistyr
duplicates drop lopnr, force

save modified/enlistment.dta, replace

