*****************************************************************************
***** This do-file creates draft measures for women using data from their ***
***** Version 1: i) full brothers, ii) fathers, iii) sons, iv) spouses    ***
***** Version 2: i) full brothers, ii) spouses, iii) fathers, iv) sons    ***
***** Note that the file requires enlistment data 1969-2005 and hence     ***
***** it runs after enlistment2003-2005_JHR.do                			  ***	
*****************************************************************************

set more off
clear all
set mem 30g
set matsize 3000
cd /home/workgroups/firmiq/data/


***************************
*** Get women's fathers ***
***************************

use flergen/flergen_relationer_2007.dta, clear
gen wom=1 if kon==2
replace wom=0 if kon==1
drop if wom==.
drop if wom==0

gen long lopnr_wom=real(perslopnr)
*destring perslopnr, gen(lopnr_wom) 
drop if lopnr_wom==.

gen long lopnr=real(perslopnr_far)
*destring perslopnr_far, gen(lopnr)

joinby lopnr using modified/enlistment69-05.dta

rename lopnr lopnr_far
rename lopnr_wom lopnr

keep perslopnr lopnr perslopnr_far lopnr_far n c pg pf 
rename n n_far
rename c c_far
rename pg pg_far
rename pf pf_far

drop if n_far==. & c_far==. & pg_far==. & pf_far==.

sort lopnr
save temp/fathers.dta, replace

****************
** Get sons ****
****************

use flergen/flergen_relationer_2007.dta, clear
gen wom=1 if kon==2
replace wom=0 if kon==1
drop if wom==.
drop if wom==1

gen long lopnr=real(perslopnr)
drop if lopnr==.

gen long lopnr_wom=real(perslopnr_mor)

sort lopnr_wom ordnrmor
* Retain oldest son
duplicates drop lopnr_wom, force 	

joinby lopnr using modified/enlistment69-05.dta

rename lopnr lopnr_son
rename lopnr_wom lopnr
rename perslopnr perslopnr_son
rename perslopnr_mor perslopnr 

keep perslopnr lopnr perslopnr_son lopnr_son n c pg pf 
rename n n_son
rename c c_son
rename pg pg_son
rename pf pf_son

drop if n_son==. & c_son==. & pg_son==. & pf_son==.

sort lopnr
save temp/sons.dta, replace

***************************************************************
**** Get spouse (ie the father of the woman's first child) ****
***************************************************************

use flergen/flergen_relationer_2007.dta, clear

keep if ordnrmor==1
drop perslopnr

gen long lopnr=real(perslopnr_far)
rename perslopnr_far perslopnr_spouse

joinby lopnr using modified/enlistment69-05.dta

rename lopnr lopnr_spouse

gen long lopnr=real(perslopnr_mor)
rename perslopnr_mor perslopnr
drop if lopnr==.

sort lopnr
duplicates drop lopnr, force 


keep perslopnr lopnr perslopnr_spouse lopnr_spouse n c pg pf 
rename n n_spouse
rename c c_spouse
rename pg pg_spouse
rename pf pf_spouse

drop if n_spouse==. & c_spouse==. & pg_spouse==. & pf_spouse==.

sort lopnr
save temp/spouse.dta, replace

************************ 
*** Get full brothers **
************************

use flergen/flergen_relationer_2007.dta, clear
gen wom=1 if kon==2
replace wom=0 if kon==1
drop if wom==.

egen long famid=group(perslopnr_mor perslopnr_far)

gen long lopnr=real(perslopnr)
drop if lopnr==.
gen long lopnr_sis=lopnr if wom==1
replace lopnr=. if wom==1

bysort famid: egen womsh=mean(wom)

* Drop if there are no sisters in the family 
drop if womsh==0 		
* Drop if there are no brothers in the family 
drop if womsh==1

gen birthyear=real(fodelsear)
gen birthmonth=real(fodelseman)
gen birthtime=(12*birthyear)+birthmonth

sort lopnr
joinby lopnr using modified/enlistment69-05.dta, unmatched(master)
drop _merge

sort famid birthtime
bysort famid wom: egen birthrank=rank(birthtime), unique

gen n1=n if birthrank==1 & wom==0
gen pf1=pf if birthrank==1 & wom==0
gen c1=c if birthrank==1 & wom==0
gen pg1=pg if birthrank==1 & wom==0

gen n2=n if birthrank==2 & wom==0
gen pf2=pf if birthrank==2 & wom==0
gen c2=c if birthrank==2 & wom==0
gen pg2=pg if birthrank==2 & wom==0

gen n3=n if birthrank==3 & wom==0
gen pf3=pf if birthrank==3 & wom==0
gen c3=c if birthrank==3 & wom==0
gen pg3=pg if birthrank==3 & wom==0

bysort famid: egen n1a=min(n1)
bysort famid: egen n2a=min(n2)
bysort famid: egen n3a=min(n3)

bysort famid: egen c1a=min(c1)
bysort famid: egen c2a=min(c2)
bysort famid: egen c3a=min(c3)

bysort famid: egen pg1a=min(pg1)
bysort famid: egen pg2a=min(pg2)
bysort famid: egen pg3a=min(pg3)

bysort famid: egen pf1a=min(pf1)
bysort famid: egen pf2a=min(pf2)
bysort famid: egen pf3a=min(pf3)

drop if lopnr_sis==.

gen n_brother=n1a
replace n_brother=n2a if n_brother==.
replace n_brother=n3a if n_brother==.

gen c_brother=c1a
replace c_brother=c2a if c_brother==.
replace c_brother=c3a if c_brother==.

gen pg_brother=pg1a
replace pg_brother=pg2a if pg_brother==.
replace pg_brother=pg3a if pg_brother==.

gen pf_brother=pf1a
replace pf_brother=pf2a if pf_brother==.
replace pf_brother=pf3a if pf_brother==.


keep lopnr_sis perslopnr n_brother c_brother pg_brother pf_brother
rename lopnr_sis lopnr

drop if n_brother==. & c_brother==. & pg_brother==. & pf_brother==.

keep lopnr perslopnr c_brother n_brother pg_brother pf_brother

sort lopnr
save temp/brothers.dta, replace

******************************
**** Append everything *******
******************************
use flergen/flergen_relationer_2007.dta, clear
gen wom=1 if kon==2
replace wom=0 if kon==1
drop if wom==.
drop if wom==0

gen long lopnr=real(perslopnr)
gen birthyear=real(fodelsear)

keep wom lopnr perslopnr birthyear
compress
joinby lopnr using temp/spouse.dta, unmatched(master)
drop _merge
compress
joinby lopnr using temp/sons.dta, unmatched(master)
drop _merge
compress
joinby lopnr using temp/fathers.dta, unmatched(master)
drop _merge
compress
joinby lopnr using temp/brothers.dta, unmatched(master)
drop _merge

* Main order: brother, father, son, spouse

gen n=n_brother
gen n_source=1 if n~=.
replace n=n_far if n==.
replace n_source=2 if n~=. & n_brother==.
replace n=n_son if n==.
replace n_source=3 if n~=. & n_brother==. & n_far==.
replace n=n_spouse if n==.
replace n_source=4 if n~=. & n_brother==. & n_far==. & n_son==.

gen c=c_brother
gen c_source=1 if c~=.
replace c=c_far if c==.
replace c_source=2 if c~=. & c_brother==.
replace c=c_son if c==.
replace c_source=3 if c~=. & c_brother==. & c_far==.
replace c=c_spouse if c==.
replace c_source=4 if c~=. & c_brother==. & c_far==. & c_son==.

gen pg=pg_brother
gen pg_source=1 if pg~=.
replace pg=pg_far if pg==.
replace pg_source=2 if pg~=. & pg_brother==.
replace pg=pg_son if pg==.
replace pg_source=3 if pg~=. & pg_brother==. & pg_far==.
replace pg=pg_spouse if pg==.
replace pg_source=4 if pg~=. & pg_brother==. & pg_far==. & pg_son==.

gen pf=pf_brother
gen pf_source=1 if pf~=.
replace pf=pf_far if pf==.
replace pf_source=2 if pf~=. & pf_brother==.
replace pf=pf_son if pf==.
replace pf_source=3 if pf~=. & pf_brother==. & pf_far==.
replace pf=pf_spouse if pf==.
replace pf_source=4 if pf~=. & pf_brother==. & pf_far==. & pf_son==.

* Change order 1: brother, spouse, son, father

gen n1=n_brother
replace n1=n_spouse if n1==.
replace n1=n_son if n1==.
replace n1=n_far if n1==.

gen c1=c_brother
replace c1=c_spouse if c1==.
replace c1=c_son if c1==.
replace c1=c_far if c1==.

gen pg1=pg_brother
replace pg1=pg_spouse if pg1==.
replace pg1=pg_son if pg1==.
replace pg1=pg_far if pg1==.

gen pf1=pf_brother
replace pf1=pf_spouse if pf1==.
replace pf1=pf_son if pf1==.
replace pf1=pf_far if pf1==.

* Change order 2: spouse, father, son, brother

gen n2=n_spouse
replace n2=n_far if n2==.
replace n2=n_son if n2==.
replace n2=n_brother if n2==.

gen c2=c_spouse
replace c2=c_far if c2==.
replace c2=c_son if c2==.
replace c2=c_brother if c2==.

gen pg2=pg_spouse
replace pg2=pg_far if pg2==.
replace pg2=pg_son if pg2==.
replace pg2=pg_brother if pg2==.

gen pf2=pf_spouse
replace pf2=pf_far if pf2==.
replace pf2=pf_son if pf2==.
replace pf2=pf_brother if pf2==.

drop if n==. & c==. & pg==. & pf==.

label var c "c: brother-father-son-spouse"
label var c1 "c: brother-spouse-father-son"

label var n "n: brother-father-son-spouse"
label var n1 "n: brother-spouse-father-son"

label var pg "pg: brother-father-son-spouse"
label var pg1 "pg: brother-spouse-father-son"

label var pf "pf: brother-father-son-spouse"
label var pf1 "pf: brother-spouse-father-son"

label var c_source "1=brother, 2=father, 3=son, 4=spouse" 
label var n_source "1=brother, 2=father, 3=son, 4=spouse"
label var pg_source "1=brother, 2=father, 3=son, 4=spouse"
label var pf_source "1=brother, 2=father, 3=son, 4=spouse"

keep lopnr perslopnr birthyear n n_source c c_source pg pg_source pf pf_source n1 c1 pg1 pf1 

sort lopnr
duplicates drop lopnr, force

save modified/enlistment_wom.dta, replace
