*************************************************************************************************
*louise.do File to yearly filed with years of education and field of study from LOUISE 1985-2006*
*************************************************************************************************

*louise.do create yearly data sets, edyr1885.dta-edyr2009.dta, with years of education (edyr), field of study (fos), sex, age, lonink, fink and year of immigration from LOUISE
*louise.do used data set "/home/workgroup/firmiq/data/modified/nyckelx.dta" wich is a dataset translating the old education standard to SUN2000 according to:
*http://www.scb.se/statistik/UF/UF0506/_dokument/WEB_SUN2000nyckelny_delad.xls
*for years 1985-1999 the old standard is first translated to SUN2000, before edyr and and fos is created by the do file edyr.do
*variable fink changes name in raw data, and partly definition 2001. Original name is kept.
 
clear all
cd /home/workgroups/firmiq/data/
set mem 20g
set more off

**************
*file for 1985-1999
**************

forvalues i=85(1)99{
use louise/louise`i'.dta
keep perslopnr fodar kon seninvar hutbsun syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
rename hutbsun hutbsun_string
rename kon sex
destring fodar,replace
destring hutbsun_string perslopnr,gen (hutbsun lopnr) force
replace hutbsun=. if hutbsun_string=="99000"
replace hutbsun=. if hutbsun_string=="00000"
gen year=1900+`i'
gen age=year-fodar
sort hutbsun
merge hutbsun using modified/nyckelx.dta
drop if _merge==2
drop _merge

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
sort lopnr
save modified/edyr19`i',replace
}


**************
*file for 2000
**************
clear
use louise/louise00.dta
keep perslopnr fodar kon seninvar hutbsun2000inr hutbsun2000niva  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
rename hutbsun2000inr sun2000inr
rename hutbsun2000niva sun2000niva_string
rename kon sex
destring fodar,replace
destring sun2000niva_string perslopnr, gen(sun2000niva lopnr) force
replace sun2000niva=. if sun2000niva_string=="999"
gen year=2000
gen age=2000-fodar

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
sort lopnr
save modified/edyr2000,replace

**************
*file for 2001
**************
clear
use louise/louise01.dta
keep perslopnr fodar kon seninvar sun2000inr sun2000niva  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
rename sun2000niva sun2000niva_string
rename kon sex
destring fodar,replace
destring sun2000niva_string perslopnr, gen(sun2000niva lopnr) force
replace sun2000niva=. if sun2000niva_string=="999"
gen year=2001
gen age=2001-fodar

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
sort lopnr
save modified/edyr2001,replace

**************
*file for 2002
**************
clear
use louise/louise02.dta
keep perslopnr fodar kon seninvar sun2000inr sun2000niva  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
rename sun2000niva sun2000niva_string
rename kon sex
destring fodar,replace
destring sun2000niva_string perslopnr, gen(sun2000niva lopnr) force
replace sun2000niva=. if sun2000niva_string=="999"
gen year=2002
gen age=2002-fodar

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
sort lopnr
save modified/edyr2002,replace

**************
*file for 2003-2006
**************
clear
forvalues i=3(1)6{
use louise/louise0`i'.dta
keep perslopnr fodar kon seninvar sun2000inr sun2000niva syssstat loneink inkfnetto nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
rename sun2000niva sun2000niva_string
rename inkfnetto fink
rename kon sex
destring fodar,replace
destring sun2000niva_string perslopnr, gen(sun2000niva lopnr) force
replace sun2000niva=. if sun2000niva_string=="999"
gen year=`i'+2000
gen age=year-fodar

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
sort lopnr
save modified/edyr200`i',replace
}


* 2007
clear
forvalues i=7(1)7{
use louise/louise0`i'.dta
keep perslopnr fodar kon seninvar sun2000inr sun2000niva syssstat loneink inkfnetto nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun

rename inkfnetto fink
rename kon sex
destring fodar,replace
rename perslopnr lopnr
replace sun2000niva=. if sun2000niva==999
gen year=`i'+2000
gen age=year-fodar

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
destring lopnr, replace
tostring lopnr, replace
sort lopnr
save modified/edyr200`i',replace
}

* 2008 and 2009
clear
forvalues i=8(1)9{
use louise/louise0`i'.dta
keep perslopnr fodar kon seninvar sun2000inr sun2000niva syssstat loneink inkfnetto nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun

rename inkfnetto fink
rename kon sex
destring fodar,replace
rename perslopnr lopnr
replace sun2000niva=. if sun2000niva==999
gen year=`i'+2000
gen age=year-fodar

*years of education
gen edyr=.
replace edyr=8 if sun2000niva==100 | sun2000niva==102 |sun2000niva==106
replace edyr=9 if sun2000niva==200 | sun2000niva==204 | sun2000niva==206
replace edyr=10 if sun2000niva==310 | sun2000niva==312 | sun2000niva==313 | sun2000niva==316 | sun2000niva==317
replace edyr=11 if sun2000niva==320 | sun2000niva==322 | sun2000niva==323 | sun2000niva==326 | sun2000niva==327
replace edyr=12 if sun2000niva==330 | sun2000niva==332 | sun2000niva==333 | sun2000niva==336 | sun2000niva==337
replace edyr=13 if sun2000niva==410 | sun2000niva==412 | sun2000niva==413 | sun2000niva==415 | sun2000niva==417
replace edyr=14 if sun2000niva==520 | sun2000niva==522 | sun2000niva==525 | sun2000niva==526 | sun2000niva==527
replace edyr=15 if sun2000niva==530 | sun2000niva==532 | sun2000niva==535 | sun2000niva==536 | sun2000niva==537
replace edyr=16 if sun2000niva==540 | sun2000niva==545 | sun2000niva==546 | sun2000niva==547
replace edyr=17 if sun2000niva==550 | sun2000niva==555 | sun2000niva==556 | sun2000niva==557
replace edyr=18 if sun2000niva==600 | sun2000niva==620
replace edyr=19 if sun2000niva==640

* field of study
gen fos=substr(sun2000inr,1,1)
gen fos_detail=substr(sun2000inr,1,2)
destring fos fos_detail,replace

*value labels according to MIS SUN 2000
lab def foslab 0 "General Programmes"
lab def foslab 1 "Education",add 
lab def foslab 2 "Humanities and Arts",add 
lab def foslab 3 "Social sciences, Business and Law",add 
lab def foslab 4 "Science, Mathematics and Computing",add 
lab def foslab 5 "Engineering, Manufacturing and Construction",add
lab def foslab 6 "Agriculture and Veterinary",add 
lab def foslab 7 "Health and Welfare",add 
lab def foslab 8 "Services",add
lab def foslab 9 "Unkonwn",add 

lab def fos_detaillab 1 "Basic / broad, general programmes"
lab def fos_detaillab 8 "Literacy and numeracy",add 
lab def fos_detaillab 9 "Personal skills" ,add 
lab def fos_detaillab 14 "Teacher training and education science",add  
lab def fos_detaillab 21 "Arts",add
lab def fos_detaillab 22 "Humanities",add  
lab def fos_detaillab 31 "Social and behavioral science" ,add 
lab def fos_detaillab 32 "Journalism and information" ,add 
lab def fos_detaillab 34 "Business and administration" ,add 
lab def fos_detaillab 38 "Law",add
lab def fos_detaillab 42 "Life science" ,add 
lab def fos_detaillab 44 "Physical science" ,add 
lab def fos_detaillab 46 "Mathematics and statistics",add  
lab def fos_detaillab 48 "Computing",add 
lab def fos_detaillab 52 "Engineering and engineering trades",add  
lab def fos_detaillab 54 "Manufacturing and processing" ,add 
lab def fos_detaillab 58 "Architecture and building" ,add 
lab def fos_detaillab 62 "Agriculture, forestry and fishery",add 
lab def fos_detaillab 64 "Veterinary" ,add 
lab def fos_detaillab 72 "Health" ,add 
lab def fos_detaillab 76 "Social services" ,add 
lab def fos_detaillab 81 "Personal services" ,add 
lab def fos_detaillab 84 "Transport services" ,add 
lab def fos_detaillab 85 "Environmental protection",add  
lab def fos_detaillab 86 "Security services" ,add 
lab def fos_detaillab 99 "Unknown",add 

lab val fos foslab
lab val fos_detail fos_detaillab

bysort fodar sex: egen edyr_m=mean(edyr)
bysort fodar sex: egen edyr_sd=sd(edyr)
gen zedyr=(edyr-edyr_m)/edyr_sd
drop edyr_m edyr_sd
replace zedyr=. if edyr==.

keep lopnr year age edyr zedyr fos fos_detail sun2000inr sex seninvar  syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
destring lopnr, replace
sort lopnr
save modified/edyr200`i',replace
}

***************************'  
* write back edyr 85-89
***************************

* cd /home/workgroup/firmiq/data/
* set mem 10g
set more off

clear
use modified/edyr1990
sort lopnr 
keep lopnr edyr zedyr fos fos_detail
save temp/edyr1990,replace

clear
use modified/edyr1989
sort lopnr
merge lopnr using temp/edyr1990, update
drop if _merge==2
gen D_imputed_edyr=0
replace D_imputed_edyr=1 if _merge==4
drop _merge
save modified/edyr1989,replace

sort lopnr 
keep lopnr edyr zedyr fos fos_detail
save temp/edyr1989,replace

clear
use modified/edyr1988
sort lopnr
merge lopnr using temp/edyr1989, update
drop if _merge==2
gen D_imputed_edyr=0
replace D_imputed_edyr=1 if _merge==4
drop _merge
save modified/edyr1988,replace

sort lopnr 
keep lopnr edyr zedyr fos fos_detail
save temp/edyr1988,replace

clear
use modified/edyr1987
sort lopnr
merge lopnr using temp/edyr1988, update
drop if _merge==2
gen D_imputed_edyr=0
replace D_imputed_edyr=1 if _merge==4
drop _merge
save modified/edyr1987,replace

sort lopnr 
keep lopnr edyr zedyr fos fos_detail
save temp/edyr1987,replace

clear
use modified/edyr1986
sort lopnr
merge lopnr using temp/edyr1987, update
drop if _merge==2
gen D_imputed_edyr=0
replace D_imputed_edyr=1 if _merge==4
drop _merge
save modified/edyr1986,replace

sort lopnr 
keep lopnr edyr zedyr fos fos_detail
save temp/edyr1986,replace

clear
use modified/edyr1985
sort lopnr
merge lopnr using temp/edyr1986, update
drop if _merge==2
gen D_imputed_edyr=0
replace D_imputed_edyr=1 if _merge==4
drop _merge
save modified/edyr1985,replace

erase temp/edyr1990.dta
erase temp/edyr1989.dta
erase temp/edyr1988.dta
erase temp/edyr1987.dta
erase temp/edyr1986.dta





