﻿*******************************************************************************
*** ENLISTMENT DATA FOR PAPERS ON TOP IQ AND STANDARD DEVIATIONS OF IQ ********
***               AND FOR ALTERNATIVE DISTRIBUTIONS                    ********
****************************************************************************** 
***
*** Main file created /modified/topiq6994.dta

**************************
***** KRIGSARKIVET *******
**************************

**** LOAD DATA
clear all
set memory 5g
use "/home/workgroups/firmiq/data/krig/krigsarkivet.dta", clear

**** Fix variables

destring inst, replace
destring perslopnr, gen(lopnr) 

** Basic human capital measures

replace pf = "." if pf == "A"
replace pf = "." if pf == "B"

rename pgrp pg

destring pg, replace
destring pf, replace
destring rpgi, replace

replace pg = . if pg == 0
replace pf = . if pf == 0

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)

lab var pf "plikttjänstförmpga (noncognitive, 1-9)"
lab var pg "provgrupp (cognitive, 1-9)"

** Year of enlistment

destring inst, replace
gen enlistyr = floor(inst/10000)
replace enlistyr = enlistyr + 1900

** CREATE ABILITY MEASURES FOR 1969-1983
** NOTE THAT TEST IS CHANGED IN 1980 AND THAT
** THE SCALE FOR SPATIAL AND TECHNICAL THEN CHANGES

* Destring and rename

rename rpg1 logic
destring logic, replace
rename stp1 slogic
destring slogic, replace

rename rpg2 verbal
destring verbal, replace
rename stp2 sverbal
destring sverbal, replace

rename rpg3 spatial
destring spatial, replace
rename stp3 sspatial
destring sspatial, replace

rename rpg4 technical
destring technical, replace
rename stp4 stechnical
destring stechnical, replace

* LOGIC

replace logic=. if logic>=41

gen logic0=logic
replace logic0=. if logic0==0 & (slogic==0 | slogic>=2 | sverbal>=3 | sspatial>=3 | stechnical>=3)

replace logic=. if logic==0

replace slogic=. if slogic==0

lab var logic "Raw score logic. Zeroes dropped"
lab var logic0 "Raw score logic. 'Real' zeroes kept"
lab var slogic "Standard points logic (1-9)" 

* VERBAL

replace verbal=. if verbal>=41

gen verbal0=verbal
replace verbal0=. if verbal0==0 & (sverbal==0 | sverbal>=2 | slogic>=3 | sspatial>=3 | stechnical>=3)

replace verbal=. if verbal==0
replace sverbal=. if sverbal==0

lab var sverbal "Standard points verbal (1-9)" 
lab var verbal0 "Raw score verbal. 'Real' zeroes kept"
lab var verbal "Raw score verbal. Zeroes dropped"

* SPATIAL

replace spatial=. if spatial>25 & enlistyr<=1979
replace spatial=. if spatial>40 & enlistyr>1979

gen spatial0=spatial
replace spatial0=. if spatial0==0 & (sspatial==0 | sspatial>=2 | sverbal>=3 | slogic>=3 | stechnical>=3)

replace spatial=. if spatial==0

replace sspatial=. if sspatial==0

lab var spatial "Raw score spatial. Zeroes dropped"
lab var spatial0 "Raw score spatial. 'Real' zeroes kept"
lab var sspatial "Standard points spatial (1-9)" 

* TECHNICAL

replace technical=. if technical>52 & enlistyr<=1979
replace technical=. if technical>40 & enlistyr>1979

gen technical0=technical
replace technical0=. if technical0==0 & (stechnical==0 | stechnical>=2 | sverbal>=3 | sspatial>=3 | slogic>=3)

replace technical=. if technical==0

replace technical=. if technical==0

replace stechnical=. if stechnical==0

lab var stechnical "Standard points technical (1-9)" 
lab var technical0 "Raw score technical. 'Real' zeroes kept"
lab var technical "Raw score technical. Zeroes dropped"

* HEIGHT, WEIGHT, PULSE AND STRENGTH 

destring lngd, replace
replace lngd=. if lngd>220
replace lngd=. if lngd<140
rename lngd height
label var height "Height in cm"

destring mass, replace
replace mass=. if mass>180
replace mass=. if mass<30
rename mass weight
label var weight "Weight in kg"

destring vpul, replace
replace vpul=. if vpul<30
replace vpul=. if vpul>150
rename vpul pulse
label var pulse "Resting pulse, bpm"

destring wmax, replace
replace wmax=. if wmax<110
replace wmax=. if wmax>410
label var wmax "Strength measure (110-410). Full coverage from 1973"

destring mfak, replace
replace mfak=. if mfak<1160
replace mfak=. if mfak>2960
label var mfak "Strength measure (1160-2960)"

destring hgrp, replace
replace hgrp=. if hgrp<300
replace hgrp=. if hgrp>920
rename hgrp handgrip
label var handgrip "Handgrip strength"

destring knst, replace
replace knst=. if knst<220
replace knst=. if knst>890
rename knst knee
label var knee "Knee strength"

destring aboj, replace
replace aboj=. if aboj<130
replace aboj=. if aboj>640
rename aboj arm
label var arm "Arm strength"

* FINAL PREPARATIONS OF COG-SKILL MEASURES

gen scog=slogic+sverbal+sspatial+stechnical 
lab var scog "Cognitive 4-36"

gen log0=logic0/40
gen verb0=verbal0/40
gen spat0=spatial0/25 if enlistyr<1980
replace spat0=spatial0/40 if enlistyr>=1980
gen tech0=technical0/52 if enlistyr<1980
replace tech0=technical0/40 if enlistyr>=1980
gen sumcog0 = log0 + verb0 + spat0 + tech0

gen log=logic/40
gen verb=verbal/40
gen spat=spatial/25 if enlistyr<1980
replace spat=spatial/40 if enlistyr>=1980
gen tech=technical/52 if enlistyr<1980
replace tech=technical/40 if enlistyr>=1980
gen sumcog = log + verb + spat + tech

lab var sumcog "Sum of normalized subtests (0-4). Zeroes dropped" 
lab var sumcog0 "Sum of normalized subtests (0-4). 'Real' zeroes kept" 

* NON-COGNITIVE

gen n_s=substr(sipe,1,1)
gen n_i=substr(sipe,2,1)
gen n_p=substr(sipe,3,1)
gen n_e=substr(sipe,4,1)

destring n_s n_i n_p n_e, replace

replace n_s=. if n_s>5
replace n_i=. if n_i>5
replace n_p=. if n_p>5
replace n_e=. if n_e>5

replace n_s=. if n_s==0
replace n_i=. if n_i==0
replace n_p=. if n_p==0
replace n_e=. if n_e==0

* Impute values for missing sub-indices
bysort pf enlistyr: egen mn_s=mean(n_s)
bysort pf enlistyr: egen mn_i=mean(n_i)
bysort pf enlistyr: egen mn_p=mean(n_p)
bysort pf enlistyr: egen mn_e=mean(n_e)


replace n_s=mn_s if n_s==. & pf~=.
replace n_i=mn_i if n_i==. & pf~=.
replace n_p=mn_p if n_p==. & pf~=.
replace n_e=mn_e if n_e==. & pf~=.

drop mn_s mn_i mn_p mn_e

* Normalized measures 0-1
gen n_s1=n_s/5
gen n_i1=n_i/5
gen n_p1=n_p/5
gen n_e1=n_e/5

lab var n_s "Noncog S (1-5)
lab var n_i "Noncog I (1-5)
lab var n_p "Noncog P (1-5)
lab var n_e "Noncog E (1-5)

lab var n_s1 "Noncog S (normalized 0-1)
lab var n_i1 "Noncog I (normalized 0-1)
lab var n_p1 "Noncog P (normalized 0-1)
lab var n_e1 "Noncog E (normalized 0-1)

gen snoncog=n_s+n_i+n_p+n_e
lab var snoncog "Noncog 4-20"

gen sumnoncog=n_s1+n_i1+n_p1+n_e1
lab var sumnoncog "Sum of normalized subtests (0-4)"

sort lopnr enlistyr
save "/home/workgroups/firmiq/data/temp/tempiq6983.dta", replace

*******************************
***** PLIKTVERKET 83-97 *******
*******************************

**** LOAD DATA
use "/home/workgroups/firmiq/data/plikt/pliktverket_83_97.dta", clear

**** Fix variables
gen long lopnr = perslopnr

** Basic human capital measures

destring pg, replace
destring pf, replace

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)
lab var pf "plikttjänstförmåga (noncognitive, 1-9)"
lab var pg "provgrupp (cognitive, 1-9)"

* Year of enlistment

gen yrslask = inst/10000
gen enlistyr = floor(yrslask)
replace enlistyr =. if enlistyr<=82|enlistyr>=98
replace enlistyr = enlistyr + 1900
drop yrslask

** Detailed human capital measures for cognitive ability

tostring stpi, replace

gen stp1=substr(stpi,1,1)
gen stp2=substr(stpi,2,1)
gen stp3=substr(stpi,3,1)
gen stp4=substr(stpi,4,1)

destring rpgi stpi stp1 stp2 stp3 stp4, replace
replace stp1=. if stp1==0
replace stp2=. if stp2==0
replace stp3=. if stp3==0
replace stp4=. if stp4==0

** New test post 1995
drop if enlistyr>1994

* Rename

rename stp1 slogic
rename stp2 sverbal
rename stp3 sspatial
rename stp4 stechnical

* LOGIC

generate logic0=rpgi/1000000
replace logic0=floor(logic0) 
replace logic0=. if logic0==0 & (pg==0 | slogic==0 | slogic>=2 | sverbal>=3 | sspatial>=3 | stechnical>=3) 
replace logic0=. if logic0>=41 

gen logic=logic0 
replace logic=. if logic0==0

replace slogic=. if slogic==0

lab var logic0 "Raw score logic. 'Real' zeroes kept"
lab var logic "Raw score logic. Zeroes dropped"
lab var slogic "Standard points logic (1-9)" 

* VERBAL

generate slask1=logic*1000000
generate slask2=rpgi-slask1
generate verbal0=floor(slask2/10000)
replace verbal0=. if verbal0==0 & (pg==0 | sverbal==0 | sverbal>=2 | stechnical>=3 | sspatial>=3 | slogic>=3)
replace verbal0=. if verbal0>=41

gen verbal=verbal0
replace verbal=. if verbal0==0 

replace sverbal=. if sverbal==0

lab var verbal0 "Raw score verbal. 'Real' zeroes kept"
lab var verbal "Raw score verbal. Zeroes dropped"
lab var sverbal "Standard points verbal (1-9)" 

* SPATIAL

generate slask3=verbal0*10000
generate slask4=rpgi-slask1-slask3
generate spatial0=floor(slask4/100)
replace spatial0=. if spatial0==0 & (pg==0 | sspatial==0 | sspatial>=2 | sverbal>=3 | stechnical>=3 | slogic>=3)
replace spatial0=. if spatial0>=41

gen spatial=spatial0
replace spatial=. if spatial0==0

replace sspatial=. if sspatial==0

lab var spatial0 "Raw score spatial. 'Real' zeroes kept"
lab var spatial "Raw score spatial. Zeroes dropped"
lab var sspatial "Standard points spatial (1-9)" 

* TECHNICAL

generate slask5=spatial0*100
generate slask6=rpgi-slask1-slask3-slask5
generate technical0=floor(slask6)
replace technical0=. if technical0==0 & (pg==0 | stechnical==0 | stechnical>=2 | sverbal>=3 | sspatial>=3 | slogic>=3) 
replace technical0=. if technical0>=41

gen technical=technical0
replace technical=. if technical0==0

replace stechnical=. if stechnical==0

lab var technical0 "Raw score technical. 'Real' zeroes kept"
lab var technical "Raw score technical. Zeroes dropped"
lab var stechnical "Standard points technical (1-9)" 


drop slask1 slask2 slask3 slask4 slask5 slask6
drop if enlistyr>1994
replace pg = . if pg == 0
replace pf = . if pf == 0

* FINAL PREPARATIONS OF SKILL MEASURES

gen scog=slogic+sverbal+sspatial+stechnical 
lab var scog "Cognitive 4-36"

gen log0=logic0/40
gen verb0=verbal0/40
gen spat0=spatial0/40
gen tech0=technical0/40 
gen sumcog0 = log0 + verb0 + spat0 + tech0

gen log=logic/40
gen verb=verbal/40
gen spat=spatial/40
gen tech=technical/40 
gen sumcog = log + verb + spat + tech

lab var sumcog0 "Sum of normalized subtests (0-4). 'Real' zeroes kept" 
lab var sumcog "Sum of normalized subtests (0-4). Zeroes dropped" 

* NON-COGNITIVE

rename sipes n_s
rename sipei n_i
rename sipep n_p
rename sipee n_e

replace n_s=. if n_s>5 | n_s<1
replace n_i=. if n_i>5 | n_i<1
replace n_p=. if n_p>5 | n_p<1
replace n_e=. if n_e>5 | n_e<1

lab var n_s "Noncog S (1-5)
lab var n_i "Noncog I (1-5)
lab var n_p "Noncog P (1-5)
lab var n_e "Noncog E (1-5)

bysort pf enlistyr: egen mn_s=mean(n_s)
bysort pf enlistyr: egen mn_i=mean(n_i)
bysort pf enlistyr: egen mn_p=mean(n_p)
bysort pf enlistyr: egen mn_e=mean(n_e)

replace n_s=mn_s if n_s==. & pf~=.
replace n_i=mn_i if n_i==. & pf~=.
replace n_p=mn_p if n_p==. & pf~=.
replace n_e=mn_e if n_e==. & pf~=.

gen n_s1=n_s/5
gen n_i1=n_i/5
gen n_p1=n_p/5
gen n_e1=n_e/5

lab var n_s1 "Noncog S (normalized 0-1)
lab var n_i1 "Noncog I (normalized 0-1)
lab var n_p1 "Noncog P (normalized 0-1)
lab var n_e1 "Noncog E (normalized 0-1)

gen snoncog=n_s+n_i+n_p+n_e
lab var snoncog "Noncog 4-20"

gen sumnoncog=n_s1+n_i1+n_p1+n_e1
lab var sumnoncog "Sum of normalized subtests (0-4)"

drop mn_s mn_i mn_p mn_e

*** Cleanups

tostring perslopnr, replace
drop rpgi stpi rpgt stpt utpf befl safh* skat

sort lopnr enlistyr
save "/home/workgroups/firmiq/data/temp/tempiq8394.dta", replace

***************************************
*** MERGE AND FINAL PREPARATIONS ******
***************************************

use "/home/workgroups/firmiq/data/temp/tempiq6983.dta", clear
append using "/home/workgroups/firmiq/data/temp/tempiq8394.dta"

keep lopnr perslopnr enlistyr scog sumcog sumcog0 log log0 logic logic0 slogic verb verb0 verbal verbal0 sverbal spat spat0 spatial spatial0 sspatial tech tech0 technical technical0 stechnical pg pf height weight wmax pulse mfak handgrip knee arm n_s n_i n_p n_e sumnoncog snoncog 

lab var log "Normalized logic (0-1). W/o zeroes"
lab var verb "Normalized verbal (0-1). W/o zeroes"
lab var spat "Normalized spatial (0-1). W/o zeroes"
lab var tech "Normalized technical (0-1). W/o zeroes"

lab var log0 "Normalized logic (0-1). With zeroes"
lab var verb0 "Normalized verbal (0-1). With zeroes"
lab var spat0 "Normalized spatial (0-1). With zeroes"
lab var tech0 "Normalized technical (0-1). With zeroes"

* Drop duplicates
sort enlistyr lopnr
duplicates drop lopnr, force

gen testregime=1 if enlistyr<1980
replace testregime=2 if enlistyr>=1980

xtile pciq1=sumcog if testregime==1, nq(100)
xtile pciq2=sumcog if testregime==2, nq(100)
gen pciq=pciq1
replace pciq=pciq2 if pciq==.
drop pciq1 pciq2

gen iq50= (pciq>50) if !missing(pciq)
gen iq40= (pciq>60) if !missing(pciq)
gen iq30= (pciq>70) if !missing(pciq)
gen iq20= (pciq>80) if !missing(pciq)
gen iq10= (pciq>90) if !missing(pciq)
gen iq5= (pciq>95) if !missing(pciq)
gen iq2= (pciq>98) if !missing(pciq)
gen iq1= (pciq>99) if !missing(pciq)

label var testregime "Period 1: 1969-1979. Period 2: 1980-1994"
label var enlistyr "Year of enlistment"
label var pciq "Percentile ranked iq, by test regime"
label var iq50 "In 50th iq percentile"
label var iq40 "In 60th iq percentile"
label var iq30 "In 70th iq percentile"
label var iq20 "In 80th iq percentile"
label var iq10 "In 90th iq percentile"
label var iq5 "In 95th iq percentile"
label var iq2 "In 98th iq percentile"
label var iq1 "In 99th iq percentile"

rename pg cog
rename pf noncog

order lopnr perslopnr enlistyr cog noncog iq1 iq2 iq5 iq10 iq20 iq30 iq40 iq50 scog sumcog sumcog0 log log0 logic logic0 slogic verb verb0 verbal verbal0 sverbal spat spat0 spatial spatial0 sspatial tech tech0 technical technical0 stechnical cog noncog height weight wmax pulse mfak handgrip knee arm

* Drop the zeroes
drop sumcog0 log0 logic0 verb0 verbal0 spat0 spatial0 tech0 technical0 

compress
sort lopnr

save "/home/workgroups/firmiq/data/modified/topiq6994.dta", replace
erase "/home/workgroups/firmiq/data/temp/tempiq6983.dta"
erase "/home/workgroups/firmiq/data/temp/tempiq8394.dta"

***************************************
******* Collapsed measures ************
***************************************

use "/home/workgroups/firmiq/data/modified/topiq6994.dta", clear

collapse (mean) cog noncog iq1 iq2 iq5 iq10 scog sumcog log verb spat tech snoncog sumnoncog n_s n_i n_p n_e (sd) scogsd=scog sumcogsd=sumcog logsd=log verbsd=verb spatsd=spat techsd=tech snoncogsd=snoncog sumnoncogsd=sumnoncog n_ssd=n_s n_isd=n_i n_psd=n_p n_esd=n_e (count) obs_cog=cog obs_noncog=noncog obs_sumcog=sumcog obs_sumnoncog=sumnoncog, by(enlistyr) 

lab var iq1 "Share in top1 percentile"
lab var iq2 "Share in top2 percentile"
lab var iq5 "Share in top5 percentile"
lab var iq10 "Share in top10 percentile"

lab var obs_cog "Number of cog observations (1-9)"
lab var obs_noncog "Number of noncog observations (1-9)"
lab var obs_sumcog "Number of cog observations (0-4)"
lab var obs_sumnoncog "Number of noncog observations (0-4)"

lab var sumcog "Sum of normalized subtests (0-4)"
lab var sumcogsd "Sd of summarized subtests (0-4)"

lab var sumnoncog "Sum of normalized subtests (0-4)"
lab var sumnoncogsd "Sd of summarized subtests (0-4)"

lab var log "Normalized logic (0-1)"
lab var verb "Normalized verbal (0-1)"
lab var spat "Normalized spatial (0-1)"
lab var tech "Normalized technical (0-1)"

lab var logsd "Sd of normalized logic (0-1)"
lab var verbsd "Sd of normalized verbal (0-1)"
lab var spatsd "Sd of normalized spatial (0-1)"
lab var techsd "Sd of normalized technical (0-1)"

lab var n_ssd "Sd of normalized S (0-1)"
lab var n_isd "Sd of normalized I (0-1)"
lab var n_psd "Sd of normalized P (0-1)"
lab var n_esd "Sd of normalized E (0-1)"

*******************************************************************
*** Adjust for change in cognitive scales between 1979 and 1980 ***
*******************************************************************

gen period=0
replace period=1 if enlistyr==1980
gen period2=0
replace period2=1 if enlistyr>1980

reg sumcogsd period period2

gen sumcogsd_adj=sumcogsd
replace sumcogsd_adj=sumcogsd-_b[period] if enlistyr>=1980
lab var sumcogsd_adj "Sd of summarized subtests (0-4), 1980 break adjusted"

drop period period2
sort enlistyr
save "/home/workgroups/firmiq/data/modified/topiq6994_collapsed.dta", replace


*****************************************************************************
*****************************************************************************
***** HERE DATA PREPARATIONS FOR ALTERNATIVE DISTRIBUTIONS ARE CREATED ******
***** Main difference from above is that imputed values for cog        ******
***** subscores are used                                               ******
*****************************************************************************
*****************************************************************************

***** KRIGSARKIVET *******

**** LOAD DATA
clear all
set memory 5g
use "/home/workgroups/firmiq/data/krig/krigsarkivet.dta", clear

**** Fix variables

destring inst, replace
destring perslopnr, gen(lopnr) 

** Basic human capital measures

replace pf = "." if pf == "A"
replace pf = "." if pf == "B"

rename pgrp pg

destring pg, replace
destring pf, replace
destring rpgi, replace

replace pg = . if pg == 0
replace pf = . if pf == 0

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)

lab var pf "plikttjänstförmåga (noncognitive, 1-9)"
lab var pg "provgrupp (cognitive, 1-9)"

** Year of enlistment

destring inst, replace
gen enlistyr = floor(inst/10000)
replace enlistyr = enlistyr + 1900


** CREATE ABILITY MEASURES FOR 1969-1983
** NOTE THAT TEST IS CHANGED IN 1980 AND THAT
** THE SCALE FOR SPATIAL AND TECHNICAL THEN CHANGES

* Destring and rename

rename rpg1 logic
destring logic, replace
rename stp1 slogic
destring slogic, replace

rename rpg2 verbal
destring verbal, replace
rename stp2 sverbal
destring sverbal, replace

rename rpg3 spatial
destring spatial, replace
rename stp3 sspatial
destring sspatial, replace

rename rpg4 technical
destring technical, replace
rename stp4 stechnical
destring stechnical, replace

* LOGIC

replace logic=. if logic>=41

gen logic0=logic
replace logic0=. if logic0==0 & (slogic==0 | slogic>=2 | sverbal>=3 | sspatial>=3 | stechnical>=3)

replace logic=. if logic==0

replace slogic=. if slogic==0

lab var logic "Raw score logic. Zeroes dropped"
lab var logic0 "Raw score logic. 'Real' zeroes kept"
lab var slogic "Standard points logic (1-9)" 


* VERBAL

replace verbal=. if verbal>=41

gen verbal0=verbal
replace verbal0=. if verbal0==0 & (sverbal==0 | sverbal>=2 | slogic>=3 | sspatial>=3 | stechnical>=3)

replace verbal=. if verbal==0
replace sverbal=. if sverbal==0

lab var sverbal "Standard points verbal (1-9)" 
lab var verbal0 "Raw score verbal. 'Real' zeroes kept"
lab var verbal "Raw score verbal. Zeroes dropped"

* SPATIAL

replace spatial=. if spatial>25 & enlistyr<=1979
replace spatial=. if spatial>40 & enlistyr>1979

gen spatial0=spatial
replace spatial0=. if spatial0==0 & (sspatial==0 | sspatial>=2 | sverbal>=3 | slogic>=3 | stechnical>=3)

replace spatial=. if spatial==0

replace sspatial=. if sspatial==0

lab var spatial "Raw score spatial. Zeroes dropped"
lab var spatial0 "Raw score spatial. 'Real' zeroes kept"
lab var sspatial "Standard points spatial (1-9)" 

* TECHNICAL

replace technical=. if technical>52 & enlistyr<=1979
replace technical=. if technical>40 & enlistyr>1979

gen technical0=technical
replace technical0=. if technical0==0 & (stechnical==0 | stechnical>=2 | sverbal>=3 | sspatial>=3 | slogic>=3)

replace technical=. if technical==0

replace technical=. if technical==0

replace stechnical=. if stechnical==0

lab var stechnical "Standard points technical (1-9)" 
lab var technical0 "Raw score technical. 'Real' zeroes kept"
lab var technical "Raw score technical. Zeroes dropped"


*** Impute values for missing sub-indices
* Raw subscores scores
bysort pg enlistyr: egen mlog=mean(logic)
bysort pg enlistyr: egen mver=mean(verbal)
bysort pg enlistyr: egen mspa=mean(spatial)
bysort pg enlistyr: egen mtec=mean(technical)

replace logic=mlog if logic==. & pg~=.
replace verbal=mver if verbal==. & pg~=.
replace spatial=mspa if spatial==. & pg~=.
replace technical=mtec if technical==. & pg~=.

drop mlog mver mspa mtec

* Standardized subscores
bysort pg enlistyr: egen mslog=mean(slogic)
bysort pg enlistyr: egen msver=mean(sverbal)
bysort pg enlistyr: egen msspa=mean(sspatial)
bysort pg enlistyr: egen mstec=mean(stechnical)

replace slogic=mslog if slogic==. & pg~=.
replace sverbal=msver if sverbal==. & pg~=.
replace sspatial=msspa if sspatial==. & pg~=.
replace stechnical=mstec if stechnical==. & pg~=.

drop mslog msver msspa mstec

* FINAL PREPARATIONS OF COG-SKILL MEASURES

gen scog=slogic+sverbal+sspatial+stechnical 
lab var scog "Cognitive 4-36"

gen log=logic/40
gen verb=verbal/40
gen spat=spatial/25 if enlistyr<1980
replace spat=spatial/40 if enlistyr>=1980
gen tech=technical/52 if enlistyr<1980
replace tech=technical/40 if enlistyr>=1980
gen sumcog = log + verb + spat + tech

lab var sumcog "Sum of normalized subtests (0-4)" 

* NON-COGNITIVE

gen n_s=substr(sipe,1,1)
gen n_i=substr(sipe,2,1)
gen n_p=substr(sipe,3,1)
gen n_e=substr(sipe,4,1)

destring n_s n_i n_p n_e, replace

replace n_s=. if n_s>5
replace n_i=. if n_i>5
replace n_p=. if n_p>5
replace n_e=. if n_e>5

replace n_s=. if n_s==0
replace n_i=. if n_i==0
replace n_p=. if n_p==0
replace n_e=. if n_e==0

* Impute values for missing sub-indices
bysort pf enlistyr: egen mn_s=mean(n_s)
bysort pf enlistyr: egen mn_i=mean(n_i)
bysort pf enlistyr: egen mn_p=mean(n_p)
bysort pf enlistyr: egen mn_e=mean(n_e)


replace n_s=mn_s if n_s==. & pf~=.
replace n_i=mn_i if n_i==. & pf~=.
replace n_p=mn_p if n_p==. & pf~=.
replace n_e=mn_e if n_e==. & pf~=.

drop mn_s mn_i mn_p mn_e

* Normalized measures 0-1
gen n_s1=n_s/5
gen n_i1=n_i/5
gen n_p1=n_p/5
gen n_e1=n_e/5

lab var n_s "Noncog S (1-5)
lab var n_i "Noncog I (1-5)
lab var n_p "Noncog P (1-5)
lab var n_e "Noncog E (1-5)

lab var n_s1 "Noncog S (normalized 0-1)
lab var n_i1 "Noncog I (normalized 0-1)
lab var n_p1 "Noncog P (normalized 0-1)
lab var n_e1 "Noncog E (normalized 0-1)

gen snoncog=n_s+n_i+n_p+n_e
lab var snoncog "Noncog 4-20"

gen sumnoncog=n_s1+n_i1+n_p1+n_e1
lab var sumnoncog "Sum of normalized subtests (0-4)"

sort lopnr enlistyr
save "/home/workgroups/firmiq/data/temp/tempiq6983.dta", replace

*******************************
***** PLIKTVERKET 83-97 *******
*******************************

**** LOAD DATA
use "/home/workgroups/firmiq/data/plikt/pliktverket_83_97.dta", clear

**** Fix variables
gen long lopnr = perslopnr

** Basic human capital measures

destring pg, replace
destring pf, replace

* Comment: pf = plikttjänstförmåga (noncognitive), pg = provgrupp (cognitive)
lab var pf "plikttjänstförmåga (noncognitive, 1-9)"
lab var pg "provgrupp (cognitive, 1-9)"

* Year of enlistment

gen yrslask = inst/10000
gen enlistyr = floor(yrslask)
replace enlistyr =. if enlistyr<=82|enlistyr>=98
replace enlistyr = enlistyr + 1900
drop yrslask

** Detailed human capital measures for cognitive ability

tostring stpi, replace

gen stp1=substr(stpi,1,1)
gen stp2=substr(stpi,2,1)
gen stp3=substr(stpi,3,1)
gen stp4=substr(stpi,4,1)

destring rpgi stpi stp1 stp2 stp3 stp4, replace
replace stp1=. if stp1==0
replace stp2=. if stp2==0
replace stp3=. if stp3==0
replace stp4=. if stp4==0

** New test post 1995
drop if enlistyr>1994

* Rename

rename stp1 slogic
rename stp2 sverbal
rename stp3 sspatial
rename stp4 stechnical

* LOGIC

generate logic0=rpgi/1000000
replace logic0=floor(logic0) 
replace logic0=. if logic0==0 & (pg==0 | slogic==0 | slogic>=2 | sverbal>=3 | sspatial>=3 | stechnical>=3) 
replace logic0=. if logic0>=41 

gen logic=logic0 
replace logic=. if logic0==0

replace slogic=. if slogic==0

lab var logic0 "Raw score logic. 'Real' zeroes kept"
lab var logic "Raw score logic. Zeroes dropped"
lab var slogic "Standard points logic (1-9)" 

* VERBAL

generate slask1=logic*1000000
generate slask2=rpgi-slask1
generate verbal0=floor(slask2/10000)
replace verbal0=. if verbal0==0 & (pg==0 | sverbal==0 | sverbal>=2 | stechnical>=3 | sspatial>=3 | slogic>=3)
replace verbal0=. if verbal0>=41

gen verbal=verbal0
replace verbal=. if verbal0==0 

replace sverbal=. if sverbal==0

lab var verbal0 "Raw score verbal. 'Real' zeroes kept"
lab var verbal "Raw score verbal. Zeroes dropped"
lab var sverbal "Standard points verbal (1-9)" 

* SPATIAL

generate slask3=verbal0*10000
generate slask4=rpgi-slask1-slask3
generate spatial0=floor(slask4/100)
replace spatial0=. if spatial0==0 & (pg==0 | sspatial==0 | sspatial>=2 | sverbal>=3 | stechnical>=3 | slogic>=3)
replace spatial0=. if spatial0>=41

gen spatial=spatial0
replace spatial=. if spatial0==0

replace sspatial=. if sspatial==0

lab var spatial0 "Raw score spatial. 'Real' zeroes kept"
lab var spatial "Raw score spatial. Zeroes dropped"
lab var sspatial "Standard points spatial (1-9)" 

* TECHNICAL

generate slask5=spatial0*100
generate slask6=rpgi-slask1-slask3-slask5
generate technical0=floor(slask6)
replace technical0=. if technical0==0 & (pg==0 | stechnical==0 | stechnical>=2 | sverbal>=3 | sspatial>=3 | slogic>=3) 
replace technical0=. if technical0>=41

gen technical=technical0
replace technical=. if technical0==0

replace stechnical=. if stechnical==0

lab var technical0 "Raw score technical. 'Real' zeroes kept"
lab var technical "Raw score technical. Zeroes dropped"
lab var stechnical "Standard points technical (1-9)" 


drop slask1 slask2 slask3 slask4 slask5 slask6
drop if enlistyr>1994
replace pg = . if pg == 0
replace pf = . if pf == 0


*** Impute values for missing sub-indices
* Raw subscores scores
bysort pg enlistyr: egen mlog=mean(logic)
bysort pg enlistyr: egen mver=mean(verbal)
bysort pg enlistyr: egen mspa=mean(spatial)
bysort pg enlistyr: egen mtec=mean(technical)

replace logic=mlog if logic==. & pg~=.
replace verbal=mver if verbal==. & pg~=.
replace spatial=mspa if spatial==. & pg~=.
replace technical=mtec if technical==. & pg~=.

drop mlog mver mspa mtec

* Standardized subscores
bysort pg enlistyr: egen mslog=mean(slogic)
bysort pg enlistyr: egen msver=mean(sverbal)
bysort pg enlistyr: egen msspa=mean(sspatial)
bysort pg enlistyr: egen mstec=mean(stechnical)

replace slogic=mslog if slogic==. & pg~=.
replace sverbal=msver if sverbal==. & pg~=.
replace sspatial=msspa if sspatial==. & pg~=.
replace stechnical=mstec if stechnical==. & pg~=.

drop mslog msver msspa mstec

* FINAL PREPARATIONS OF COG-SKILL MEASURES

gen scog=slogic+sverbal+sspatial+stechnical 
lab var scog "Cognitive 4-36"

gen log=logic/40
gen verb=verbal/40
gen spat=spatial/40
gen tech=technical/40 
gen sumcog = log + verb + spat + tech

lab var sumcog "Sum of normalized subtests (0-4)" 

* NON-COGNITIVE

rename sipes n_s
rename sipei n_i
rename sipep n_p
rename sipee n_e

replace n_s=. if n_s>5 | n_s<1
replace n_i=. if n_i>5 | n_i<1
replace n_p=. if n_p>5 | n_p<1
replace n_e=. if n_e>5 | n_e<1

lab var n_s "Noncog S (1-5)
lab var n_i "Noncog I (1-5)
lab var n_p "Noncog P (1-5)
lab var n_e "Noncog E (1-5)

bysort pf enlistyr: egen mn_s=mean(n_s)
bysort pf enlistyr: egen mn_i=mean(n_i)
bysort pf enlistyr: egen mn_p=mean(n_p)
bysort pf enlistyr: egen mn_e=mean(n_e)

replace n_s=mn_s if n_s==. & pf~=.
replace n_i=mn_i if n_i==. & pf~=.
replace n_p=mn_p if n_p==. & pf~=.
replace n_e=mn_e if n_e==. & pf~=.

gen n_s1=n_s/5
gen n_i1=n_i/5
gen n_p1=n_p/5
gen n_e1=n_e/5

lab var n_s1 "Noncog S (normalized 0-1)
lab var n_i1 "Noncog I (normalized 0-1)
lab var n_p1 "Noncog P (normalized 0-1)
lab var n_e1 "Noncog E (normalized 0-1)

gen snoncog=n_s+n_i+n_p+n_e
lab var snoncog "Noncog 4-20"

gen sumnoncog=n_s1+n_i1+n_p1+n_e1
lab var sumnoncog "Sum of normalized subtests (0-4)"

drop mn_s mn_i mn_p mn_e

*** Cleanups

tostring perslopnr, replace
drop rpgi stpi rpgt stpt utpf befl safh* skat

sort lopnr enlistyr
save "/home/workgroups/firmiq/data/temp/tempiq8394.dta", replace

***************************************
*** MERGE AND FINAL PREPARATIONS ******
***************************************

use "/home/workgroups/firmiq/data/temp/tempiq6983.dta", clear
append using "/home/workgroups/firmiq/data/temp/tempiq8394.dta"

keep lopnr perslopnr enlistyr scog sumcog log logic slogic verb verbal sverbal spat spatial sspatial tech technical stechnical pg pf height weight wmax pulse mfak handgrip knee arm n_s n_i n_p n_e sumnoncog snoncog 

lab var log "Normalized logic (0-1)"
lab var verb "Normalized verbal (0-1)"
lab var spat "Normalized spatial (0-1)"
lab var tech "Normalized technical (0-1)"

* Drop duplicates
sort enlistyr lopnr
duplicates drop lopnr, force

gen testregime=1 if enlistyr<1980
replace testregime=2 if enlistyr>=1980

xtile pciq1=sumcog if testregime==1, nq(100)
xtile pciq2=sumcog if testregime==2, nq(100)
gen pciq=pciq1
replace pciq=pciq2 if pciq==.
drop pciq1 pciq2

gen iq50= (pciq>50) if !missing(pciq)
gen iq40= (pciq>60) if !missing(pciq)
gen iq30= (pciq>70) if !missing(pciq)
gen iq20= (pciq>80) if !missing(pciq)
gen iq10= (pciq>90) if !missing(pciq)
gen iq5= (pciq>95) if !missing(pciq)
gen iq2= (pciq>98) if !missing(pciq)
gen iq1= (pciq>99) if !missing(pciq)

label var testregime "Period 1: 1969-1979. Period 2: 1980-1994"
label var enlistyr "Year of enlistment"
label var pciq "Percentile ranked iq, by test regime"
label var iq50 "In 50th iq percentile"
label var iq40 "In 60th iq percentile"
label var iq30 "In 70th iq percentile"
label var iq20 "In 80th iq percentile"
label var iq10 "In 90th iq percentile"
label var iq5 "In 95th iq percentile"
label var iq2 "In 98th iq percentile"
label var iq1 "In 99th iq percentile"

rename pg cog
rename pf noncog

order lopnr perslopnr enlistyr cog noncog iq1 iq2 iq5 iq10 iq20 iq30 iq40 iq50 scog sumcog log logic slogic verb verbal sverbal spat spatial sspatial tech technical stechnical height weight wmax pulse mfak handgrip knee arm

compress
sort lopnr

save "/home/workgroups/firmiq/data/modified/skilldetail6994.dta", replace
erase "/home/workgroups/firmiq/data/temp/tempiq6983.dta"
erase "/home/workgroups/firmiq/data/temp/tempiq8394.dta"

***************************************
******* Collapsed measures ************
***************************************

use "/home/workgroups/firmiq/data/modified/skilldetail6994.dta", clear

collapse (mean) cog noncog iq1 iq2 iq5 iq10 scog sumcog log verb spat tech snoncog sumnoncog n_s n_i n_p n_e (sd) scogsd=scog sumcogsd=sumcog logsd=log verbsd=verb spatsd=spat techsd=tech snoncogsd=snoncog sumnoncogsd=sumnoncog n_ssd=n_s n_isd=n_i n_psd=n_p n_esd=n_e (count) obs_cog=cog obs_noncog=noncog obs_sumcog=sumcog obs_sumnoncog=sumnoncog, by(enlistyr) 

lab var iq1 "Share in top1 percentile"
lab var iq2 "Share in top2 percentile"
lab var iq5 "Share in top5 percentile"
lab var iq10 "Share in top10 percentile"

lab var obs_cog "Number of cog observations (1-9)"
lab var obs_noncog "Number of noncog observations (1-9)"
lab var obs_sumcog "Number of cog observations (0-4)"
lab var obs_sumnoncog "Number of noncog observations (0-4)"

lab var sumcog "Sum of normalized subtests (0-4)"
lab var sumcogsd "Sd of summarized subtests (0-4)"

lab var sumnoncog "Sum of normalized subtests (0-4)"
lab var sumnoncogsd "Sd of summarized subtests (0-4)"

lab var log "Normalized logic (0-1)"
lab var verb "Normalized verbal (0-1)"
lab var spat "Normalized spatial (0-1)"
lab var tech "Normalized technical (0-1)"

lab var logsd "Sd of normalized logic (0-1)"
lab var verbsd "Sd of normalized verbal (0-1)"
lab var spatsd "Sd of normalized spatial (0-1)"
lab var techsd "Sd of normalized technical (0-1)"

lab var n_ssd "Sd of normalized S (0-1)"
lab var n_isd "Sd of normalized I (0-1)"
lab var n_psd "Sd of normalized P (0-1)"
lab var n_esd "Sd of normalized E (0-1)"

*******************************************************************
*** Adjust for change in cognitive scales between 1979 and 1980 ***
*******************************************************************

gen period=0
replace period=1 if enlistyr==1980
gen period2=0
replace period2=1 if enlistyr>1980

reg sumcogsd period period2
gen sumcogsd_adj=sumcogsd
replace sumcogsd_adj=sumcogsd-_b[period] if enlistyr>=1980
lab var sumcogsd_adj "Sd of summarized subtests (0-4), 1980 break adjusted"

reg sumcog period period2
gen sumcog_adj=sumcog
replace sumcog_adj=sumcog-_b[period] if enlistyr>=1980
lab var sumcog_adj "Mean of normalized subtests (0-4), 1980 break adjusted"

drop period period2
sort enlistyr
save "/home/workgroups/firmiq/data/modified/skilldetail6994_collapsed.dta", replace

end

