﻿
******************************************************************
*** Do-file creating results for 			                ******
*** Håkanson, Lindqvist and Vlachos, "Firms and Skills"	    ******
*** Journal of Human Resources 	         		            ******
****************************************************************** 

clear
set mem 20g
cd /home/workgroups/firmiq/data/
set more off

**********************************
* Figure 1. Sorting over time  ***
**********************************

use modified/vardecomp_aggregate, clear
drop if year==1985
drop if year==2009
keep year corr_bs_c_ftg_10 corr_ws_c_ftg_10 corr_bs_n_ftg_10 corr_ws_n_ftg_10 corr_bs_c_ast_10 corr_ws_c_ast_10 corr_bs_n_ast_10 corr_ws_n_ast_10

lab var corr_bs_c_ftg_10 "Cognitive"
lab var corr_ws_c_ftg_10 "Cognitive"
lab var corr_bs_n_ftg_10 "Non-cognitive"
lab var corr_ws_n_ftg_10 "Non-cognitive"
lab var year "Year"

* Firm
graph drop _all
twoway (line corr_bs_c_ftg_10 year, yaxis(1) ylabel(0(0.05)0.25,axis(1)) ymtick(0(0.05)0.25, axis(1))) (line corr_bs_n_ftg_10 year, yaxis(1) ylabel(0(0.05)0.25,axis(1)) ymtick(0(0.05)0.25, axis(1))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("A: Between firm")  name(fig1a)
graph save fig1a,replace
twoway (line corr_ws_c_ftg_10 year, yaxis(1) ylabel(0.65(0.05)0.9, axis(1)) ymtick(0.65(0.05)0.9, axis(1))) (line corr_ws_n_ftg_10 year, yaxis(1) ylabel(0.65(0.05)0.9, axis(1)) ymtick(0.65(0.05)0.9, axis(1))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(fig1b) 
graph save fig1b,replace
grc1leg fig1a fig1b, graphr(c(white)) legendfrom(fig1a)
graph export results/fig1.eps,replace
graph export results/fig1.png,replace
graph export results/fig1.tif,replace
graph export results/fig1.pdf,replace
graph save results/fig1.gph,replace
* Note: Between and within firm skill variances. The sample includes 30-35 year-old men employed at firms with at least 10 employees. Variances corrected for firm-level sample size.

**************************************
*** Figure 2. Sorting by education ***
**************************************

use modified/vardecomp_aggregate, clear
drop if year==1985
drop if year==2009
keep year corr_bs_e_ftg_10 corr_ws_e_ftg_10 corr_bs_ze_ftg_10 corr_ws_ze_ftg_10  corr_bs_e_ast_10 corr_ws_e_ast_10 corr_bs_ze_ast_10 corr_ws_ze_ast_10

lab var corr_bs_e_ftg_10 "Education (years)"
lab var corr_ws_e_ftg_10 "Education (years)"
lab var corr_bs_ze_ftg_10 "Education (standardized)"
lab var corr_ws_ze_ftg_10 "Education (standardized)"
lab var year "Year"

* Firm
graph drop _all
twoway (line corr_bs_e_ftg_10 year, yaxis(1) ylabel(1(0.5)3.5,axis(1)) ymtick(1(0.5)3.5, axis(1)))  (line corr_bs_ze_ftg_10 year, yaxis(2) ylabel(0.15(0.1)0.65,axis(2)) ymtick(0.15(0.1)0.65, axis(2))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subtitle("A: Between firm") name(fig2a)
*twoway (line corr_bs_e_ftg_10 year, yaxis(1) ylabel(0(0.5)4,axis(1)) ymtick(0(0.5)4, axis(1)))  (line corr_bs_ze_ftg_10 year, yaxis(2) ylabel(0(0.05)0.4,axis(2)) ymtick(0(0.05)0.4, axis(2))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subtitle("A: Between firm") name(fig2a)
graph save fig2a,replace
twoway  (line corr_ws_e_ftg_10 year, yaxis(1) ylabel(1(0.5)3.5, axis(1)) ymtick(1(0.5)3.5, axis(1))) (line corr_ws_ze_ftg_10 year, yaxis(2) ylabel(0.15(0.1)0.65, axis(2)) ymtick(0.15(0.1)0.65, axis(2))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(fig2b)
*twoway  (line corr_ws_e_ftg_10 year, yaxis(1) ylabel(0(0.5)4, axis(1)) ymtick(0(0.5)4, axis(1))) (line corr_ws_ze_ftg_10 year, yaxis(2) ylabel(0.45(0.05)0.85, axis(2)) ymtick(0.45(0.05)0.85, axis(2))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(fig2b)
graph save fig2b,replace
grc1leg fig2a fig2b, graphr(c(white)) legendfrom(fig2a)
graph export results/fig2.eps,replace
graph export results/fig2.png,replace
graph export results/fig2.tif,replace
graph export results/fig2.pdf,replace
graph save results/fig2.gph,replace
* Note: Between and within-firm variances in educational attainment expressen in years of schooling (Panel A) and years of schooling standardized by cohort (Panel B). The sample includes 30-35 year-old men employed at firms with at least 10 employees. Variances corrected for firm-level sample size.

*****************************************
*** Figure 3: Sorting on AKM effects ****
*****************************************		

use modified/akm_vardecomp_3035, clear
keep year corr_bs_p corr_ws_p corr_bs_c corr_ws_c corr_bs_n corr_ws_n
rename corr_bs_p corr_bs_p_3035 
rename corr_ws_p corr_ws_p_3035
rename corr_bs_c corr_bs_c_3035
rename corr_ws_c corr_ws_c_3035
rename corr_bs_n corr_bs_n_3035
rename corr_ws_n corr_ws_n_3035

merge 1:1 year using modified/akm_vardecomp_2460
foreach i of numlist 1985 1986 1987 1988 2006 2007 2008 2009 2010 {
insobs 1
	replace year=`i' if year==.
}

lab var corr_bs_p_3035 "Men 30-35"
lab var corr_ws_p_3035 "Men 30-35"
lab var corr_bs_p "Men 24-60"
lab var corr_ws_p "Men 24-60"
lab var year "Year"

*** Fig3 
graph drop _all
twoway (line corr_bs_p_3035 year, xscale(range(1985(5)2010)) xmtick(1985(5)2010) yaxis(1) ylabel(0.15(0.05)0.45, axis(1)) ymtick(0.15(0.05)0.45, axis(1))) (line corr_bs_p year, xscale(range(1985(5)2010)) xmtick(1985(5)2010)), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("A: Between firm") name(fig3a) 
twoway (line corr_ws_p_3035 year, xscale(range(1985(5)2010)) xmtick(1985(5)2010) yaxis(1) ylabel(0.55(0.05)0.85, axis(1)) ymtick(0.55(0.05)0.85, axis(1))) (line corr_ws_p year, xscale(range(1985(5)2010)) xmtick(1985(5)2010)), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(fig3b)
grc1leg fig3a fig3b, graphr(c(white)) legendfrom(fig3a)
graph export results/fig3.eps,replace
graph export results/fig3.png,replace
graph export results/fig3.tif,replace
graph export results/fig3.pdf,replace
graph save results/fig3.gph,replace


********************************************************
*** Figure 4: Decomposing the between-firm variance  ***
********************************************************

use modified/vardecomp_bfwi_bi, clear
drop if year==1985
drop if year==2009
keep year corr_bi_c_ftg_10 corr_bfwi_c_ftg_10 corr_bi_c_ast_10 corr_bfwi_c_ast_10 corr_bi_n_ftg_10 corr_bfwi_n_ftg_10 corr_bi_n_ast_10 corr_bfwi_n_ast_10

lab var corr_bi_c_ftg_10 "Cognitive"
lab var corr_bfwi_c_ftg_10 "Cognitive"
lab var corr_bi_c_ast_10 "Cognitive"
lab var corr_bfwi_c_ast_10 "Cognitive"

lab var corr_bi_n_ftg_10 "Non-cognitive"
lab var corr_bfwi_n_ftg_10 "Non-cognitive"
lab var corr_bi_n_ast_10 "Non-cognitive"
lab var corr_bfwi_n_ast_10 "Non-cognitive"
lab var year "Year"

* Firm
graph drop _all
line corr_bi_c_ftg_10 corr_bi_n_ftg_10 year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(2)) ymtick(0.0(0.05)0.15) ylabel(0.0(0.05)0.15) yscale(range(0 0.15)) subt("A: Between industry") name(fig4a)
line corr_bfwi_c_ftg_10 corr_bfwi_n_ftg_10 year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(2)) ymtick(0.0(0.05)0.15) ylabel(0.0(0.05)0.15) yscale(range(0 0.15)) subt("B: Between firm, within industry") name(fig4b)
grc1leg fig4a fig4b, graphr(c(white)) legendfrom(fig4a)
graph export results/fig4.eps,replace
graph export results/fig4.png,replace
graph export results/fig4.tif,replace
graph export results/fig4.pdf,replace
graph save results/fig4.gph,replace

***************************************************************************************************
*** Figure 5: Counterfactual between-firm variance (dropping sector 72; dropping sectors 32-72) ***
***************************************************************************************************

use modified/vardecomp_aggregate, clear
merge 1:1 year using modified/vardecomp_aggregate_robust
drop _merge
keep year corr_btot_c_ftg_10 corr_btot_n_ftg_10 corr_btot_c_ast_10 corr_btot_n_ast_10  corr_btot_c_D_ftg_10 corr_btot_n_D_ftg_10 corr_btot_c_D_ast_10 corr_btot_n_D_ast_10 corr_btot_c_E_ftg_10 corr_btot_n_E_ftg_10 corr_btot_c_E_ast_10 corr_btot_n_E_ast_10 
drop if year==1985
drop if year==2009

lab var corr_btot_c_ftg_10 "All"
lab var corr_btot_n_ftg_10 "All"
lab var corr_btot_c_ast_10 "All"
lab var corr_btot_n_ast_10 "All"

lab var corr_btot_c_D_ftg_10 "Exc. computer services (72)"
lab var corr_btot_n_D_ftg_10 "Exc. computer services (72)"
lab var corr_btot_c_D_ast_10 "Exc. computer services (72)"
lab var corr_btot_n_D_ast_10 "Exc. computer services (72)"

lab var corr_btot_c_E_ftg_10 "Exc. computer services & telecom equip. (72, 32)"
lab var corr_btot_n_E_ftg_10 "Exc. computer services & telecom equip. (72, 32)"
lab var corr_btot_c_E_ast_10 "Exc. computer services & telecom equip. (72, 32)"
lab var corr_btot_n_E_ast_10 "Exc. computer services & telecom equip. (72, 32)"
lab var year "Year"

graph drop _all
line corr_btot_c_ftg_10 corr_btot_c_D_ftg_10 corr_btot_c_E_ftg_10 year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(3)) ymtick(0.16(0.02)0.24) ylabel(0.16(0.02)0.24) yscale(range(0.16 0.24)) subt("A: Cognitive skill") name(fig5a)
line corr_btot_n_ftg_10 corr_btot_n_D_ftg_10 corr_btot_n_E_ftg_10 year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(3)) ymtick(0.08(0.01)0.12) ylabel(0.08(0.01)0.12) yscale(range(0.08 0.12)) subt("B: Non-cognitive skill") name(fig5b)
grc1leg fig5a fig5b, graphr(c(white)) legendfrom(fig5a)
graph export results/fig5.eps,replace
graph export results/fig5.png,replace
graph export results/fig5.tif,replace
graph export results/fig5.pdf,replace
graph save results/fig5.gph,replace
* Note: Between-firm skill variances including and excluding Computer services (72) and Computer services (72) and Telecom equipments (32). The sample consists of 30-35 year-old men employed at firms with at least 10 employees. Variances corrected for firm-level sample size.

***************************************************
*** Figure 6. Decomposing the variance of wages ***
***************************************************

use modified/wagevardecomposition_ftg_10.dta, clear
lab var year "Year"

graph drop _all
twoway (line wvar wvarw_adj wvarb_adj year), ylabel(0(0.02)0.08) yscale(range(0,0.08)) scheme(s2mono) graphr(c(white)) legend(cols(1)) name(fig6)
graph save results/fig6.gph,replace
graph export results/fig6.eps,replace
graph export results/fig6.png,replace
graph export results/fig6.tif,replace
graph export results/fig6.pdf,replace


************************************************************************************************
*********** Figures 7 and 8: Decomposing between and within firm variance of wages *************
************************************************************************************************

use modified/betas_and_variances_rev2018_ftg_10.dta, clear
	lab var wvarbhat "Total variance"
	gen wvarb_exp=svarbhat*beta_sjhat^2
	lab var wvarb_exp "Predicted variance"
	gen wvarb_exp_1986gradients=svarbhat*beta_sjhat_1986^2
	lab var wvarb_exp_1986gradient "Only sorting"
	gen wvarb_exp_1986sorting=svarbhat_1986*beta_sjhat^2
	lab var wvarb_exp_1986sorting "Only gradient"
	lab var wvarwhat "Total variance"
	gen wvarw_exp=svarwhat*beta_sw^2
	lab var wvarw_exp "Predicted variance"
	gen wvarw_exp_1986gradients=svarwhat*beta_sw_1986^2
	lab var wvarw_exp_1986gradient "Only sorting"
	gen wvarw_exp_1986sorting=svarwhat_1986*beta_sw^2
	lab var wvarw_exp_1986sorting "Only gradient"
save modified/between_within_actual_counterfactual.dta, replace

**** Fig7: Decomposing between firm wage variance

use modified/between_within_actual_counterfactual.dta, clear 
lab var year "Year"
graph drop _all
twoway (line wvarbhat wvarb_exp wvarb_exp_1986gradients wvarb_exp_1986sorting year), scheme(s2mono) graphr(c(white)) legend(cols(2)) ymtick(0(0.01)0.04) ylabel(0(0.01)0.04) yscale(range(0 0.04)) name(fig7)
graph save results/fig7.gph,replace
graph export results/fig7.eps,replace
graph export results/fig7.png,replace
graph export results/fig7.pdf,replace
graph export results/fig7.tif,replace

**** Make fig8: Decomposing within firm wage variance

use modified/between_within_actual_counterfactual.dta, clear 
lab var year "Year"
graph drop _all
twoway (line wvarwhat wvarw_exp wvarw_exp_1986gradient wvarw_exp_1986sorting year), scheme(s2mono) graphr(c(white)) legend(cols(2)) ymtick(0(0.01)0.04) ylabel(0(0.01)0.04) yscale(range(0 0.04)) name(fig8)
graph save results/fig8.gph,replace
graph export results/fig8.eps,replace
graph export results/fig8.png,replace
graph export results/fig8.tif,replace
graph export results/fig8.pdf,replace

***************************
*** Table1: Robustness  ***
***************************

* Measurement error correction
forvalues j=1986(11)2008{
forvalues i=1(1)1000{
use lopnr fos fos_detail edyr c n sex sample_3035_10_ftg ftgsni* ftgstorl_ftg age ftgnr year using modified/sample`j', clear

keep if sample_3035_10_ftg==1

g count=1
*Observed samples and sizes
rename ftgstorl_ftg Nj
bysort ftgnr: egen N2j=total(count) 
egen N2=total(count) 

*create random assignment of cognitive and non cognitive skill 
g mei_c=rnormal(0,0.364005)
*g mei2_c=mei_c^2

g mei_n=rnormal(0,0.544977)
*g mei2_n=mei_n^2

*Measurement error means
	*firm
bysort ftgnr: egen me_cj=mean(mei_c) 
bysort ftgnr: egen me_nj=mean(mei_n) 
 
	*sample
egen me_cbar=mean(mei_c)
egen me_nbar=mean(mei_n)

*components for bf
g mec_ij=(mei_c-me_cj)^2
g men_ij=(mei_n-me_nj)^2

*comp for total me variance

g metot_c=(mei_c-me_cbar)^2
g metot_n=(mei_n-me_nbar)^2
egen me_c=sum(metot_c)
replace me_c=me_c*(1/(N2-1))
egen me_n=sum(metot_n)
replace me_n=me_n*(1/(N2-1))

*2.Collapse to firm level
collapse (sum) mec_ij men_ij (mean) me_cj me_cbar me_nj me_nbar me_c me_n Nj N2j N2 , by (year ftgnr ftgsni2)

*sample correction firm level
g thetaj=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*measurement error
g mej2_c=N2j*((me_cj-me_cbar)^2-thetaj*mec_ij)
g mej2_n=N2j*((me_nj-me_nbar)^2-thetaj*men_ij)

*3. Overall collapse
collapse (sum)  N=Nj mej2_c mej2_n (mean) N2 me_c me_n, by(year)
*measurement error
g me_bf_c=mej2_c/N2
g me_wf_c=me_c-me_bf_c

g me_bf_n=mej2_n/N2
g me_wf_n=me_n-me_bf_n

gen sim=`i'
save decomp_me_robust_`j'_`i',replace
}
}

forvalues j=1986(11)2008{
use  decomp_me_robust_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_me_robust_`j'_`i'
	}
save decomp_me_robust_`j',replace

merge m:1 year using modified/vardecomp_aggregate, keepus(corr_wtot_c_ftg_10 corr_btot_c_ftg_10 corr_wtot_n_ftg_10 corr_btot_n_ftg_10 year)
drop if _merge==2
}
clear
forvalues j=1986(11)2008{
forvalues i=1(1)1000{
erase decomp_me_robust_`j'_`i'.dta	
}
}


forvalues j=1986(11)2008{
use decomp_me_robust_`j'
merge m:1 year using modified/vardecomp_aggregate, keepus(corr_bs_c_ftg_10 corr_ws_c_ftg_10 corr_bs_n_ftg_10 corr_ws_n_ftg_10 year)
drop if _merge==2
drop _merge

g ws_c_adj=(corr_ws_c_ftg_10-me_wf_c)/(1-0.1325/(corr_bs_c_ftg_10+corr_ws_c_ftg_10))
g bs_c_adj=(corr_bs_c_ftg_10-me_bf_c)/(1-0.1325/(corr_bs_c_ftg_10+corr_ws_c_ftg_10))

g ws_n_adj=(corr_ws_n_ftg_10-me_wf_n)/(1-0.297/(corr_bs_n_ftg_10+corr_ws_n_ftg_10))
g bs_n_adj=(corr_bs_n_ftg_10-me_bf_n)/(1-0.297/(corr_bs_n_ftg_10+corr_ws_n_ftg_10))

collapse (p1) low_ws_c_adj=ws_c_adj low_bs_c_adj=bs_c_adj  low_ws_n_adj=ws_n_adj low_bs_n_adj=bs_n_adj (p50) ws_c_adj bs_c_adj  ws_n_adj bs_n_adj (p99) high_ws_c_adj=ws_c_adj high_bs_c_adj=bs_c_adj  high_ws_n_adj=ws_n_adj high_bs_n_adj=bs_n_adj (mean) corr_bs_c_ftg_10 corr_ws_c_ftg_10 corr_bs_n_ftg_10 corr_ws_n_ftg_10
g year=`j'
save me_robust`j',replace
}

clear
use me_robust1986
forvalues j=1997(11)2008{
append using me_robust`j'
}
sort year
save modified/measurement_error_robust,replace

* Data for Table: Baseline and ME-corrected
use modified/measurement_error_robust,clear
lab var corr_ws_c_ftg_10 "Within firm"
lab var ws_c_adj "Within firm, ME-adjusted"
lab var corr_bs_c_ftg_10 "Between firm"
lab var bs_c_adj "Between firm, ME-adjusted"

lab var corr_ws_n_ftg_10 "Within firm"
lab var ws_n_adj "Within firm, ME-adjusted"
lab var corr_bs_n_ftg_10 "Between firm"
lab var bs_n_adj "Between firm, ME-adjusted"

sort year
save results/robust_table_c12, replace

* Alternative skill distributions
use modified/uniform_vardecomp,clear
keep year corr_ws_c corr_ws_n0 corr_bs_c corr_bs_n
keep if year==1986 | year==1997| year==2008

lab var corr_ws_c "Within firm (uniform)"
lab var corr_ws_n "Within firm (uniform)"
lab var corr_bs_c "Between firm (uniform)"
lab var corr_bs_n "Between firm (uniform)"

sort year
save results/robust_table_c345, replace

* Older men 
use modified/vardecomp_aggregate_robust, clear
keep year corr_ws_c_K_ftg_10 corr_ws_n_K_ftg_10 corr_bs_c_K_ftg_10 corr_bs_n_K_ftg_10
keep if year==1997 | year==2008
lab var corr_ws_c_K_ftg_10 "Within firm (men 30-45)"
lab var corr_ws_n_K_ftg_10 "Within firm (men 30-45)"
lab var corr_bs_c_K_ftg_10 "Between firm (men 30-45)"
lab var corr_bs_n_K_ftg_10 "Between firm (men 30-45)"

sort year
save results/robust_table_c6, replace

* Men and women
use modified/vardecomp_aggregate_robust, clear

keep year corr_ws_c_L_ftg_10 corr_ws_n_L_ftg_10 corr_bs_c_L_ftg_10 corr_bs_n_L_ftg_10
keep if year==1986 | year==1997 | year==2008
lab var corr_ws_c_L_ftg_10 "Within firm (men and women)"
lab var corr_ws_n_L_ftg_10 "Within firm (men and women)"
lab var corr_bs_c_L_ftg_10 "Between firm (men and women)"
lab var corr_bs_n_L_ftg_10 "Between firm (men and women)"

sort year
save results/robust_table_c7, replace

* Including public firms
use modified/vardecomp_aggregate_robust, clear

keep year corr_ws_c_M_ftg_10 corr_ws_n_M_ftg_10 corr_bs_c_M_ftg_10 corr_bs_n_M_ftg_10
keep if year==1986 | year==1997 | year==2008
lab var corr_ws_c_M_ftg_10 "Within firm (public)"
lab var corr_ws_n_M_ftg_10 "Within firm (public)"
lab var corr_bs_c_M_ftg_10 "Between firm (public)"
lab var corr_bs_n_M_ftg_10 "Between firm (public)"

sort year
save results/robust_table_c8, replace

* Size cutoffs
use modified/vardecomp_aggregate, clear

keep year corr_ws_c_ftg_10 corr_ws_n_ftg_10 corr_ws_c_ftg_50 corr_ws_n_ftg_50 corr_ws_c_ftg_100 corr_ws_n_ftg_100    corr_bs_c_ftg_10 corr_bs_n_ftg_10 corr_bs_c_ftg_50 corr_bs_n_ftg_50 corr_bs_c_ftg_100 corr_bs_n_ftg_100
keep if year==1986 | year==1997 | year==2008

lab var corr_ws_c_ftg_10 "Within firm, size >=10"
lab var corr_ws_c_ftg_50 "Within firm, size >=50"
lab var corr_ws_c_ftg_100 "Within firm, size >=100" 

lab var corr_ws_n_ftg_10 "Within firm, size >=10"
lab var corr_ws_n_ftg_50 "Within firm, size >=50"
lab var corr_ws_n_ftg_100 "Within firm, size >=100" 

lab var corr_bs_c_ftg_10 "Between firm, size >=10"
lab var corr_bs_c_ftg_50 "Between firm, size >=50"
lab var corr_bs_c_ftg_100 "Between firm, size >=100" 

lab var corr_bs_n_ftg_10 "Between firm, size >=10"
lab var corr_bs_n_ftg_50 "Between firm, size >=50"
lab var corr_bs_n_ftg_100 "Between firm, size >=100" 

sort year
save results/robust_table_c91011, replace

* NOTE: Simulations for standard errors at the end of the file


**********************************
*** Table2: skills by industry ***
**********************************

use modified/vardecomp_industry_ftg_10, clear
keep if year==1986 | year==2008
drop if ftgsni2==.

keep ftgsni2 year Nk N2k N2 corr_bs_c corr_bs_n ck nk
reshape wide Nk N2k N2 corr_bs_c corr_bs_n ck nk, i(ftgsni2) j(year)

g alfa1986=N2k1986/N21986*100
g alfa2008=N2k2008/N22008*100
g dalfa=alfa2008-alfa1986
g dbs_c=corr_bs_c2008-corr_bs_c1986
g dbs_n=corr_bs_n2008-corr_bs_n1986
sort dbs_c

g kod=ftgsni2

lab def snilabel 01 "Agriculture, hunting and related service activities" ,add
lab def snilabel 02 "Forestry, logging and related service activities" ,add
lab def snilabel 05 "Fishing, operation of fish hatcheries and fish farms" ,add
lab def snilabel 10  "Mining of coal and lignite, extraction of peat" ,add
lab def snilabel 11  "Extraction of crude petroleum and natural gas" ,add
lab def snilabel 12  "Mining of uranium and thorium ores" ,add
lab def snilabel 13  "Mining of metal ores" ,add
lab def snilabel 14  "Other mining and quarrying" ,add
lab def snilabel 15  "Manufacture of food products and beverages" ,add
lab def snilabel 16  "Manufacture of tobacco products" ,add
lab def snilabel 17  "Manufacture of textiles" ,add
lab def snilabel 18  "Manufacture of wearing apparel" ,add
lab def snilabel 19  "Tanning and dressing of leather" ,add
lab def snilabel 20  "Manufacture of wood and of products of wood and cork, except furniture" ,add
lab def snilabel 21  "Manufacture of paper and paper products" ,add
lab def snilabel 22  "Publishing, printing and reproduction of recorded media" ,add
lab def snilabel 23  "Manufacture of coke, refined petroleum products and nuclear fuel" ,add
lab def snilabel 24  "Manufacture of chemicals and chemical products" ,add
lab def snilabel 25  "Manufacture of rubber and plastics products" ,add
lab def snilabel 26  "Manufacture of other nonmetallic mineral products" ,add
lab def snilabel 27  "Manufacture of basic metals" ,add
lab def snilabel 28  "Manufacture of fabricated metal products, except machinery and equipment" ,add
lab def snilabel 29  "Manufacture of machinery and equipment n.e.c." ,add
lab def snilabel 30  "Manufacture of office, accounting and computing machinery" ,add
lab def snilabel 31  "Manufacture of electrical machinery and apparatus n.e.c." ,add
lab def snilabel 32  "Manufacture of radio, television and communication equipment and apparatus" ,add
lab def snilabel 33  "Manufacture of medical, precision and optical instruments, watches and clocks" ,add
lab def snilabel 34  "Manufacture of motor vehicles, trailers and semitrailers" ,add
lab def snilabel 35  "Manufacture of other transport equipment" ,add
lab def snilabel 36  "Manufacture of furniture, manufacturing n.e.c." ,add
lab def snilabel 37  "Recycling" ,add
lab def snilabel 40  "Electricity, gas, steam and hot water supply" ,add
lab def snilabel 41  "Collection, purification and distribution of water" ,add
lab def snilabel 45  "Construction" ,add
lab def snilabel 50  "Sale, maintenance and repair of motor vehicles and motorcycles, retail sale of automotive fuel" ,add
lab def snilabel 51  "Wholesale trade and commission trade, except of motor vehicles and motorcycles" ,add
lab def snilabel 52  "Retail trade, except of motor vehicles and motorcycles, repair of personal and household goods" ,add
lab def snilabel 55  "Hotels and restaurants" ,add
lab def snilabel 60  "Land transport, transport via pipelines" ,add
lab def snilabel 61  "Water transport" ,add
lab def snilabel 62  "Air transport" ,add
lab def snilabel 63  "Supporting and auxiliary transport activities, activities of travel agencies" ,add
lab def snilabel 64  "Post and telecommunications" ,add
lab def snilabel 65  "Financial intermediation, except insurance and pension funding" ,add
lab def snilabel 66  "Insurance and pension funding, except compulsory social security",add
lab def snilabel 67  "Activities auxiliary to financial intermediation" ,add
lab def snilabel 70  "Real estate activities" ,add
lab def snilabel 71  "Renting of machinery and equipment without operator and of personal and household goods" ,add
lab def snilabel 72  "Computer and related activities" ,add
lab def snilabel 73  "Research and development" ,add
lab def snilabel 74  "Other business activities" ,add
lab def snilabel 75  "Public administration and defence, compulsory social security" ,add
lab def snilabel 80  "Education" ,add
lab def snilabel 85  "Health and social work" ,add
lab def snilabel 90  "Sewage and refuse disposal, sanitation and similar activities" ,add
lab def snilabel 91  "Activities of membership organizations n.e.c." ,add
lab def snilabel 92  "Recreational, cultural and sporting activities" ,add
lab def snilabel 93  "Other service activities" ,add
lab def snilabel 95  "Private households with employed persons" ,add
lab def snilabel 99  "Extraterritorial organizations and bodies" ,add

lab val ftgsni2 snilabel

drop if missing(corr_bs_c1986)
drop if missing(corr_bs_c2008)

g dc= ck2008-ck1986 
g dn= nk2008-nk1986 
drop if alfa1986<1.5 & alfa2008<1.5

keep kod ftgsni2 ck1986 dc nk1986 dn alfa1986 dalfa
order kod ftgsni2 ck1986 dc nk1986 dn alfa1986 dalfa
gsort  -ck1986

outsheet using results/table2.csv,replace
mkmat  ftgsni2 ck1986 dc nk1986 dn  alfa1986 dalfa, matrix(A)  rownames(ftgsni2)
matrix colnames A = ftgsni2 ck1986 dc nk1986 dn  alfa1986 dalfa
outtable using results/table2.tex, mat(A) format (%12.2f) nobox replace
outtable using results/table2.rtf, mat(A) format (%12.2f) nobox replace


*******************************************************
**** Table3: Within firm skill variance by industry ***
*******************************************************

use modified/vardecomp_industry_ftg_10,clear
keep ftgsni2 year Nk N2k N2 corr_ws_c corr_ws_n
keep if year==1986 | year==2008

reshape wide Nk N2k N2 corr_ws_c corr_ws_n, i(ftgsni2) j(year)

g kod=ftgsni2

lab def snilabel 01 "Agriculture, hunting and related service activities" ,add
lab def snilabel 02 "Forestry, logging and related service activities" ,add
lab def snilabel 05 "Fishing, operation of fish hatcheries and fish farms" ,add
lab def snilabel 10  "Mining of coal and lignite, extraction of peat" ,add
lab def snilabel 11  "Extraction of crude petroleum and natural gas" ,add
lab def snilabel 12  "Mining of uranium and thorium ores" ,add
lab def snilabel 13  "Mining of metal ores" ,add
lab def snilabel 14  "Other mining and quarrying" ,add
lab def snilabel 15  "Manufacture of food products and beverages" ,add
lab def snilabel 16  "Manufacture of tobacco products" ,add
lab def snilabel 17  "Manufacture of textiles" ,add
lab def snilabel 18  "Manufacture of wearing apparel" ,add
lab def snilabel 19  "Tanning and dressing of leather" ,add
lab def snilabel 20  "Manufacture of wood and of products of wood and cork, except furniture" ,add
lab def snilabel 21  "Manufacture of paper and paper products" ,add
lab def snilabel 22  "Publishing, printing and reproduction of recorded media" ,add
lab def snilabel 23  "Manufacture of coke, refined petroleum products and nuclear fuel" ,add
lab def snilabel 24  "Manufacture of chemicals and chemical products" ,add
lab def snilabel 25  "Manufacture of rubber and plastics products" ,add
lab def snilabel 26  "Manufacture of other nonmetallic mineral products" ,add
lab def snilabel 27  "Manufacture of basic metals" ,add
lab def snilabel 28  "Manufacture of fabricated metal products, except machinery and equipment" ,add
lab def snilabel 29  "Manufacture of machinery and equipment n.e.c." ,add
lab def snilabel 30  "Manufacture of office, accounting and computing machinery" ,add
lab def snilabel 31  "Manufacture of electrical machinery and apparatus n.e.c." ,add
lab def snilabel 32  "Manufacture of radio, television and communication equipment and apparatus" ,add
lab def snilabel 33  "Manufacture of medical, precision and optical instruments, watches and clocks" ,add
lab def snilabel 34  "Manufacture of motor vehicles, trailers and semitrailers" ,add
lab def snilabel 35  "Manufacture of other transport equipment" ,add
lab def snilabel 36  "Manufacture of furniture, manufacturing n.e.c." ,add
lab def snilabel 37  "Recycling" ,add
lab def snilabel 40  "Electricity, gas, steam and hot water supply" ,add
lab def snilabel 41  "Collection, purification and distribution of water" ,add
lab def snilabel 45  "Construction" ,add
lab def snilabel 50  "Sale, maintenance and repair of motor vehicles and motorcycles, retail sale of automotive fuel" ,add
lab def snilabel 51  "Wholesale trade and commission trade, except of motor vehicles and motorcycles" ,add
lab def snilabel 52  "Retail trade, except of motor vehicles and motorcycles, repair of personal and household goods" ,add
lab def snilabel 55  "Hotels and restaurants" ,add
lab def snilabel 60  "Land transport, transport via pipelines" ,add
lab def snilabel 61  "Water transport" ,add
lab def snilabel 62  "Air transport" ,add
lab def snilabel 63  "Supporting and auxiliary transport activities, activities of travel agencies" ,add
lab def snilabel 64  "Post and telecommunications" ,add
lab def snilabel 65  "Financial intermediation, except insurance and pension funding" ,add
lab def snilabel 66  "Insurance and pension funding, except compulsory social security",add
lab def snilabel 67  "Activities auxiliary to financial intermediation" ,add
lab def snilabel 70  "Real estate activities" ,add
lab def snilabel 71  "Renting of machinery and equipment without operator and of personal and household goods" ,add
lab def snilabel 72  "Computer and related activities" ,add
lab def snilabel 73  "Research and development" ,add
lab def snilabel 74  "Other business activities" ,add
lab def snilabel 75  "Public administration and defence, compulsory social security" ,add
lab def snilabel 80  "Education" ,add
lab def snilabel 85  "Health and social work" ,add
lab def snilabel 90  "Sewage and refuse disposal, sanitation and similar activities" ,add
lab def snilabel 91  "Activities of membership organizations n.e.c." ,add
lab def snilabel 92  "Recreational, cultural and sporting activities" ,add
lab def snilabel 93  "Other service activities" ,add
lab def snilabel 95  "Private households with employed persons" ,add
lab def snilabel 99  "Extraterritorial organizations and bodies" ,add

lab val ftgsni2 snilabel

g alfa1986=N2k1986/N21986*100
g alfa2008=N2k2008/N22008*100
drop if missing(corr_ws_c2008)
drop if missing(corr_ws_c1986)

g dalfa=alfa2008-alfa1986
g dws_c=corr_ws_c2008-corr_ws_c1986
g dws_n=corr_ws_n2008-corr_ws_n1986
sort dws_c

drop if alfa1986<1.5 & alfa2008<1.5

*** Table3
keep kod ftgsni2 corr_ws_c1986 corr_ws_n1986 dws_c dws_n alfa1986 dalfa
order kod ftgsni2 corr_ws_c1986 corr_ws_n1986 dws_c dws_n alfa1986 dalfa
gsort -corr_ws_c1986

outsheet using results/table3.csv,replace
mkmat ftgsni2 corr_ws_c1986 dws_c corr_ws_n1986 dws_n alfa1986 dalfa, matrix(A)  rownames(ftgsni2)
matrix colnames A = ftgsni2 Vwf_k_c1986 dVwfc Vwf_k_n1986 dVwfn alfa1986 dalfa
outtable using results/table3.tex, mat(A) format (%12.2f) nobox replace
outtable using results/table3.rft, mat(A) format (%12.2f) nobox replace

***************************************************************
*** Table 4: Decomposing the variance of wages           ******
*** dta-files are constructed in master file             ******
***************************************************************

* Full sample
use modified/between_within_actual_counterfactual.dta, clear 
l year wvar wvarbhat wvarwhat wvarb_exp wvarw_exp wvarb_exp_1986gradients wvarb_exp_1986sorting wvarw_exp_1986gradients wvarw_exp_1986sorting if year==1986 | year==2008
* Excluding ICT
use modified/between_within_actual_counterfactual_exICT.dta, clear
l year wvar wvarbhat wvarwhat wvarb_exp wvarw_exp wvarb_exp_1986gradients wvarb_exp_1986sorting wvarw_exp_1986gradients wvarw_exp_1986sorting if year==1986 | year==2008
* Excluding finance
use modified/between_within_actual_counterfactual_exFinance.dta, clear
l year wvar wvarbhat wvarwhat wvarb_exp wvarw_exp wvarb_exp_1986gradients wvarb_exp_1986sorting wvarw_exp_1986gradients wvarw_exp_1986sorting if year==1986 | year==2008



**********************
***** APPENDICES *****
**********************

*** Appendix A

***********************************
*** Figure A1: Ability trends ***
***********************************

use modified/skilldetail6994_collapsed.dta, clear

lab var sumcog "Cognitive skills (mean)"
lab var sumcogsd "Cognitive skills (std)"

lab var verb "Verbal"
lab var log "Logical"
lab var spat "Spatial"
lab var tech "Technical"

graph twoway (line sumcog enlistyr if enlistyr>=1969 & enlistyr<1980, lpattern(solid)) (line sumcog enlistyr if enlistyr>=1980, lpattern(solid)) (line sumcogsd enlistyr if enlistyr>=1969 & enlistyr<1980, lpattern(dash)) (line sumcogsd enlistyr if enlistyr>=1980, lpattern(dash)) , scheme(s2mono) graphr(c(white)) xtitle("Enlistment year") ytitle("Mean and standard deviation") yscale(range(0(0.5)2.5)) legend(order(1 3) rows(2))
graph export results/figA1.eps,replace
graph save results/figA1.gph,replace
* Note: The mean and standard deviation of raw cognitive scores (range 0-4). The break between 1979 and 1980 indicates a change in the testing procedure.  


**********************************
*** Figure A2 Sample selection ***
**********************************

clear
file open myfile using results/selection_of_firms_men3035.csv, write replace

forvalues i=1986(1)2008{
	use sex ftgstorl_ftg sample_3035_10_ftg privfirm_ftg seninv age c n edyr using modified/sample`i',clear

	destring seninv,replace
	replace seninv=. if seninv==0
	g fodar =`i'-age
	g lateinv=0
	replace lateinv=1 if seninv-fodar>=18 & seninv!=.
	replace lateinv=0 if c!=. | n!=.
	drop if ftgstorl_ftg==0

	keep if sex=="1" & age>= 30 & age<= 35	& lateinv==0
	keep if n!=. & c!=. & edyr!=.
	
	g count=1	
	egen all_employed=total(count) 
	local all_employed=all_employed

	drop if ftgstorl_ftg<10
	egen all_above10=total(count) 
	local all_above10=all_above10

	drop if privfirm_ftg==0
	egen all_private10=total(count) 
	local all_private10=all_private10

	keep if sample_3035_10_ftg==1
	egen all_sample=total(count) 
	local all_sample=all_sample

	file write myfile "`all_employed';`all_above10';`all_private10';`all_sample';`i';" _n

	clear
}

file close myfile

clear
file open myfile using results/selection_of_firms_meanskill.csv, write replace

forvalues i=1986(1)2008{
	use sex ftgstorl_ftg sample_3035_10_ftg privfirm_ftg seninv age c n edyr using modified/sample`i',clear

	destring seninv,replace
	replace seninv=. if seninv==0
	g fodar =`i'-age
	g lateinv=0
	replace lateinv=1 if seninv-fodar>=18 & seninv!=.
	replace lateinv=0 if c!=. | n!=.
	drop if ftgstorl_ftg==0

	keep if sex=="1" & age>= 30 & age<= 35	& lateinv==0
	keep if n!=. & c!=. & edyr!=.
	
	g count=1	
	egen all_employed_c=mean(c) 
	local all_employed_c=all_employed_c
	egen all_employed_n=mean(n) 
	local all_employed_n=all_employed_n

	drop if ftgstorl_ftg<10
	egen all_above10_c=mean(c) 
	local all_above10_c=all_above10_c
	egen all_above10_n=mean(n) 
	local all_above10_n=all_above10_n
	
	
	drop if privfirm==0
	egen all_private10_c=mean(c) 
	local all_private10_c=all_private10_c
	egen all_private10_n=mean(n) 
	local all_private10_n=all_private10_n

	keep if sample_3035_10_ftg==1
	egen all_sample_c=mean(c) 
	local all_sample_c=all_sample_c
	egen all_sample_n=mean(n) 
	local all_sample_n=all_sample_n

	file write myfile "`all_employed_c';`all_above10_c';`all_private10_c';`all_sample_c';`all_employed_n';`all_above10_n';`all_private10_n';`all_sample_n';`i';" _n
	clear
}

file close myfile
clear 
file open myfile using results/selection_of_firms_sdskill.csv, write replace

forvalues i=1986(1)2008{
	use sex ftgstorl_ftg sample_3035_10_ftg privfirm_ftg seninv age c n edyr using modified/sample`i',clear

	destring seninv,replace
	replace seninv=. if seninv==0
	g fodar =`i'-age
	g lateinv=0
	replace lateinv=1 if seninv-fodar>=18 & seninv!=.
	replace lateinv=0 if c!=. | n!=.
	drop if ftgstorl_ftg==0

	keep if sex=="1" & age>= 30 & age<= 35	& lateinv==0
	keep if n!=. & c!=. & edyr!=.
	
	g count=1	
	egen all_employed_c=sd(c) 
	local all_employed_c=all_employed_c
	egen all_employed_n=sd(n) 
	local all_employed_n=all_employed_n

	drop if ftgstorl_ftg<10
	egen all_above10_c=sd(c) 
	local all_above10_c=all_above10_c
	egen all_above10_n=sd(n) 
	local all_above10_n=all_above10_n
	
	drop if privfirm==0
	egen all_private10_c=sd(c) 
	local all_private10_c=all_private10_c
	egen all_private10_n=sd(n) 
	local all_private10_n=all_private10_n

	keep if sample_3035_10_ftg==1
	egen all_sample_c=sd(c) 
	local all_sample_c=all_sample_c
	egen all_sample_n=sd(n) 
	local all_sample_n=all_sample_n

	file write myfile "`all_employed_c';`all_above10_c';`all_private10_c';`all_sample_c';`all_employed_n';`all_above10_n';`all_private10_n';`all_sample_n';`i';" _n
	clear
}

file close myfile
clear
insheet using results/selection_of_firms_men3035.csv, delim(;)

replace v1=v1/1000
replace v2=v2/1000
replace v3=v3/1000
replace v4=v4/1000

rename v1 all_employed 
rename v2 all_above10
rename v3 all_private10
rename v4 all_sample
rename v5 year

lab var  all_employed "All men employed"
lab var  all_above10 "Firm size >=10"
lab var  all_private10 "Private firms"
lab var  all_sample "Final sample"

twoway line all_employed all_above10 all_private10 all_sample year, scheme(s2mono) graphr(c(white)) xsize(4) legend(cols(1) size(tiny) lw(thin)) ysc(r(400)) ylabel(0(100)400) ymtick(0(100)400) subtitle("Number observed (1000)")
graph save results/figA2a.gph,replace
graph export results/figA2a.eps,replace

g all=all_employed/all_employed*100
g above10=all_above10/all_employed*100
g private10=all_private10/all_employed*100
g sample=all_sample/all_employed*100

twoway line all above10 private10 sample year, scheme(s2mono) graphr(c(white)) xsize(4) legend(cols(1) size(tiny) lw(thin)) ysc(r(100)) ylabel(0(20)100) ymtick(0(20)100) subtitle("Share observed (percent)")
graph save results/figA2b.gph,replace
graph export results/figA2b.eps,replace

clear
insheet using results/selection_of_firms_meanskill.csv, delim(;)

rename v1 all_employed_c 
rename v2 all_above10_c
rename v3 all_private10_c
rename v4 all_sample_c
rename v5 all_employed_n 
rename v6 all_above10_n
rename v7 all_private10_n
rename v8 all_sample_n
rename v9 year

lab var  all_employed_c "All men employed"
lab var  all_above10_c "Firm size >=10"
lab var  all_private10_c "Private firms"
lab var  all_sample_c "Final sample"

lab var  all_employed_n "All men employed"
lab var  all_above10_n "Firm size >=10"
lab var  all_private10_n "Private firms"
lab var  all_sample_n "Final sample"

twoway line all_employed_c all_above10_c all_private10_c all_sample_c year, scheme(s2mono) graphr(c(white)) xsize(4) legend(cols(1) size(tiny) lw(thin)) ysc(r(0.1)) ylabel(-0.1(0.05)0.1) ymtick(-0.1(0.05)0.1) subtitle("Mean cognitive")
graph save results/figA2c.gph,replace
graph export results/figA2c.eps,replace

twoway line all_employed_n all_above10_n all_private10_n all_sample_n year, scheme(s2mono) graphr(c(white)) xsize(4) legend(cols(1) size(tiny) lw(thin)) ysc(r(0.1)) ylabel(-0.1(0.05)0.1) ymtick(-0.1(0.05)0.1) subtitle("Mean non-cognitive")
graph save results/figA2d.gph,replace
graph export results/figA2d.eps,replace

clear
insheet using results/selection_of_firms_sdskill.csv, delim(;)

rename v1 all_employed_c 
rename v2 all_above10_c
rename v3 all_private10_c
rename v4 all_sample_c
rename v5 all_employed_n 
rename v6 all_above10_n
rename v7 all_private10_n
rename v8 all_sample_n
rename v9 year

* Variance rather than std
replace all_employed_c=all_employed_c*all_employed_c 
replace all_above10_c=all_above10_c*all_above10_c
replace all_private10_c=all_private10_c*all_private10_c
replace all_sample_c=all_sample_c*all_sample_c
replace all_employed_n=all_employed_n*all_employed_n 
replace all_above10_n=all_above10_n*all_above10_n
replace all_private10_n=all_private10_n*all_private10_n
replace all_sample_n=all_sample_n*all_sample_n

lab var  all_employed_c "All men employed"
lab var  all_above10_c "Firm size >=10"
lab var  all_private10_c "Private firms"
lab var  all_sample_c "Final sample"

lab var  all_employed_n "All men employed"
lab var  all_above10_n "Firm size >=10"
lab var  all_private10_n "Private firms"
lab var  all_sample_n "Final sample"

twoway line all_employed_c all_above10_c all_private10_c all_sample_c year, scheme(s2mono) graphr(c(white)) xsize(4) legend(cols(1) size(tiny) lw(thin)) ysc(r(1)) ylabel(0.8(0.05)1) ymtick(0.8(0.05)1) subtitle("Variance cognitive")
graph save results/figA2e.gph,replace
graph export results/figA2e.eps,replace

twoway line all_employed_n all_above10_n all_private10_n all_sample_n year, scheme(s2mono) graphr(c(white)) xsize(4) legend(cols(1) size(tiny) lw(thin)) ysc(r(1)) ylabel(0.8(0.05)1) ymtick(0.8(0.05)1) subtitle("Variance non-cognitive")
graph save results/figA2f.gph,replace
graph export results/figA2f.eps,replace

cd /home/workgroups/firmiq/data/results/
grc1leg figA2a.gph figA2b.gph figA2c.gph figA2d.gph figA2e.gph figA2f.gph, graphr(c(white)) c(2) altshrink imargin(l=30 r=30)
cd /home/workgroups/firmiq/data/
graph save results/figureA2.gph,replace
graph export results/figureA2.eps,replace

*************************************************************************************
*** Figure A3: Correlations in firm-level average skill based on different groups ***
*************************************************************************************

cd /home/workgroups/firmiq/data/
forvalues i=1986(1)2008{
	use year ftgnr sex age ftgstorl_ftg privfirm_ftg seninv age c n edyr using modified/sample`i',clear
	drop if ftgnr==""
	keep if privfirm_ftg==1
	keep if ftgstorl_ftg>=10
	keep if age>=30 & age<=45
	keep if c~=. & n~=. & edyr~=.
	gen count=1
	
	bysort ftgnr: egen cmen3035=mean(c) if age>=30 & age<=35 & sex=="1" 
	bysort ftgnr: egen nmen3035=mean(n) if age>=30 & age<=35 & sex=="1"
	bysort ftgnr: egen emen3035=mean(edyr) if age>=30 & age<=35 & sex=="1"
	
	bysort ftgnr: egen cwom3035=mean(c) if age>=30 & age<=35 & sex=="2" 
	bysort ftgnr: egen nwom3035=mean(n) if age>=30 & age<=35 & sex=="2"
	bysort ftgnr: egen ewom3035=mean(edyr) if age>=30 & age<=35 & sex=="2"

	bysort ftgnr: egen cmen3045=mean(c) if age>=30 & age<=45 & sex=="1" 
	bysort ftgnr: egen nmen3045=mean(n) if age>=30 & age<=45 & sex=="1"
	bysort ftgnr: egen emen3045=mean(edyr) if age>=30 & age<=45 & sex=="1"
	
	bysort ftgnr: egen count3035=sum(count) if age>=30 & age<=35
	bysort ftgnr: egen count3045=sum(count) if age>=30 & age<=35 & sex=="1"
	
	collapse (mean) year cmen3035 nmen3035 emen3035 cwom3035 nwom3035 ewom3035  cmen3045 nmen3045 emen3045 count3035 count3045, by(ftgnr)
	
	reg cmen3035 cwom3035 [aw=count3035]
	gen temp=e(r2)
	gen corr_menwom_c=temp^0.5
	drop temp

	reg nmen3035 nwom3035 [aw=count3035]
	gen temp=e(r2)
	gen corr_menwom_n=temp^0.5
	drop temp
	
	reg emen3035 ewom3035 [aw=count3035]
	gen temp=e(r2)
	gen corr_menwom_e=temp^0.5
	drop temp
	
	reg cmen3045 cmen3035 [aw=count3045]
	gen temp=e(r2)
	gen corr_menmen_c=temp^0.5
	drop temp
	
	reg nmen3045 nmen3035 [aw=count3045]
	gen temp=e(r2)
	gen corr_menmen_n=temp^0.5
	drop temp

	reg emen3045 emen3035 [aw=count3045]
	gen temp=e(r2)
	gen corr_menmen_e=temp^0.5
	drop temp

	collapse corr_menwom_c corr_menwom_n corr_menwom_e corr_menmen_c corr_menmen_n corr_menmen_e, by(year)	
	save temp/skillcorr`i'.dta, replace	
}

use temp/skillcorr1986,clear
forvalues i=1987(1)2008{
	append using temp/skillcorr`i'
}
save modified/skillcorr_ftg, replace 

*** Figure A3
* Panel A (men3035 and men3045)
use modified/skillcorr_ftg,clear
drop if year <1995
lab var corr_menwom_c "Corr cognitive"
lab var corr_menwom_n "Corr non-cognitive"
lab var corr_menwom_e "Corr years of education"

lab var corr_menmen_c "Corr cognitive"
lab var corr_menmen_n "Corr non-cognitive"
lab var corr_menmen_e "Corr years of education"
lab var year "Year"

graph drop _all
line corr_menmen_c corr_menmen_n corr_menmen_e year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(3)) ymtick(0.5(0.1)1) ylabel(0.5(0.1)1) yscale(range(0.5 1)) subt("A: Men 30-35 and 30-45") name(figA3a)
graph save figA3a.gph,replace

* Panel B: men3035 and women 3035
use modified/skillcorr_ftg,clear
lab var corr_menwom_c "Corr cognitive"
lab var corr_menwom_n "Corr non-cognitive"
lab var corr_menwom_e "Corr years of education"

lab var corr_menmen_c "Corr cognitive"
lab var corr_menmen_n "Corr non-cognitive"
lab var corr_menmen_e "Corr years of education"
lab var year "Year"

line corr_menwom_c corr_menwom_n corr_menwom_e year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(3)) ymtick(0(0.2)1) ylabel(0(0.2)1) yscale(range(0 1)) subt("B: Men 30-35 and women 30-55") name(figA3b)
graph save figA3b.gph,replace

grc1leg figA3a figA3b, graphr(c(white)) legendfrom(figA3a)
graph export results/figA3.eps,replace
graph export results/figA3.png,replace
graph save results/figA3.gph,replace


***********************************************
*** Figure A4: Share workers by firm size ***
***********************************************

use modified/vardecomp_unit_ftg_10,clear
keep if year==1986 | year==2008
egen size=cut(ftgstorl_ftg),at(10,50,200,500,2000,100000)

g ftgcount=1
bysort year: egen totftg=sum(ftgcount)

collapse (sum) ftgcount count=N2j (mean) totftg samplesize=N2, by(size year)

g share_sample=count/samplesize*100
g share_ftg=ftgcount/totftg*100
lab def barlab 10 "10-49",add
lab def barlab 50 "50-199",add
lab def barlab 200 "200-499",add
lab def barlab 500 "500-1999",add
lab def barlab 2000 "2000-",add
lab val size barlab

graph drop _all
graph bar share_sample share_ftg if year==1986, over(size) scheme(s2mono) graphr(c(white)) legend(label(1 "Share of sample") label(2 "Share of firms") size(small)) subtitle(1986) name(size1986)
graph bar share_sample share_ftg if year==2008, over(size) scheme(s2mono) graphr(c(white)) legend(label(1 "Share of sample") label(2 "Share of firms") size(small)) subtitle(2008) name(size2008)
grc1leg size1986 size2008, graphr(c(white)) legendfrom(size1986)
graph export results/figA4.eps,replace
graph save results/figA4.gph,replace

*******************
*** Table A1 ******
*******************
clear
log using results/wagepredictionlog, append text 

set more off
set matsize 10000

use modified/sample1986, clear
	forvalues i=1987(1)2008 {
	append using modified/sample`i' 
	}


keep lopnr year ftgnr lonfink_ftg sex seninvar loneink age edyr fos_detail zedyr c n manl_ftg ftgsni2 manl_imp_ftg inc_ftg inc_ftg2 manl_imp_ftg2 lninc_ftg lnwage_ftg lnwpred_ftg in_sample_3035_10_ftg privfirm_ftg imputed_ssyk_ftg 

keep if age>=20 & age<=64

* Polynomials of earnings
gen wom=1 if sex=="2"
replace wom=0 if sex=="1"
drop sex

g lninc_ftg2=lninc_ftg*lninc_ftg
g lninc_ftg3=lninc_ftg2*lninc_ftg
g lninc_ftg4=lninc_ftg3*lninc_ftg
g lninc_ftg5=lninc_ftg4*lninc_ftg

gen wageimputation_ftg=.
replace wageimputation_ftg=1 if manl_ftg~=.
replace wageimputation_ftg=2 if manl_imp_ftg~=. & manl_ftg==.
replace wageimputation_ftg=3 if lninc_ftg~=. & manl_imp_ftg==. & manl_ftg==.

gen w1=lnwage_ftg if wageimputation_ftg==1
gen w2=lnwage_ftg if wageimputation_ftg==2

gen w12=w1
replace w12=w2 if w12==.

* reg w12 i.year##i.wom##c.lninc_ftg i.year##i.wom##c.lninc_ftg2 i.year##i.wom##c.lninc_ftg3 i.year##i.wom##c.lninc_ftg4 i.year##i.wom##c.lninc_ftg5 i.year##i.wom##i.ftgsni2
log using results/wagepredictionlog, append text 
set more off

reg w1 i.year##i.wom##c.lninc_ftg i.year##i.wom##c.lninc_ftg2 i.year##i.wom##c.lninc_ftg3 i.year##i.wom##c.lninc_ftg4 i.year##i.wom##c.lninc_ftg5 i.year##i.wom##i.ftgsni2
predict w1hat
reg w2 i.year##i.wom##c.lninc_ftg i.year##i.wom##c.lninc_ftg2 i.year##i.wom##c.lninc_ftg3 i.year##i.wom##c.lninc_ftg4 i.year##i.wom##c.lninc_ftg5 i.year##i.wom##i.ftgsni2
predict w2hat
reg w12 i.year##i.wom##c.lninc_ftg i.year##i.wom##c.lninc_ftg2 i.year##i.wom##c.lninc_ftg3 i.year##i.wom##c.lninc_ftg4 i.year##i.wom##c.lninc_ftg5 i.year##i.wom##i.ftgsni2
predict w12hat
reg w12 i.year##c.lninc_ftg i.year##c.lninc_ftg2 i.year##c.lninc_ftg3 i.year##c.lninc_ftg4 i.year##c.lninc_ftg5 i.year##i.ftgsni2 if wom==0
predict w12hat_men

sum w1 w2 w12 lnwage_ftg

*predict w1hat, xb

reg w2 i.year##i.wom##c.lninc_ftg i.year##i.wom##c.lninc_ftg2 i.year##i.wom##c.lninc_ftg3 i.year##i.wom##c.lninc_ftg4 i.year##i.wom##c.lninc_ftg5 i.year##i.wom##i.ftgsni2
predict w2hat, xb

* Table A1
sum lnwage_ftg if wageimputation==1
gen obs_imp1=r(N)
gen mean_imp1=r(mean)
gen sd_imp1=r(sd)

sum lnwage_ftg if wageimputation==2
gen obs_imp2=r(N)
gen mean_imp2=r(mean)
gen sd_imp2=r(sd)

sum lnwpred_ftg if wageimputation==3 if privfirm_ftg==1
gen obs_imp3=r(N)
gen mean_imp3=r(mean)
gen sd_imp3=r(sd)

sum lnwage_ftg if wageimputation==1 & zedyr>=0 & zedyr~=.
gen obs_imp1_hs=r(N)
gen mean_imp1_hs=r(mean)
gen sd_imp1_hs=r(sd)

sum lnwage_ftg if wageimputation==2 & zedyr>=0 & zedyr~=.
gen obs_imp2_hs=r(N)
gen mean_imp2_hs=r(mean)
gen sd_imp2_hs=r(sd)

sum lnwpred_ftg if wageimputation==3 & zedyr>=0 & zedyr~=.
gen obs_imp3_hs=r(N)
gen mean_imp3_hs=r(mean)
gen sd_imp3_hs=r(sd)

sum lnwage_ftg if wageimputation==1 & zedyr<0 & zedyr~=.
gen obs_imp1_ls=r(N)
gen mean_imp1_ls=r(mean)
gen sd_imp1_ls=r(sd)

sum lnwage_ftg if wageimputation==2 & zedyr<0 & zedyr~=.
gen obs_imp2_ls=r(N)
gen mean_imp2_ls=r(mean)
gen sd_imp2_ls=r(sd)

sum lnwpred_ftg if wageimputation==3 & zedyr<0 & zedyr~=.
gen obs_imp3_ls=r(N)
gen mean_imp3_ls=r(mean)
gen sd_imp3_ls=r(mean)

log close

******************
*** Appendix C ***
******************

*****************************************************
*** Figure C1. Distribution of firm average skill ***
***************************************************** 

* Firm
use modified/vardecomp_unit_ftg_10,clear
drop if year==1985
drop if year==2009
keep year ftgnr cj nj N2j

graph drop _all
graph twoway (kdensity cj [aw=N2j] if year==1986, bwidth(0.0618) lpattern(dash)) (kdensity cj [aw=N2j] if year==2008, bwidth(0.0618) lpattern(solid)), ylabel(0(0.5)2) ymtick(0(0.5)2) scheme(s2mono) graphr(c(white)) xtitle("Firm skill level") subt("A: Cognitive skill") ytitle("Kernel density") legend(order(1 "1986" 2 "2008") rows(1)) name(fig1986)
graph twoway (kdensity nj [aw=N2j] if year==1986, bwidth(0.0412) lpattern(dash)) (kdensity nj [aw=N2j] if year==2008, bwidth(0.0412) lpattern(solid)), ylabel(0(0.5)2) ymtick(0(0.5)2) scheme(s2mono) graphr(c(white)) xtitle("Firm skill level") subt("B: Non-cognitive skill") ytitle("Kernel density") legend(order(1 "1986" 2 "2008") rows(1)) name(fig2008)
grc1leg fig1986 fig2008, graphr(c(white)) legendfrom(fig1986)
graph export results/figC1.eps,replace
graph save results/figC1.gph,replace


********************************
*** Figure C2: Kendall's tau ***
********************************

forvalues i=1986(1)2008{
use lopnr sample_3035_10_ftg c n ftgsni* ftgstorl_ftg ftgnr year using modified/sample`i', clear

keep if sample_3035_10_ftg==1

save temp/kendall`i',replace
}
clear
use temp/kendall1986
forvalues i=1987(1)2008{
append using temp/kendall`i'
}
sort year
save temp/kendall,replace

forvalues i=1986(1)2008{
erase temp/kendall`i'.dta
}

use temp/kendall,clear

merge m:1 ftgnr year using modified/vardecomp_unit_ftg_10, keepus(ftgnr year cj nj)
drop if _merge==2
drop _merge

gen taoc=0
gen taon=0

forvalues i=1986(1)2008{
	gen taoc`i'=0 
	gen taon`i'=0
	
	ktau c cj if year==`i'
	scalar tc=r(tau_b) 
	replace taoc`i'=taoc`i'+tc
	
	ktau n nj if year==`i'
	scalar tn=r(tau_b) 
	replace taon`i'=taon`i'+tn

	replace taoc=taoc`i' if year==`i'
	replace taon=taon`i' if year==`i'
	
	drop taoc`i' taon`i'
}

drop if taoc==.
drop if taon==.
drop if year==.
duplicates drop year, force
keep year taoc taon

save modified/kendallstao.dta, replace
*
use modified/kendallstao.dta, clear
lab var taon "Non-cognitive"
lab var taoc "Cognitive"
lab var year "Year"
sort year

line taoc taon year, scheme(s2mono) graphr(c(white)) legend(cols(1) rows(2)) ymtick(0(0.1)0.4) ylabel(0(0.1)0.4) yscale(range(0 0.4)) ytitle("Kendall's tao")
graph export results/figC2.eps,replace
graph save results/figC2.gph,replace
* Note Kendall rank correlations between own and firm level skills. The sample includes 30-35 year-old men and women employed at firms with at least 10 employees.
	
********************************	
****** Figures C3 and C4     ***
****** Sorting on subscores  ***
********************************

use modified/detailed_vardecomp_aggregate_ftg_10,clear
drop if year==1985 | year>=2006

lab var corr_bs_l "Logic"
lab var corr_bs_v "Verbal" 
lab var corr_bs_s "Spatial" 
lab var corr_bs_t "Technical" 

lab var corr_ws_l "Logic"
lab var corr_ws_v "Verbal" 
lab var corr_ws_s "Spatial" 
lab var corr_ws_t "Technical" 

lab var corr_bs_n1 "Social maturity"
lab var corr_bs_n2 "Intensity" 
lab var corr_bs_n3 "Psychological energy" 
lab var corr_bs_n4 "Emotional stability" 

lab var corr_ws_n1 "Social maturity"
lab var corr_ws_n2 "Intensity" 
lab var corr_ws_n3 "Psychological energy" 
lab var corr_ws_n4 "Emotional stability" 
lab var year "Year"

* Figure C3
graph drop _all
twoway (line corr_bs_l year)(line corr_bs_v year) (line corr_bs_s year) (line corr_bs_t year), scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("A: Between firm") name(figC3a)
twoway (line corr_ws_l year) (line corr_ws_v year) (line corr_ws_s year) (line corr_ws_t year), scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("B: Within firm") name(figC3b)
grc1leg figC3a figC3b, graphr(c(white)) legendfrom(figC3a)
graph export results/figC3.eps,replace
graph export results/figC3.png,replace
graph save results/figC3.gph,replace

* Figure C4
graph drop _all
twoway (line corr_bs_n1 year)(line corr_bs_n2 year) (line corr_bs_n3 year) (line corr_bs_n4 year), scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("A: Between firm") name(figC4a)
twoway (line corr_ws_n1 year) (line corr_ws_n2 year) (line corr_ws_n3 year) (line corr_ws_n4 year), scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("B: Within firm") name(figC4b)
grc1leg figC4a figC4b, graphr(c(white)) legendfrom(figC4a)
graph export results/figC4.eps,replace
graph export results/figC4.png,replace
graph save results/figC4.gph,replace


************************************************
***** Fig C5: Residualized skill measures ******
************************************************

use modified/residualized_skills.dta, clear
lab var corr_bs_c "Cognitive"
lab var corr_ws_c "Cognitive"
lab var corr_bs_n "Non-cognitive"
lab var corr_ws_n "Non-cognitive"
lab var year "Year"


graph drop _all
twoway (line corr_bs_c year, yaxis(1) ylabel(0(0.05)0.22,axis(1)) ymtick(0(0.05)0.22, axis(1))) (line corr_bs_n year), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("A: Between firm") name(figC5a)
graph save figC5a,replace
twoway (line corr_ws_c year, yaxis(1) ylabel(0.6(0.05)0.82, axis(1)) ymtick(0.6(0.05)0.82, axis(1))) (line corr_ws_n year), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(figC5b)
graph save figC5b,replace
grc1leg figC5a figC5b, graphr(c(white)) legendfrom(figC5a)
graph export results/figC5.eps,replace
graph export results/figC5.png,replace
graph save results/figC5.gph,replace
* Note. The sample includes 30-35 year-old men employed at private firms with at least 10 employees.Variance components are corrected for sample size according to the procedure in AppendixB1.

****************************************************************
*** Figure C6. Sorting by education for different samples   ****
****************************************************************

*** figC6
use modified/vardecomp_aggregate.dta, clear
drop if year==1985
drop if year==2009

lab var corr_bs_ze_ftg_10 "Main sample"
lab var corr_bs_ze_ftg_10 "Main sample"
lab var corr_ws_ze_ftg_10 "Main sample"
lab var corr_ws_ze_ftg_10 "Main sample"
lab var N2_ftg_10  "Main sample"

merge 1:1 year using modified/vardecomp_aggregate_ed2460.dta
drop _merge
merge 1:1 year using modified/vardecomp_aggregate_alled2460.dta

graph drop _all
twoway (line corr_bs_ze_ftg_10 corr_bs_ze_ed2460 corr_bs_ze_alled2460 year, yaxis(1) ylabel(0.1(0.05)0.5,axis(1)) ymtick(0.1(0.05)0.5, axis(1))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("A: Between firm") name(figCXa)
graph save figCXa,replace
twoway (line corr_ws_ze_ftg_10 corr_ws_ze_ed2460 corr_ws_ze_alled2460 year, yaxis(1) ylabel(0.4(0.05)0.8,axis(1)) ymtick(0.4(0.05)0.8, axis(1))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(figCXb) 
graph save figCXb,replace
grc1leg figCXa figCXb, graphr(c(white)) legendfrom(figCXa)
graph save results/figC6.gph,replace

********************************************************************
*** Figure C7. Histogram of industry-level mean cognitive skill ****
********************************************************************

foreach x in ftg {
	foreach j in 10 {
		foreach i in 1986 2008 {
			use modified/sample`i', clear
				drop if `x'nr==""	
				keep if sample_3035_`j'_`x'==1
				merge 1:1 lopnr using modified/combskill_measure.dta
				drop if _merge==2

				gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
				replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
				replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
				replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
				replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.

				gen engineer=0 if edyr~=. & fos~=.
				replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
				label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"
				gen ba_law=0
				replace ba_law=1 if (fos_detail==38|fos_detail==34) & edyr>=15 
				
				drop if ftgsni2==.
				* Skills total
				egen cmean=mean(c)
				egen nmean=mean(n)
				egen smean=mean(skill)

				* Skills: engineers and withot engineers
				egen cmean_engincl=mean(c) if engineer==1 
				egen nmean_engincl=mean(n) if engineer==1
				egen smean_engincl=mean(skill) if engineer==1				
				
				egen cmean_engexcl=mean(c) if engineer==0 
				egen nmean_engexcl=mean(n) if engineer==0
				egen smean_engexcl=mean(skill) if engineer==0						

				* Skills: business and law
				egen cmean_balawincl=mean(c) if ba_law==1 
				egen nmean_balawincl=mean(n) if ba_law==1
				egen smean_balawincl=mean(skill) if ba_law==1				
				
				egen cmean_balawexcl=mean(c) if ba_law==0 
				egen nmean_balawexcl=mean(n) if ba_law==0
				egen smean_balawexcl=mean(skill) if ba_law==0										

				* Observations
				egen obs=count(c)
				egen obs_engincl=count(c) if engineer==1 
				egen obs_engexcl=count(c) if engineer==0 
				egen obs_balawincl=count(c) if ba_law==1 
				egen obs_balawexcl=count(c) if ba_law==0 
				
				* Skills by industry: all
				bysort ftgsni2: egen cmean_sni2=mean(c)
				bysort ftgsni2: egen nmean_sni2=mean(n)
				bysort ftgsni2: egen smean_sni2=mean(skill)
				
				* Skills by industry: engineers and withot engineers
				bysort ftgsni2: egen cmean_engincl_sni2=mean(c) if engineer==1 
				bysort ftgsni2: egen nmean_engincl_sni2=mean(n) if engineer==1
				bysort ftgsni2: egen smean_engincl_sni2=mean(skill) if engineer==1				
				
				bysort ftgsni2: egen cmean_engexcl_sni2=mean(c) if engineer==0 
				bysort ftgsni2: egen nmean_engexcl_sni2=mean(n) if engineer==0
				bysort ftgsni2: egen smean_engexcl_sni2=mean(skill) if engineer==0						
				
				* Skills by industry: business and law
				bysort ftgsni2: egen cmean_balawincl_sni2=mean(c) if ba_law==1 
				bysort ftgsni2: egen nmean_balawincl_sni2=mean(n) if ba_law==1
				bysort ftgsni2: egen smean_balawincl_sni2=mean(skill) if ba_law==1				
				
				bysort ftgsni2: egen cmean_balawexcl_sni2=mean(c) if ba_law==0 
				bysort ftgsni2: egen nmean_balawexcl_sni2=mean(n) if ba_law==0
				bysort ftgsni2: egen smean_balawexcl_sni2=mean(skill) if ba_law==0										
				
				* Observations by industry
				bysort ftgsni2: egen obs_sni2=count(c)
				bysort ftgsni2: egen obs_engincl_sni2=count(c) if engineer==1 
				bysort ftgsni2: egen obs_engexcl_sni2=count(c) if engineer==0 
				bysort ftgsni2: egen obs_balawincl_sni2=count(c) if ba_law==1 
				bysort ftgsni2: egen obs_balawexcl_sni2=count(c) if ba_law==0 
				
				collapse year cmean nmean smean cmean_engincl nmean_engincl smean_engincl cmean_engexcl nmean_engexcl smean_engexcl cmean_balawincl nmean_balawincl smean_balawincl cmean_balawexcl nmean_balawexcl smean_balawexcl obs obs_engincl obs_engexcl obs_balawincl obs_balawexcl cmean_sni2 nmean_sni2 smean_sni2 cmean_engincl_sni2 nmean_engincl_sni2 smean_engincl_sni2 cmean_engexcl_sni2 nmean_engexcl_sni2 smean_engexcl_sni2 cmean_balawincl_sni2 nmean_balawincl_sni2 smean_balawincl_sni2 cmean_balawexcl_sni2 nmean_balawexcl_sni2 smean_balawexcl_sni2 obs_sni2 obs_engincl_sni2 obs_engexcl_sni2 obs_balawincl_sni2 obs_balawexcl_sni2, by(ftgsni2)
				
				save temp\industry_means_`i'.dta, replace
				
		}
	}
}
 
use  temp\industry_means_1986.dta, clear
append using temp\industry_means_2008.dta				

*** Figure C7
use  temp\industry_means_1986.dta, clear
append using temp\industry_means_2008.dta				
lab var cmean_sni2 "Mean cognitive skill"
graph drop _all
twoway (hist cmean_sni2 [fw=obs_sni2] if year==1986, width(0.05) percent), scheme(s2mono) graphr(c(white)) ymtick(0(5)20) ylabel(0(5)20) yscale(range(0 20)) xscale(range(-0.7 1)) subt("Panel A: 1986") name(figC7a)
graph save results/figC7a.gph,replace
twoway (hist cmean_sni2 [fw=obs_sni2] if year==2008, width(0.05) percent), scheme(s2mono) graphr(c(white)) ymtick(0(5)20) ylabel(0(5)20) yscale(range(0 20)) xscale(range(-0.7 1)) subt("Panel B: 2008") name(figC7b) 
graph save results/figC7b.gph,replace
*twoway (hist cmean_sni2 [fw=obs_sni2] if year==1986, percent blcolor(gs6) bfcolor(gs10)) (hist cmean_sni2 [fw=obs_sni2] if year==2008, percent blcolor(black) bfcolor(none)), scheme(s2mono) graphr(c(white)) legend(order(1 "1986" 2 "2008" )) 
graph combine results/figC7a.gph results/figC7b.gph, graphr(c(white))
graph save results/figC7.gph,replace

**********************************************************
*** Figure C8: Share workers in ICT-sector (32 and 72) ***
**********************************************************

forvalues i=1986(1)2008{
	use year ftgnr sex ftgsni2 ftgstorl_ftg sample_3035_10_ftg privfirm_ftg ftgstorl_ftg seninv age c n using modified/sample`i',clear
	drop if ftgnr==""
	destring seninv,replace
	replace seninv=. if seninv==0
	g fodar =year-age
	g lateinv=0
	replace lateinv=1 if seninv-fodar>=18 & seninv!=.
	replace lateinv=0 if c!=. | n!=.
	drop if ftgstorl_ftg<10

	keep if  age>= 21 & age<= 64
	keep if privfirm_ftg==1

	g d2164m=0 if sex=="1"
	replace d2164m=1 if (ftgsni==32 | ftgsni==72) & sex=="1"

	g d2164f=0 if sex=="2"
	replace d2164f=1 if (ftgsni==32 | ftgsni==72) & sex=="2"
	
	g d3035f=0 if sex=="2" & age>= 30 & age<= 35
	replace d3035f=1 if (ftgsni==32 | ftgsni==72) & sex=="2" & age>= 30 & age<= 35

	g dsample=0 if sample_3035_10_ftg==1
	replace dsample=1 if (ftgsni==32 | ftgsni==72) & sample_3035_10_ftg==1

	collapse s2164m=d2164m s2164f=d2164f s3035f=d3035f ssample=dsample year
	save temp/itsize`i'.dta,replace
}

use temp/itsize1986.dta, clear
forvalues i=1987(1)2008{
	append using temp/itsize`i'
}	

lab var s2164m "Men 21-64"
lab var s2164f "Women 21-64"
lab var s3035f "Women 30-35"
lab var ssample "Men 30-35"
lab var year "Year"
graph drop _all
line s2164m ssample year, ylabel(0(0.04)0.12) ymtick(0(0.04)0.12) , scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("Men")
graph save figC8a,replace 
line s2164f s3035f year, ylabel(0(0.04)0.12) ymtick(0(0.04)0.12) , scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("Women")
graph save figC8b,replace
graph combine figC8a.gph figC8b.gph, graphr(c(white)) xsize(7) c(3)
graph save results/figC8.gph,replace
* Note: Share workers in the IT (NACE 72) and telecom (32) industries.

***************************************************************
*** Figure C9. Wage structure and changes in industry size **** 
***************************************************************

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1985(1)2008 {
		use modified/sample`i', clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		keep if sample_3035_`j'_`x'==1
		
		* Keep only valid industries
		keep if `x'sni3~=.
		
		* Generate count variable
		*g count=1
		
		bysort `x'nr: egen meanw=mean(lnwpred_`x')
		gen wdm=lnwpred_`x'-meanw
		bysort `x'sni3: egen wage_sni3_sd_within=sd(wdm)
		bysort `x'sni3: egen wage_sni3_mean=mean(lnwpred_`x') 
		bysort `x'sni3: egen wage_sni3_sd=sd(lnwpred_`x')
		bysort `x'sni3: egen obs_sni3=count(lnwpred_`x')
		keep if obs_sni3>=5
		egen obs=count(lnwpred_`x')
		gen share_sni3=obs_sni3/obs 
		
		collapse c n wage_sni3_mean wage_sni3_sd wage_sni3_sd_within obs_sni3 obs share_sni3 year ,by(`x'sni3)
		
		save temp/wage_dispersion_sni3_`i'.dta, replace
		
		}
	}
}

forvalues i=1985(1)2008 {
use temp/wage_dispersion_sni3_`i', clear		
rename wage_sni3_mean wmean`i'
rename wage_sni3_sd wsd`i'
rename wage_sni3_sd_within wsdw`i'
rename share_sni3 share`i'
rename obs obs`i'
rename obs_sni3 obssni`i'
rename c c`i'
rename n n`i'
drop year
sort ftgsni3
save temp/wdisp`i'.dta, replace
}

use temp/wdisp1985, clear
forvalues i=1986(1)2008 {
	merge 1:1 ftgsni3 using temp/wdisp`i'
	drop _merge
	}
save modified/wdispersion_industry.dta, replace

*** Figure C9
use modified/wdispersion_industry.dta, clear

* Income and dispersion groups	
xtile wgroup1985 = wmean1985, nq(5) 
xtile sdgroup1985 = wsd1985, nq(5) 

* Changes
gen change9786=share1997-share1986
gen change0897=share2008-share1997
gen change0886=share2008-share1986

lab var change9786 "Share change 1986-1997"
lab var change0897 "Share change 1997-2008"
lab var change0886 "Share change 1986-2008"

* Figure C9: Changes in industry changes by mean income and dispesion 1985
graph drop _all
graph bar (mean) change9786 (mean) change0897 (mean) change0886 if wgroup1985~=., over(wgroup1985) legend(rows(3)) legend(label(1 "Share change 1986-1997")) legend(label(2 "Share change 1997-2008")) legend(label(3 "Share change 1986-2008")) scheme(s2mono) graphr(c(white)) b1title("Income group (1985)") name(share1)
graph bar (mean) change9786 (mean) change0897 (mean) change0886 if wgroup1985~=., over(sdgroup1985) legend(rows(3)) legend(label(1 "Share change 1986-1997")) legend(label(2 "Share change 1997-2008")) legend(label(3 "Share change 1986-2008")) scheme(s2mono) graphr(c(white)) b1title("Wage dispersion group (1985)") name(share2)
grc1leg share1 share2, graphr(c(white)) legendfrom(share1)
graph save results/figC9.gph, replace

***************************************************************
*** Fig C10. Predicting the between-industry skill variance ***
***************************************************************

use modified/wdispersion_industry.dta, clear

* Income and dispersion groups	
xtile wgroup1985 = wmean1985, nq(5) 
xtile sdgroup1985 = wsd1985, nq(5)

forvalues i=1986(1)2008 {
	gen lnshare`i'=ln(share`i')
	gen change`i'_1986=share`i'-share1986
	gen lnchange`i'_1986=lnshare`i'-lnshare1986
	gen cchange`i'_1986=c`i'-c1986
	gen nchange`i'_1986=n`i'-n1986
	gen wchange`i'_1986=wmean`i'-wmean1986
	gen wsdwchange`i'_1986=wsdw`i'-wsdw1986
	}
	
forvalues i=1986(1)2008 {
	reg change`i'_1986 i.wgroup1985 i.sdgroup1985
	predict changehat`i' if e(sample)
	reg lnchange`i'_1986 i.wgroup1985 i.sdgroup1985
	predict lnchangehat`i' if e(sample)
	reg cchange`i'_1986 i.wgroup1985 i.sdgroup1985
	predict cchangehat`i' if e(sample)
	reg nchange`i'_1986 i.wgroup1985 i.sdgroup1985
	predict nchangehat`i' if e(sample)
	reg wchange`i'_1986 i.wgroup1985 i.sdgroup1985
	predict wchangehat`i' if e(sample)
	reg wsdwchange`i'_1986 i.wgroup1985 i.sdgroup1985
	predict wsdwchangehat`i' if e(sample)

	}

forvalues i=1986(1)2008 {
	gen predshare`i'= share1986 + changehat`i'
	gen predshareln`i'= share1986*(1+lnchangehat`i')
	gen cpred`i'=c1986+cchangehat`i'
	gen npred`i'=n1986+nchangehat`i'
	gen wpred`i'=wmean1986+wchangehat`i'
	gen wsdwpred`i'=wsdw1986+wsdwchangehat`i'
	}

forvalues i=1986(1)2008 {
	egen totactshare`i'=sum(share`i')
	egen totshare`i'= sum(predshare`i')
	egen totshareln`i'= sum(predshareln`i')
	}	
	
forvalues i=1986(1)2008 {
	replace predshare`i'=predshare`i'/totshare`i'
	replace predshareln`i'=predshareln`i'/totshareln`i'
	}	

* Gen 1986 skills
gen cpre=c1986
gen npre=n1986
gen wpre=wmean1986	
gen wsdwpre=wsdw1986
	
* Reshape data

reshape long c n wmean wsdw npred cpred wpred wsdwpred share predshare predshareln, i(ftgsni3) j(year)	
keep ftgsni3 year c n wmean wsdw npred cpred wpred wsdwpred share predshare predshareln cpre npre wpre wsdwpre
drop if year==1985

rename wmean w
rename cpre c1986
rename npre n1986
rename wpre w1986
rename wsdwpre wsdw1986

* Actual sorting
sort year

egen cbar=sum(c*share) if share~=., by(year)
egen nbar=sum(n*share) if share~=., by(year)
egen wbar=sum(w*share) if share~=., by(year)
egen wsdwbar=sum(wsdw*share) if share~=., by(year)

gen csq=share*(c-cbar)^2 if share~=.
gen nsq=share*(n-nbar)^2 if share~=.
gen wsq=share*(w-wbar)^2 if share~=.

* Sorting based on predicted shares
egen cpredbar=sum(c*predshareln) if predshareln~=., by(year)
egen npredbar=sum(n*predshareln) if predshareln~=., by(year)
egen wpredbar=sum(w*predshareln) if predshareln~=., by(year)
egen wsdwpredbar=sum(wsdw*predshareln) if predshareln~=., by(year)

gen cpredsq=predshareln*(c-cpredbar)^2 if predshareln~=.
gen npredsq=predshareln*(n-npredbar)^2 if predshareln~=.
gen wpredsq=predshareln*(w-wpredbar)^2 if predshareln~=.

* Sorting based on predicted shares and predicted skills
egen cpredpredbar=sum(cpred*predshareln) if predshareln~=., by(year)
egen npredpredbar=sum(npred*predshareln) if predshareln~=., by(year)
egen wpredpredbar=sum(wpred*predshareln) if predshareln~=., by(year)
egen wsdwpredpredbar=sum(wsdwpred*predshareln) if predshareln~=., by(year)

gen cpredpredsq=predshare*(cpred-cpredpredbar)^2
gen npredpredsq=predshare*(npred-npredpredbar)^2
gen wpredpredsq=predshare*(wpred-wpredpredbar)^2

* Sorting based on 1986 skills and actual shares
egen c1986bar=sum(c1986*share) if share~=., by(year)
egen n1986bar=sum(n1986*share) if share~=., by(year)
egen w1986bar=sum(w1986*share) if share~=., by(year)
egen wsdw1986bar=sum(wsdw1986*share) if share~=., by(year)

gen c1986sq=share*(c1986-c1986bar)^2 if share~=.
gen n1986sq=share*(n1986-n1986bar)^2 if share~=.
gen w1986sq=share*(w1986-w1986bar)^2 if share~=.

* Sorting based on 1986 skills and predicted shares
egen c1986predbar=sum(c1986*predshareln) if predshareln~=., by(year)
egen n1986predbar=sum(n1986*predshareln) if predshareln~=., by(year)
egen w1986predbar=sum(w1986*predshareln) if predshareln~=., by(year)
egen wsdw1986predbar=sum(wsdw1986*predshareln) if predshareln~=., by(year)

gen c1986predsq=predshareln*(c1986-c1986predbar)^2 if predshareln~=.
gen n1986predsq=predshareln*(n1986-n1986predbar)^2 if predshareln~=.
gen w1986predsq=predshareln*(w1986-w1986predbar)^2 if predshareln~=.

collapse (mean) wsdwbar wsdwpredbar wsdwpredpredbar wsdw1986bar wsdw1986predbar (sum) share predshare predshareln csq nsq wsq cpredsq npredsq wpredsq npredpredsq cpredpredsq wpredpredsq c1986sq n1986sq w1986sq c1986predsq n1986predsq w1986predsq, by(year)

lab var csq "Between industry"
lab var nsq "Between industry"
lab var cpredsq "Between industry (predicted shares)"
lab var npredsq "Between industry (predicted shares)"
lab var cpredpredsq "Between industry (predicted shares, predicted skills)"
lab var npredpredsq "Between industry (predicted shares, predicted skills)"
lab var c1986sq "Between industry (1986 skills)"
lab var n1986sq "Between industry (1986 skills)"
lab var c1986predsq "Between industry (predicted shares, 1986 skills)"
lab var n1986predsq "Between industry (predicted shares, 1986 skills)"

lab var wsq "Actual"
lab var wpredsq "Predicted shares"
lab var wpredpredsq "Predicted shares, predicted wages"
lab var w1986sq "1986 wages"
lab var w1986predsq "Predicted shares, 1986 wages"

lab var wsdwbar "Actual"
lab var wsdwpredbar "Predicted shares"
lab var wsdwpredpredbar "Predicted shares, predicted sorting"
lab var wsdw1986bar "1986 sorting"
lab var wsdw1986predbar "Predicted shares, 1986 sorting"

*** Figure C10
graph drop _all
twoway (line csq c1986predsq cpredpredsq year), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("A: Cognitive") name(figC10a)
twoway (line nsq n1986predsq npredpredsq year), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Non-cognitive") name(figC10b)
grc1leg figC10a figC10b, graphr(c(white)) legendfrom(figC10a)
graph save results/figC10.gph,replace


******************************************************************************
**** Figure C11: Decomposing the between-firm variance: Educational groups ***
******************************************************************************

foreach x in ftg {
	forvalues i=1986(1)2008 {
		use modified/sample`i'.dta,clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.

		* Rename non-cog
		rename n nc

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen ssyk2=group(edlevel fos_detail)

		* Generate count variable
		g count=1

		* Count actual number of observations at different levels
		egen N=total(count)
		lab var N "Total observations"
		bysort ftgnr: egen Nj=total(count)
		lab var Nj "Firm number of observations"
		bysort ssyk2: egen Nh=total(count)
		lab var Nh "Education group number of observations"
		bysort ftgnr ssyk2: egen Njh=total(count)
		lab var Njh "Firm-by-education group number of observations"
		
		* Keep relevant sample
		keep if sample_3035_10_`x'==1

		* Count observations for sample
		egen n2=total(count)
		lab var n2 "Number of sample observations"
		bysort ssyk2: egen nh=total(count)
		lab var nh "Education group number of sample observations"
		bysort ftgnr ssyk2: egen njh=total(count)
		lab var njh "Firm-by-education group number of sample observations"
		bysort ftgnr: egen nj=total(count)
		lab var nj "Firm number of observations"
		
		*Predicted skills
		*individual
		areg c, absorb(ssyk2)
		predict cresij if e(sample), resid
		predict cpredij if e(sample), xbd
		areg nc, absorb(ssyk2)
		predict ncresij if e(sample), resid
		predict ncpredij if e(sample), xbd

		bysort ftgnr: egen cj=mean(c)
		bysort ftgnr: egen ncj=mean(nc)
		lab var cj "Firm mean cognitive"
		lab var ncj "Firm mean non-cognitive"

		bysort ftgnr: egen cpredj=mean(cpredij)
		bysort ftgnr: egen ncpredj=mean(ncpredij)
		
		* Firm level predicted skills (cjtilde, ncjtilde)
		lab var cpredj "Firm mean predicted cognitive"
		lab var ncpredj "Firm mean predicted non-cognitive"
		
		*firm level mean residual 
		bysort ftgnr: egen cresj=mean(cresij) 	
		bysort ftgnr: egen ncresj=mean(ncresij) 	
		
		* Sample mean skilld
		egen cmean=mean(c)
		egen ncmean=mean(nc)
		
		*** Between firm skill variance and its major components (sample size adjusted)

		* Sample size adjustment parameter (between firm)
		gen theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
		
		* Components for between firm sample size adjustments
		bysort ftgnr: egen wfc=sum((c-cj)^2)
		bysort ftgnr: egen wfnc=sum((nc-ncj)^2)
		
		bysort ftgnr: egen adj1c=sum(((c-cpredij)-(cj-cpredj))^2)
		bysort ftgnr: egen adj1nc=sum(((nc-ncpredij)-(ncj-ncpredj))^2)
		
		bysort ftgnr: egen adj2c=sum((cpredij-cpredj)^2)
		bysort ftgnr: egen adj2nc=sum((ncpredij-ncpredj)^2)
		
		bysort ftgnr: egen adj3c=sum(((c-cpredij) - (cj-cpredj))*(cpredij-cpredj))  
		bysort ftgnr: egen adj3nc=sum(((nc-ncpredij) - (ncj-ncpredj))*(ncpredij-ncpredj))  

		* Between firm variance: not adjusted
		egen bfc=sum((cj-cmean)^2)
		replace bfc=bfc/n2
		egen bfnc=sum((ncj-ncmean)^2)
		replace bfn=bfn/n2
		
		* Between firm skill variance: adjusted
		egen bfc_adj=sum((cj-cmean)^2 - (theta_bf*wfc))
		replace bfc_adj=bfc_adj/n2
		egen bfnc_adj=sum((ncj-ncmean)^2 - (theta_bf*wfnc))
		replace bfnc_adj=bfnc_adj/n2
		
		* Components for matching adjustment
		
		* Decomposing between firm variance: assortative matching (am), edu composition (comp), and covariance (cov)
		egen am_c_adj=sum((cj-cpredj)^2 - (theta_bf*adj1c))
		replace am_c_adj=am_c_adj/n2
		egen comp_c_adj=sum((cpredj-cmean)^2 - (theta_bf*adj2c))
		replace comp_c_adj=comp_c_adj/n2
		egen cov_c_adj=sum((cj-cpredj)*(cpredj-cmean) - (theta_bf*adj3c))
		replace cov_c_adj=2*cov_c_adj/n2
		
		egen am_nc_adj=sum((ncj-ncpredj)^2 - (theta_bf*adj1nc))
		replace am_nc_adj=am_nc_adj/n2
		egen comp_nc_adj=sum((ncpredj-ncmean)^2 - (theta_bf*adj2nc))
		replace comp_nc_adj=comp_nc_adj/n2
		egen cov_nc_adj=sum((ncj-ncpredj)*(ncpredj-ncmean) - (theta_bf*adj3nc))
		replace cov_nc_adj=2*cov_nc_adj/n2

		* Save these
		keep year bf* am* comp* cov* n2 nj* N*
		duplicates drop year, force
		save temp/bf_edudecomp_3035_`i'.dta, replace
	
	}
}

* Append into one file
use temp/bf_edudecomp_3035_1986.dta, clear
forvalues i=1987(1)2008 {
	append using temp/bf_edudecomp_3035_`i'
	}
* Insert labels
lab var bfc_adj "Between firm total"
lab var am_c_adj "Assortative matching"
lab var comp_c_adj "Composition"
lab var cov_c_adj "Covariance"
		
lab var bfnc_adj "Between firm total"
lab var am_nc_adj "Assortative matching"
lab var comp_nc_adj "Composition"
lab var cov_nc_adj "Covariance"

save modified/bf_edudecomp_3035_10_ftg.dta, replace

*** Make figure C11X

use modified/bf_edudecomp_3035_10_ftg.dta, clear
graph drop _all
twoway (line am_c_adj comp_c_adj cov_c_adj year), scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("A: Cognitive") name(figC11Xa)
graph save figC11Xa,replace
twoway (line am_nc_adj comp_nc_adj cov_nc_adj year), scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("B: Non-cognitive") name(figC11Xb)
graph save figC11Xb,replace

grc1leg figC11Xa figC11Xb, graphr(c(white)) ycommon legendfrom(figC11Xa)
graph export results/figC11X.eps,replace
graph export results/figC11X.png,replace
graph save results/figC11X.gph,replace

*** figC11: educational sorting excluding ICT ***

foreach x in ftg {
	forvalues i=1986(1)2008 {
		use modified/sample`i'.dta,clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.

		* Drop IT (72) and telecom (32) 
		drop if `x'sni2==72
		drop if `x'sni2==32

		* Rename non-cog
		rename n nc

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen ssyk2=group(edlevel fos_detail)

		* Generate count variable
		g count=1

		* Count actual number of observations at different levels
		egen N=total(count)
		lab var N "Total observations"
		bysort ftgnr: egen Nj=total(count)
		lab var Nj "Firm number of observations"
		bysort ssyk2: egen Nh=total(count)
		lab var Nh "Education group number of observations"
		bysort ftgnr ssyk2: egen Njh=total(count)
		lab var Njh "Firm-by-education group number of observations"
		
		* Keep relevant sample
		keep if sample_3035_10_`x'==1

		* Count observations for sample
		bysort ftgnr: egen nj=total(count)
		lab var nj "Firm number of observations"
		drop if nj<2
		egen n2=total(count)
		lab var n2 "Number of sample observations"
		bysort ssyk2: egen nh=total(count)
		lab var nh "Education group number of sample observations"
		bysort ftgnr ssyk2: egen njh=total(count)
		lab var njh "Firm-by-education group number of sample observations"
		
		*Predicted skills
		*individual
		areg c, absorb(ssyk2)
		predict cresij if e(sample), resid
		predict cpredij if e(sample), xbd
		areg nc, absorb(ssyk2)
		predict ncresij if e(sample), resid
		predict ncpredij if e(sample), xbd

		bysort ftgnr: egen cj=mean(c)
		bysort ftgnr: egen ncj=mean(nc)
		lab var cj "Firm mean cognitive"
		lab var ncj "Firm mean non-cognitive"

		bysort ftgnr: egen cpredj=mean(cpredij)
		bysort ftgnr: egen ncpredj=mean(ncpredij)
		
		* Firm level predicted skills (cjtilde, ncjtilde)
		lab var cpredj "Firm mean predicted cognitive"
		lab var ncpredj "Firm mean predicted non-cognitive"
		
		*firm level mean residual 
		bysort ftgnr: egen cresj=mean(cresij) 	
		bysort ftgnr: egen ncresj=mean(ncresij) 	
		
		* Sample mean skilld
		egen cmean=mean(c)
		egen ncmean=mean(nc)
		
		*** Between firm skill variance and its major components (sample size adjusted)

		* Sample size adjustment parameter (between firm)
		gen theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
		
		* Components for between firm sample size adjustments
		bysort ftgnr: egen wfc=sum((c-cj)^2)
		bysort ftgnr: egen wfnc=sum((nc-ncj)^2)
		
		bysort ftgnr: egen adj1c=sum(((c-cpredij)-(cj-cpredj))^2)
		bysort ftgnr: egen adj1nc=sum(((nc-ncpredij)-(ncj-ncpredj))^2)
		
		bysort ftgnr: egen adj2c=sum((cpredij-cpredj)^2)
		bysort ftgnr: egen adj2nc=sum((ncpredij-ncpredj)^2)
		
		bysort ftgnr: egen adj3c=sum(((c-cpredij) - (cj-cpredj))*(cpredij-cpredj))  
		bysort ftgnr: egen adj3nc=sum(((nc-ncpredij) - (ncj-ncpredj))*(ncpredij-ncpredj))  

		* Between firm variance: not adjusted
		egen bfc=sum((cj-cmean)^2)
		replace bfc=bfc/n2
		egen bfnc=sum((ncj-ncmean)^2)
		replace bfn=bfn/n2
		
		* Between firm skill variance: adjusted
		egen bfc_adj=sum((cj-cmean)^2 - (theta_bf*wfc))
		replace bfc_adj=bfc_adj/n2
		egen bfnc_adj=sum((ncj-ncmean)^2 - (theta_bf*wfnc))
		replace bfnc_adj=bfnc_adj/n2
		
		* Components for matching adjustment
		
		* Decomposing between firm variance: assortative matching (am), edu composition (comp), and covariance (cov)
		egen am_c_adj=sum((cj-cpredj)^2 - (theta_bf*adj1c))
		replace am_c_adj=am_c_adj/n2
		egen comp_c_adj=sum((cpredj-cmean)^2 - (theta_bf*adj2c))
		replace comp_c_adj=comp_c_adj/n2
		egen cov_c_adj=sum((cj-cpredj)*(cpredj-cmean) - (theta_bf*adj3c))
		replace cov_c_adj=2*cov_c_adj/n2
		
		egen am_nc_adj=sum((ncj-ncpredj)^2 - (theta_bf*adj1nc))
		replace am_nc_adj=am_nc_adj/n2
		egen comp_nc_adj=sum((ncpredj-ncmean)^2 - (theta_bf*adj2nc))
		replace comp_nc_adj=comp_nc_adj/n2
		egen cov_nc_adj=sum((ncj-ncpredj)*(ncpredj-ncmean) - (theta_bf*adj3nc))
		replace cov_nc_adj=2*cov_nc_adj/n2

		* Save these
		keep year bf* am* comp* cov* n2 nj* N*
		duplicates drop year, force
		save temp/bf_edudecomp_3035_exICT_`i'.dta, replace
	
	}
}

* Append into one file
use temp/bf_edudecomp_3035_exICT_1986.dta, clear
forvalues i=1987(1)2008 {
	append using temp/bf_edudecomp_3035_exICT_`i'
	}
* Insert labels
lab var bfc_adj "Between firm total"
lab var am_c_adj "Assortative matching"
lab var comp_c_adj "Composition"
lab var cov_c_adj "Covariance"
		
lab var bfnc_adj "Between firm total"
lab var am_nc_adj "Assortative matching"
lab var comp_nc_adj "Composition"
lab var cov_nc_adj "Covariance"

save modified/bf_edudecomp_3035_exICT.dta, replace

*** Make figC11

use modified/bf_edudecomp_3035_exICT.dta, clear
graph drop _all
twoway (line am_c_adj comp_c_adj cov_c_adj year), scheme(s2mono) yscale(range(0,0.15)) graphr(c(white)) legend(cols(2)) subt("A: Cognitive") name(figC11a)
graph save figC11a,replace
twoway (line am_nc_adj comp_nc_adj cov_nc_adj year), scheme(s2mono) yscale(range(0,0.15)) graphr(c(white)) legend(cols(2)) subt("B: Non-cognitive") name(figC11b)
graph save figC11b,replace

grc1leg figC11a figC11b, graphr(c(white)) ycommon legendfrom(figC11a)
graph export results/figC11.eps,replace
graph export results/figC11.png,replace
graph save results/figC11.gph,replace


**************************************************************************************************
****** Fig C12: Wage decompostion for three samples: 1) 30-35 men, 2) 24-60 men, 3) 20-64 all ***** 
**************************************************************************************************

use modified/wagevardecomposition_ftg_10.dta, clear
merge 1:1 year using modified/wagevardecomposition_all_ftg_10.dta
drop _merge
merge 1:1 year  using  modified/wagevardecomposition_2460_ftg_10.dta 
drop _merge

lab var wvarw_adjall "All 20-64"
lab var wvarw_adj2460 "Men 24-60"
lab var wvarw "Men 30-35"

lab var wvarb_adjall "All 20-64"
lab var wvarb_adj2460 "Men 24-60"
lab var wvarb_adj "Men 30-35"
lab var year "Year"

graph drop _all
twoway (line wvarb_adjall wvarb_adj2460 wvarb_adj year), ylabel(0.01(0.01)0.04) yscale(range(0.01,0.04)) scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("A: Between firm") name(figC12a)
twoway (line wvarw_adjall wvarw_adj2460 wvarw_adj year), ylabel(0.03(0.01)0.06) yscale(range(0.03,0.06)) scheme(s2mono) graphr(c(white)) legend(cols(2)) subt("B: Within firm") name(figC12b)
grc1leg figC12a figC12b, graphr(c(white)) legendfrom(figC12a)
graph save results/figC12.gph,replace

********************************************************************************
*** Fig C13. Between firm actual and predicted sorting with and without ICT ****
********************************************************************************

use modified/between_within_actual_counterfactual_exICT.dta, clear 
keep year wvarbhat wvarb_exp
rename wvarbhat wvarbhat_exICT
rename wvarb_exp wvarb_exp_exICT
merge 1:1 year using modified/between_within_actual_counterfactual.dta

lab var wvarbhat "Full sample"
lab var wvarbhat_exICT "Excluding ICT"
lab var wvarb_exp "Full sample"
lab var wvarb_exp_exICT "Excluding ICT"

graph drop _all
twoway (line wvarbhat wvarbhat_exICT year), scheme(s2mono) graphr(c(white)) legend(cols(2)) ymtick(0(0.01)0.04) ylabel(0(0.01)0.04) yscale(range(0 0.04)) subt("A: Actual") name(figC13a)
twoway (line wvarb_exp wvarb_exp_exICT year), scheme(s2mono) graphr(c(white)) legend(cols(2)) ymtick(0(0.01)0.04) ylabel(0(0.01)0.04) yscale(range(0 0.04)) subt("B: Predicted")  name(figC13b)
grc1leg figC13a figRC13b, graphr(c(white)) ycommon legendfrom(figC13a)
graph export results/figC13.eps,replace
graph export results/figC13.png,replace
graph save results/figC13.gph,replace

**************************************
*** Table C1. Simulated variances  ***
**************************************

foreach j in 1986 2008{
forvalues i=1(1)1000{
use lopnr fos fos_detail edyr c n sample_3035_10_ftg ftgsni* ftgstorl_ftg age sex ftgnr year using modified/sample`j', clear

keep if sample_3035_10_ftg==1

*This part generate occupation proxy by combining field of study and level of education
gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
lab def edlevellab 1 "Compulsory schooling or less"
lab def edlevellab 2 "2-year secondary",add 
lab def edlevellab 3 "3-year secondary",add 
lab def edlevellab 4 "Some tertiary",add 
lab def edlevellab 5 "At least 3-year tertiary",add 
lab val edlevel edlevellab
egen yrke=group(edlevel fos_detail)


*create random assignment of cognitive and non cognitive skill 
g lop=_n
preserve
keep c n yrke edyr
g random=runiform()
sort random
g lop=_n
drop random
sort lop
save randomc,replace
restore
drop c n edyr yrke
sort lop
merge 1:1 lop using randomc
drop _merge

*1.create variables
g count=1

*Actual skill means
	*industry
bysort ftgsni2: egen ck=mean(c) 
bysort ftgsni2: egen nk=mean(n) 
bysort ftgsni2: egen ek=mean(edyr)

	*firm
bysort ftgnr: egen cj=mean(c) 
bysort ftgnr: egen nj=mean(n) 
bysort ftgnr: egen ej=mean(edyr) 

	*firm yrke
bysort ftgnr yrke: egen chj=mean(c) 
bysort ftgnr yrke: egen nhj=mean(n) 
bysort ftgnr yrke: egen ehj=mean(edyr) 

	*yrke
bysort yrke: egen ch=mean(c) 
bysort yrke: egen nh=mean(n) 
bysort yrke: egen eh=mean(edyr) 

	*sample
egen cbar=mean(c)
egen nbar=mean(n)
egen ebar=mean(edyr)

*Observed samples and sizes
rename ftgstorl Nj
bysort ftgnr yrke: egen N2hj=total(count) 
bysort yrke: egen N2h=total(count) 
bysort ftgnr: egen N2j=total(count) 
egen N2=total(count) 

*Predicted skills
	*individual
areg c, absorb(yrke)
predict cijtilde if e(sample),xbd
predict cijres if e(sample), resid
areg n, absorb(yrke)
predict nijtilde if e(sample),xbd
predict nijres if e(sample), resid
areg edyr, absorb(yrke)
predict eijtilde if e(sample), xbd
predict eijres if e(sample), resid


bysort ftgnr: egen cjres=mean(cijres)
bysort ftgnr: egen njres=mean(nijres)
bysort ftgnr: egen ejres=mean(eijres)

g cjtilde=cj-cjres
g njtilde=nj-njres
g ejtilde=ej-ejres

rename edyr e

*Components for (corrected and uncorrected) variances (to be collapsed)

	*within firm technical 
g wt_c=(cijtilde-cjtilde)^2
g wt_n=(nijtilde-njtilde)^2
g wt_e=(eijtilde-ejtilde)^2

	*within firm assortative 
g wa_c=((c-cijtilde)-(cj-cjtilde))^2
g wa_n=((n-nijtilde)-(nj-njtilde))^2
g wa_e=((e-eijtilde)-(ej-ejtilde))^2

	*within firm total simple
g ws_c=(c-cj)^2
g ws_n=(n-nj)^2
g ws_e=(e-ej)^2

	*within firm covariance technical assortative 
g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))

	*within firm total decomposed (to check results should after collapsed be equal to ws_X )
g wtot_c=wt_c+wa_c+2*wat_c
g wtot_n=wt_n+wa_n+2*wat_n
g wtot_e=wt_e+wa_e+2*wat_e

	*between firm technical
g bt_c=(cjtilde-cbar)^2
g bt_n=(njtilde-nbar)^2
g bt_e=(ejtilde-ebar)^2

	*between firm assortative
g ba_c=(cj-cjtilde)^2
g ba_n=(nj-njtilde)^2
g ba_e=(ej-ejtilde)^2

	*between firm total simple
g bs_c=(cj-cbar)^2
g bs_n=(nj-nbar)^2
g bs_e=(ej-ebar)^2

	*between firm covariance technical assortative
g bat_c=(cjtilde-cbar)*(cj-cjtilde)
g bat_n=(njtilde-nbar)*(nj-njtilde)
g bat_e=(ejtilde-ebar)*(ej-ejtilde)

	*between firm total decomposed
g btot_c=bt_c+ba_c+2*bat_c
g btot_n=bt_n+ba_n+2*bat_n
g btot_e=bt_e+ba_e+2*bat_e

	*total technical
g tt_c=(cijtilde-cbar)^2 
g tt_n=(nijtilde-nbar)^2 
g tt_e=(eijtilde-ebar)^2 

	*total assortative
g ta_c=(c-cijtilde)^2
g ta_n=(n-nijtilde)^2
g ta_e=(e-eijtilde)^2

	*total simple
g ts_c=(c-cbar)^2
g ts_n=(n-nbar)^2
g ts_e=(e-ebar)^2
	
	*covariance CS NCS
g wcov=(c-cj)*(n-nj)	

	*component for corr_bi (this goes into the industry matrix)
g corr_bi_c=(c-ck)^2
g corr_bi_n=(n-nk)^2
g corr_bi_e=(e-ek)^2


*2.Collapse to firm level
collapse (sum) w* t* cijtilde nijtilde eijtilde cijres nijres eijres c n e corr_bi* (mean) b* Nj N2j N2 cj nj ej ck nk ek cbar nbar ebar, by (year ftgnr ftgsni2)

*sample correction firm level
g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))


*components for corrected variances

	*within firm total simple corrected
g corr_ws_c=ws_c*thetaj_w*N2j
g corr_ws_n=ws_n*thetaj_w*N2j
g corr_ws_e=ws_e*thetaj_w*N2j

	*within firm technical corrected
g corr_wt_c=wt_c*thetaj_w*N2j
g corr_wt_n=wt_n*thetaj_w*N2j
g corr_wt_e=wt_e*thetaj_w*N2j

	*within firm assortative corrected
g corr_wa_c=wa_c*thetaj_w*N2j
g corr_wa_n=wa_n*thetaj_w*N2j
g corr_wa_e=wa_e*thetaj_w*N2j

	*within firm covariance technical assortative corrected
g corr_wat_c=wat_c*thetaj_w*N2j
g corr_wat_n=wat_n*thetaj_w*N2j
g corr_wat_e=wat_e*thetaj_w*N2j

	*within firm total decomposed corrected
g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e

	*between firm total simple corrected
g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)

	*between firm technical corrected
g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)

	*between firm assortative corrected
g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)

	*between firm covariance technical assortative corrected
g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)

	*between firm total decomposed corrected
g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e

	*covariance CS NCS corrected
g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
g corr_wcov=N2j*thetaj_w*wcov


*components for uncorrected variances

	*between firm technical
replace bt_c=bt_c*N2j
replace bt_n=bt_n*N2j
replace bt_e=bt_e*N2j

	*between firm assortative
replace ba_c=ba_c*N2j
replace ba_n=ba_n*N2j
replace ba_e=ba_e*N2j

	*between firm covariance technical assortative
replace bat_c=bat_c*N2j
replace bat_n=bat_n*N2j
replace bat_e=bat_e*N2j

	*between firm total simple
replace bs_c=bs_c*N2j
replace bs_n=bs_n*N2j
replace bs_e=bs_e*N2j

	*between firm total decomposed
replace btot_c=btot_c*N2j
replace btot_n=btot_n*N2j
replace btot_e=btot_e*N2j

	*covariance CS NCS
g bcov=N2j*(cj-cbar)*(nj-nbar)

*components for bfwi variance
g bfwi_c=N2j*(cj-ck)^2
g bfwi_n=N2j*(nj-nk)^2
g bfwi_e=N2j*(ej-ek)^2


*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

*final uncorrected variances 
	*within firm technical
replace wt_c=wt_c*1/N2
replace wt_n=wt_n*1/N2
replace wt_e=wt_e*1/N2

	*within firm assortative
replace wa_c=wa_c*1/N2
replace wa_n=wa_n*1/N2
replace wa_e=wa_e*1/N2

	*within firm covariance assortative technichal
replace wat_c=wat_c*2/N2
replace wat_n=wat_n*2/N2
replace wat_e=wat_e*2/N2

	*within firm total decomposed
replace wtot_c=wtot_c*1/N2
replace wtot_n=wtot_n*1/N2
replace wtot_e=wtot_e*1/N2

	*within firm total simple
replace ws_c=ws_c*1/N2
replace ws_n=ws_n*1/N2
replace ws_e=ws_e*1/N2

	*between firm technical
replace bt_c=bt_c*1/N2
replace bt_n=bt_n*1/N2
replace bt_e=bt_e*1/N2

	*between firm assortative
replace ba_c=ba_c*1/N2
replace ba_n=ba_n*1/N2
replace ba_e=ba_e*1/N2

	*between firm covariance assortative technical
replace bat_c=bat_c*2/N2
replace bat_n=bat_n*2/N2
replace bat_e=bat_e*2/N2

	*between firm total simple
replace bs_c=bs_c*1/N2
replace bs_n=bs_n*1/N2
replace bs_e=bs_e*1/N2

	*between firm total decomposed
replace btot_c=btot_c*1/N2
replace btot_n=btot_n*1/N2
replace btot_e=btot_e*1/N2

	*total technical
replace tt_c=tt_c*1/N2
replace tt_n=tt_n*1/N2
replace tt_e=tt_e*1/N2

	*total assortative
replace ta_c=ta_c*1/N2
replace ta_n=ta_n*1/N2
replace ta_e=ta_e*1/N2

	*total simple
replace ts_c=ts_c*1/N2
replace ts_n=ts_n*1/N2
replace ts_e=ts_e*1/N2

	*covariances skill
replace bcov=bcov*1/N2
replace wcov=wcov*1/N2

*final sample corrected variances 

	*within firm technical corrected
replace corr_wt_c=corr_wt_c*1/N2
replace corr_wt_n=corr_wt_n*1/N2
replace corr_wt_e=corr_wt_e*1/N2

	*within firm assortative corrected
replace corr_wa_c=corr_wa_c*1/N2
replace corr_wa_n=corr_wa_n*1/N2
replace corr_wa_e=corr_wa_e*1/N2

	*within firm covariance assortative technichal corrected
replace corr_wat_c=corr_wat_c*2/N2
replace corr_wat_n=corr_wat_n*2/N2
replace corr_wat_e=corr_wat_e*2/N2

	*within firm total decomposed corrected
replace corr_wtot_c=corr_wtot_c*1/N2
replace corr_wtot_n=corr_wtot_n*1/N2
replace corr_wtot_e=corr_wtot_e*1/N2

	*within firm total simple corrected
replace corr_ws_c=corr_ws_c*1/N2
replace corr_ws_n=corr_ws_n*1/N2
replace corr_ws_e=corr_ws_e*1/N2

	*between firm technical
replace corr_bt_c=corr_bt_c*1/N2
replace corr_bt_n=corr_bt_n*1/N2
replace corr_bt_e=corr_bt_e*1/N2

	*between firm assortative
replace corr_ba_c=corr_ba_c*1/N2
replace corr_ba_n=corr_ba_n*1/N2
replace corr_ba_e=corr_ba_e*1/N2

	*between firm covariance assortative technical
replace corr_bat_c=corr_bat_c*2/N2
replace corr_bat_n=corr_bat_n*2/N2
replace corr_bat_e=corr_bat_e*2/N2

	*between firm total simple
replace corr_bs_c=corr_bs_c*1/N2
replace corr_bs_n=corr_bs_n*1/N2
replace corr_bs_e=corr_bs_e*1/N2

	*between firm total decomposed
replace corr_btot_c=corr_btot_c*1/N2
replace corr_btot_n=corr_btot_n*1/N2
replace corr_btot_e=corr_btot_e*1/N2

	*covariances skill
replace corr_bcov=corr_bcov*1/N2
replace corr_wcov=corr_wcov*1/N2

gen sim=`i'
save decomp_sim_`j'_`i',replace
}
}


foreach j in 1986 2008{
use  decomp_sim_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_sim_`j'_`i'
	}
save temp/decomp_sim_`j',replace
}
clear
foreach j in 1986 2008{
forvalues i=1(1)1000{
erase decomp_sim_`j'_`i'.dta	
}
}

foreach j in 1986 2008{
use temp/decomp_sim_`j'
collapse (p1) p1_corr_ws_c=corr_ws_c p1_corr_ws_n=corr_ws_n p1_corr_wt_c=corr_wt_c p1_corr_wt_n=corr_wt_n p1_corr_wa_c=corr_wa_c p1_corr_wa_n=corr_wa_n p1_corr_wat_c=corr_wat_c p1_corr_wat_n=corr_wat_n p1_corr_bs_c=corr_bs_c p1_corr_bs_n=corr_bs_n p1_corr_bt_c=corr_bt_c p1_corr_bt_n=corr_bt_n p1_corr_ba_c=corr_ba_c p1_corr_ba_n=corr_ba_n p1_corr_bat_c=corr_bat_c p1_corr_bat_n=corr_bat_n p1_corr_wcov=corr_wcov p1_corr_bcov=corr_bcov (p99) p99_corr_ws_c=corr_ws_c p99_corr_ws_n=corr_ws_n p99_corr_wt_c=corr_wt_c p99_corr_wt_n=corr_wt_n p99_corr_wa_c=corr_wa_c p99_corr_wa_n=corr_wa_n p99_corr_wat_c=corr_wat_c p99_corr_wat_n=corr_wat_n p99_corr_bs_c=corr_bs_c p99_corr_bs_n=corr_bs_n p99_corr_bt_c=corr_bt_c p99_corr_bt_n=corr_bt_n p99_corr_ba_c=corr_ba_c p99_corr_ba_n=corr_ba_n p99_corr_bat_c=corr_bat_c p99_corr_bat_n=corr_bat_n p99_corr_wcov=corr_wcov p99_corr_bcov=corr_bcov (p50) p50_corr_ws_c=corr_ws_c p50_corr_ws_n=corr_ws_n p50_corr_wt_c=corr_wt_c p50_corr_wt_n=corr_wt_n p50_corr_wa_c=corr_wa_c p50_corr_wa_n=corr_wa_n p50_corr_wat_c=corr_wat_c p50_corr_wat_n=corr_wat_n p50_corr_bs_c=corr_bs_n p50_corr_bs_n=corr_bs_n p50_corr_bt_c=corr_bt_c p50_corr_bt_n=corr_bt_n p50_corr_ba_c=corr_ba_c p50_corr_ba_n=corr_ba_n p50_corr_bat_c=corr_bat_c p50_corr_bat_n=corr_bat_n p50_corr_wcov=corr_wcov p50_corr_bcov=corr_bcov
g year=`j'
save temp/sim`j',replace
}

clear
use temp/sim1986
append using temp/sim2008
sort year
save modified/simulations,replace

use modified/vardecomp_aggregate,clear
keep if year==1986 | year==2008
keep year corr_ws_c_ftg_10 corr_ws_n_ftg_10 corr_wt_c_ftg_10 corr_wt_n_ftg_10 corr_wa_c_ftg_10 corr_wa_n_ftg_10 corr_wat_c_ftg_10 corr_wat_n_ftg_10 corr_wcov_ftg_10 corr_bs_c_ftg_10 corr_bs_n_ftg_10 corr_bt_c_ftg_10 corr_bt_n_ftg_10 corr_ba_c_ftg_10 corr_ba_n_ftg_10 corr_bat_c_ftg_10 corr_bat_n_ftg_10 corr_bcov_ftg_10
rename corr_ws_c_ftg_10 corr_ws_c
rename corr_ws_n_ftg_10 corr_ws_n
rename corr_wt_c_ftg_10 corr_wt_c
rename corr_wt_n_ftg_10 corr_wt_n
rename corr_wa_c_ftg_10 corr_wa_c
rename corr_wa_n_ftg_10 corr_wa_n
rename corr_wat_c_ftg_10 corr_wat_c
rename corr_wat_n_ftg_10 corr_wat_n
rename corr_wcov_ftg_10 corr_wcov
rename corr_bs_c_ftg_10 corr_bs_c
rename corr_bs_n_ftg_10 corr_bs_n
rename corr_bt_c_ftg_10 corr_bt_c
rename corr_bt_n_ftg_10 corr_bt_n
rename corr_ba_c_ftg_10 corr_ba_c
rename corr_ba_n_ftg_10 corr_ba_n
rename corr_bat_c_ftg_10 corr_bat_c
rename corr_bat_n_ftg_10 corr_bat_n
rename corr_bcov_ftg_10 corr_bcov
sort year
merge 1:1 year using modified/simulations
drop if _merge==1 
drop _merge

outsheet using results/tableC11.csv,replace

preserve
keep if year==1986
keep corr_ws_c p1_corr_ws_c p50_corr_ws_c p99_corr_ws_c corr_wt_c p1_corr_wt_c p50_corr_wt_c p99_corr_wt_c corr_wa_c p1_corr_wa_c p50_corr_wa_c p99_corr_wa_c corr_wat_c p1_corr_wat_c p50_corr_wat_c p99_corr_wat_c corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_c p1_corr_bs_c p50_corr_bs_c p99_corr_bs_c corr_bt_c p1_corr_bt_c p50_corr_bt_c p99_corr_bt_c corr_ba_c p1_corr_ba_c p50_corr_ba_c p99_corr_ba_c corr_bat_c p1_corr_bat_c p50_corr_bat_c p99_corr_bat_c corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
order corr_ws_c p1_corr_ws_c p50_corr_ws_c p99_corr_ws_c corr_wt_c p1_corr_wt_c p50_corr_wt_c p99_corr_wt_c corr_wa_c p1_corr_wa_c p50_corr_wa_c p99_corr_wa_c corr_wat_c p1_corr_wat_c p50_corr_wat_c p99_corr_wat_c corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_c p1_corr_bs_c p50_corr_bs_c p99_corr_bs_c corr_bt_c p1_corr_bt_c p50_corr_bt_c p99_corr_bt_c corr_ba_c p1_corr_ba_c p50_corr_ba_c p99_corr_ba_c corr_bat_c p1_corr_bat_c p50_corr_bat_c p99_corr_bat_c corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
outsheet using results/tableC11_1986_c.csv,replace
restore

preserve
keep if year==1986
keep corr_ws_n p1_corr_ws_n p50_corr_ws_n p99_corr_ws_n corr_wt_n p1_corr_wt_n p50_corr_wt_n p99_corr_wt_n corr_wa_n p1_corr_wa_n p50_corr_wa_n p99_corr_wa_n corr_wat_n p1_corr_wat_n p50_corr_wat_n p99_corr_wat_n corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_n p1_corr_bs_n p50_corr_bs_n p99_corr_bs_n corr_bt_n p1_corr_bt_n p50_corr_bt_n p99_corr_bt_n corr_ba_n p1_corr_ba_n p50_corr_ba_n p99_corr_ba_n corr_bat_n p1_corr_bat_n p50_corr_bat_n p99_corr_bat_n corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
order corr_ws_n p1_corr_ws_n p50_corr_ws_n p99_corr_ws_n corr_wt_n p1_corr_wt_n p50_corr_wt_n p99_corr_wt_n corr_wa_n p1_corr_wa_n p50_corr_wa_n p99_corr_wa_n corr_wat_n p1_corr_wat_n p50_corr_wat_n p99_corr_wat_n corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_n p1_corr_bs_n p50_corr_bs_n p99_corr_bs_n corr_bt_n p1_corr_bt_n p50_corr_bt_n p99_corr_bt_n corr_ba_n p1_corr_ba_n p50_corr_ba_n p99_corr_ba_n corr_bat_n p1_corr_bat_n p50_corr_bat_n p99_corr_bat_n corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
outsheet using results/tableC11_1986_n.csv,replace
restore

preserve
keep if year==2008
keep corr_ws_c p1_corr_ws_c p50_corr_ws_c p99_corr_ws_c corr_wt_c p1_corr_wt_c p50_corr_wt_c p99_corr_wt_c corr_wa_c p1_corr_wa_c p50_corr_wa_c p99_corr_wa_c corr_wat_c p1_corr_wat_c p50_corr_wat_c p99_corr_wat_c corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_c p1_corr_bs_c p50_corr_bs_c p99_corr_bs_c corr_bt_c p1_corr_bt_c p50_corr_bt_c p99_corr_bt_c corr_ba_c p1_corr_ba_c p50_corr_ba_c p99_corr_ba_c corr_bat_c p1_corr_bat_c p50_corr_bat_c p99_corr_bat_c corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
order corr_ws_c p1_corr_ws_c p50_corr_ws_c p99_corr_ws_c corr_wt_c p1_corr_wt_c p50_corr_wt_c p99_corr_wt_c corr_wa_c p1_corr_wa_c p50_corr_wa_c p99_corr_wa_c corr_wat_c p1_corr_wat_c p50_corr_wat_c p99_corr_wat_c corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_c p1_corr_bs_c p50_corr_bs_c p99_corr_bs_c corr_bt_c p1_corr_bt_c p50_corr_bt_c p99_corr_bt_c corr_ba_c p1_corr_ba_c p50_corr_ba_c p99_corr_ba_c corr_bat_c p1_corr_bat_c p50_corr_bat_c p99_corr_bat_c corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
outsheet using results/tableC11_2008_c.csv,replace
restore

preserve
keep if year==2008
keep corr_ws_n p1_corr_ws_n p50_corr_ws_n p99_corr_ws_n corr_wt_n p1_corr_wt_n p50_corr_wt_n p99_corr_wt_n corr_wa_n p1_corr_wa_n p50_corr_wa_n p99_corr_wa_n corr_wat_n p1_corr_wat_n p50_corr_wat_n p99_corr_wat_n corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_n p1_corr_bs_n p50_corr_bs_n p99_corr_bs_n corr_bt_n p1_corr_bt_n p50_corr_bt_n p99_corr_bt_n corr_ba_n p1_corr_ba_n p50_corr_ba_n p99_corr_ba_n corr_bat_n p1_corr_bat_n p50_corr_bat_n p99_corr_bat_n corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
order corr_ws_n p1_corr_ws_n p50_corr_ws_n p99_corr_ws_n corr_wt_n p1_corr_wt_n p50_corr_wt_n p99_corr_wt_n corr_wa_n p1_corr_wa_n p50_corr_wa_n p99_corr_wa_n corr_wat_n p1_corr_wat_n p50_corr_wat_n p99_corr_wat_n corr_wcov p1_corr_wcov p50_corr_wcov p99_corr_wcov corr_bs_n p1_corr_bs_n p50_corr_bs_n p99_corr_bs_n corr_bt_n p1_corr_bt_n p50_corr_bt_n p99_corr_bt_n corr_ba_n p1_corr_ba_n p50_corr_ba_n p99_corr_ba_n corr_bat_n p1_corr_bat_n p50_corr_bat_n p99_corr_bat_n corr_bcov p1_corr_bcov p50_corr_bcov p99_corr_bcov
outsheet using results/tableC11_2008_n.csv,replace
restore


*****************************************************
*** Table C2. Distribution of firm average skills ***
*****************************************************
use modified/vardecomp_unit_ftg_10,clear
keep if year==1986 | year==2008

* Summmary stats table
gen sd_125c=0
replace sd_125c=1 if cj>=1.25
gen sd_1c=0
replace sd_1c=1 if cj>=1
gen sd_075c=0
replace sd_075c=1 if cj>=0.75
gen sd_05c=0
replace sd_05c=1 if cj>=0.5
gen sd_025c=0
replace sd_025c=1 if cj>=0.25
gen sd_0c=0
replace sd_0c=1 if cj>=0 
gen sd_n0c=0
replace sd_n0c=1 if cj<0 
gen sd_n025c=0
replace sd_n025c=1 if cj<=-0.25
gen sd_n05c=0
replace sd_n05c=1 if cj<=-0.5 
gen sd_n075c=0
replace sd_n075c=1 if cj<=-0.75
gen sd_n01c=0
replace sd_n01c=1 if cj<=-1
gen sd_n0125c=0
replace sd_n0125c=1 if cj<=-1.25

gen sd_125n=0
replace sd_125n=1 if nj>=1.25
gen sd_1n=0
replace sd_1n=1 if nj>=1
gen sd_075n=0
replace sd_075n=1 if nj>=0.75 
gen sd_05n=0
replace sd_05n=1 if nj>=0.5 
gen sd_025n=0
replace sd_025n=1 if nj>=0.25 
gen sd_0n=0
replace sd_0n=1 if nj>=0
gen sd_n0n=0
replace sd_n0n=1 if nj<0
gen sd_n025n=0
replace sd_n025n=1 if nj<=-0.25
gen sd_n05n=0
replace sd_n05n=1 if nj<=-0.5
gen sd_n075n=0
replace sd_n075n=1 if nj<=-0.75
gen sd_n01n=0
replace sd_n01n=1 if nj<=-1
gen sd_n0125n=0
replace sd_n0125n=1 if nj<=-1.25

collapse (mean) meanc=cj meann=nj sd_125c sd_1c sd_075c sd_05c sd_025c sd_0c sd_n0c sd_n025c sd_n05c sd_n075c sd_n01c sd_n0125c sd_125n sd_1n sd_075n sd_05n sd_025n sd_0n sd_n0n sd_n025n sd_n05n sd_n075n sd_n01n sd_n0125n (sd) sdc=cj sdn=nj [aw=N2j], by(year)
drop if year==.

reshape long mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125, i(year) j(skill) string
keep if skill=="c" | skill=="n"

lab var mean "Mean" 
lab var sd "Std"
lab var sd_125 "Above 1.25 std" 
lab var sd_1 "Above 1 std"
lab var sd_075 "Above .75 std"
lab var sd_05 "Above .5 std"
lab var sd_025 "Above .25 std"
lab var sd_0 "Above 0 std"
lab var sd_n0 "Below 0 std"
lab var sd_n025 "Below -.25 std"
lab var sd_n05 "Below -.5 std"
lab var sd_n075 "Below -0.75 std"
lab var sd_n01 "Below -1 std"
lab var sd_n0125 "Below -1.25 std"

outreg2 mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125 if year==1986 & skill=="c" using results/tableC2.rtf, replace label dec(3) sum(log) eqkeep(mean) sortvar(mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125) ctitle(1986, 2008, 1986, 2008) cttop(Cognitive,1986)
outreg2 mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125 if year==2008 & skill=="c" using results/tableC2.rtf, append label dec(3) sum(log) eqkeep(mean) sortvar(mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125) cttop(,2008)
outreg2 mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125 if year==1986 & skill=="n" using results/tableC2.rtf, append label dec(3) sum(log) eqkeep(mean) sortvar(mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125) cttop(Non-cognitive,1986)
outreg2 mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125 if year==2008 & skill=="n" using results/tableC2.rtf, append label dec(3) sum(log) eqkeep(mean) sortvar(mean sd sd_125 sd_1 sd_075 sd_05 sd_025 sd_0 sd_n0 sd_n025 sd_n05 sd_n075 sd_n01 sd_n0125) cttop(,2008)
* Note: Firm level skill means, standard deviations, and the share of employees in firms with different mean skill levels. Weighted by the number of 30-35 year old men employed.

******************************************************************
*** Table C3. Decomposing change in within-firm skill variance ***
******************************************************************

use modified/vardecomp_industry_ftg_10,clear
keep ftgsni2 year Nk N2k N2 corr_ws_c corr_ws_n
keep if year==1986 | year==2008

reshape wide Nk N2k N2 corr_ws_c corr_ws_n, i(ftgsni2) j(year)

g alfa1986=N2k1986/N21986*100
g alfa2008=N2k2008/N22008*100
drop if missing(corr_ws_c2008)
drop if missing(corr_ws_c1986)

g dalfa=alfa2008-alfa1986
g dws_c=corr_ws_c2008-corr_ws_c1986
g dws_n=corr_ws_n2008-corr_ws_n1986

g dwithinc=alfa1986*dws_c/100
g dwithinn=alfa1986*dws_n/100

g dsizec=dalfa*corr_ws_c1986/100
g dsizen=dalfa*corr_ws_n1986/100

g covarc=dalfa*dws_c/100
g covarn=dalfa*dws_n/100

keep ftgsni2 dwithinc dwithinn dsizec dsizen covarc covarn
reshape long dwithin dsize covar, i(ftgsni2) j(skill) string
collapse (sum) dwithin dsize covar, by(skill)

lab var dwithin "Change within-firm variance"
lab var dsize "Change in industry size"
lab var covar "Covariance"

outreg2 dwithin dsize covar if skill=="c" using results/tableC3.rtf, replace lab dec(3) sideway sortvar(dwithin dsize covar) sum(log) eqkeep(mean) cttop("Cognitive")
outreg2 dwithin dsize covar if skill=="n" using results/tableC3.rtf, append lab dec(3) sideway sortvar(dwithin dsize covar) sum(log) eqkeep(mean) cttop("Non-cognitive")
* Note: Changes in within-firm variance attributed to changes in industry mean variance, the size of industries, and the covariance between these. The sample consists of 30-35 year-old men employed at firms with at least 10 employees.

***********************************
*** Table C4. Wages by industry ***
***********************************

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(22)2008 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample
		keep if sample_3035_`j'_`x'==1
		
		*** Wage means
		*industry
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*sample
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		*Observed samples and sizes
		* rename ftgstorl_`x' Nj
		bysort `x'nr: egen N2j=total(count) 
		egen N2=total(count) 

		*within firm wage variance 
		g w_wpred=(lnwpred_`x'-lnwpredj)^2
		g w_wage=(lnwage_`x'-lnwagej)^2

		* Collapse to firm/plant level
		collapse (sum) w* lnwpred_`x' lnwage_`x' (mean) lnwpredj lnwagej ftgstorl_`x' Nj N2j N2 lnwpredk lnwagek lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		* Collapse to industry
		collapse (sum) w* Nk=Nj N2k=N2j (mean) N2 lnwpredk lnwagek lnwpredbar lnwagebar, by(year `x'sni2)

		***final industry level uncorrected variances

		*within firm/plant total variance 
		replace w_wpred=w_wpred*1/N2k
		replace w_wage=w_wage*1/N2k

		save temp/within_wage_industry`i',replace
	
				}
			}
		}

use temp/within_wage_industry1986, clear
append using temp/within_wage_industry2008

reshape wide w_wpred w_wage Nk N2k N2 lnwpredk lnwagek lnwpredbar lnwagebar, i(ftgsni2) j(year)

g kod=ftgsni2

lab def snilabel 01 "Agriculture, hunting and related service activities" ,add
lab def snilabel 02 "Forestry, logging and related service activities" ,add
lab def snilabel 05 "Fishing, operation of fish hatcheries and fish farms" ,add
lab def snilabel 10  "Mining of coal and lignite, extraction of peat" ,add
lab def snilabel 11  "Extraction of crude petroleum and natural gas" ,add
lab def snilabel 12  "Mining of uranium and thorium ores" ,add
lab def snilabel 13  "Mining of metal ores" ,add
lab def snilabel 14  "Other mining and quarrying" ,add
lab def snilabel 15  "Manufacture of food products and beverages" ,add
lab def snilabel 16  "Manufacture of tobacco products" ,add
lab def snilabel 17  "Manufacture of textiles" ,add
lab def snilabel 18  "Manufacture of wearing apparel" ,add
lab def snilabel 19  "Tanning and dressing of leather" ,add
lab def snilabel 20  "Manufacture of wood and of products of wood and cork, except furniture" ,add
lab def snilabel 21  "Manufacture of paper and paper products" ,add
lab def snilabel 22  "Publishing, printing and reproduction of recorded media" ,add
lab def snilabel 23  "Manufacture of coke, refined petroleum products and nuclear fuel" ,add
lab def snilabel 24  "Manufacture of chemicals and chemical products" ,add
lab def snilabel 25  "Manufacture of rubber and plastics products" ,add
lab def snilabel 26  "Manufacture of other nonmetallic mineral products" ,add
lab def snilabel 27  "Manufacture of basic metals" ,add
lab def snilabel 28  "Manufacture of fabricated metal products, except machinery and equipment" ,add
lab def snilabel 29  "Manufacture of machinery and equipment n.e.c." ,add
lab def snilabel 30  "Manufacture of office, accounting and computing machinery" ,add
lab def snilabel 31  "Manufacture of electrical machinery and apparatus n.e.c." ,add
lab def snilabel 32  "Manufacture of radio, television and communication equipment and apparatus" ,add
lab def snilabel 33  "Manufacture of medical, precision and optical instruments, watches and clocks" ,add
lab def snilabel 34  "Manufacture of motor vehicles, trailers and semitrailers" ,add
lab def snilabel 35  "Manufacture of other transport equipment" ,add
lab def snilabel 36  "Manufacture of furniture, manufacturing n.e.c." ,add
lab def snilabel 37  "Recycling" ,add
lab def snilabel 40  "Electricity, gas, steam and hot water supply" ,add
lab def snilabel 41  "Collection, purification and distribution of water" ,add
lab def snilabel 45  "Construction" ,add
lab def snilabel 50  "Sale, maintenance and repair of motor vehicles and motorcycles, retail sale of automotive fuel" ,add
lab def snilabel 51  "Wholesale trade and commission trade, except of motor vehicles and motorcycles" ,add
lab def snilabel 52  "Retail trade, except of motor vehicles and motorcycles, repair of personal and household goods" ,add
lab def snilabel 55  "Hotels and restaurants" ,add
lab def snilabel 60  "Land transport, transport via pipelines" ,add
lab def snilabel 61  "Water transport" ,add
lab def snilabel 62  "Air transport" ,add
lab def snilabel 63  "Supporting and auxiliary transport activities, activities of travel agencies" ,add
lab def snilabel 64  "Post and telecommunications" ,add
lab def snilabel 65  "Financial intermediation, except insurance and pension funding" ,add
lab def snilabel 66  "Insurance and pension funding, except compulsory social security",add
lab def snilabel 67  "Activities auxiliary to financial intermediation" ,add
lab def snilabel 70  "Real estate activities" ,add
lab def snilabel 71  "Renting of machinery and equipment without operator and of personal and household goods" ,add
lab def snilabel 72  "Computer and related activities" ,add
lab def snilabel 73  "Research and development" ,add
lab def snilabel 74  "Other business activities" ,add
lab def snilabel 75  "Public administration and defence, compulsory social security" ,add
lab def snilabel 80  "Education" ,add
lab def snilabel 85  "Health and social work" ,add
lab def snilabel 90  "Sewage and refuse disposal, sanitation and similar activities" ,add
lab def snilabel 91  "Activities of membership organizations n.e.c." ,add
lab def snilabel 92  "Recreational, cultural and sporting activities" ,add
lab def snilabel 93  "Other service activities" ,add
lab def snilabel 95  "Private households with employed persons" ,add
lab def snilabel 99  "Extraterritorial organizations and bodies" ,add

lab val ftgsni2 snilabel

g alfa1986=N2k1986/N21986*100
g alfa2008=N2k2008/N22008*100
drop if missing(w_wpred1986)
drop if missing(w_wpred2008)

g dalfa=alfa2008-alfa1986
g dwithin=w_wpred2008-w_wpred1986
g dwpred=lnwpredk2008-lnwpredk1986

sort lnwpredk1986

drop if alfa1986<1.5 & alfa2008<1.5

*** Table C4
keep kod ftgsni2 lnwpredk1986 dwpred w_wpred1986 dwithin alfa1986 dalfa
order  kod ftgsni2 lnwpredk1986 dwpred w_wpred1986 dwithin alfa1986 dalfa
gsort -lnwpredk1986
export delimited  using results/tableC4.csv,replace

outsheet using results/tableC4.csv,replace
mkmat ftgsni2 ftgsni2 lnwpredk1986 dwpred w_wpred1986 dwithin alfa1986 dalfa, matrix(A)  rownames(ftgsni2)
matrix colnames A = ftgsni2 lnwpredk1986 dwpred w_wpred1986 dwithin alfa1986 dalfa
outtable using results/tableC4.tex, mat(A) format (%12.2f) nobox replace
outtable using results/tableC4.rft, mat(A) format (%12.2f) nobox replace

********************
**** Appendix D ****
********************

***************************************************
*** Figure D1: Loadings of c and n on p (AKM) *****
***************************************************

* Figure D1
use modified/akm_factor_loadings_3035, clear
lab var year "Year"
line betac_3035 betan_3035 r2_3035 year, ylabel(0.1(0.05)0.4) yscale(range(0.1 0.4)) scheme(s2mono) graphr(c(white)) legend(cols(1)) ytitle("Coeff/R2")
graph save results/figD1.gph,replace
graph export results/figD1.eps,replace
graph export results/figD1.png,replace

********************************************************************************
**** Figue D2: Standard deviation of worker and firm effects (full sample) *****
********************************************************************************

use modified/akm_rolling_4_2.dta, clear
*gen praw=.
*gen fraw=.
forvalues i=1990(1)2005 {
	sum praw`i'
	gen pmean`i'=r(mean)
	gen psd`i'=r(sd)
	gen pobs`i'=r(N)
	sum fraw`i' 
	gen fmean`i'=r(mean)
	gen fsd`i'=r(sd)
	gen fobs`i'=r(N)
}
duplicates drop year, force
keep year fobs* fsd* fmean* pobs* psd* pmean*
rename year id
reshape long  fobs fsd fmean pobs psd pmean, i(id) j(year)
keep if id==1989
lab var psd "Worker effects"
lab var fsd "Firm effects"
lab var year "Year"
line psd fsd year, ylabel(0(0.05)0.3) yscale(range(0 0.3)) scheme(s2mono) graphr(c(white)) legend(cols(1)) ytitle("Standard deviation")
graph save results/figD2.gph,replace
graph export results/figD2.eps,replace
graph export results/figD2.png,replace

********************************************
*** Figure D3. person/firm correlations. ***
********************************************

use modified/akm_rolling_4_2.dta, clear
	forvalues i=1989(1)2005 {
	merge 1:1 lopnr using modified/sample`i'.dta, keepus(age) 
	rename age age`i'
	drop if _merge==2
	drop _merge
	}
forvalues i=1989(1)2005 {
	pwcorr praw`i' fraw`i'	
	gen corr`i'=r(rho)
	pwcorr praw`i' fraw`i' if age`i'>=30 &  age`i'<=35	
	gen corr3035`i'=r(rho) 
	}
duplicates drop year, force
keep lopnr year corr*
rename year tid
reshape long corr corr3035, i(lopnr) j(year)
duplicates drop year, force
drop tid
sort year
save modified/person_firm_correlations_AKM2.dta, replace

** Make figD3: person-firm correlations for men 24-60 and men 30-35
use modified/person_firm_correlations_AKM2.dta, clear
lab var corr "All men"
lab var corr3035 "Men 30-35"
lab var year "Year"
twoway (line corr corr3035 year), scheme(s2mono) graphr(c(white)) legend(cols(1)) ytitle("Correlation")  
graph save results/figD3.gph,replace


*****************************
*** Appendix E. Macro data **
*****************************
use modified/macrodata8608, clear
lab var unemployment "Unemployment (16-64)"
lab var bankruptcies "Bankruptcies"
lab var bnppercapita "GDP per capita (2018 SEK)"
lab var employment1664 "Employment rate (16-64)"
lab var year "Year"

* Figure E1. Bankruptcies
line bankruptcies year, scheme(s2mono) graphr(c(white)) ytitle("Number of bankruptcies")  
graph save results/figE1.gph,replace

* Figure E2. GDP per capita and unemployment
twoway (line bnppercapita year, yaxis(1) ytitle("GDP per capita (2018 SEK)", axis(1)) ylabel(0(150000)450000, axis(1)) ymtick(0(150000)450000, axis(1))) (line unemployment year, yaxis(2) ytitle("Unemployment (%)", axis(2)) ylabel(0(4)12,axis(2)) ymtick(0(4)12, axis(2))), scheme(s2mono) graphr(c(white)) legend(cols(1)) 
graph save results/figE2.gph,replace

* Figure E3. Employment rate
line employment1664 year, scheme(s2mono) graphr(c(white)) ytitle("Employment rate")  

*************************************
*** Appendix F. EU/KLEMS and STAN ***
*************************************

*** EU-Klems
use modified/eu_klems.dta, clear

drop year1970-year1985
drop if country=="CYP" | country=="KOR" | country=="CZE" | country=="EST" | country=="GRC" | country=="HUN" | country=="LTU" | country=="LUX" | country=="LVA" | country=="MLT" | country=="POL" | country=="PRT" | country=="SVK" | country=="SVN"
keep if var=="EMPE"
replace country="USA" if country=="USA-NAICS"

gen t86=year1986 if ind=="TOT"
gen t07=year2007 if ind=="TOT"
gen t06=year2006 if ind=="TOT"

bysort country: egen totemp1986=mean(t86)
bysort country: egen totemp2007=mean(t07)
bysort country: egen totemp2006=mean(t06)

gen empsh1986=year1986/totemp1986
gen empsh2006=year2006/totemp2006
gen empsh2007=year2007/totemp2007

gen dempsh8606=empsh2006-empsh1986
gen dempsh8607=empsh2007-empsh1986

gen schange=dempsh8606 if country=="SWE"
bysort ind: egen dempsweden=mean(dempsh8606)

graph hbar (asis) dempsh8606 if dempsh8606~=. & ind=="D", over(country, sort(dempsh8606)) scheme(s2mono) graphr(c(white)) subt("A: Manufacturing") 
graph save results/figF1a, replace
graph hbar (asis) dempsh8606 if dempsh8606~=. & ind=="71t74", over(country, sort(dempsh8606)) scheme(s2mono) graphr(c(white)) subt("B: Business services")
graph save results/figF1b, replace
graph combine "results/figF1a" "results/figF1b", graphr(c(white)) xsize(7) c(3) 
graph save results/figF1.gph, replace

*** STAN
use modified/stan8608ver2.dta, clear
egen country_ind_year=group(country ind year)
egen country_ind=group(country ind)
reshape wide value, i(country_ind_year) j(var) string
order country ind year country_ind valueESHT valueESHM valueVSHM valueVSHT
rename valueESHT empsh
rename valueESHM eshm 
rename valueVSHM vshm
rename valueVSHT vsht 
tsset country_ind year
replace ind="4582X" if ind=="AAA1"

replace empsh=empsh/100

bysort country_ind: gen dempsh8608=empsh-L22.empsh
bysort country_ind: gen dempsh9008=empsh-L18.empsh
bysort country_ind: gen dempsh9097=L11.empsh-L18.empsh
bysort country_ind: gen dempsh9708=empsh-L11.empsh

 * D6263 IT and other information services
graph hbar (asis) dempsh8608 if dempsh8608~=. & ind=="6263", over(country, sort(dempsh8608)) scheme(s2mono) graphr(c(white)) subt("IT and other information services")
graph save results/figF2, replace

******** SIMULATIONS FOR STANDARD ERRORS (Table 1)

*** Simulations for standard errors

* Basic and alternative distributions  

foreach x in ftg {
foreach j in 1986 1997 2008 {
forvalues i=1(1)1000 {
use lopnr fos fos_detail c n sample_3035_10_ftg ftgsni* ftgstorl_`x' age sex `x'nr year using modified/sample`j', clear

merge 1:1 lopnr using temp/alternative_skills.dta
drop if _merge==2
drop _merge

	* Drop firms/plants without identifiers
	drop if `x'nr==""
	
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_3035_10_ftg==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n n_uni c_uni n_beta24 c_beta24 n_beta42 c_beta42
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n n_uni c_uni n_beta24 c_beta24 n_beta42 c_beta42
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort ftgnr: egen cj=mean(c)
	bysort ftgnr: egen c_unij=mean(c_uni)
	bysort ftgnr: egen c_beta24j=mean(c_beta24)
	bysort ftgnr: egen c_beta42j=mean(c_beta42)

	bysort ftgnr: egen nj=mean(n)
	bysort ftgnr: egen n_unij=mean(n_uni)
	bysort ftgnr: egen n_beta24j=mean(n_beta24)
	bysort ftgnr: egen n_beta42j=mean(n_beta42)

	*sample
	egen cbar=mean(c)
	egen c_unibar=mean(c_uni)
	egen c_beta24bar=mean(c_beta24)
	egen c_beta42bar=mean(c_beta42)

	egen nbar=mean(n)
	egen n_unibar=mean(n_uni)
	egen n_beta24bar=mean(n_beta24)
	egen n_beta42bar=mean(n_beta42)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	g ws_c_uni=(c_uni-c_unij)^2
	g ws_c_beta24=(c_beta24-c_beta24j)^2
	g ws_c_beta42=(c_beta42-c_beta42j)^2
	
	g ws_n=(n-nj)^2
	g ws_n_uni=(n_uni-n_unij)^2
	g ws_n_beta24=(n_beta24-n_beta24j)^2
	g ws_n_beta42=(n_beta42-n_beta42j)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	g bs_c_uni=(c_unij-c_unibar)^2
	g bs_c_beta24=(c_beta24j-c_beta24bar)^2
	g bs_c_beta42=(c_beta42j-c_beta42bar)^2
	
	g bs_n=(nj-cbar)^2
	g bs_n_uni=(n_unij-n_unibar)^2
	g bs_n_beta24=(n_beta24j-n_beta24bar)^2
	g bs_n_beta42=(n_beta42j-n_beta42bar)^2

	*total simple
	g ts_c=(c-cbar)^2
	g ts_c_uni=(c_uni-c_unibar)^2
	g ts_c_beta24=(c_beta24-c_beta24bar)^2
	g ts_c_beta42=(c_beta42-c_beta42bar)^2
	
	g ts_n=(n-nbar)^2
	g ts_n_uni=(n_uni-n_unibar)^2
	g ts_n_beta24=(n_beta24-n_beta24bar)^2
	g ts_n_beta42=(n_beta42-n_beta42bar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c c_uni c_beta24 c_beta42 n n_uni n_beta24 n_beta42 (mean) b* Nj N2j N2 cj c_unij c_beta24j c_beta42j nj n_unij n_beta24j n_beta42j cbar c_unibar c_beta24bar c_beta42bar nbar n_unibar n_beta24bar n_beta42bar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))
	
*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	g corr_ws_c_uni=ws_c_uni*thetaj_w*N2j
	g corr_ws_c_beta24=ws_c_beta24*thetaj_w*N2j
	g corr_ws_c_beta42=ws_c_beta42*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j
	g corr_ws_n_uni=ws_n_uni*thetaj_w*N2j
	g corr_ws_n_beta24=ws_n_beta24*thetaj_w*N2j
	g corr_ws_n_beta42=ws_n_beta42*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	g corr_bs_c_uni=N2j*(bs_c_uni-thetaj_b*ws_c_uni)
	g corr_bs_c_beta24=N2j*(bs_c_beta24-thetaj_b*ws_c_beta24)
	g corr_bs_c_beta42=N2j*(bs_c_beta42-thetaj_b*ws_c_beta42)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
	g corr_bs_n_uni=N2j*(bs_n_uni-thetaj_b*ws_n_uni)
	g corr_bs_n_beta24=N2j*(bs_n_beta24-thetaj_b*ws_n_beta24)
	g corr_bs_n_beta42=N2j*(bs_n_beta42-thetaj_b*ws_n_beta42)

	*between firm total simple
	replace bs_c=bs_c*N2j
	replace bs_c_uni=bs_c_uni*N2j
	replace bs_c_beta24=bs_c_beta24*N2j
	replace bs_c_beta42=bs_c_beta42*N2j
	
	replace bs_n=bs_n*N2j
	replace bs_n_uni=bs_n_uni*N2j
	replace bs_n_beta24=bs_n_beta24*N2j
	replace bs_n_beta42=bs_n_beta42*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	replace ws_c_uni=ws_c_uni*1/N2
	replace ws_c_beta24=ws_c_beta24*1/N2
	replace ws_c_beta42=ws_c_beta42*1/N2
	
	replace ws_n=ws_n*1/N2
	replace ws_n_uni=ws_n_uni*1/N2
	replace ws_n_beta24=ws_n_beta24*1/N2
	replace ws_n_beta42=ws_n_beta42*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	replace bs_c_uni=bs_c_uni*1/N2
	replace bs_c_beta24=bs_c_beta24*1/N2
	replace bs_c_beta42=bs_c_beta42*1/N2
	
	replace bs_n=bs_n*1/N2
	replace bs_n_uni=bs_n_uni*1/N2
	replace bs_n_beta24=bs_n_beta24*1/N2
	replace bs_n_beta42=bs_n_beta42*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	replace ts_c_uni=ts_c_uni*1/N2
	replace ts_c_beta24=ts_c_beta24*1/N2
	replace ts_c_beta42=ts_c_beta42*1/N2
	
	replace ts_n=ts_n*1/N2
	replace ts_n_uni=ts_n_uni*1/N2
	replace ts_n_beta24=ts_n_beta24*1/N2
	replace ts_n_beta42=ts_n_beta42*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	replace corr_ws_c_uni=corr_ws_c_uni*1/N2
	replace corr_ws_c_beta24=corr_ws_c_beta24*1/N2
	replace corr_ws_c_beta42=corr_ws_c_beta42*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2
	replace corr_ws_n_uni=corr_ws_n_uni*1/N2
	replace corr_ws_n_beta24=corr_ws_n_beta24*1/N2
	replace corr_ws_n_beta42=corr_ws_n_beta42*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	replace corr_bs_c_uni=corr_bs_c_uni*1/N2
	replace corr_bs_c_beta24=corr_bs_c_beta24*1/N2
	replace corr_bs_c_beta42=corr_bs_c_beta42*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2
	replace corr_bs_n_uni=corr_bs_n_uni*1/N2
	replace corr_bs_n_beta24=corr_bs_n_beta24*1/N2
	replace corr_bs_n_beta42=corr_bs_n_beta42*1/N2

gen simA=`i'
save decomp_simA_`j'_`i',replace
}
}
}

foreach j in 1986 1997 2008 {
use  decomp_simA_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_simA_`j'_`i'
	}
save temp/decomp_simA_`j',replace
}

foreach j in 1986 1997 2008 {
	use temp/decomp_simA_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_c_uni_sd=corr_ws_c_uni corr_ws_c_beta24_sd=corr_ws_c_beta24 corr_ws_c_beta42_sd=corr_ws_c_beta42 corr_ws_n_sd=corr_ws_n corr_ws_n_uni_sd=corr_ws_n_uni corr_ws_n_beta24_sd=corr_ws_n_beta24 corr_ws_n_beta42_sd=corr_ws_n_beta42 corr_bs_c_sd=corr_bs_c corr_bs_c_uni_sd=corr_bs_c_uni corr_bs_c_beta24_sd=corr_bs_c_beta24 corr_bs_c_beta42_sd=corr_bs_c_beta42 corr_bs_n_sd=corr_bs_n corr_bs_n_uni_sd=corr_bs_n_uni corr_bs_n_beta24_sd=corr_bs_n_beta24 corr_bs_n_beta42_sd=corr_bs_n_beta42 (p1) corr_ws_c_p1=corr_ws_c corr_ws_c_uni_p1=corr_ws_c_uni corr_ws_c_beta24_p1=corr_ws_c_beta24 corr_ws_c_beta42_p1=corr_ws_c_beta42 corr_ws_n_p1=corr_ws_n corr_ws_n_uni_p1=corr_ws_n_uni corr_ws_n_beta24_p1=corr_ws_n_beta24 corr_ws_n_beta42_p1=corr_ws_n_beta42 corr_bs_c_p1=corr_bs_c corr_bs_c_uni_p1=corr_bs_c_uni corr_bs_c_beta24_p1=corr_bs_c_beta24 corr_bs_c_beta42_p1=corr_bs_c_beta42 corr_bs_n_p1=corr_bs_n corr_bs_n_uni_p1=corr_bs_n_uni corr_bs_n_beta24_p1=corr_bs_n_beta24 corr_bs_n_beta42_p1=corr_bs_n_beta42 (p99) corr_ws_c_p99=corr_ws_c corr_ws_c_uni_p99=corr_ws_c_uni corr_ws_c_beta24_p99=corr_ws_c_beta24 corr_ws_c_beta42_p99=corr_ws_c_beta42 corr_ws_n_p99=corr_ws_n corr_ws_n_uni_p99=corr_ws_n_uni corr_ws_n_beta24_p99=corr_ws_n_beta24 corr_ws_n_beta42_p99=corr_ws_n_beta42 corr_bs_c_p99=corr_bs_c corr_bs_c_uni_p99=corr_bs_c_uni corr_bs_c_beta24_p99=corr_bs_c_beta24 corr_bs_c_beta42_p99=corr_bs_c_beta42 corr_bs_n_p99=corr_bs_n corr_bs_n_uni_p99=corr_bs_n_uni corr_bs_n_beta24_p99=corr_bs_n_beta24 corr_bs_n_beta42_p99=corr_bs_n_beta42  (p50) corr_ws_c_p50=corr_ws_c corr_ws_c_uni_p50=corr_ws_c_uni corr_ws_c_beta24_p50=corr_ws_c_beta24 corr_ws_c_beta42_p50=corr_ws_c_beta42 corr_ws_n_p50=corr_ws_n corr_ws_n_uni_p50=corr_ws_n_uni corr_ws_n_beta24_p50=corr_ws_n_beta24 corr_ws_n_beta42_p50=corr_ws_n_beta42 corr_bs_c_p50=corr_bs_c corr_bs_c_uni_p50=corr_bs_c_uni corr_bs_c_beta24_p50=corr_bs_c_beta24 corr_bs_c_beta42_p50=corr_bs_c_beta42 corr_bs_n_p50=corr_bs_n corr_bs_n_uni_p50=corr_bs_n_uni corr_bs_n_beta24_p50=corr_bs_n_beta24 corr_bs_n_beta42_p50=corr_bs_n_beta42, by(year) 
	g year=`j'
	save temp/simA`j',replace
}

clear
use temp/simA1986
append using temp/simA1997
append using temp/simA2008
sort year
save modified/simulationsA,replace
outsheet using results/simulationsA.csv, comma replace

*
preserve
keep if year==1986
keep corr_ws_c corr_ws_c_sd corr_ws_c_p1 corr_ws_c_p50 corr_ws_c_p99 corr_ws_n corr_ws_n_sd corr_ws_n_p1 corr_ws_n_p50 corr_ws_n_p99   corr_bs_c corr_bs_c_sd corr_bs_c_p1 corr_bs_c_p50 corr_bs_c_p99 corr_bs_n corr_bs_n_sd corr_bs_n_p1 corr_bs_n_p50 corr_bs_n_p99     
order  corr_ws_c corr_ws_c_sd corr_ws_c_p1 corr_ws_c_p50 corr_ws_c_p99 corr_ws_n corr_ws_n_sd corr_ws_n_p1 corr_ws_n_p50 corr_ws_n_p99   corr_bs_c corr_bs_c_sd corr_bs_c_p1 corr_bs_c_p50 corr_bs_c_p99 corr_bs_n corr_bs_n_sd corr_bs_n_p1 corr_bs_n_p50 corr_bs_n_p99  
outsheet using results/tableSimulationsA_1986.csv,replace
restore

preserve
keep if year==1997
keep corr_ws_c corr_ws_c_sd corr_ws_c_p1 corr_ws_c_p50 corr_ws_c_p99 corr_ws_n corr_ws_n_sd corr_ws_n_p1 corr_ws_n_p50 corr_ws_n_p99   corr_bs_c corr_bs_c_sd corr_bs_c_p1 corr_bs_c_p50 corr_bs_c_p99 corr_bs_n corr_bs_n_sd corr_bs_n_p1 corr_bs_n_p50 corr_bs_n_p99  
order corr_ws_c corr_ws_c_sd corr_ws_c_p1 corr_ws_c_p50 corr_ws_c_p99 corr_ws_n corr_ws_n_sd corr_ws_n_p1 corr_ws_n_p50 corr_ws_n_p99   corr_bs_c corr_bs_c_sd corr_bs_c_p1 corr_bs_c_p50 corr_bs_c_p99 corr_bs_n corr_bs_n_sd corr_bs_n_p1 corr_bs_n_p50 corr_bs_n_p99  
outsheet using results/tableSimulationsA_1997.csv,replace
restore

preserve
keep if year==2008
keep corr_ws_c corr_ws_c_sd corr_ws_c_p1 corr_ws_c_p50 corr_ws_c_p99 corr_ws_n corr_ws_n_sd corr_ws_n_p1 corr_ws_n_p50 corr_ws_n_p99   corr_bs_c corr_bs_c_sd corr_bs_c_p1 corr_bs_c_p50 corr_bs_c_p99 corr_bs_n corr_bs_n_sd corr_bs_n_p1 corr_bs_n_p50 corr_bs_n_p99  
order corr_ws_c corr_ws_c_sd corr_ws_c_p1 corr_ws_c_p50 corr_ws_c_p99 corr_ws_n corr_ws_n_sd corr_ws_n_p1 corr_ws_n_p50 corr_ws_n_p99   corr_bs_c corr_bs_c_sd corr_bs_c_p1 corr_bs_c_p50 corr_bs_c_p99 corr_bs_n corr_bs_n_sd corr_bs_n_p1 corr_bs_n_p50 corr_bs_n_p99  
outsheet using results/tableSimulationsA_2008.csv,replace
restore

*** Clean up
clear
foreach j in 1986 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simA_`j'_`i'.dta	
	}
}

**** Simulations women (B)
clear
foreach x in ftg {
foreach j in 1986 1997 2008 {
forvalues i=1(1)1000{
use lopnr fos fos_detail c n edyr ftgsni* ftgstorl_`x' age sex ftgnr privfirm_`x' `x'nr year using modified/sample`j', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""

	gen sample_`x'_10=0
	replace sample_`x'_10=1 if age>= 30 & age<=35 & ftgstorl_`x'>=10 & ftgstorl_`x'~=. & n!=. & c!=. & edyr!=. & privfirm_`x'==1

	* At least two employees
	bysort `x'nr: egen sample_`x'=sum(sample_`x'_10)
	replace sample_`x'_10=0 if sample_`x'<=1
	drop sample_`x'
					
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_`x'_10==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n 
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n 
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort ftgnr: egen cj=mean(c)

	bysort ftgnr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)

	egen nbar=mean(n)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2

gen simB=`i'
save decomp_simB_`j'_`i',replace
}
}
}

foreach j in 1986 1997 2008 {
use  decomp_simB_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_simB_`j'_`i'
	}
save temp/decomp_simB_`j',replace
}

foreach j in 1986 1997 2008 {
	use temp/decomp_simB_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_n_sd=corr_ws_n corr_bs_c_sd=corr_bs_c corr_bs_n_sd=corr_bs_n (p1) corr_ws_c_p1=corr_ws_c corr_ws_n_p1=corr_ws_n corr_bs_c_p1=corr_bs_c corr_bs_n_p1=corr_bs_n (p99) corr_ws_c_p99=corr_ws_c corr_ws_n_p99=corr_ws_n corr_bs_c_p99=corr_bs_c corr_bs_n_p99=corr_bs_n (p50) corr_ws_c_p50=corr_ws_c corr_ws_n_p50=corr_ws_n corr_bs_c_p50=corr_bs_c corr_bs_n_p50=corr_bs_n 
	g year=`j'
	save temp/simB`j',replace
}

clear
use temp/simB1986
append using temp/simB1997
append using temp/simB2008
sort year
save modified/simulationsB,replace
outsheet using results/simulationsB.csv,comma replace

* Clean up
clear
foreach j in 1986 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simB_`j'_`i'.dta	
	}
}

***** 30-45 year olds, 1997 and 2008 (C)
clear
foreach x in ftg {
foreach j in 1997 2008 {
forvalues i=1(1)1000 {
use lopnr fos fos_detail c n edyr ftgsni* ftgstorl_`x' age sex `x'nr privfirm_`x' year using modified/sample`j', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""

	gen sample_`x'_10=0
	replace sample_`x'_10=1 if age>= 30 & age<= 45 & ftgstorl_`x'>=10 & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_`x'==1
	* At least two employees
	bysort `x'nr: egen sample_`x'=sum(sample_`x'_10) 
	replace sample_`x'_10=0 if sample_`x'<=1
	drop sample_`x'
					
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_`x'_10==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n 
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n 
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort ftgnr: egen cj=mean(c)

	bysort ftgnr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)

	egen nbar=mean(n)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2

gen simC=`i'
save decomp_simC_`j'_`i',replace
}
}
}

foreach j in 1997 2008 {
use  decomp_simC_`j'_1,replace
	forvalues i=2(1)1000 {
	append using decomp_simC_`j'_`i'
	}
save temp/decomp_simC_`j',replace
}

foreach j in 1997 2008 {
	use temp/decomp_simC_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_n_sd=corr_ws_n corr_bs_c_sd=corr_bs_c corr_bs_n_sd=corr_bs_n (p1) corr_ws_c_p1=corr_ws_c corr_ws_n_p1=corr_ws_n corr_bs_c_p1=corr_bs_c corr_bs_n_p1=corr_bs_n (p99) corr_ws_c_p99=corr_ws_c corr_ws_n_p99=corr_ws_n corr_bs_c_p99=corr_bs_c corr_bs_n_p99=corr_bs_n (p50) corr_ws_c_p50=corr_ws_c corr_ws_n_p50=corr_ws_n corr_bs_c_p50=corr_bs_c corr_bs_n_p50=corr_bs_n 
	g year=`j'
	save temp/simC`j',replace
}
clear
use temp/simC1997
append using temp/simC2008

sort year
save modified/simulationsC,replace
outsheet using results/simulationsC.csv,comma replace

* Clean up
clear
foreach j in 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simC_`j'_`i'.dta	
	}
}

***** Adding public sector workers (D)
clear
foreach x in ftg {
foreach j in 1986 1997 2008 {
forvalues i=1(1)1000 {
use lopnr fos fos_detail c n edyr ftgsni* ftgstorl_`x' age sex ftgnr privfirm_`x' `x'sni2 `x'nr year using modified/sample`j', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""

	drop if `x'sni2==75 |`x'sni2==80 |`x'sni2==85 | `x'sni2==99 
	gen sample_`x'_10=0
	replace sample_`x'_10=1 if age>= 30 & age<= 35 & ftgstorl_`x'>=10 & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=.
	* At least two employees
	bysort `x'nr: egen sample_`x'=sum(sample_`x'_10)
	replace sample_`x'_10=0 if sample_`x'<=1
	drop sample_`x'
					
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_`x'_10==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n 
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n 
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort ftgnr: egen cj=mean(c)

	bysort ftgnr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)

	egen nbar=mean(n)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2

gen simD=`i'
save decomp_simD_`j'_`i',replace
}
}
}

foreach j in 1986 1997 2008 {
use  decomp_simD_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_simD_`j'_`i'
	}
save temp/decomp_simD_`j',replace
}

foreach j in 1986 1997 2008 {
	use temp/decomp_simD_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_n_sd=corr_ws_n corr_bs_c_sd=corr_bs_c corr_bs_n_sd=corr_bs_n (p1) corr_ws_c_p1=corr_ws_c corr_ws_n_p1=corr_ws_n corr_bs_c_p1=corr_bs_c corr_bs_n_p1=corr_bs_n (p99) corr_ws_c_p99=corr_ws_c corr_ws_n_p99=corr_ws_n corr_bs_c_p99=corr_bs_c corr_bs_n_p99=corr_bs_n (p50) corr_ws_c_p50=corr_ws_c corr_ws_n_p50=corr_ws_n corr_bs_c_p50=corr_bs_c corr_bs_n_p50=corr_bs_n 
	g year=`j'
	save temp/simD`j',replace
}

clear
use temp/simD1986
append using temp/simD1997
append using temp/simD2008
sort year
save modified/simulationsD,replace
outsheet using results/simulationsD.csv,comma replace

* Clean up
clear
foreach j in 1986 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simD_`j'_`i'.dta	
	}
}

****** Firm size 50+ (E)
clear
foreach x in ftg {
foreach j in 1986 1997 2008 {
forvalues i=1(1)1000 {
use lopnr fos fos_detail c n edyr ftgsni* ftgstorl_`x' age sex ftgnr privfirm_`x' year using modified/sample`j', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""

	gen sample_`x'_50=0
	replace sample_`x'_50=1 if age>= 30 & age<=35 & ftgstorl_`x'>=50 & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_`x'==1
	* At least two employees
	bysort `x'nr: egen sample_`x'=sum(sample_`x'_50) 
	replace sample_`x'_50=0 if sample_`x'<=1
	drop sample_`x'
					
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_`x'_50==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n 
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n 
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort ftgnr: egen cj=mean(c)

	bysort ftgnr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)

	egen nbar=mean(n)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2

gen simE=`i'
save decomp_simE_`j'_`i',replace
}
}
}

foreach j in 1986 1997 2008 {
use  decomp_simE_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_simE_`j'_`i'
	}
save temp/decomp_simE_`j',replace
}

foreach j in 1986 1997 2008 {
	use temp/decomp_simE_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_n_sd=corr_ws_n corr_bs_c_sd=corr_bs_c corr_bs_n_sd=corr_bs_n (p1) corr_ws_c_p1=corr_ws_c corr_ws_n_p1=corr_ws_n corr_bs_c_p1=corr_bs_c corr_bs_n_p1=corr_bs_n (p99) corr_ws_c_p99=corr_ws_c corr_ws_n_p99=corr_ws_n corr_bs_c_p99=corr_bs_c corr_bs_n_p99=corr_bs_n (p50) corr_ws_c_p50=corr_ws_c corr_ws_n_p50=corr_ws_n corr_bs_c_p50=corr_bs_c corr_bs_n_p50=corr_bs_n 
	g year=`j'
	save temp/simE`j',replace
}

clear
use temp/simE1986
append using temp/simE1997
append using temp/simE2008

sort year
save modified/simulationsE,replace
outsheet using results/simulationsE.csv,comma replace

* Clean up
clear
foreach j in 1986 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simE_`j'_`i'.dta	
	}
}


*** Firm size 100+ (F)
clear
foreach x in ftg {
foreach j in 1986 1997 2008 {
forvalues i=1(1)1000 {
use lopnr fos fos_detail c n edyr ftgsni* ftgstorl_`x' age sex `x'nr privfirm_`x' year using modified/sample`j', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""

	gen sample_`x'_100=0
	replace sample_`x'_100=1 if age>= 30 & age<=35 & ftgstorl_`x'>=100 & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_`x'==1
	* At least two employees
	bysort `x'nr: egen sample_`x'=sum(sample_`x'_100) 
	replace sample_`x'_100=0 if sample_`x'<=1
	drop sample_`x'
					
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_`x'_100==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n 
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n 
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort ftgnr: egen cj=mean(c)

	bysort ftgnr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)

	egen nbar=mean(n)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2

gen simF=`i'
save decomp_simF_`j'_`i',replace
}
}
}

foreach j in 1986 1997 2008 {
use  decomp_simF_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_simF_`j'_`i'
	}
save temp/decomp_simF_`j',replace
}

foreach j in 1986 1997 2008 {
	use temp/decomp_simF_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_n_sd=corr_ws_n corr_bs_c_sd=corr_bs_c corr_bs_n_sd=corr_bs_n (p1) corr_ws_c_p1=corr_ws_c corr_ws_n_p1=corr_ws_n corr_bs_c_p1=corr_bs_c corr_bs_n_p1=corr_bs_n (p99) corr_ws_c_p99=corr_ws_c corr_ws_n_p99=corr_ws_n corr_bs_c_p99=corr_bs_c corr_bs_n_p99=corr_bs_n (p50) corr_ws_c_p50=corr_ws_c corr_ws_n_p50=corr_ws_n corr_bs_c_p50=corr_bs_c corr_bs_n_p50=corr_bs_n 
	g year=`j'
	save temp/simF`j',replace
}

clear
use temp/simF1986
append using temp/simF1997
append using temp/simF2008

sort year
save modified/simulationsF,replace
outsheet using results/simulationsF.csv,comma replace

* Clean up
clear
foreach j in 1986 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simF_`j'_`i'.dta	
	}
}


*** Plant/ast (G)

clear
foreach x in ast {
foreach j in 1986 1997 2008 {
forvalues i=1(1)1000 {
use lopnr fos fos_detail c n edyr ftgsni* ftgstorl_`x' age sex `x'nr privfirm_`x' year using modified/sample`j', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""

	gen sample_`x'_10=0
	replace sample_`x'_10=1 if age>= 30 & age<=35 & ftgstorl_`x'>=10 & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_`x'==1
	* At least two employees
	bysort `x'nr: egen sample_`x'=sum(sample_`x'_10) 
	replace sample_`x'_10=0 if sample_`x'<=1
	drop sample_`x'
					
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)
	
	* Keep relevant sample
	keep if sample_`x'_10==1

	*create random assignment of cognitive and non cognitive skill 
	g lop=_n
	preserve
		keep c n 
		g random=runiform()
		sort random
		g lop=_n
		drop random
		sort lop
		save randomc,replace
	restore

	drop c n 
	sort lop
	merge 1:1 lop using randomc
	drop _merge

	*firm
	bysort `x'nr: egen cj=mean(c)

	bysort `x'nr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)

	egen nbar=mean(n)

	bysort `x'nr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year `x'nr)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	
	replace corr_bs_n=corr_bs_n*1/N2

gen simG=`i'
save decomp_simG_`j'_`i',replace
}
}
}

foreach j in 1986 1997 2008 {
use  decomp_simG_`j'_1,replace
	forvalues i=2(1)1000{
	append using decomp_simG_`j'_`i'
	}
save temp/decomp_simG_`j',replace
}

foreach j in 1986 1997 2008 {
	use temp/decomp_simG_`j'
	collapse (sd) corr_ws_c_sd=corr_ws_c corr_ws_n_sd=corr_ws_n corr_bs_c_sd=corr_bs_c corr_bs_n_sd=corr_bs_n (p1) corr_ws_c_p1=corr_ws_c corr_ws_n_p1=corr_ws_n corr_bs_c_p1=corr_bs_c corr_bs_n_p1=corr_bs_n (p99) corr_ws_c_p99=corr_ws_c corr_ws_n_p99=corr_ws_n corr_bs_c_p99=corr_bs_c corr_bs_n_p99=corr_bs_n (p50) corr_ws_c_p50=corr_ws_c corr_ws_n_p50=corr_ws_n corr_bs_c_p50=corr_bs_c corr_bs_n_p50=corr_bs_n 
	g year=`j'
	save temp/simG`j',replace
}

clear
use temp/simG1986
append using temp/simG1997
append using temp/simG2008

sort year
save modified/simulationsG,replace
outsheet using results/simulationsG.csv,comma replace

* Clean up
clear
foreach j in 1986 1997 2008{
	forvalues i=1(1)1000 {
	erase decomp_simG_`j'_`i'.dta	
	}
}


END 