﻿******************************************************************
*** Do-file creating datasets for 			    ******
*** Håkanson, Lindqvist and Vlachos, "Firms and Skills"	    ******
*** Journal of Human Resources 				    ******
****************************************************************** 


clear
set mem 20g
cd /home/workgroups/firmiq/data/
set more off


*1a. Individual variables: louise.do fetches louise data and creates edyr`i'.dta
*variables in edyr`i': lopnr year age edyr fos fos_detail sex seninvar syssstat loneink fink nordtyngdpunkt osttyngdpunkt sams forsamling kommun lan astkommun
*louise.do create yearly data sets, edyr1985.dta-edyr2009.dta, with years of education (edyr), field of study (fos), sex, age, lonink, fink and year of immigration from LOUISE
*louise.do used data set "/home/workgroup/firmiq/data/modified/nyckelx.dta" wich is a dataset translating the old education standard to SUN2000 according to:
*http://www.scb.se/statistik/UF/UF0506/_dokument/WEB_SUN2000nyckelny_delad.xls
*for years 1985-1999 the old standard is first translated to SUN2000, before edyr and and fos is created by the do file edyr.do
*variable fink changes name in raw data, and partly definition 2001. Original name is kept.

do /home/workgroups/firmiq/Analys/louise_JHR.do

*
*1b. Enlistment data. Note: Separate file for women.
*

do /home/workgroups/firmiq/Analys/enlistment_JHR.do
do /home/workgroups/firmiq/Analys/enlistment2003-2005_JHR.do
do /home/workgroups/firmiq/Analys/enlistment_women_JHR.do
do /home/workgroups/firmiq/Analys/topiq_JHR.do

* 
*  1c. Different assumptions on distribution*
*

clear

use modified/enlistment.dta, clear

*assume uniform distribution (use percentile rank)
bysort enlistyr: gen n_uni=pctn
bysort enlistyr: egen nuni_mean=mean(n_uni)
bysort enlistyr: egen nuni_sd=sd(n_uni)
replace n_uni=(n_uni-nuni_mean)/nuni_sd
bysort enlistyr: gen c_uni=pctc
bysort enlistyr: egen cuni_mean=mean(c_uni)
bysort enlistyr: egen cuni_sd=sd(c_uni)
replace c_uni=(c_uni-cuni_mean)/cuni_sd
drop nuni_mean nuni_sd cuni_mean cuni_sd

*beta
bysort enlistyr: gen n_beta24=invibeta(2,4,pctc)
bysort enlistyr: gen c_beta24=invibeta(2,4,pctn)

bysort enlistyr: gen n_beta42=invibeta(4,2,pctc)
bysort enlistyr: gen c_beta42=invibeta(4,2,pctn)

keep lopnr n_uni c_uni c_beta24 c_beta42 n_beta24 n_beta42
sort lopnr
save temp/alternative_skills,replace

* Prepare to generate weights: Number of listed in each 1-9 group by enlistment year

use modified/enlistment.dta,clear
drop if c==.

collapse (count) c_group_count_pop=c,by(enlistyr pg)
save modified/c_weights.dta,replace

use modified/enlistment.dta,clear
drop if n==.

collapse (count) n_group_count_pop=n,by(enlistyr pf)
save modified/n_weights.dta,replace

*2. Linking people to places: creates key`i'.dta
*   from RAMS the individual entry (firm + plant) with the largest income (lonfink) is identified in "jobrank"
*   We sum income by plant and firm, respectively and select the firm and plant with highest total income
*   For plants, we therefore also have a firm id (ast_ftg) that corresponds to the highest income plant
*   For firms, also have a plant id (ftg_ast) based on the plant that corresponds to the highest income firm
*   We also include a variable indicating the number of times an individual is observed (number_jobs)
*   variables in key`i': ftgnr identifies firm (string), astnr identifies plant (string), lonfink. 

forvalues i=85(1)89{
clear
use lonfink perslopnr ftglopnr_su astlopnr_su manfran mantill using rams/anst`i'.dta
replace astlopnr_su="00000000" if astlopnr_su==""

gen year=1900+`i'
rename perslopnr lopnr
rename ftglopnr_su ftgnr
rename astlopnr_su astnr

*rank jobentries by income
drop if lonfink==.
drop if lonfink<=0
bysort lopnr: egen jobrank=rank(lonfink),f

* Create number of maximum number of workplaces
bysort lopnr: egen number_jobs=max(jobrank)

* Number of firms in which individual works
egen job_ftg_number=group(lopnr ftgnr)
bysort lopnr: egen max_ftg=max(job_ftg_number)
bysort lopnr: egen min_ftg=min(job_ftg_number)
gen number_ftg=(max_ftg-min_ftg)+1

* Number of plants in which individual works
egen job_ast_number=group(lopnr astnr)
bysort lopnr: egen max_ast=max(job_ast_number)
bysort lopnr: egen min_ast=min(job_ast_number)
gen number_ast=(max_ast-min_ast)+1

lab var number_jobs "Total number of individual entries"
lab var number_ftg "Total number of firms by individual"
lab var number_ast "Total number of plants by individual"

drop max_ftg min_ftg max_ast min_ast job_ftg_number job_ast_number

* Drop individuals that have the same income in the same firm more than one time
duplicates tag lopnr ftgnr lonfink, gen(duptag)
drop if duptag>=1
drop duptag

* Sum income by firm and plant, respectively
bysort lopnr ftgnr: egen lonfink_ftg=sum(lonfink)
bysort lopnr astnr: egen lonfink_ast=sum(lonfink)
replace lonfink_ast=. if astnr=="00000000"

*** Firm
* Find firm with highest income
bysort lopnr: egen maxlon_ftg=max(lonfink_ftg)
gen max_ftg=ftgnr if lonfink_ftg==maxlon_ftg
bysort lopnr: egen max_ftgnr=mode(max_ftg), maxmode

* Find plant of highest income firm. Priority is given to plants (within firm) that are non-missing
bysort lopnr max_ftg: egen tempink=rank(lonfink_ast),field
gen ast_max=astnr if max_ftg==ftgnr & tempink==1
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==2
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==3
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==4
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==5
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==6
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==7
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==8
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==9
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==10
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==11
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==12
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==13
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==14
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==15
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr
bysort lopnr: egen ftg_ast=mode(ast_max),maxmode 
lab var ftg_ast "Plant matched to highest income firm"

* Create spell lengths
destring manfran, gen(manfran_ftg)
destring mantill, gen(mantill_ftg)
replace manfran_ftg=. if manfran_ftg==0
replace mantill_ftg=. if mantill_ftg==0
gen spell_ftg=(mantill_ftg-manfran_ftg)+1

* Total months at each firm
bysort lopnr ftgnr: egen spellsum_ftg=sum(spell_ftg)
gen temp=1 if spell_ftg==.
bysort lopnr ftgnr: egen temp2=max(temp)
replace spellsum_ftg=. if temp2==1
drop temp 

bysort lopnr ftgnr: egen manmax_ftg=max(mantill_ftg)
replace manmax_ftg=. if temp2==1
bysort lopnr ftgnr: egen manmin_ftg=min(manfran_ftg)
replace manmin_ftg=. if temp2==1
gen spellsum_ftg2=(manmax_ftg-manmin_ftg)+1
egen spellsum_ftg3=rowmin(spellsum_ftg spellsum_ftg2)

* Months worked at highest income firm
gen spellsum_ftg4=spellsum_ftg3 if ftgnr==max_ftgnr & max_ftg~=""
bysort lopnr: egen spellsum_ftg5=max(spellsum_ftg4)

* Clean - firm
drop spell_ftg temp2 spellsum_ftg spellsum_ftg2 spellsum_ftg3 spellsum_ftg4 manmax_ftg manmin_ftg manfran_ftg mantill_ftg tempink ast_max 
rename spellsum_ftg5 spellsum_ftg
lab var spellsum_ftg "Months worked at highest income firm"
replace ftg_ast="" if ftg_ast=="00000000"

*** Plant

* Find plant with highest income (If multiple plants with the same highest income, pick the one corresponding to the highest income firm)
bysort lopnr: egen maxlon_ast=max(lonfink_ast)
gen max_ast=astnr if lonfink_ast==maxlon_ast
bysort lopnr: egen ftgrank=rank(lonfink_ftg) if max_ast~="",unique
gen max_ast2=max_ast if ftgrank==1
bysort lopnr: egen max_astnr=mode(max_ast2)
gen temp=ftgnr if max_ast2~=""
bysort lopnr: egen ast_ftg=mode(temp)
drop temp
lab var ast_ftg "Firm matched to highest income plant"

* Create spell lengths for each plant
destring manfran, gen(manfran_ast)
destring mantill, gen(mantill_ast)
replace manfran_ast=. if manfran_ast==0
replace mantill_ast=. if mantill_ast==0
replace manfran_ast=. if astnr=="00000000"
replace mantill_ast=. if astnr=="00000000"
gen spell_ast=(mantill_ast-manfran_ast)+1

* Total months at each plant
bysort lopnr astnr: egen spellsum_ast=sum(spell_ast)
gen temp=1 if spell_ast==.
bysort lopnr astnr: egen temp2=max(temp)
replace spellsum_ast=. if temp2==1

bysort lopnr astnr: egen manmax_ast=max(mantill_ast)
replace manmax_ast=. if temp2==1
bysort lopnr astnr: egen manmin_ast=min(manfran_ast)
replace manmin_ast=. if temp2==1
gen spellsum_ast2=(manmax_ast-manmin_ast)+1
egen spellsum_ast3=rowmin(spellsum_ast spellsum_ast2)

* Months at highest income plant
gen spellsum_ast4=spellsum_ast3 if astnr==max_ast2 & max_ast2~="00000000"
bysort lopnr: egen spellsum_ast5=max(spellsum_ast4)

* Clean - plant
drop lonfink_ast max_ast spell_ast spellsum_ast temp temp2 manmax_ast manmin_ast spellsum_ast2 spellsum_ast3 spellsum_ast4
rename spellsum_ast5 spellsum_ast
lab var spellsum_ast "Months worked at highest income plant"

* Final clean
drop manfran manfran_ast mantill mantill_ast lonfink ftgnr astnr jobrank number_jobs number_ftg number_ast lonfink_ftg max_ftg ftgrank max_ast2
rename max_astnr astnr
rename max_ftgnr ftgnr
replace astnr="" if astnr=="00000000"
rename maxlon_ftg lonfink_ftg
rename maxlon_ast lonfink_ast
label var lonfink_ftg "Income at highest income firm"
label var lonfink_ast "Income at highest income plant"
label var ftgnr "Firm with highest total income"
lab var astnr "Plant with highest total income"

duplicates drop lopnr, force
sort lopnr ftgnr astnr 
save modified/key19`i', replace
}

forvalues i=90(1)99{
clear
use lonfink perslopnr ftglopnr_su astlopnr_su manfran mantill using rams/anst`i'.dta
replace astlopnr_su="00000000" if astlopnr_su==""

gen year=1900+`i'
rename perslopnr lopnr
rename ftglopnr_su ftgnr
rename astlopnr_su astnr

*rank jobentries by income
drop if lonfink==.
drop if lonfink<=0
bysort lopnr: egen jobrank=rank(lonfink),f

* Create number of maximum number of workplaces
bysort lopnr: egen number_jobs=max(jobrank)

* Number of firms in which individual works
egen job_ftg_number=group(lopnr ftgnr)
bysort lopnr: egen max_ftg=max(job_ftg_number)
bysort lopnr: egen min_ftg=min(job_ftg_number)
gen number_ftg=(max_ftg-min_ftg)+1

* Number of plants in which individual works
egen job_ast_number=group(lopnr astnr)
bysort lopnr: egen max_ast=max(job_ast_number)
bysort lopnr: egen min_ast=min(job_ast_number)
gen number_ast=(max_ast-min_ast)+1

lab var number_jobs "Total number of individual entries"
lab var number_ftg "Total number of firms by individual"
lab var number_ast "Total number of plants by individual"

drop max_ftg min_ftg max_ast min_ast job_ftg_number job_ast_number

* Drop individuals that have the same income in the same firm more than one time
duplicates tag lopnr ftgnr lonfink, gen(duptag)
drop if duptag>=1
drop duptag

* Sum income by firm and plant, respectively
bysort lopnr ftgnr: egen lonfink_ftg=sum(lonfink)
bysort lopnr astnr: egen lonfink_ast=sum(lonfink)
replace lonfink_ast=. if astnr=="00000000"

*** Firm
* Find firm with highest income
bysort lopnr: egen maxlon_ftg=max(lonfink_ftg)
gen max_ftg=ftgnr if lonfink_ftg==maxlon_ftg
bysort lopnr: egen max_ftgnr=mode(max_ftg),maxmode

* Find plant of highest income firm. Priority is given to plants (within firm) that are non-missing
bysort lopnr max_ftg: egen tempink=rank(lonfink_ast),field
gen ast_max=astnr if max_ftg==ftgnr & tempink==1
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==2
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==3
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==4
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==5
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==6
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==7
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==8
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==9
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==10
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==11
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==12
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==13
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==14
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==15
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr
bysort lopnr: egen ftg_ast=mode(ast_max),maxmode 
lab var ftg_ast "Plant matched to highest income firm"

* Create spell lengths
gen manfran_ftg=manfran
gen mantill_ftg=mantill 
replace manfran_ftg=. if manfran_ftg==0
replace mantill_ftg=. if mantill_ftg==0
gen spell_ftg=(mantill_ftg-manfran_ftg)+1

* Total months at firm
bysort lopnr ftgnr: egen spellsum_ftg=sum(spell_ftg)
gen temp=1 if spell_ftg==.
bysort lopnr ftgnr: egen temp2=max(temp)
replace spellsum_ftg=. if temp2==1
drop temp

bysort lopnr ftgnr: egen manmax_ftg=max(mantill_ftg)
replace manmax_ftg=. if temp2==1
bysort lopnr ftgnr: egen manmin_ftg=min(manfran_ftg)
replace manmin_ftg=. if temp2==1
gen spellsum_ftg2=(manmax_ftg-manmin_ftg)+1
egen spellsum_ftg3=rowmin(spellsum_ftg spellsum_ftg2)

* Months worked at highest income firm
gen spellsum_ftg4=spellsum_ftg3 if ftgnr==max_ftgnr & max_ftg~=""
bysort lopnr: egen spellsum_ftg5=max(spellsum_ftg4)

* Clean - firm
drop spell_ftg temp2 spellsum_ftg spellsum_ftg2 spellsum_ftg3 spellsum_ftg4 manmax_ftg manmin_ftg manfran_ftg mantill_ftg tempink ast_max 
rename spellsum_ftg5 spellsum_ftg
lab var spellsum_ftg "Months worked at highest income firm"
replace ftg_ast="" if ftg_ast=="00000000"

*** Plant

* Find plant with highest income (If multiple plants with the same highest income, pick the one corresponding to the highest income firm)
bysort lopnr: egen maxlon_ast=max(lonfink_ast)
gen max_ast=astnr if lonfink_ast==maxlon_ast
bysort lopnr: egen ftgrank=rank(lonfink_ftg) if max_ast~="",unique
gen max_ast2=max_ast if ftgrank==1
bysort lopnr: egen max_astnr=mode(max_ast2)
gen temp=ftgnr if max_ast2~=""
bysort lopnr: egen ast_ftg=mode(temp)
drop temp
lab var ast_ftg "Firm matched to highest income plant"

* Create spell lengths for each plant
gen manfran_ast=manfran
gen mantill_ast=mantill
replace manfran_ast=. if manfran_ast==0
replace mantill_ast=. if mantill_ast==0
replace manfran_ast=. if astnr=="00000000"
replace mantill_ast=. if astnr=="00000000"
gen spell_ast=(mantill_ast-manfran_ast)+1

* Total months at plant
bysort lopnr astnr: egen spellsum_ast=sum(spell_ast)
gen temp=1 if spell_ast==.
bysort lopnr astnr: egen temp2=max(temp)
replace spellsum_ast=. if temp2==1

bysort lopnr astnr: egen manmax_ast=max(mantill_ast)
replace manmax_ast=. if temp2==1
bysort lopnr astnr: egen manmin_ast=min(manfran_ast)
replace manmin_ast=. if temp2==1
gen spellsum_ast2=(manmax_ast-manmin_ast)+1
egen spellsum_ast3=rowmin(spellsum_ast spellsum_ast2)

* Months at highest income plant
gen spellsum_ast4=spellsum_ast3 if astnr==max_ast2 & max_ast2~="00000000"
bysort lopnr: egen spellsum_ast5=max(spellsum_ast4)

* Clean - plant
drop lonfink_ast max_ast spell_ast spellsum_ast temp temp2 manmax_ast manmin_ast spellsum_ast2 spellsum_ast3 spellsum_ast4
rename spellsum_ast5 spellsum_ast
lab var spellsum_ast "Months worked at highest income plant"

* Final clean
drop manfran manfran_ast mantill mantill_ast lonfink ftgnr astnr jobrank number_jobs number_ftg number_ast lonfink_ftg max_ftg ftgrank max_ast2
rename max_astnr astnr
rename max_ftgnr ftgnr
replace astnr="" if astnr=="00000000"
rename maxlon_ftg lonfink_ftg
rename maxlon_ast lonfink_ast
label var lonfink_ftg "Income at highest income firm"
label var lonfink_ast "Income at highest income plant"
label var ftgnr "Firm with highest total income"
lab var astnr "Plant with highest total income"

duplicates drop lopnr, force
sort lopnr ftgnr astnr 
save modified/key19`i', replace
}

* 2000-2006
forvalues i=0(1)6{
clear
use lonfink perslopnr ftglopnr_su astlopnr_su manfran mantill using rams/anst0`i'.dta
replace astlopnr_su="00000000" if astlopnr_su==""

gen year=2000+`i'
rename perslopnr lopnr
rename ftglopnr_su ftgnr
rename astlopnr_su astnr

*rank jobentries by income
drop if lonfink==.
drop if lonfink<=0
bysort lopnr: egen jobrank=rank(lonfink),f

* Create number of maximum number of workplaces
bysort lopnr: egen number_jobs=max(jobrank)

* Number of firms in which individual works
egen job_ftg_number=group(lopnr ftgnr)
bysort lopnr: egen max_ftg=max(job_ftg_number)
bysort lopnr: egen min_ftg=min(job_ftg_number)
gen number_ftg=(max_ftg-min_ftg)+1

* Number of plants in which individual works
egen job_ast_number=group(lopnr astnr)
bysort lopnr: egen max_ast=max(job_ast_number)
bysort lopnr: egen min_ast=min(job_ast_number)
gen number_ast=(max_ast-min_ast)+1

lab var number_jobs "Total number of individual entries"
lab var number_ftg "Total number of firms by individual"
lab var number_ast "Total number of plants by individual"

drop max_ftg min_ftg max_ast min_ast job_ftg_number job_ast_number

* Drop individuals that have the same income in the same firm more than one time
duplicates tag lopnr ftgnr lonfink, gen(duptag)
drop if duptag>=1
drop duptag

* Sum income by firm and plant, respectively
bysort lopnr ftgnr: egen lonfink_ftg=sum(lonfink)
bysort lopnr astnr: egen lonfink_ast=sum(lonfink)
replace lonfink_ast=. if astnr=="00000000"

*** Firm
* Find firm with highest income
bysort lopnr: egen maxlon_ftg=max(lonfink_ftg)
gen max_ftg=ftgnr if lonfink_ftg==maxlon_ftg
bysort lopnr: egen max_ftgnr=mode(max_ftg),maxmode

* Find plant of highest income firm. Priority is given to plants (within firm) that are non-missing
bysort lopnr max_ftg: egen tempink=rank(lonfink_ast),field
gen ast_max=astnr if max_ftg==ftgnr & tempink==1
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==2
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==3
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==4
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==5
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==6
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==7
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==8
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==9
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==10
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==11
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==12
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==13
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==14
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==15
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr
bysort lopnr: egen ftg_ast=mode(ast_max),maxmode 
lab var ftg_ast "Plant matched to highest income firm"

* Create spell lengths
gen manfran_ftg=manfran
gen mantill_ftg=mantill
replace manfran_ftg=. if manfran_ftg==0
replace mantill_ftg=. if mantill_ftg==0
gen spell_ftg=(mantill_ftg-manfran_ftg)+1

* Total months at firm
bysort lopnr ftgnr: egen spellsum_ftg=sum(spell_ftg)
gen temp=1 if spell_ftg==.
bysort lopnr ftgnr: egen temp2=max(temp)
replace spellsum_ftg=. if temp2==1
drop temp

bysort lopnr ftgnr: egen manmax_ftg=max(mantill_ftg)
replace manmax_ftg=. if temp2==1
bysort lopnr ftgnr: egen manmin_ftg=min(manfran_ftg)
replace manmin_ftg=. if temp2==1
gen spellsum_ftg2=(manmax_ftg-manmin_ftg)+1
egen spellsum_ftg3=rowmin(spellsum_ftg spellsum_ftg2)

* Months worked at highest income firm
gen spellsum_ftg4=spellsum_ftg3 if ftgnr==max_ftgnr & max_ftg~=""
bysort lopnr: egen spellsum_ftg5=max(spellsum_ftg4)

* Clean - firm
drop spell_ftg temp2 spellsum_ftg spellsum_ftg2 spellsum_ftg3 spellsum_ftg4 manmax_ftg manmin_ftg manfran_ftg mantill_ftg tempink ast_max 
rename spellsum_ftg5 spellsum_ftg
lab var spellsum_ftg "Months worked at highest income firm"
replace ftg_ast="" if ftg_ast=="00000000"

*** Plant

* Find plant with highest income (If multiple plants with the same highest income, pick the one corresponding to the highest income firm)
bysort lopnr: egen maxlon_ast=max(lonfink_ast)
gen max_ast=astnr if lonfink_ast==maxlon_ast
bysort lopnr: egen ftgrank=rank(lonfink_ftg) if max_ast~="",unique
gen max_ast2=max_ast if ftgrank==1
bysort lopnr: egen max_astnr=mode(max_ast2)
gen temp=ftgnr if max_ast2~=""
bysort lopnr: egen ast_ftg=mode(temp)
drop temp
lab var ast_ftg "Firm matched to highest income plant"

* Create spell lengths for each plant
gen manfran_ast=manfran
gen mantill_ast=mantill
replace manfran_ast=. if manfran_ast==0
replace mantill_ast=. if mantill_ast==0
replace manfran_ast=. if astnr=="00000000"
replace mantill_ast=. if astnr=="00000000"
gen spell_ast=(mantill_ast-manfran_ast)+1

* Total months at plant
bysort lopnr astnr: egen spellsum_ast=sum(spell_ast)
gen temp=1 if spell_ast==.
bysort lopnr astnr: egen temp2=max(temp)
replace spellsum_ast=. if temp2==1

bysort lopnr astnr: egen manmax_ast=max(mantill_ast)
replace manmax_ast=. if temp2==1
bysort lopnr astnr: egen manmin_ast=min(manfran_ast)
replace manmin_ast=. if temp2==1
gen spellsum_ast2=(manmax_ast-manmin_ast)+1
egen spellsum_ast3=rowmin(spellsum_ast spellsum_ast2)

* Months at highest income plant
gen spellsum_ast4=spellsum_ast3 if astnr==max_ast2 & max_ast2~="00000000"
bysort lopnr: egen spellsum_ast5=max(spellsum_ast4)

* Clean - plant
drop lonfink_ast max_ast spell_ast spellsum_ast temp temp2 manmax_ast manmin_ast spellsum_ast2 spellsum_ast3 spellsum_ast4
rename spellsum_ast5 spellsum_ast
lab var spellsum_ast "Months worked at highest income plant"

* Final clean
drop manfran manfran_ast mantill mantill_ast lonfink ftgnr astnr jobrank number_jobs number_ftg number_ast lonfink_ftg max_ftg ftgrank max_ast2
rename max_astnr astnr
rename max_ftgnr ftgnr
replace astnr="" if astnr=="00000000"
rename maxlon_ftg lonfink_ftg
rename maxlon_ast lonfink_ast
label var lonfink_ftg "Income at highest income firm"
label var lonfink_ast "Income at highest income plant"
label var ftgnr "Firm with highest total income"
lab var astnr "Plant with highest total income"

duplicates drop lopnr, force
sort lopnr ftgnr astnr 
save modified/key200`i',replace
}

* 2007
forvalues i=7(1)7{
clear
use lonfink perslopnr ftglopnr_su astlopnr_su manfran mantill using rams/anst0`i'.dta
replace astlopnr_su="00000000" if astlopnr_su==""

gen year=2000+`i'
rename perslopnr lopnr
rename ftglopnr_su ftgnr
rename astlopnr_su astnr

*rank jobentries by income
drop if lonfink==.
drop if lonfink<=0
bysort lopnr: egen jobrank=rank(lonfink),f

* Create number of maximum number of workplaces
bysort lopnr: egen number_jobs=max(jobrank)

* Number of firms in which individual works
egen job_ftg_number=group(lopnr ftgnr)
bysort lopnr: egen max_ftg=max(job_ftg_number)
bysort lopnr: egen min_ftg=min(job_ftg_number)
gen number_ftg=(max_ftg-min_ftg)+1

* Number of plants in which individual works
egen job_ast_number=group(lopnr astnr)
bysort lopnr: egen max_ast=max(job_ast_number)
bysort lopnr: egen min_ast=min(job_ast_number)
gen number_ast=(max_ast-min_ast)+1

lab var number_jobs "Total number of individual entries"
lab var number_ftg "Total number of firms by individual"
lab var number_ast "Total number of plants by individual"

drop max_ftg min_ftg max_ast min_ast job_ftg_number job_ast_number

* Drop individuals that have the same income in the same firm more than one time
duplicates tag lopnr ftgnr lonfink, gen(duptag)
drop if duptag>=1
drop duptag

* Sum income by firm and plant, respectively
bysort lopnr ftgnr: egen lonfink_ftg=sum(lonfink)
bysort lopnr astnr: egen lonfink_ast=sum(lonfink)
replace lonfink_ast=. if astnr=="00000000"

*** Firm
* Find firm with highest income
bysort lopnr: egen maxlon_ftg=max(lonfink_ftg)
gen max_ftg=ftgnr if lonfink_ftg==maxlon_ftg
bysort lopnr: egen max_ftgnr=mode(max_ftg), maxmode

* Find plant of highest income firm. Priority is given to plants (within firm) that are non-missing
bysort lopnr max_ftg: egen tempink=rank(lonfink_ast),field
gen ast_max=astnr if max_ftg==ftgnr & tempink==1
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==2
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==3
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==4
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==5
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==6
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==7
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==8
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==9
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==10
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==11
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==12
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==13
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==14
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr & tempink==15
replace ast_max=astnr if ast_max=="" & max_ftg==ftgnr
bysort lopnr: egen ftg_ast=mode(ast_max),maxmode 
lab var ftg_ast "Plant matched to highest income firm"

* Create spell lengths
gen manfran_ftg=manfran
gen mantill_ftg=mantill
replace manfran_ftg=. if manfran_ftg==0
replace mantill_ftg=. if mantill_ftg==0
gen spell_ftg=(mantill_ftg-manfran_ftg)+1

* Total months at firm
bysort lopnr ftgnr: egen spellsum_ftg=sum(spell_ftg)
gen temp=1 if spell_ftg==.
bysort lopnr ftgnr: egen temp2=max(temp)
replace spellsum_ftg=. if temp2==1
drop temp 

bysort lopnr ftgnr: egen manmax_ftg=max(mantill_ftg)
replace manmax_ftg=. if temp2==1
bysort lopnr ftgnr: egen manmin_ftg=min(manfran_ftg)
replace manmin_ftg=. if temp2==1
gen spellsum_ftg2=(manmax_ftg-manmin_ftg)+1
egen spellsum_ftg3=rowmin(spellsum_ftg spellsum_ftg2)

* Months worked at highest income firm
gen spellsum_ftg4=spellsum_ftg3 if ftgnr==max_ftgnr & max_ftg~=""
bysort lopnr: egen spellsum_ftg5=max(spellsum_ftg4)

* Clean - firm
drop spell_ftg temp2 spellsum_ftg spellsum_ftg2 spellsum_ftg3 spellsum_ftg4 manmax_ftg manmin_ftg manfran_ftg mantill_ftg tempink ast_max 
rename spellsum_ftg5 spellsum_ftg
lab var spellsum_ftg "Months worked at highest income firm"
replace ftg_ast="" if ftg_ast=="00000000"

*** Plant

* Find plant with highest income (If multiple plants with the same highest income, pick the one corresponding to the highest income firm)
bysort lopnr: egen maxlon_ast=max(lonfink_ast)
gen max_ast=astnr if lonfink_ast==maxlon_ast
bysort lopnr: egen ftgrank=rank(lonfink_ftg) if max_ast~="",unique
gen max_ast2=max_ast if ftgrank==1
bysort lopnr: egen max_astnr=mode(max_ast2)
gen temp=ftgnr if max_ast2~=""
bysort lopnr: egen ast_ftg=mode(temp)
drop temp
lab var ast_ftg "Firm matched to highest income plant"

* Create spell lengths for each plant
gen manfran_ast=manfran
gen mantill_ast=mantill
replace manfran_ast=. if manfran_ast==0
replace mantill_ast=. if mantill_ast==0
replace manfran_ast=. if astnr=="00000000"
replace mantill_ast=. if astnr=="00000000"
gen spell_ast=(mantill_ast-manfran_ast)+1

* Total months at plant
bysort lopnr astnr: egen spellsum_ast=sum(spell_ast)
gen temp=1 if spell_ast==.
bysort lopnr astnr: egen temp2=max(temp)
replace spellsum_ast=. if temp2==1

bysort lopnr astnr: egen manmax_ast=max(mantill_ast)
replace manmax_ast=. if temp2==1
bysort lopnr astnr: egen manmin_ast=min(manfran_ast)
replace manmin_ast=. if temp2==1
gen spellsum_ast2=(manmax_ast-manmin_ast)+1
egen spellsum_ast3=rowmin(spellsum_ast spellsum_ast2)

* Months at highest income plant
gen spellsum_ast4=spellsum_ast3 if astnr==max_ast2 & max_ast2~="00000000"
bysort lopnr: egen spellsum_ast5=max(spellsum_ast4)

* Clean - plant
drop lonfink_ast max_ast spell_ast spellsum_ast temp temp2 manmax_ast manmin_ast spellsum_ast2 spellsum_ast3 spellsum_ast4
rename spellsum_ast5 spellsum_ast
lab var spellsum_ast "Months worked at highest income plant"

* Final clean
drop manfran manfran_ast mantill mantill_ast lonfink ftgnr astnr jobrank number_jobs number_ftg number_ast lonfink_ftg max_ftg ftgrank max_ast2
rename max_astnr astnr
rename max_ftgnr ftgnr
replace astnr="" if astnr=="00000000"
rename maxlon_ftg lonfink_ftg
rename maxlon_ast lonfink_ast
label var lonfink_ftg "Income at highest income firm"
label var lonfink_ast "Income at highest income plant"
label var ftgnr "Firm with highest total income"
lab var astnr "Plant with highest total income"

duplicates drop lopnr, force
destring astnr,replace
tostring astnr,replace
destring ftg_ast,replace
tostring ftg_ast,replace
destring lopnr, replace
tostring lopnr,replace
replace astnr="" if astnr=="0"
replace astnr="" if astnr=="."
replace ftg_ast="" if ftg_ast=="0"
replace ftg_ast="" if ftg_ast=="."
sort lopnr ftgnr astnr
save modified/key200`i',replace
}

*2008
forvalues i=8(1)8{
clear
use lonfink perslopnr ftglopnr_su astlopnr_su manfran mantill using rams/anst0`i'.dta
replace astlopnr_su=0 if astlopnr_su==.

gen year=2000+`i'
rename perslopnr lopnr
rename ftglopnr_su ftgnr
rename astlopnr_su astnr

*rank jobentries by income
drop if lonfink==.
drop if lonfink<=0
bysort lopnr: egen jobrank=rank(lonfink),f

* Create number of maximum number of workplaces
bysort lopnr: egen number_jobs=max(jobrank)

* Number of firms
egen job_ftg_number=group(lopnr ftgnr)
bysort lopnr: egen max_ftg=max(job_ftg_number)
bysort lopnr: egen min_ftg=min(job_ftg_number)
gen number_ftg=(max_ftg-min_ftg)+1

* Number of plants
egen job_ast_number=group(lopnr astnr)
bysort lopnr: egen max_ast=max(job_ast_number)
bysort lopnr: egen min_ast=min(job_ast_number)
gen number_ast=(max_ast-min_ast)+1

lab var number_jobs "Total number of individual entries"
lab var number_ftg "Total number of firms by individual"
lab var number_ast "Total number of plants by individual"

drop max_ftg min_ftg max_ast min_ast job_ftg_number job_ast_number

* Drop individuals that have the same income in the same firm more than one time
duplicates tag lopnr ftgnr lonfink, gen(duptag)
drop if duptag>=1
drop duptag

* Sum income by firm and plant, respectively
bysort lopnr ftgnr: egen lonfink_ftg=sum(lonfink)
bysort lopnr astnr: egen lonfink_ast=sum(lonfink)
replace lonfink_ast=. if astnr==0

*** Firm
* Find firm with highest income
bysort lopnr: egen maxlon_ftg=max(lonfink_ftg)
gen max_ftg=ftgnr if lonfink_ftg==maxlon_ftg
bysort lopnr: egen max_ftgnr=mode(max_ftg), maxmode

* Find plant of highest income firm. Priority is given to plants (within firm) that are non-missing
bysort lopnr max_ftg: egen tempink=rank(lonfink_ast),field
gen ast_max=astnr if max_ftg==ftgnr & tempink==1
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==2
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==3
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==4
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==5
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==6
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==7
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==8
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==9
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==10
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==11
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==12
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==13
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==14
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==15
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr
bysort lopnr: egen ftg_ast=mode(ast_max),maxmode 
lab var ftg_ast "Plant matched to highest income firm"

* Create spell lengths
gen manfran_ftg=manfran
gen mantill_ftg=mantill
replace manfran_ftg=. if manfran_ftg==0
replace manfran_ftg=. if manfran_ftg==99
replace mantill_ftg=. if mantill_ftg==0
replace mantill_ftg=. if mantill_ftg==99
gen spell_ftg=(mantill_ftg-manfran_ftg)+1

* Total months at firm
bysort lopnr ftgnr: egen spellsum_ftg=sum(spell_ftg)
gen temp=1 if spell_ftg==.
bysort lopnr ftgnr: egen temp2=max(temp)
replace spellsum_ftg=. if temp2==1
drop temp

bysort lopnr ftgnr: egen manmax_ftg=max(mantill_ftg)
replace manmax_ftg=. if temp2==1
bysort lopnr ftgnr: egen manmin_ftg=min(manfran_ftg)
replace manmin_ftg=. if temp2==1
gen spellsum_ftg2=(manmax_ftg-manmin_ftg)+1
egen spellsum_ftg3=rowmin(spellsum_ftg spellsum_ftg2)

* Months worked at highest income firm
gen spellsum_ftg4=spellsum_ftg3 if ftgnr==max_ftgnr & max_ftg~=""
bysort lopnr: egen spellsum_ftg5=max(spellsum_ftg4)

* Clean - firm
drop spell_ftg temp2 spellsum_ftg spellsum_ftg2 spellsum_ftg3 spellsum_ftg4 manmax_ftg manmin_ftg manfran_ftg mantill_ftg tempink ast_max 
rename spellsum_ftg5 spellsum_ftg
lab var spellsum_ftg "Months worked at highest income firm"
replace ftg_ast=. if ftg_ast==0

*** Plant

* Find plant with highest income (If multiple plants with the same highest income, pick the one corresponding to the highest income firm)
bysort lopnr: egen maxlon_ast=max(lonfink_ast)
gen max_ast=astnr if lonfink_ast==maxlon_ast
bysort lopnr: egen ftgrank=rank(lonfink_ftg) if max_ast~=.,unique
gen max_ast2=max_ast if ftgrank==1
bysort lopnr: egen max_astnr=mode(max_ast2)
gen temp=ftgnr if max_ast2~=.
bysort lopnr: egen ast_ftg=mode(temp)
drop temp
lab var ast_ftg "Firm matched to highest income plant"

* Create spell lengths
gen manfran_ast=manfran
gen mantill_ast=mantill
replace manfran_ast=. if manfran_ast==0
replace manfran_ast=. if manfran_ast==99
replace mantill_ast=. if mantill_ast==0
replace mantill_ast=. if mantill_ast==99
replace manfran_ast=. if astnr==0
replace mantill_ast=. if astnr==0
gen spell_ast=(mantill_ast-manfran_ast)+1

* Total months at plant
bysort lopnr astnr: egen spellsum_ast=sum(spell_ast)
gen temp=1 if spell_ast==.
bysort lopnr astnr: egen temp2=max(temp)
replace spellsum_ast=. if temp2==1

bysort lopnr astnr: egen manmax_ast=max(mantill_ast)
replace manmax_ast=. if temp2==1
bysort lopnr astnr: egen manmin_ast=min(manfran_ast)
replace manmin_ast=. if temp2==1
gen spellsum_ast2=(manmax_ast-manmin_ast)+1
egen spellsum_ast3=rowmin(spellsum_ast spellsum_ast2)

* Months at highest income plant
gen spellsum_ast4=spellsum_ast3 if astnr==max_ast2 & max_ast2~=0
bysort lopnr: egen spellsum_ast5=max(spellsum_ast4)

* Clean - plant
drop lonfink_ast max_ast spell_ast spellsum_ast temp temp2 manmax_ast manmin_ast spellsum_ast2 spellsum_ast3 spellsum_ast4
rename spellsum_ast5 spellsum_ast
lab var spellsum_ast "Months worked at highest income plant"

* Final clean
drop manfran manfran_ast mantill mantill_ast lonfink ftgnr astnr jobrank number_jobs number_ftg number_ast lonfink_ftg max_ftg ftgrank max_ast2
rename max_astnr astnr
rename max_ftgnr ftgnr
rename maxlon_ftg lonfink_ftg
rename maxlon_ast lonfink_ast
label var lonfink_ftg "Income at highest income firm"
label var lonfink_ast "Income at highest income plant"
label var ftgnr "Firm with highest total income"
lab var astnr "Plant with highest total income"

duplicates drop lopnr, force
tostring astnr,replace
tostring ftg_ast,replace
replace astnr="" if astnr=="0"
replace astnr="" if astnr=="."
replace ftg_ast="" if ftg_ast=="0"
replace ftg_ast="" if ftg_ast=="."
sort lopnr ftgnr astnr
save modified/key200`i',replace
}

*2009 
forvalues i=9(1)9{
clear
use lonfink perslopnr ftglopnr_su astlopnr_su manfran mantill using rams/anst0`i'.dta
replace astlopnr_su=0 if astlopnr_su==.

gen year=2000+`i'
rename perslopnr lopnr
rename ftglopnr_su ftgnr
rename astlopnr_su astnr

*rank jobentries by income
drop if lonfink==.
drop if lonfink<=0
bysort lopnr: egen jobrank=rank(lonfink),f

* Create number of jobs
bysort lopnr: egen number_jobs=max(jobrank)

* Number of firms
egen job_ftg_number=group(lopnr ftgnr)
bysort lopnr: egen max_ftg=max(job_ftg_number)
bysort lopnr: egen min_ftg=min(job_ftg_number)
gen number_ftg=(max_ftg-min_ftg)+1

* Number of plants
egen job_ast_number=group(lopnr astnr)
bysort lopnr: egen max_ast=max(job_ast_number)
bysort lopnr: egen min_ast=min(job_ast_number)
gen number_ast=(max_ast-min_ast)+1

lab var number_jobs "Total number of individual entries"
lab var number_ftg "Total number of firms by individual"
lab var number_ast "Total number of plants by individual"

drop max_ftg min_ftg max_ast min_ast job_ftg_number job_ast_number

* Drop individuals that have the same income in the same firm more than one time
duplicates tag lopnr ftgnr lonfink, gen(duptag)
drop if duptag>=1
drop duptag

* Sum income by firm and plant, respectively
bysort lopnr ftgnr: egen lonfink_ftg=sum(lonfink)
bysort lopnr astnr: egen lonfink_ast=sum(lonfink)
replace lonfink_ast=. if astnr==0

*** Firm
* Find firm with highest income
bysort lopnr: egen maxlon_ftg=max(lonfink_ftg)
gen max_ftg=ftgnr if lonfink_ftg==maxlon_ftg
bysort lopnr: egen max_ftgnr=mode(max_ftg),maxmode

* Find plant of highest income firm. Priority is given to plants (within firm) that are non-missing
bysort lopnr max_ftg: egen tempink=rank(lonfink_ast),field
gen ast_max=astnr if max_ftg==ftgnr & tempink==1
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==2
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==3
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==4
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==5
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==6
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==7
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==8
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==9
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==10
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==11
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==12
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==13
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==14
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr & tempink==15
replace ast_max=astnr if ast_max==. & max_ftg==ftgnr
bysort lopnr: egen ftg_ast=mode(ast_max),maxmode 
lab var ftg_ast "Plant matched to highest income firm"

* Create spell lengths
gen manfran_ftg=manfran
gen mantill_ftg=mantill
replace manfran_ftg=. if manfran_ftg==0
replace mantill_ftg=. if mantill_ftg==0
gen spell_ftg=(mantill_ftg-manfran_ftg)+1

* Total months at each firm
bysort lopnr ftgnr: egen spellsum_ftg=sum(spell_ftg)
gen temp=1 if spell_ftg==.
bysort lopnr ftgnr: egen temp2=max(temp)
replace spellsum_ftg=. if temp2==1
drop temp 

bysort lopnr ftgnr: egen manmax_ftg=max(mantill_ftg)
replace manmax_ftg=. if temp2==1
bysort lopnr ftgnr: egen manmin_ftg=min(manfran_ftg)
replace manmin_ftg=. if temp2==1
gen spellsum_ftg2=(manmax_ftg-manmin_ftg)+1
egen spellsum_ftg3=rowmin(spellsum_ftg spellsum_ftg2)

* Months worked at highest income firm
gen spellsum_ftg4=spellsum_ftg3 if ftgnr==max_ftgnr & max_ftg~=""
bysort lopnr: egen spellsum_ftg5=max(spellsum_ftg4)

* Clean - firm
drop spell_ftg temp2 spellsum_ftg spellsum_ftg2 spellsum_ftg3 spellsum_ftg4 manmax_ftg manmin_ftg manfran_ftg mantill_ftg tempink ast_max 
rename spellsum_ftg5 spellsum_ftg
lab var spellsum_ftg "Months worked at highest income firm"
replace ftg_ast=. if ftg_ast==0

*** Plant
* Find plant with highest income (If multiple plants with the same highest income, pick the one corresponding to the highest income firm)
bysort lopnr: egen maxlon_ast=max(lonfink_ast)
gen max_ast=astnr if lonfink_ast==maxlon_ast
bysort lopnr: egen ftgrank=rank(lonfink_ftg) if max_ast~=.,unique
gen max_ast2=max_ast if ftgrank==1
bysort lopnr: egen max_astnr=mode(max_ast2)
gen temp=ftgnr if max_ast2~=.
bysort lopnr: egen ast_ftg=mode(temp)
drop temp
lab var ast_ftg "Firm matched to highest income plant"

* Create spell lengths
gen manfran_ast=manfran
gen mantill_ast=mantill
replace manfran_ast=. if manfran_ast==0
replace mantill_ast=. if mantill_ast==0
replace manfran_ast=. if astnr==0
replace mantill_ast=. if astnr==0
gen spell_ast=(mantill_ast-manfran_ast)+1

* Total months at each plant
bysort lopnr astnr: egen spellsum_ast=sum(spell_ast)
gen temp=1 if spell_ast==.
bysort lopnr astnr: egen temp2=max(temp)
replace spellsum_ast=. if temp2==1

bysort lopnr astnr: egen manmax_ast=max(mantill_ast)
replace manmax_ast=. if temp2==1
bysort lopnr astnr: egen manmin_ast=min(manfran_ast)
replace manmin_ast=. if temp2==1
gen spellsum_ast2=(manmax_ast-manmin_ast)+1
egen spellsum_ast3=rowmin(spellsum_ast spellsum_ast2)

* Months at highest income plant
gen spellsum_ast4=spellsum_ast3 if astnr==max_astnr & max_ast2~=0
bysort lopnr: egen spellsum_ast5=max(spellsum_ast4)

* Clean - plant
drop lonfink_ast max_ast spell_ast spellsum_ast temp temp2 manmax_ast manmin_ast spellsum_ast2 spellsum_ast3 spellsum_ast4
rename spellsum_ast5 spellsum_ast
lab var spellsum_ast "Months worked at highest income plant"

* Final clean
drop manfran manfran_ast mantill mantill_ast lonfink ftgnr astnr jobrank number_jobs number_ftg number_ast lonfink_ftg max_ftg ftgrank max_ast2
rename max_astnr astnr
rename max_ftgnr ftgnr

tostring astnr,replace
tostring ftg_ast,replace
replace astnr="" if astnr=="0"
replace astnr="" if astnr=="."
replace ftg_ast="" if ftg_ast=="0"
replace ftg_ast="" if ftg_ast=="."
rename maxlon_ftg lonfink_ftg
rename maxlon_ast lonfink_ast
label var lonfink_ftg "Income at highest income firm"
label var lonfink_ast "Income at highest income plant"
label var ftgnr "Firm with highest total income"
lab var astnr "Plant with highest total income"
duplicates drop lopnr, force
sort lopnr ftgnr astnr 

save modified/key200`i',replace
}

*3. Generating consistent sni codes
* Generates sniast.dta and sniftg.dta in modified containing consistent sni classifications for all firms and plant with ftgnr~="00000000" and astnr~="00000000"
* gross sample i.e limitation on private firms not implemented, firmsize implemented in last step
* 5 digit sni (sni92) for years 1989-2009. For firms "alive" in 1989 sni code 1989 is  extrapolated backwards (ie allow for no change of sni the early years)
* For ALL firms reduced level sni astsnib ftgsnib is coded (consistent across all years). 42 different industries.
* This used to be done in /home/workgroup/firmiq/Analys/sni.do, but is now incorporated in this file (2014-12-15)
* sni.do generates sniast.dta and sniftg.dta in modified containing consistent sni classifications for all firms and plant with ftgnr~="00000000" and astnr~="00000000"
* firmsize implemented in last step
* 5 digit sni (sni92) for years 1989-2007
* For firms "alive" in 1989 sni code 1989 is  extrapolated backwards (ie allow for no change of sni the early years)
* This imputess a 5 digit sni for X out of Y firms  and X out of Y plants 1985-1989
* For ALL firms reduced level sni astsnib ftgsnib is coded (consistent across all years). 42 different industries, this measure is used for initial industry breakdowns
* Last run: 2014-12-15

clear
set mem 10g
set more off
cd /home/workgroup/firmiq/data

* Own key between sni69 -sni92 (4 positions)

use ftglopnr_su ar sni69 sni92 omsattning using "/home/workgroups/firmiq/data/fek/industristat_arbst_1985_2002.dta"
destring ar, g(year)
drop ar
drop if year<1990|year>1993

replace sni69=substr(sni69,1,4)
replace sni92=substr(sni92,1,4)
destring sni69 sni92, replace

sort sni69 -omsattning
by sni69: egen x=rank(sni92),field
keep if x==1
duplicates drop sni69,force
keep sni69 sni92
save temp/egen_nyckel_sni69_sni92_4stall,replace

*build temporary datasets
*1985-1988
forvalues i=85 (1) 88 {
use astsnib ftgsnib ftglopnr_su astlopnr_su ftgstorl aststorl using "/home/workgroups/firmiq/data/rams/ftgastgeo`i'.dta"
gen year=1900+`i'
rename astlopnr_su astnr
rename ftglopnr_su ftgnr
sort astnr
save "/home/workgroups/firmiq/data/temp/sni`i'.dta" ,replace
}

*1989-1999
forvalues i=89 (1) 99 {
use astsni ftgsni ftglopnr_su astlopnr_su ftgstorl aststorl using "/home/workgroups/firmiq/data/rams/ftgastgeo`i'.dta"
gen year=1900+`i'
rename astlopnr_su astnr
rename ftglopnr_su ftgnr
destring astsni ftgsni,replace
sort astnr
save "/home/workgroups/firmiq/data/temp/sni`i'.dta",replace 
}

*2000-2007
forvalues i=0 (1) 7 {
use astsni ftgsni ftglopnr_su astlopnr_su ftgstorl aststorl using "/home/workgroups/firmiq/data/rams/ftgastgeo0`i'.dta"
gen year=2000+`i'
rename astlopnr_su astnr
tostring astnr,replace
rename ftglopnr_su ftgnr
destring astsni ftgsni,replace
sort astnr
save "/home/workgroups/firmiq/data/temp/sni0`i'.dta" ,replace
}

*2008
use astsni02 ftgsni02 ftglopnr_su astlopnr_su ftgstorl aststorl using "/home/workgroups/firmiq/data/rams/ftgastgeo08.dta"
rename ftgsni02 ftgsni
rename astsni02 astsni
gen year=2008
rename astlopnr_su astnr
tostring astnr,replace
rename ftglopnr_su ftgnr
destring astsni ftgsni,replace
sort astnr
save "/home/workgroups/firmiq/data/temp/sni08.dta" ,replace

*2009
use astsni02 ftgsni02 ftglopnr_su astlopnr_su ftgstorl aststorl using "/home/workgroups/firmiq/data/rams/ftgastgeo09.dta"
rename ftgsni02 ftgsni
rename astsni02 astsni
gen year=2009
rename astlopnr_su astnr
tostring astnr,replace
rename ftglopnr_su ftgnr
destring astsni ftgsni,replace
sort astnr
save "/home/workgroups/firmiq/data/temp/sni09.dta" ,replace

*append and collapse

clear
use "/home/workgroups/firmiq/data/temp/sni85"
tostring astnr,replace
forvalues i=86(1)99 {
append using "/home/workgroups/firmiq/data/temp/sni`i'"
}
forvalues i=0(1)9 {
append using "/home/workgroups/firmiq/data/temp/sni0`i'"
}
replace astsni=. if astsni==0
replace ftgsni=. if ftgsni==0

preserve
drop if astnr=="00000000"
drop if astnr=="0"
keep astsni astnr astsnib year
gsort astnr year -astsni
duplicates drop astnr year,force
save "/home/workgroups/firmiq/data/temp/sniast",replace
restore

gsort ftgnr year -ftgsni
duplicates drop ftgnr year,force
keep ftgsni ftgnr ftgsnib year
save "/home/workgroups/firmiq/data/temp/sniftg",replace

*Firm Level industry code imputation

*1. Impute back
use "/home/workgroups/firmiq/data/temp/sniftg"
gsort ftgnr -year
gen ftgsni2=int(ftgsni/1000)
gen ftgsni3=int(ftgsni/100)
gen ftgsni4=int(ftgsni/10)
gen D_replace_ftgsni=0
replace D_replace_ftgsni=1 if ftgsni==.
by ftgnr: replace  ftgsni= ftgsni[_n-1] if missing(ftgsni) 
by ftgnr: replace  ftgsni2= ftgsni2[_n-1] if missing(ftgsni2)
by ftgnr: replace  ftgsni3= ftgsni3[_n-1] if missing(ftgsni3) 
by ftgnr: replace  ftgsni4= ftgsni4[_n-1] if missing(ftgsni4)
replace D_replace_ftgsni=2 if D_replace_ftgsni==1 & ftgsni!=.
tab D_replace_ftgsni
sort ftgnr year
save "/home/workgroups/firmiq/data/modified/sniftg",replace

*This part picks up sni69 from industristat and use own key to impute 2-digit sni92

*collect and transfer data from fek (industristat) 
clear
use ftglopnr_su ar sni69 sni92 using fek/industristat_ftg_1985_2002.dta
destring ar, replace
rename ar year
rename ftglopnr_su ftgnr
rename sni92 sni92_fek
keep if year<1991
sort ftgnr year
rename sni69 sni69_5
gen sni69=substr(sni69_5,1,4)
destring sni69 sni69_5 sni92_fek,replace
sort sni69

*this part comes from Jonas trade file "industry_aggregates_ftg_register.do" (first part of key)
merge m:1 sni69 using temp/egen_nyckel_sni69_sni92_4stall.dta
drop if _merge==2
drop _merge

sort sni69
g ftgsni2=int(sni92/100)
g sni69_2=int(sni69/100)

*second part of key: corrections
replace ftgsni2=1 if sni69_2==11
replace ftgsni2=2 if sni69_2==12
replace ftgsni2=5 if sni69_2==13
replace ftgsni2=10 if sni69_2==21
replace ftgsni2=11 if sni69_2==22
replace ftgsni2=14 if sni69==2903
replace ftgsni2=15 if sni69==3132
replace ftgsni2=17 if (sni69>=3211 & sni69<=3219)
replace ftgsni2=18 if sni69==3220 | sni69==3232
replace ftgsni2=19 if sni69==3231 | sni69==3233
replace ftgsni2=20 if sni69>=3311 & sni69<=3319
replace ftgsni2=21 if sni69>=3411 & sni69<=3419
replace ftgsni2=22 if sni69==3420
replace ftgsni2=25 if sni69==3513
replace ftgsni2=24 if sni69==3529
replace ftgsni2=23 if sni69==3530
replace ftgsni2=23 if sni69==3540
replace ftgsni2=25 if sni69==3551 | sni69==3559 | sni69==3560
replace ftgsni2=26 if sni69==3691
replace ftgsni2=27 if sni69==3710 | sni69==3720
replace ftgsni2=28 if sni69==3811 
replace ftgsni2=36 if sni69==3812
replace ftgsni2=28 if sni69==3813
replace ftgsni2=28 if sni69==3819
replace ftgsni2=29 if sni69==3823
replace ftgsni2=29 if sni69==3824
replace ftgsni2=30 if sni69==3825
replace ftgsni2=29 if sni69==3829
replace ftgsni2=31 if sni69==3831
replace ftgsni2=32 if sni69==3832
replace ftgsni2=29 if sni69==3833
replace ftgsni2=31 if sni69==3839
replace ftgsni2=34 if sni69==3843
replace ftgsni2=35 if sni69==3849
replace ftgsni2=33 if sni69==3851
replace ftgsni2=40 if sni69==4101 | sni69==4102
replace ftgsni2=41 if sni69==4200
replace ftgsni2=92 if sni69==9411 | sni69==9415
replace ftgsni2=74 if sni69==9592

replace ftgsni2=22 if sni69==9414
replace ftgsni2=33 if sni69==9331
replace ftgsni2=22 if sni69==8329
replace ftgsni2=50 if sni69==6129

replace ftgsni2=16 if sni69==9911
replace ftgsni2=5 if sni69==9931
replace ftgsni2=17 if sni69==9932
replace ftgsni2=20 if sni69==9933
replace ftgsni2=21 if sni69==9934
replace ftgsni2=25 if sni69==9935
replace ftgsni2=26 if sni69==9936
replace ftgsni2=27 if sni69==9937
replace ftgsni2=29 if sni69==9938
replace ftgsni2=36 if sni69==9939

* third part ofkey: fill blanks manually
drop if sni69==1000 & ftgsni2==.
replace ftgsni2=1 if sni69==1120 & ftgsni2==.
drop if sni69==3000 & ftgsni2==.
replace ftgsni2=22 if sni69_5==94144 & ftgsni2==.
replace ftgsni2=40 if sni69==4103 & ftgsni2==.
replace ftgsni2=45 if sni69_2==50 & ftgsni2==.
drop if sni69==6000 & ftgsni2==.
replace ftgsni2=37 if sni69_5==61117 & ftgsni2==.
replace ftgsni2=50 if (sni69==6131 | sni69==6143 | sni69==6129 | sni69==6241 | sni69==6242 | sni69==9513)  & ftgsni2==.
replace ftgsni2=51 if sni69_2==61  & ftgsni2==.
replace ftgsni2=52 if ((sni69_2==62 & sni69_5~=62323) | sni69==9511 | sni69==9512 | sni69==9514 | sni69==9519) & ftgsni2==.
replace ftgsni2=55 if (sni69_2==63 | sni69_5==62210) & ftgsni2==.
drop if sni69==7000 & ftgsni2==.
replace ftgsni2=60 if (sni69>=7111 & sni69<=7115)  & ftgsni2==.
replace ftgsni2=61 if (sni69>=7121 & sni69<=7122)  & ftgsni2==.
replace ftgsni2=62 if sni69==7131  & ftgsni2==.
replace ftgsni2=63 if (sni69==7116 | sni69==7123 | sni69==7132 | sni69==7191 | sni69==7192)  & ftgsni2==.
replace ftgsni2=64 if sni69==7200  & ftgsni2==.
drop if sni69==8000 & ftgsni2==.
replace ftgsni2=65 if sni69==8103  & ftgsni2==.
replace ftgsni2=71 if (sni69>=8330 | sni69_5==62323 | sni69_5==71169 | sni69_5==71239 | sni69_5==71320 | sni69_5==94121)  & ftgsni2==.
replace ftgsni2=72 if sni69==8323  & ftgsni2==.
replace ftgsni2=73 if sni69==9320 & ftgsni2==.
replace ftgsni2=74 if ((sni69>=8321 & sni69<=8329) | sni69_5==92003 | sni69_5==92004 | sni69_5==92005 | sni69_5==92009 | sni69==9592) & ftgsni2==.
replace ftgsni2=75 if sni69==9100 & ftgsni2==.
replace ftgsni2=80 if sni69==9310 & ftgsni2==.
replace ftgsni2=85 if (sni69==9331 | sni69==9332 | sni69==9340) & ftgsni2==.
replace ftgsni2=90 if (sni69_5>=92001 & sni69_5<=92002) & ftgsni2==.
replace ftgsni2=91 if sni69==9350 & ftgsni2==.
replace ftgsni2=92 if sni69_2==94 & ftgsni2==.
replace ftgsni2=93 if (sni69==9520 | sni69_5==9591 | sni69==9599)  & ftgsni2==.
replace ftgsni2=95 if sni69==9530 & ftgsni2==.

sort ftgnr year
keep ftgnr year ftgsni2 sni92_fek
rename ftgsni2 ftgsni2_fek
duplicates drop ftgnr year,force
save temp/impute_sni69_ftg,replace

* Merge translated values from SNI69

clear
use modified/sniftg
sort ftgnr year
merge 1:1 ftgnr year using temp/impute_sni69_ftg
drop if _merge==2
drop _merge
replace ftgsni2=ftgsni2_fek if missing(ftgsni2)
replace D_replace_ftgsni=3 if ftgsni2!=. & D_replace_ftgsni==1

*impute back
gsort ftgnr -year
by ftgnr: replace  ftgsni2= ftgsni2[_n-1] if missing(ftgsni2) & year<1990
replace D_replace_ftgsni=3 if ftgsni2!=. & D_replace_ftgsni==1
tab D_replace_ftgsni
drop sni92_fek ftgsni2_fek
sort ftgnr year
save modified/sniftg,replace

* Plant Level

*extrapolate back snicodes*

use "/home/workgroups/firmiq/data/temp/sniast"
g astsni2=int(astsni/1000)
g astsni3=int(astsni/100)
g astsni4=int(astsni/10)
g D_replace_astsni=0
replace D_replace_astsni=1 if astsni==.
gsort astnr -year
by astnr: replace  astsni= astsni[_n-1] if missing(astsni) 
by astnr: replace  astsni2= astsni2[_n-1] if missing(astsni2)
by astnr: replace  astsni3= astsni3[_n-1] if missing(astsni3) 
by astnr: replace  astsni4= astsni2[_n-1] if missing(astsni4)
replace D_replace_astsni=2 if D_replace_astsni==1 & astsni!=.
*D_replace_astsni==2 are imputed
tab D_replace_astsni
sort astnr year
save "/home/workgroups/firmiq/data/modified/sniast",replace

*This part picks up sni69 from industristat and use own key to impute 2-digit sni92

*collect and transfer data from fek (industristat) 
clear
use astlopnr_su ar sni69 sni92 using fek/industristat_arbst_1985_2002.dta
destring ar, replace
rename ar year
rename astlopnr_su astnr
rename sni92 sni92_fek
keep if year<1991
sort astnr year
rename sni69 sni69_5
gen sni69=substr(sni69_5,1,4)
destring sni69 sni69_5 sni92_fek,replace
sort sni69

*this part comes from Jonas trade file "industry_aggregates_ftg_register.do" first part of key
merge m:1 sni69 using temp/egen_nyckel_sni69_sni92_4stall.dta
drop if _merge==2
drop _merge

sort sni69
gen astsni2=int(sni92/100)
gen sni69_2=int(sni69/100)

*second part of key: corrections
replace astsni2=1 if sni69_2==11
replace astsni2=2 if sni69_2==12
replace astsni2=5 if sni69_2==13
replace astsni2=10 if sni69_2==21
replace astsni2=11 if sni69_2==22
replace astsni2=14 if sni69==2903
replace astsni2=15 if sni69==3132
replace astsni2=17 if (sni69>=3211 & sni69<=3219)
replace astsni2=18 if sni69==3220 | sni69==3232
replace astsni2=19 if sni69==3231 | sni69==3233
replace astsni2=20 if sni69>=3311 & sni69<=3319
replace astsni2=21 if sni69>=3411 & sni69<=3419
replace astsni2=22 if sni69==3420
replace astsni2=25 if sni69==3513
replace astsni2=24 if sni69==3529
replace astsni2=23 if sni69==3530
replace astsni2=23 if sni69==3540
replace astsni2=25 if sni69==3551 | sni69==3559 | sni69==3560
replace astsni2=26 if sni69==3691
replace astsni2=27 if sni69==3710 | sni69==3720
replace astsni2=28 if sni69==3811 
replace astsni2=36 if sni69==3812
replace astsni2=28 if sni69==3813
replace astsni2=28 if sni69==3819
replace astsni2=29 if sni69==3823
replace astsni2=29 if sni69==3824
replace astsni2=30 if sni69==3825
replace astsni2=29 if sni69==3829
replace astsni2=31 if sni69==3831
replace astsni2=32 if sni69==3832
replace astsni2=29 if sni69==3833
replace astsni2=31 if sni69==3839
replace astsni2=34 if sni69==3843
replace astsni2=35 if sni69==3849
replace astsni2=33 if sni69==3851
replace astsni2=40 if sni69==4101 | sni69==4102
replace astsni2=41 if sni69==4200
replace astsni2=92 if sni69==9411 | sni69==9415
replace astsni2=74 if sni69==9592

replace astsni2=22 if sni69==9414
replace astsni2=33 if sni69==9331
replace astsni2=22 if sni69==8329
replace astsni2=50 if sni69==6129

replace astsni2=16 if sni69==9911
replace astsni2=5 if sni69==9931
replace astsni2=17 if sni69==9932
replace astsni2=20 if sni69==9933
replace astsni2=21 if sni69==9934
replace astsni2=25 if sni69==9935
replace astsni2=26 if sni69==9936
replace astsni2=27 if sni69==9937
replace astsni2=29 if sni69==9938
replace astsni2=36 if sni69==9939

* third part ofkey: fill blanks manually
drop if sni69==1000 & astsni2==.
replace astsni2=1 if sni69==1120 & astsni2==.
drop if sni69==3000 & astsni2==.
replace astsni2=22 if sni69_5==94144 & astsni2==.
replace astsni2=40 if sni69==4103 & astsni2==.
replace astsni2=45 if sni69_2==50 & astsni2==.
drop if sni69==6000 & astsni2==.
replace astsni2=37 if sni69_5==61117 & astsni2==.
replace astsni2=50 if (sni69==6131 | sni69==6143 | sni69==6129 | sni69==6241 | sni69==6242 | sni69==9513)  & astsni2==.
replace astsni2=51 if sni69_2==61  & astsni2==.
replace astsni2=52 if ((sni69_2==62 & sni69_5~=62323) | sni69==9511 | sni69==9512 | sni69==9514 | sni69==9519) & astsni2==.
replace astsni2=55 if (sni69_2==63 | sni69_5==62210) & astsni2==.
drop if sni69==7000 & astsni2==.
replace astsni2=60 if (sni69>=7111 & sni69<=7115)  & astsni2==.
replace astsni2=61 if (sni69>=7121 & sni69<=7122)  & astsni2==.
replace astsni2=62 if sni69==7131  & astsni2==.
replace astsni2=63 if (sni69==7116 | sni69==7123 | sni69==7132 | sni69==7191 | sni69==7192)  & astsni2==.
replace astsni2=64 if sni69==7200  & astsni2==.
drop if sni69==8000 & astsni2==.
replace astsni2=65 if sni69==8103  & astsni2==.
replace astsni2=71 if (sni69>=8330 | sni69_5==62323 | sni69_5==71169 | sni69_5==71239 | sni69_5==71320 | sni69_5==94121)  & astsni2==.
replace astsni2=72 if sni69==8323  & astsni2==.
replace astsni2=73 if sni69==9320 & astsni2==.
replace astsni2=74 if ((sni69>=8321 & sni69<=8329) | sni69_5==92003 | sni69_5==92004 | sni69_5==92005 | sni69_5==92009 | sni69==9592) & astsni2==.
replace astsni2=75 if sni69==9100 & astsni2==.
replace astsni2=80 if sni69==9310 & astsni2==.
replace astsni2=85 if (sni69==9331 | sni69==9332 | sni69==9340) & astsni2==.
replace astsni2=90 if (sni69_5>=92001 & sni69_5<=92002) & astsni2==.
replace astsni2=91 if sni69==9350 & astsni2==.
replace astsni2=92 if sni69_2==94 & astsni2==.
replace astsni2=93 if (sni69==9520 | sni69_5==9591 | sni69==9599)  & astsni2==.
replace astsni2=95 if sni69==9530 & astsni2==.

sort astnr year
rename astsni2 astsni2_fek
keep astnr year astsni2 sni92_fek
duplicates drop astnr year,force
save temp/impute_sni69_ast,replace

*impute codes to sniast.dta and sniftg.dta*

clear
use modified/sniast
sort astnr year
merge 1:1 astnr year using temp/impute_sni69_ast
drop if _merge==2
drop _merge

*prio 2 finns sni2 via sni69?
replace astsni2=astsni2_fek if missing(astsni2)
replace D_replace_astsni=3 if astsni2!=. & D_replace_astsni==1

*impute back
gsort astnr -year
by astnr: replace  astsni2= astsni2[_n-1] if missing(astsni2) & year<1990
replace D_replace_astsni=3 if astsni2!=. & D_replace_astsni==1

tab D_replace_astsni
sort astnr year
drop sni92_fek astsni2_fek
save modified/sniast,replace

* Clean
erase "/home/workgroups/firmiq/data/temp/sniast.dta"
erase "/home/workgroups/firmiq/data/temp/sniftg.dta"

forvalues i=85(1)99 {
erase temp/sni`i'.dta
}
forvalues i=0(1)9 {
erase temp/sni0`i'.dta
}

*4. Identifying sample firms (private 50 employees - later restriction 2 obs of c and n i imputed)

* To get a consistent sample we use firms with at least 50 employees as our unit of observation.
* privatefirms.do identifies private firms from ftgastgeo`i'. Output data is temp/private`i'.dta
* variables in temp/private`i'.dta: ftgnr year privatefirm privfirm50 ftgstorl
* result of selection is saved in results/selection_of_firms.dta
* NOTE: we now do not restrict firms to have at least 50 employees. We keep all firms
* with at least one employee. We also create a dummy, firm50, for firms with at least 50 employees.

file open myfile using selection_of_firms.csv, write replace

forvalues i=85 (1)98 {
	use rams/ftgastgeo`i'.dta, clear
	destring instkod kod, replace
	drop if ftglopnr_su=="00000000" | ftglopnr_su==""	
	rename ftglopnr_su ftgnr
	rename astlopnr_su astnr
	gen firm50=0 
	replace firm50=. if ftgstorl==.
	replace firm50=1 if ftgstorl>=50
	* Restrict to private sector
	gen sektor = floor(instkod/1000)
	gen private = 1
	replace private = 0 if sektor == 11 | sektor == 12 | sektor == 13 | sektor == 14 | sektor == 15
	gen own = floor((instkod-(sektor*1000))/100)
	replace private = 0 if own==1 | own==2
	gen jur = instkod - sektor*1000 - own*100
	g privfirm=0
	replace privfirm = 1 if private == 1 & jur~=10
	local j=1900+`i'
	g year=`j'
	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgstorl privfirm firm50 ftgnr astnr year
	
	* Save private_geo (geo codes for firm and plant)
	preserve 
	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgnr astnr year
	sort ftgnr astnr
	save temp/private_geo`j'.dta, replace
	restore
	
	* Save private (privfirm, firm50 ftgstorl)
	keep ftgstorl privfirm firm50 ftgnr year
	gsort ftgnr -ftgstorl
	duplicates drop ftgnr,force
	sort ftgnr
	save temp/private`j'.dta, replace
	
	* Note: here we only count firms with at least 50 employees
	qui sum privfirm if ftgstorl>49 & ftgstorl~=. & privfirm==1
	local N_firms=r(N)
	local n_firms=r(sum)
	file write myfile "`N_firms'; `n_firms'" _n
	}

clear
* Year 1999
	set more off
	use rams/ftgastgeo99.dta, clear
	destring  kod, replace
	drop if ftglopnr_su=="00000000"| ftglopnr_su==""					
	sort ftglopnr 			
	rename ftglopnr_su ftgnr
	rename astlopnr_su astnr
	gen firm50=0
	replace firm50=. if ftgstorl==.
	replace firm50=1 if ftgstorl>=50 
	* Restrict to prive sector (different algorithm than 1986-1998)
	destring agkat, replace
	destring jurform, replace
	destring sektor, replace
	gen private = 1 if agkat==9 
	replace private = 0 if agkat==1|agkat==2
	replace private = 0 if sektor == 120|sektor == 211|sektor == 311|sektor == 312|sektor == 320|sektor == 411|sektor == 412|sektor == 413|sektor == 421|sektor == 422|sektor == 423|sektor == 500|sektor == 710|sektor == 721|sektor == 722
	g privfirm=0
	replace privfirm = 1 if private == 1 & jur~=10
	g year=1999

	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgstorl privfirm firm50 ftgnr astnr year
	
	* Save private_geo (geo codes for firm and plant)
	preserve 
	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgnr astnr year
	sort ftgnr astnr
	save temp/private_geo1999.dta, replace
	restore
	
	* Save private (privfirm, firm50 ftgstorl)
	keep ftgstorl privfirm firm50 ftgnr year
	gsort ftgnr -ftgstorl
	duplicates drop ftgnr,force
	sort ftgnr
	save temp/private1999.dta, replace
	
	* Note: here we only count firms with at least 50 employees
	qui sum privfirm if ftgstorl>49 & ftgstorl~=. & privfirm==1
	local N_firms=r(N)
	local n_firms=r(sum)
	file write myfile "`N_firms'; `n_firms'" _n
	
* Year 2000
	use rams/ftgastgeo00.dta, clear
	destring kod, replace
	drop if ftglopnr_su=="00000000"| ftglopnr_su==""					
	sort ftglopnr 	
	rename ftglopnr_su ftgnr
	rename astlopnr_su astnr
	gen firm50=0
	replace firm50=. if ftgstorl==.
	replace firm50=1 if ftgstorl>=50 
	*Restrict to prive sector (different algorithm than 1986-1998, but same as 1999)
	destring agkat, replace
	destring jurform, replace
	destring sektor, replace
	gen private = 1 if agkat==9 
	replace private = 0 if agkat==1|agkat==2
	replace private = 0 if sektor == 120|sektor == 211|sektor == 311|sektor == 312|sektor == 320|sektor == 411|sektor == 412|sektor == 413|sektor == 421|sektor == 422|sektor == 423|sektor == 500|sektor == 710|sektor == 721|sektor == 722
	g privfirm=0
	replace privfirm = 1 if private == 1 & jur~=10
	g year=2000

	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgstorl privfirm firm50 ftgnr astnr year
	* For some reason there are a couple of duplicates wrt ftgnr astnr
	duplicates drop ftgnr astnr, force

	* Save private_geo (geo codes for firm and plant)
	preserve 
	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgnr astnr year
	sort ftgnr astnr
	save temp/private_geo2000.dta, replace
	restore
	
	* Save private (privfirm, firm50 ftgstorl)
	keep ftgstorl privfirm firm50 ftgnr year
	gsort ftgnr -ftgstorl
	duplicates drop ftgnr,force
	sort ftgnr
	save temp/private2000.dta, replace
	
	* Note: here we only count firms with at least 50 employees
	qui sum privfirm if ftgstorl>49 & ftgstorl~=. & privfirm==1
	local N_firms=r(N)
	local n_firms=r(sum)
	file write myfile "`N_firms'; `n_firms'" _n
	
*2001-2006 
	clear
forvalues i=1(1)6 {
	use rams/ftgastgeo0`i'.dta, clear
	destring kod, replace
	drop if ftglopnr_su=="00000000"| ftglopnr_su==""					 
	rename ftglopnr_su ftgnr
	rename astlopnr_su astnr
	gen firm50=0
	replace firm50=. if ftgstorl==.
	replace firm50=1 if ftgstorl>=50 
	* Restrict to prive sector
	destring agkat, replace
	destring jurform, replace
	destring sektor, replace
	gen private = 1 if agkat==41|agkat==42|agkat==50 
	replace private = 0 if agkat==10|agkat==20|agkat==30
	replace private = 0 if sektor == 120|sektor == 211|sektor == 311|sektor == 312|sektor == 320|sektor == 411|sektor == 412|sektor == 413|sektor == 421|sektor == 422|sektor == 423|sektor == 500|sektor == 710|sektor == 721|sektor == 722
	g privfirm=0
	replace privfirm = 1 if private == 1 & jur~=10
	local j=2000+`i'
	g year=`j'

	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgstorl privfirm firm50 ftgnr astnr year
	
	* Save private_geo (geo codes for firm and plant)
	preserve 
	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgnr astnr year
	sort ftgnr astnr
	save temp/private_geo`j'.dta, replace
	restore
	
	* Save private (privfirm, firm50 ftgstorl)
	keep ftgstorl privfirm firm50 ftgnr year
	gsort ftgnr -ftgstorl
	duplicates drop ftgnr,force
	sort ftgnr
	save temp/private`j'.dta, replace
	
	* Note: here we only count firms with at least 50 employees
	qui sum privfirm if ftgstorl>49 & ftgstorl~=. & privfirm==1
	local N_firms=r(N)
	local n_firms=r(sum)
	file write myfile "`N_firms'; `n_firms'" _n
	}

		
* 2007-2009	
	clear
forvalues i=7(1)9 {
	use rams/ftgastgeo0`i'.dta, clear
	destring kod, replace
	drop if ftglopnr_su=="00000000"| ftglopnr_su==""					 
	sort ftglopnr 													
	rename ftglopnr_su ftgnr
	rename astlopnr_su astnr
	gen firm50=0
	replace firm50=. if ftgstorl==.
	replace firm50=1 if ftgstorl>=50 
	* Restrict to prive sector 
	destring agkat, replace
	destring jurform, replace
	destring sektor, replace
	destring astnr, replace
	tostring astnr, replace
	gen private = 1 if agkat==41|agkat==42|agkat==50 
	replace private = 0 if agkat==10|agkat==20|agkat==30
	replace private = 0 if sektor == 120|sektor == 211|sektor == 311|sektor == 312|sektor == 320|sektor == 411|sektor == 412|sektor == 413|sektor == 421|sektor == 422|sektor == 423|sektor == 500|sektor == 710|sektor == 721|sektor == 722
	g privfirm=0
	replace privfirm = 1 if private == 1 & jur~=10
	local j=2000+`i'
	g year=`j'

	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgstorl privfirm firm50 ftgnr astnr year
	
	* Save private_geo (geo codes for firm and plant)
	preserve 
	keep osttyngdpunkt nordtyngdpunkt astkommun astsams ftgnr astnr year
	sort ftgnr astnr
	save temp/private_geo`j'.dta, replace
	restore
	
	* Save private (privfirm, firm50 ftgstorl)
	keep ftgstorl privfirm firm50 ftgnr year
	gsort ftgnr -ftgstorl
	duplicates drop ftgnr,force
	sort ftgnr
	save temp/private`j'.dta, replace
	
	* Note: here we only count firms with at least 50 employees
	qui sum privfirm if ftgstorl>49 & ftgstorl~=. & privfirm==1
	local N_firms=r(N)
	local n_firms=r(sum)
	file write myfile "`N_firms'; `n_firms'" _n
	}	
	
file close myfile

clear
insheet using selection_of_firms.csv, delim(;)
rename v1 N_firms_total
rename v2 n_firms_private
g year=_n+1984
g share_private=n_firms/N_firms*100
sort year
save /home/workgroups/firmiq/results/selection_of_firms,replace
clear

*5 Occupations: This parts retrieves information from the structural wage statistics (SWS) 
* Variables collected are: manl ssyk arbtim anstform uppr safyrke yrke
* Note: from SWS observations without plant and firm identifier are dropped

*step 1 : key for ssyk esec and egp.
* Variables in esec_key: egp esec ssyk3 ssyk96

* step 2 : occupations and tjomf (mostly occupations)
* For blue collars: 	2 digit yrke 85-94 (maybe according to nyk?)
*					4 digit safyrke 95???????
*					3 digit ssyk 96-08 (4 digit from 05 but recoded)
*					
*					anstform 85-94
*					no info 95-98, use arbtim to infer anstform/tjomf
*					tjomf 99-08
*			
* For white collars	3 digit yrke + 4 digit yrkesaf 85-94	(yrkesaf missing 1991)
*					3 digit ssyk 96-08 (4 digit from 05 but recoded)
*					
*					anstform 85-08
*					tjomf 95-08
*
* step 3: impute ssyk +- 2 year to increase sample (this is done in the merging procedure)
			
* output data is first temp/sws`i' from which we pick one value for each firm and plant
* Final files are temp/sws_ftg`i' and temp/sws_ast`i'
* Last run: 2014-12-15

*use ssyk/ssyk96_to_isco_awm_esec_egp_2010_1 

clear
use ssyk96_to_isco_awm_esec_egp_2010_1.dta
replace ssyk96=110 if ssyk96==11
tostring ssyk96, gen (ssyk3)
keep  egp esec ssyk3 ssyk96
sort ssyk3
save temp/esec_key,replace


forvalues i=85(1)94{
use lon/lon_arb_`i'.dta
keep perslopnr ftglopnr_su astlopnr_su arbtim lonarbtid manl yrke anstform uppr
local j=1900+`i'
g year=`j'
save temp/arb`j',replace
clear
}
*anstform saknas 95, men saf yrke dyker upp 
use lon/lon_arb_95.dta
keep perslopnr ftglopnr_su astlopnr_su arbtim lonarbtid manl uppr safyrke yrke
g year=1995
save temp/arb1995,replace

*anstform saknas 96-98,3 siffrig ssyk
forvalues i=96(1)98{
use lon/lon_arb_`i'.dta
keep perslopnr ftglopnr_su astlopnr_su arbtim lonarbtid manl uppr ssyk
local j=1900+`i'
g year=`j'
save temp/arb`j',replace
clear
}

*tjomf och ssyk finns
use lon/lon_arb_99.dta
keep perslopnr ftglopnr_su astlopnr_su arbtim lonarbtid manl uppr ssyk tjomf
g year=1999
save temp/arb1999,replace

forvalues i=0(1)9{
use lon/lon_arb_0`i'.dta
keep perslopnr ftglopnr_su astlopnr_su arbtim lonarbtid manl uppr ssyk tjomf
local j=2000+`i'
g year=`j'
destring ssyk,replace force
g ssyk3=int(ssyk/10) if ssyk>=1000
replace ssyk=ssyk3 if ssyk>=1000 
drop ssyk3
tostring ssyk,replace
save temp/arb`j',replace
clear
}

forvalues i=85(1)90{
use lon/lon_tjm_`i'.dta
keep perslopnr ftglopnr_su astlopnr_su ovktid lonarbtid manl yrke yrkesaf anstform uppr
local j=1900+`i'
g year=`j'
save temp/tjm`j',replace
clear
}

*yrkesaf saknas 91
use lon/lon_tjm_91.dta
keep perslopnr ftglopnr_su astlopnr_su ovktid lonarbtid manl yrke anstform uppr
g year=1991
save temp/tjm1991,replace
clear

forvalues i=92(1)94{
use lon/lon_tjm_`i'.dta
keep perslopnr ftglopnr_su astlopnr_su ovktid lonarbtid manl yrke yrkesaf anstform uppr
local j=1900+`i'
g year=`j'
save temp/tjm`j',replace
clear
}

*95 ssyk 3 digit, note anstform (0,1) 95, then back to (1,2)
forvalues i=95(1)99{
use lon/lon_tjm_`i'.dta
keep perslopnr ftglopnr_su astlopnr_su ssyk ovktid tjomf anstform lonarbtid manl uppr
tostring anstform,replace
local j=1900+`i'
g year=`j'
replace anstform="2" if anstform=="1" & year==1995
replace anstform="1" if anstform=="0" & year==1995
save temp/tjm`j',replace
clear
}

*2001 onwards ssyk is (partly) 4 digit
forvalues i=0(1)9{
use lon/lon_tjm_0`i'.dta
keep perslopnr ftglopnr_su astlopnr_su ssyk ovktid tjomf anstform lonarbtid manl uppr
tostring anstform,replace
local j=2000+`i'
g year=`j'
destring ssyk,replace force
g ssyk3=int(ssyk/10) if ssyk>1000
replace ssyk=ssyk3 if ssyk>1000 
drop ssyk3
tostring ssyk,replace
save temp/tjm`j',replace
clear
}

* create sws-file. 
forvalues i=1985(1)2006{
use temp/arb`i'
append using temp/tjm`i'
rename astlopnr_su astnr
tostring astnr,replace
rename ftglopnr_su ftgnr
rename perslopnr lopnr
destring lopnr,replace
drop if missing(ftgnr)
drop if missing(astnr)
duplicates drop
gsort lopnr ftgnr astnr -lonarbtid
duplicates drop lopnr ftgnr astnr,force 
sort lopnr ftgnr astnr
save temp/sws`i',replace
}

forvalues i=2007(1)2007{
use temp/arb`i'
append using temp/tjm`i'
rename astlopnr_su astnr
tostring astnr,replace
rename ftglopnr_su ftgnr
rename perslopnr lopnr
destring lopnr,replace
drop if missing(ftgnr)
drop if missing(astnr)

destring astnr, replace
tostring astnr, replace

duplicates drop
gsort lopnr ftgnr astnr -lonarbtid
duplicates drop lopnr ftgnr astnr,force 
sort lopnr ftgnr astnr
save temp/sws`i',replace
}

forvalues i=2008(1)2009{
use temp/arb`i'
append using temp/tjm`i'
rename astlopnr_su astnr
rename ftglopnr_su ftgnr
rename perslopnr lopnr
tostring astnr,replace
destring lopnr,replace
drop if missing(ftgnr)
drop if missing(astnr)

destring astnr, replace
tostring astnr, replace
replace astnr="0" if astnr=="."
replace astnr="0" if astnr==""

duplicates drop
gsort lopnr ftgnr astnr -lonarbtid
duplicates drop lopnr ftgnr astnr,force 
sort lopnr ftgnr astnr
save temp/sws`i',replace
}

forvalues i=1995(1)2009{
use temp/sws`i'
replace ssyk="" if ssyk=="***"
destring ssyk,replace force
replace ssyk=. if ssyk==99
replace ssyk=. if ssyk==999
save,replace
}

*** Get separate SWS-values by firm and plant, respectiveley, and generate sws_ftg and sws_ast.
forvalues i=1985(1)1990{
clear
use temp/sws`i'
gsort lopnr ftgnr -lonarbtid
duplicates drop lopnr ftgnr,force
rename manl manl_ftg
rename yrke yrke_ftg
rename yrkesaf yrkesaf_ftg
rename lonarbtid lonarbtid_ftg
rename anstform anstform_ftg
rename astnr astnr_sws_ftg
rename arbtim arbtim_ftg
rename uppr uppr_ftg
rename ovktid ovktid_ftg
keep lopnr ftgnr manl_ftg yrke_ftg yrkesaf_ftg lonarbtid_ftg anstform_ftg astnr_sws_ftg arbtim_ftg uppr_ftg ovktid_ftg year
sort lopnr ftgnr
save temp/sws_ftg`i'.dta, replace

clear
use temp/sws`i'
drop if astnr=="00000000"
drop if astnr=="0"
gsort lopnr astnr -lonarbtid
duplicates drop lopnr astnr,force
rename manl manl_ast
rename yrke yrke_ast
rename yrkesaf yrkesaf_ast
rename lonarbtid lonarbtid_ast
rename anstform anstform_ast
rename ftgnr ftgnr_sws_ast
rename arbtim arbtim_ast
rename uppr uppr_ast
rename ovktid ovktid_ast
keep lopnr astnr manl_ast yrke_ast yrkesaf_ast lonarbtid_ast anstform_ast ftgnr_sws_ast arbtim_ast uppr_ast ovktid_ast year
sort lopnr astnr
save temp/sws_ast`i'.dta, replace
}

* Inget yrkessaf f򲠱991
forvalues i=1991(1)1991{
clear
use temp/sws`i'
gsort lopnr ftgnr -lonarbtid
duplicates drop lopnr ftgnr,force
rename manl manl_ftg
rename yrke yrke_ftg
rename lonarbtid lonarbtid_ftg
rename anstform anstform_ftg
rename astnr astnr_sws_ftg
rename arbtim arbtim_ftg
rename uppr uppr_ftg
rename ovktid ovktid_ftg
keep lopnr ftgnr manl_ftg yrke_ftg lonarbtid_ftg anstform_ftg astnr_sws_ftg arbtim_ftg uppr_ftg ovktid_ftg year
sort lopnr ftgnr
save temp/sws_ftg`i'.dta, replace

clear
use temp/sws`i'
drop if astnr=="00000000"
drop if astnr=="0"
gsort lopnr astnr -lonarbtid
duplicates drop lopnr astnr,force
rename manl manl_ast
rename yrke yrke_ast
rename lonarbtid lonarbtid_ast
rename anstform anstform_ast
rename ftgnr ftgnr_sws_ast
rename arbtim arbtim_ast
rename uppr uppr_ast
rename ovktid ovktid_ast
keep lopnr astnr manl_ast yrke_ast lonarbtid_ast anstform_ast ftgnr_sws_ast arbtim_ast uppr_ast ovktid_ast year
sort lopnr astnr
save temp/sws_ast`i'.dta, replace
}

forvalues i=1992(1)1994{
clear
use temp/sws`i'
gsort lopnr ftgnr -lonarbtid
duplicates drop lopnr ftgnr,force
rename manl manl_ftg
rename yrke yrke_ftg
rename yrkesaf yrkesaf_ftg
rename lonarbtid lonarbtid_ftg
rename anstform anstform_ftg
rename astnr astnr_sws_ftg
rename arbtim arbtim_ftg
rename uppr uppr_ftg
rename ovktid ovktid_ftg
keep lopnr ftgnr manl_ftg yrke_ftg yrkesaf_ftg lonarbtid_ftg anstform_ftg astnr_sws_ftg arbtim_ftg uppr_ftg ovktid_ftg year
sort lopnr ftgnr
save temp/sws_ftg`i'.dta, replace

clear
use temp/sws`i'
drop if astnr=="00000000"
drop if astnr=="0"
gsort lopnr astnr -lonarbtid
duplicates drop lopnr astnr,force
rename manl manl_ast
rename yrke yrke_ast
rename yrkesaf yrkesaf_ast
rename lonarbtid lonarbtid_ast
rename anstform anstform_ast
rename ftgnr ftgnr_sws_ast
rename arbtim arbtim_ast
rename uppr uppr_ast
rename ovktid ovktid_ast
keep lopnr astnr manl_ast yrke_ast yrkesaf_ast lonarbtid_ast anstform_ast ftgnr_sws_ast arbtim_ast uppr_ast ovktid_ast year
sort lopnr astnr
save temp/sws_ast`i'.dta, replace
}

* safyrke finns bara f򲠱995
forvalues i=1995(1)1995{
clear
use temp/sws`i'
gsort lopnr ftgnr -lonarbtid
duplicates drop lopnr ftgnr,force
rename manl manl_ftg
rename yrke yrke_ftg
rename safyrke safyrke_ftg
rename ssyk ssyk_ftg
rename lonarbtid lonarbtid_ftg
rename anstform anstform_ftg
rename astnr astnr_sws_ftg
rename arbtim arbtim_ftg
rename uppr uppr_ftg
rename ovktid ovktid_ftg
rename tjomf tjomf_ftg
keep lopnr ftgnr manl_ftg yrke_ftg safyrke_ftg ssyk_ftg lonarbtid_ftg anstform_ftg astnr_sws_ftg arbtim_ftg uppr_ftg ovktid_ftg tjomf_ftg year
sort lopnr ftgnr
save temp/sws_ftg`i'.dta, replace

clear
use temp/sws`i'
drop if astnr=="00000000"
drop if astnr=="0"
gsort lopnr astnr -lonarbtid
duplicates drop lopnr astnr,force
rename manl manl_ast
rename yrke yrke_ast
rename safyrke safyrke_ast
rename ssyk ssyk_ast
rename lonarbtid lonarbtid_ast
rename anstform anstform_ast
rename ftgnr ftgnr_sws_ast
rename arbtim arbtim_ast
rename uppr uppr_ast
rename ovktid ovktid_ast
rename tjomf tjomf_ast
keep lopnr astnr manl_ast yrke_ast safyrke_ast ssyk_ast lonarbtid_ast anstform_ast ftgnr_sws_ast arbtim_ast uppr_ast ovktid_ast tjomf_ast year
sort lopnr astnr
save temp/sws_ast`i'.dta, replace
}

* 1996 och fram洠finns bara ssyk
forvalues i=1996(1)2009{
clear
use temp/sws`i'
gsort lopnr ftgnr -lonarbtid
duplicates drop lopnr ftgnr,force
rename manl manl_ftg
rename ssyk ssyk_ftg
rename lonarbtid lonarbtid_ftg
rename anstform anstform_ftg
rename astnr astnr_sws_ftg
rename arbtim arbtim_ftg
rename uppr uppr_ftg
rename ovktid ovktid_ftg
rename tjomf tjomf_ftg
keep lopnr ftgnr manl_ftg ssyk_ftg lonarbtid_ftg anstform_ftg astnr_sws_ftg arbtim_ftg uppr_ftg ovktid_ftg tjomf_ftg year
sort lopnr ftgnr
save temp/sws_ftg`i'.dta, replace

clear
use temp/sws`i'
drop if astnr=="00000000"
drop if astnr=="0"
gsort lopnr astnr -lonarbtid
duplicates drop lopnr astnr,force
rename manl manl_ast
rename ssyk ssyk_ast
rename lonarbtid lonarbtid_ast
rename anstform anstform_ast
rename ftgnr ftgnr_sws_ast
rename arbtim arbtim_ast
rename uppr uppr_ast
rename ovktid ovktid_ast
rename tjomf tjomf_ast
keep lopnr astnr manl_ast ssyk_ast lonarbtid_ast anstform_ast ftgnr_sws_ast arbtim_ast uppr_ast ovktid_ast tjomf_ast year
sort lopnr astnr
save temp/sws_ast`i'.dta, replace
}


*6 Matching individual sets: key, edyr, sws and enlistment data files 
*  to create the indfirm`i' data file (was done in match.do earlier).
*  variables in indfirm`i': 
*

* Prepare enlistment files
set more off
use modified/enlistment.dta
sort lopnr
save modified/enlistment.dta, replace
use modified/enlistment_wom.dta
sort lopnr
save modified/enlistment_wom.dta, replace
use temp/alternative_skills.dta
sort lopnr
save temp/alternative_skills.dta, replace

log using matching,replace

*** Merge files 
forvalues i=1985(1)2006{

display `i'
use modified/key`i'.dta, clear 
destring lopnr,replace
sort lopnr
merge 1:1 lopnr using modified/edyr`i'.dta
drop if _merge==2
drop  _merge
sort lopnr
merge 1:1 lopnr using modified/enlistment.dta, keepus(lopnr c c_old n n_old)
drop if _merge==2
rename _merge enlistmerge

replace c=. if sex=="2"
replace c_old=. if sex=="2"
replace n=. if sex=="2"
replace n_old=. if sex=="2"

sort lopnr
merge 1:1 lopnr using modified/enlistment_wom.dta, keepus(lopnr c n ) update
drop if _merge==2
rename _merge enlistmerge_wom
sort lopnr
merge 1:1 lopnr using temp/alternative_skills.dta, keepus(lopnr n_uni c_uni c_beta24 c_beta42 n_beta24 n_beta42) update
drop if _merge==2
rename _merge enlistmerge_altskills

* Merge with sws by firm
sort lopnr ftgnr astnr
merge 1:1 lopnr ftgnr using temp/sws_ftg`i'
drop if _merge==2
drop _merge

* Merge with sws by plant
sort lopnr ftgnr astnr
merge 1:1 lopnr astnr using temp/sws_ast`i'
drop if _merge==2
drop _merge

sort lopnr ftgnr astnr
save modified/indfirm`i', replace
}

* 2007
forvalues i=2007(1)2007{
display `i'
use modified/key`i'.dta, clear 
sort lopnr
merge 1:1 lopnr using modified/edyr`i'.dta
drop if _merge==2
drop  _merge

destring lopnr,replace
sort lopnr
merge 1:1 lopnr using modified/enlistment.dta, keepus(lopnr c c_old n n_old)
drop if _merge==2
rename _merge enlistmerge

replace c=. if sex==2
replace c_old=. if sex==2
replace n=. if sex==2
replace n_old=. if sex==2

sort lopnr
merge 1:1 lopnr using modified/enlistment_wom.dta, keepus(lopnr c n) update
drop if _merge==2
rename _merge enlistmerge_wom
sort lopnr
merge 1:1 lopnr using temp/alternative_skills.dta, keepus(lopnr n_uni c_uni c_beta24 c_beta42 n_beta24 n_beta42) update
drop if _merge==2
rename _merge enlistmerge_altskills

sort lopnr ftgnr astnr

* Merge with sws by firm
sort lopnr ftgnr astnr
merge 1:1 lopnr ftgnr using temp/sws_ftg`i'
drop if _merge==2
drop _merge

* Merge with sws by plant
sort lopnr ftgnr astnr
merge 1:1 lopnr astnr using temp/sws_ast`i'
drop if _merge==2
drop _merge

sort lopnr ftgnr astnr
save modified/indfirm`i', replace
}

* 2008-2009
forvalues i=2008(1)2009{
display `i'
use modified/key`i'.dta, clear 
sort lopnr
merge 1:1 lopnr using modified/edyr`i'.dta
drop if _merge==2
drop  _merge
sort lopnr
merge 1:1 lopnr using modified/enlistment.dta, keepus(lopnr c c_old n n_old)
drop if _merge==2
rename _merge enlistmerge

replace c=. if sex==2
replace c_old=. if sex==2
replace n=. if sex==2
replace n_old=. if sex==2

sort lopnr
merge 1:1 lopnr using modified/enlistment_wom.dta, keepus(lopnr c n) update
drop if _merge==2
rename _merge enlistmerge_wom
merge 1:1 lopnr using temp/alternative_skills.dta, keepus(lopnr n_uni c_uni c_beta24 c_beta42 n_beta24 n_beta42) update
drop if _merge==2
rename _merge enlistmerge_altskills

* Merge with sws by firm
sort lopnr ftgnr astnr
merge 1:1 lopnr ftgnr using temp/sws_ftg`i'
drop if _merge==2
drop _merge

* Merge with sws by plant
sort lopnr ftgnr astnr
merge 1:1 lopnr astnr using temp/sws_ast`i'
drop if _merge==2
drop _merge

sort lopnr ftgnr astnr
save modified/indfirm`i', replace
}

* Some variables are byte for 2007 and 2008. OBS 2009???
forvalues i=2007(1)2009{
clear 
use modified/indfirm`i'
tostring sex, replace
tostring seninvar, replace
tostring lan, replace
tostring kommun, replace
tostring forsamling, replace 
tostring syssstatj, replace 
tostring astkommun, replace
tostring sams, replace 
save, replace
}

log close

*** Clean files do save disk space

*clear
*forvalues i=1985(1)2008{
*	erase temp/sws_ast`i'.dta
*	erase temp/sws_ftg`i'.dta
*	erase temp/sws`i'.dta
*	erase temp/arb`i'.dta
*	erase temp/tjm`i'.dta
*}
	
* 6b imputing ssyk
* Creates new indfirm files from 1996 and onwards with imputed ssyk (+/- 2 years)
* From 1995 and onwards, these temporary indfirm files are called indfirm2_year

* 1995
use modified/indfirm1995
sort lopnr
display "1995"
display "after"
merge 1:1 lopnr ftgnr using modified/indfirm1996,update keepus(ssyk_ftg)
g imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm1996,update keepus(ssyk_ast)
g imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr ftgnr using modified/indfirm1997,update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm1997,update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

save modified/indfirm2_1995,replace

* 1996
use modified/indfirm1996
sort lopnr
display "1996"
display "before"
merge 1:1 lopnr ftgnr using modified/indfirm1995,update keepus(ssyk_ftg)
g imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm1995,update keepus(ssyk_ast)
g imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr ftgnr using modified/indfirm1997,update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm1997,update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr ftgnr using modified/indfirm1998,update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm1998,update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

save modified/indfirm2_1996, replace

* 1997-2007
forvalues i=1997(1)2007{
clear
use modified/indfirm`i'

local j=`i'-1
sort lopnr
display `i'
display "before"

merge 1:1 lopnr ftgnr using modified/indfirm`j',update keepus(ssyk_ftg)
g imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm`j',update keepus(ssyk_ast)
g imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

local k=`i'+1
sort lopnr
display `i'
display "after"

merge 1:1 lopnr ftgnr using modified/indfirm`k',update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm`k',update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

local l=`i'-2
sort lopnr
display `i'
display "before"

merge 1:1 lopnr ftgnr using modified/indfirm`l',update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm`l',update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

local m=`i'+2
sort lopnr
display `i'
display "after"

merge 1:1 lopnr ftgnr using modified/indfirm`m',update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm`m',update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

save modified/indfirm2_`i',replace
}

* 2008
use modified/indfirm2008
sort lopnr
display "2008"
display "before"
codebook ssyk_ftg
merge 1:1 lopnr ftgnr using modified/indfirm2007,update keepus(ssyk_ftg)
g imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm2007,update keepus(ssyk_ast)
g imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

display "after"
merge 1:1 lopnr ftgnr using modified/indfirm2009,update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm2009,update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

display "before"
merge 1:1 lopnr ftgnr using modified/indfirm2006,update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm2006,update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

save modified/indfirm2_2008, replace

* 2009

use modified/indfirm2009
sort lopnr
display "2009"
display "before"
codebook ssyk_ftg
merge 1:1 lopnr ftgnr using modified/indfirm2008,update keepus(ssyk_ftg)
g imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm2008,update keepus(ssyk_ast)
g imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr ftgnr using modified/indfirm2007,update keepus(ssyk_ftg)
replace imputed_ssyk_ftg=1 if _merge==4
drop if _merge==2
drop _merge

merge 1:1 lopnr astnr using modified/indfirm2007,update keepus(ssyk_ast)
replace imputed_ssyk_ast=1 if _merge==4
drop if _merge==2
drop _merge

save modified/indfirm2_2009, replace

* 1995-2009
clear
forvalues i=1995(1)2009{
	erase modified/indfirm`i'.dta
	use modified/indfirm2_`i'
	save modified/indfirm`i', replace
	erase modified/indfirm2_`i'.dta
}	



* Generate file with minmum wages and GDP deflator
* Generate minimum monthly wages (nominal)
* Defined as lowest hourly wage reported * 40 (hours/week) * 4.5 (weeks)
* Source: "Collective agreements, data compiled by Per Skedinger"
* File to use minumimwage.dta (includes GDP-deflator (2008))

clear
cd /home/workgroups/firmiq/data/
set more off

set obs 25
egen year=fill(1985/2009)
gen minwage=.	
replace minwage=1625.4 		if year==1974
replace minwage=1625.4 		if year==1975
replace minwage=1807.2 		if year==1976
replace minwage=2001.6 		if year==1977
replace minwage=3384 		if year==1978
replace minwage=3645 		if year==1979
replace minwage=4131 		if year==1980
replace minwage=4464 		if year==1981
replace minwage=4752 		if year==1982
replace minwage=4977 		if year==1983
replace minwage=4977 		if year==1984
replace minwage=5760 		if year==1985
replace minwage=6246 		if year==1986
replace minwage=6613.2 		if year==1987
replace minwage=7137 		if year==1988
replace minwage=7137 		if year==1989
replace minwage=8424 		if year==1990
replace minwage=8746.2 		if year==1991
replace minwage=9192.6 		if year==1992
replace minwage=9216 		if year==1993
replace minwage=9504 		if year==1994
replace minwage=9729 		if year==1995
replace minwage=10472.4 	if year==1996
replace minwage=10962 		if year==1997
replace minwage=11302.2 	if year==1998
replace minwage=11302.2 	if year==1999
replace minwage=11707.2 	if year==2000
replace minwage=12117.6 	if year==2001
replace minwage=12481.2 	if year==2002
replace minwage=12855.6 	if year==2003
replace minwage=13150.8 	if year==2004
replace minwage=13480.2 	if year==2005
replace minwage=13816.8 	if year==2006
replace minwage=14192.25652 if year==2007
replace minwage=14255.42857 if year==2008
replace minwage=14454.49846 if year==2009

gen deflator=.
replace deflator=0.18405467		 if year==1974
replace deflator=0.202050114	 if year==1975
replace deflator=0.223006834	 if year==1976
replace deflator=0.248291572	 if year==1977
replace deflator=0.273348519	 if year==1978
replace deflator=0.292938497	 if year==1979
replace deflator=0.332801822	 if year==1980
replace deflator=0.373120729	 if year==1981
replace deflator=0.40501139		 if year==1982
replace deflator=0.441230068	 if year==1983
replace deflator=0.476537585	 if year==1984
replace deflator=0.511617312	 if year==1985
replace deflator=0.533257403	 if year==1986
replace deflator=0.555808656	 if year==1987
replace deflator=0.588154897	 if year==1988
replace deflator=0.625968109	 if year==1989
replace deflator=0.691571754	 if year==1990
replace deflator=0.756036446	 if year==1991
replace deflator=0.773348519	 if year==1992
replace deflator=0.809339408	 if year==1993
replace deflator=0.827107062	 if year==1994
replace deflator=0.848063781	 if year==1995
replace deflator=0.851936219	 if year==1996
replace deflator=0.856492027	 if year==1997
replace deflator=0.855125285	 if year==1998
replace deflator=0.859225513	 if year==1999
replace deflator=0.867653759	 if year==2000
replace deflator=0.888838269	 if year==2001
replace deflator=0.907972665	 if year==2002
replace deflator=0.925512528	 if year==2003
replace deflator=0.928929385	 if year==2004
replace deflator=0.933257403	 if year==2005
replace deflator=0.946013667	 if year==2006
replace deflator=0.966514806	 if year==2007
replace deflator=1				 if year==2008
replace deflator=0.997266515	 if year==2009

save modified/minimumwage.dta, replace

*** 7 
* Merging individual and firm level data to sample`i'.dta
* This part is changed alot since before. The selection on private firms is done 
* spearately (see section 3), wich enables more compact code. Also
* From ftgastgeo`i' we collect coordinates for the plant.
* From anst`i' we collect manfran mantill lonfink perslopnr ftglopnr_su astlopnr_su and later generate 
* full time equivalent wages.
* Then we add on individual characteristics variables from indfirm`i', industry codes from sniftg, 
* minimum wages and the indicator private firms.
* Output data from this section is sample`i' with ALL employees, PRIVATE firm. 
* Indicators of sample restrictions are generated

************ Firm level data: based on files "productiondata_JHR.do", "implicitprices_JHR.do" and "implicit_depreciation_JHR.do"

clear
forvalues i=1985(1)2009 {

* Merge industry codes
	use modified/indfirm`i'.dta, clear
	rename ftgnr temp
	rename ast_ftg ftgnr
	sort ftgnr
	merge m:1 ftgnr year using modified/sniftg.dta
	drop if _merge==2
	drop _merge	
	rename ftgsnib ast_ftgsnib 
	rename ftgsni ast_ftgsni 
	rename ftgsni2 ast_ftgsni2 
	rename ftgsni3 ast_ftgsni3 
	rename ftgsni4 ast_ftgsni4
	rename ftgnr ast_ftg
	rename temp ftgnr
	lab var ast_ftgsni "SNI of firm to highest income plant"
	
	rename astnr temp
	rename ftg_ast astnr
	sort astnr
	merge m:1 astnr year using modified/sniast.dta
	drop if _merge==2
	drop _merge	
	rename astsnib ftg_astsnib 
	rename astsni ftg_astsni 
	rename astsni2 ftg_astsni2 
	rename astsni3 ftg_astsni3 
	rename astsni4 ftg_astsni4
	rename astnr ftg_ast
	rename temp astnr
	lab var ftg_astsni "SNI of plant to highest income firm"
	
	sort ftgnr	
	merge m:1 ftgnr year using modified/sniftg.dta
	drop if _merge==2
	drop _merge	
	lab var ftgsni "SNI of highest income firm"
	
	sort astnr
	merge m:1 astnr year using modified/sniast.dta
	drop if _merge==2
	drop _merge	
	lab var astsni "SNI of highest income plant"

* Keep some geography from Louise	
	rename osttyngdpunkt osttyngdpunkt_louise 
	rename nordtyngdpunkt nordtyngdpunkt_louise
	rename astkommun astkommun_louise
	label var astkommun_louise "Astkommun from Louise"
	label var osttyngdpunkt_louise "Coordinates from Louise" 
	label var nordtyngdpunkt_louise "Coordinates from Louise"
	
* Merge with private_geo (plant level coordinates) and private (firm level characteristics)
	rename astnr temp
	rename ftg_ast astnr
	merge m:1 ftgnr astnr using temp/private_geo`i'
	drop if _merge==2
	drop _merge
	rename astnr ftg_ast
	rename temp astnr
	rename astsams astsams_ftg
	rename astkommun astkommun_ftg
	rename osttyngdpunkt osttyngdpunkt_ftg
	rename nordtyngdpunkt nordtyngdpunkt_ftg
	label var astsams_ftg "Astsams based on highest income firm"
	label var astkommun_ftg "Astkommun based on highest income firm"
	label var osttyngdpunkt_ftg "Coordinates based on highest income firm" 
	label var nordtyngdpunkt_ftg "Coordinates based on highest income firm"

	rename ftgnr temp
	rename ast_ftg ftgnr
	merge m:1 ftgnr astnr using temp/private_geo`i'
	drop if _merge==2
	drop _merge
	rename astsams astsams_ast
	rename astkommun astkommun_ast
	rename osttyngdpunkt osttyngdpunkt_ast
	rename nordtyngdpunkt nordtyngdpunkt_ast
	label var astsams_ast "Astsams based on highest income plant"
	label var astkommun_ast "Astkommun based on highest income plant"
	label var osttyngdpunkt_ast "Coordinates based on highest income plant" 
	label var nordtyngdpunkt_ast "Coordinates based on highest income plant"
	
	merge m:1 ftgnr using temp/private`i'
	drop if _merge==2
	drop _merge
	rename ftgstorl ftgstorl_ast
	rename firm50 firm50_ast
	rename privfirm privfirm_ast
	label var ftgstorl_ast "Firm size based on highest income plant"
	label var privfirm_ast "Private based on highest income plant"
	label var firm50_ast "Firm>=50 employees size based on highest income plant"
	rename ftgnr ast_ftg
	rename temp ftgnr

	merge m:1 ftgnr using temp/private`i'
	drop if _merge==2
	drop _merge
	rename ftgstorl ftgstorl_ftg
	rename firm50 firm50_ftg
	rename privfirm privfirm_ftg
	label var ftgstorl_ftg "Firm size based on highest income firm"
	label var privfirm_ftg "Private based on highest income firm"
	label var firm50_ftg "Firm>=50 employees size based on highest income firm"
	
* generate main restriction dummies 	

	* Firm
	g sample_3035_50_ftg=0

	replace sample_3035_50_ftg=1 if age>= 30 & age<= 35 & ftgstorl_ftg>=50 & ftgstorl_ftg~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_ftg==1
	bysort ftgnr: egen sample_ftg=sum(sample_3035_50_ftg)	
	replace sample_3035_50_ftg=0 if sample_ftg<=1
	replace sample_3035_50_ftg=0 if privfirm_ftg~=1 & privfirm_ftg~=.
	drop sample_ftg
	
	bysort ftgnr: egen sample_ftg=mean(sample_3035_50_ftg)
	g in_sample_3035_50_ftg=1 if sample_ftg>0 & sample_ftg~=.
	replace in_sample_3035_50_ftg=0 if sample_ftg==0
	drop sample_ftg 
	
	g sample_3045_50_ftg=0

	replace sample_3045_50_ftg=1 if age>= 30 & age<= 45 & year >=1995 & ftgstorl_ftg>=50 & ftgstorl_ftg~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_ftg==1
	bysort ftgnr: egen sample_ftg=sum(sample_3045_50_ftg)	
	replace sample_3045_50_ftg=0 if sample_ftg<=1
	replace sample_3045_50_ftg=0 if privfirm_ftg~=1 & privfirm_ftg~=.
	drop sample_ftg

	bysort ftgnr: egen sample_ftg=mean(sample_3045_50_ftg)
	g in_sample_3045_50_ftg=1 if sample_ftg>0 & sample_ftg~=.
	replace in_sample_3045_50_ftg=0 if sample_ftg==0
	drop sample_ftg 
	
	g sample_3035_50f_ftg=0

	replace sample_3035_50f_ftg=1 if age>= 30 & age<= 35 & ftgstorl_ftg>=50 & ftgstorl_ftg~=.  & n!=. & c!=. & edyr!=. & privfirm_ftg==1
	bysort ftgnr: egen sample_ftg=sum(sample_3035_50f_ftg)	
	replace sample_3035_50f_ftg=0 if sample_ftg<=1
	replace sample_3035_50f_ftg=0 if privfirm_ftg~=1 & privfirm_ftg~=.
	drop sample_ftg

	bysort ftgnr: egen sample_ftg=mean(sample_3035_50f_ftg)
	g in_sample_3035_50f_ftg=1 if sample_ftg>0 & sample_ftg~=.
	replace in_sample_3035_50f_ftg=0 if sample_ftg==0
	drop sample_ftg 
	
	* Plant
	g sample_3035_50_ast=0

	replace sample_3035_50_ast=1 if age>= 30 & age<= 35 & ftgstorl_ast>=50 & ftgstorl_ast~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_ast==1
	bysort astnr: egen sample_ast=sum(sample_3035_50_ast)	
	replace sample_3035_50_ast=0 if sample_ast<=1
	replace sample_3035_50_ast=0 if privfirm_ast~=1 & privfirm_ast~=.
	drop sample_ast

	bysort astnr: egen sample_ast=mean(sample_3035_50_ast)
	g in_sample_3035_50_ast=1 if sample_ast>0 & sample_ast~=.
	replace in_sample_3035_50_ast=0 if sample_ast==0
	drop sample_ast 
	
	g sample_3045_50_ast=0

	replace sample_3045_50_ast=1  if age>= 30 & age<= 45 & year >=1995 & ftgstorl_ast>=50 & ftgstorl_ast~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_ast==1
	bysort astnr: egen sample_ast=sum(sample_3045_50_ast)	
	replace sample_3045_50_ast=0 if sample_ast<=1
	replace sample_3045_50_ast=0 if privfirm_ast~=1 & privfirm_ast~=.
	drop sample_ast

	bysort astnr: egen sample_ast=mean(sample_3045_50_ast)
	g in_sample_3045_50_ast=1 if sample_ast>0 & sample_ast~=.
	replace in_sample_3045_50_ast=0 if sample_ast==0
	drop sample_ast 
	
	g sample_3035_50f_ast=0

	replace sample_3035_50f_ast=1 if age>= 30 & age<= 35 & ftgstorl_ast>=50 & ftgstorl_ast~=. & n!=. & c!=. & edyr!=. & privfirm_ast==1
	bysort astnr: egen sample_ast=sum(sample_3035_50f_ast)	
	replace sample_3035_50f_ast=0 if sample_ast<=1
	replace sample_3035_50f_ast=0 if privfirm_ast~=1 & privfirm_ast~=.
	drop sample_ast

	bysort astnr: egen sample_ast=mean(sample_3035_50f_ast)
	g in_sample_3035_50f_ast=1 if sample_ast>0 & sample_ast~=.
	replace in_sample_3035_50f_ast=0 if sample_ast==0
	drop sample_ast 

* Get minumum wages based on Skedinger (2008)
	sort year
	merge m:1 year using modified/minimumwage
	drop if _merge==2
	drop _merge

* Convert sws-wages to 2008 SEK
	replace manl_ftg=manl_ftg/deflator
	replace manl_ast=manl_ast/deflator
	replace minwage=minwage/deflator
	gen swswage=manl_ftg
	replace swswage=manl_ast if swswage==.
	
* Prepare age classes and collapse for sws-wage imputations	
	drop if missing(age)
	drop if age>=66
	egen ageclass=cut(age), at(16,29,45,66)
	
	preserve
	collapse (mean) swswage, by(year ftgsni2 ageclass)
	reshape wide swswage, i(ftgsni2 year) j(ageclass)
	save temp/manlcollapse_ftg`i'.dta, replace	
	restore

	preserve
	collapse (mean) swswage, by(year astsni2 ageclass)
	reshape wide swswage, i(astsni2 year) j(ageclass)
	save temp/manlcollapse_ast`i'.dta, replace	
	restore
	
	drop swswage
	sort lopnr ftgnr astnr
	save modified/sample`i'.dta, replace
	clear
}

* Fix some strings to numerical is sample2007-2009
	forvalues i=2007(1)2009{
	use modified/sample`i',clear
	tostring astkommun_ftg, replace
	tostring astkommun_ast, replace
	tostring astsams_ftg, replace
	tostring astsams_ast, replace
	save, replace
	}
	
* Create wage growth
* Firm
use temp/manlcollapse_ftg1985.dta, clear
	forvalues i=1986(1)2009{
	append using temp/manlcollapse_ftg`i'.dta
}	
	
tsset ftgsni2 year
foreach i of numlist 16 29 45 {
	g dw_ftg`i'=swswage`i'/L.swswage`i'
}
reshape long swswage dw_ftg, i(year ftgsni2) j(ageclass)
replace dw_ftg=0.95 if dw_ftg<=0.94
replace dw_ftg=1.15 if dw_ftg>=1.16
drop swswage
sort year ftgsni2 ageclass
save temp/wgrowth_ftg,replace

* Plant
use temp/manlcollapse_ast1985.dta, clear
	forvalues i=1986(1)2009{
	append using temp/manlcollapse_ast`i'.dta
	}	
	
tsset astsni2 year
foreach i of numlist 16 29 45 {
	g dw_ast`i'=swswage`i'/L.swswage`i'
}
reshape long swswage dw_ast, i(year astsni2) j(ageclass)
replace dw_ast=0.95 if dw_ast<=0.94
replace dw_ast=1.15 if dw_ast>=1.16

drop swswage
sort year astsni2 ageclass
save temp/wgrowth_ast,replace

use temp/wgrowth_ftg,clear
gen astsni2=ftgsni2
merge m:m year astsni2 ageclass using temp/wgrowth_ast, update
drop _merge
gen dw=(dw_ftg+dw_ast)/2
replace dw=dw_ftg if dw==.
replace dw=dw_ast if dw==.
drop dw_ftg dw_ast
replace astsni2=ftgsni2 if astsni2==.
drop if ftgsni2==.
sort year astsni2 ageclass
save temp/wgrowth, replace

* Update sws-wages with leads and lags. Saves file temp/manl_impute.dta containg manl_ftg1 and manl_ast1 
use modified/sample1985.dta, clear
keep lopnr year ageclass astsni2 ftgsni2 manl_ftg manl_ast ftgnr astnr

forvalues i=1986(1)2009 {
	display "Appending "`i'
	append using modified/sample`i'
	keep lopnr year ageclass astsni2 ftgsni2 manl_ftg manl_ast ftgnr astnr
	}
	
	* Merge with wage growth
	display "Append wage growth firm"
	sort year ftgsni2 ageclass
	merge m:1 year ftgsni2 ageclass using temp/wgrowth
	drop  if _merge==2
	drop _merge
	rename dw dw_ftg

	display "Append wage growth plant"
	sort year astsni2 ageclass
	merge m:1 year astsni2 ageclass using temp/wgrowth
	drop  if _merge==2
	drop _merge
	rename dw dw_ast

	display "tsset"
	tsset lopnr year
	
	*Firm
	display "Generate firm identifiers"
	egen Nftgnr=group(ftgnr)
	sort lopnr year

	* impute values forward and backward 2 years
	g manl_imp_ftg=manl_ftg
	bysort lopnr: replace manl_imp_ftg=L.manl_imp_ftg*dw_ftg if missing(manl_imp_ftg) & Nftgnr==L.Nftgnr & Nftgnr~=.
	bysort lopnr: replace manl_imp_ftg=F.manl_imp_ftg/F.dw_ftg if missing(manl_imp_ftg) & Nftgnr==F.Nftgnr & Nftgnr~=.
	bysort lopnr: replace manl_imp_ftg=L2.manl_imp_ftg*L2.dw_ftg*L.dw_ftg if missing(manl_imp_ftg) & Nftgnr==L2.Nftgnr & Nftgnr~=.
	bysort lopnr: replace manl_imp_ftg=F2.manl_imp_ftg/(F2.dw_ftg*F.dw_ftg) if missing(manl_imp_ftg) & Nftgnr==F2.Nftgnr & Nftgnr~=.

	*Plant
	display "Generate plant identifiers"
	destring astnr, g(Nastnr)
	sort lopnr year

	* impute values forward and backward 2 years
	g manl_imp_ast=manl_ast
	bysort lopnr: replace manl_imp_ast=L.manl_imp_ast*dw_ast if missing(manl_imp_ast) & Nastnr==L.Nastnr & Nastnr~=.
	bysort lopnr: replace manl_imp_ast=F.manl_imp_ast/F.dw_ast if missing(manl_imp_ast) & Nastnr==F.Nastnr & Nastnr~=.
	bysort lopnr: replace manl_imp_ast=L2.manl_imp_ast*L2.dw_ast*L.dw_ast if missing(manl_imp_ast) & Nastnr==L2.Nastnr & Nastnr~=.
	bysort lopnr: replace manl_imp_ast=F2.manl_imp_ast/(F2.dw_ast*F.dw_ast) if missing(manl_ast) & Nastnr==F2.Nastnr & Nastnr~=.

	keep lopnr year manl_imp_ftg manl_imp_ast ftgnr astnr
	lab var manl_imp_ftg "SWS-wages imputed +/-2 years"
	lab var manl_imp_ast "SWS-wages imputed +/-2 years"
	sort lopnr year ftgnr astnr
	
save temp/manl_impute, replace	

* Return to with sample`i': wages Labor earnings (lonfink-Louise) and wages (SWS)
* NOTE: manl_ftg, manl_ast, manl_imp_ftg, manl_imp_ast, and minwage are already deflated to 2008 SEK

forvalues i=1985(1)2009 {
	use modified/sample`i', clear
	
	* Get imputed sws-wages
	merge 1:1 lopnr year ftgnr using temp/manl_impute, keepus(manl_imp_ftg)
	drop if _merge==2
	drop _merge
	merge 1:1 lopnr year astnr using temp/manl_impute, keepus(manl_imp_ast)
	drop if _merge==2
	drop _merge

	* Deflate earnings using gdp-deflator (wages and minwage already deflated)
	replace lonfink_ftg=lonfink_ftg/deflator
	replace lonfink_ast=lonfink_ast/deflator 
	replace loneink=loneink/deflator

	* Monthly earnings
	gen inc_ftg=lonfink_ftg/spellsum_ftg			
	gen inc_ast=lonfink_ast/spellsum_ast			
	
	* Keep untrimmed earnings and wages
	gen inc_ftg2=inc_ftg
	gen inc_ast2=inc_ast
	gen manl_imp_ftg2=manl_imp_ftg
	gen manl_imp_ast2=manl_imp_ast

	* To avoid division bias, we only use labor earnings for those with >=4 months of work
	replace inc_ftg=. if spellsum_ftg<=3
	replace inc_ast=. if spellsum_ast<=3

	* Set labor income and wages<minwage to missing
	replace inc_ftg=. if inc_ftg<minwage
	replace inc_ast=. if inc_ast<minwage
	replace manl_imp_ftg=. if manl_imp_ftg<minwage
	replace manl_imp_ast=. if manl_imp_ast<minwage
	
	*trim earnings distribution: 99.75th percentile for earnings and 99.9th for wages 
	xtile x_ftg=inc_ftg, nq(400)
	xtile x_ast=inc_ast, nq(400)
	replace inc_ftg=. if x_ftg==400
	replace inc_ast=. if x_ast==400
	drop x_ftg x_ast

	xtile x_ftg=manl_imp_ftg, nq(1000)
	xtile x_ast=manl_imp_ast, nq(1000)
	replace manl_imp_ftg=. if x_ftg==1000
	replace manl_imp_ast=. if x_ast==1000
	drop x_ftg x_ast

	* Log earnings and wages
	gen lninc_ftg=ln(inc_ftg)
	gen lninc_ast=ln(inc_ast)
	gen lnwage_ftg=ln(manl_imp_ftg)
	gen lnwage_ast=ln(manl_imp_ast)

	* Wage prediction
	* Dependent variable for wage prediction
	g lnwpred_ftg=lnwage_ftg
	g lnwpred_ast=lnwage_ast
	
	* Polynomials of earnings
	g lninc_ftg2=lninc_ftg*lninc_ftg
	g lninc_ftg3=lninc_ftg2*lninc_ftg
	g lninc_ftg4=lninc_ftg3*lninc_ftg
	g lninc_ftg5=lninc_ftg4*lninc_ftg

	g lninc_ast2=lninc_ast*lninc_ast
	g lninc_ast3=lninc_ast2*lninc_ast
	g lninc_ast4=lninc_ast3*lninc_ast
	g lninc_ast5=lninc_ast4*lninc_ast

	xi: reg lnwpred_ftg i.sex*lninc_ftg i.sex*lninc_ftg2 i.sex*lninc_ftg3 i.sex*lninc_ftg4 i.sex*lninc_ftg5 i.sex*i.ftgsni2
	predict what, xb
	replace lnwpred_ftg=what if missing(lnwpred_ftg)
	drop what
	
	xi: reg lnwpred_ast i.sex*lninc_ast i.sex*lninc_ast2 i.sex*lninc_ast3 i.sex*lninc_ast4 i.sex*lninc_ast5 i.sex*i.astsni2
	predict what, xb
	replace lnwpred_ast=what if missing(lnwpred_ast)
	drop what

	drop _* lninc_ftg2 lninc_ftg3 lninc_ftg4 lninc_ftg5 lninc_ast2 lninc_ast3 lninc_ast4 lninc_ast5 ageclass
	
	lab var lnwpred_ftg "Predicted monthly wages"
	lab var lnwpred_ast "Predicted monthly wages"
	lab var loneink "Labor earnings (LOUISE)"
	lab var inc_ftg "Monthly labor earnings (LOUISE)"
	lab var inc_ast "Monthly labor earnings (LOUISE)"
	lab var inc_ftg2 "Untrimmed monthly earnings income (LOUISE)"
	lab var inc_ast2 "Untrimmed monthly earnings income (LOUISE)"
	lab var manl_imp_ftg "Monthly wage (SWS)"
	lab var manl_imp_ast "Monthly wage (SWS)"
	lab var manl_imp_ftg2 "Untrimmed monthly wage (SWS)"
	lab var manl_imp_ast2 "Untrimmed monthly wage (SWS)"
	lab var lninc_ftg "Log monthly labor earnings (LOUISE)"
	lab var lninc_ast "Log monthly labor earnings (LOUISE)"
	lab var lnwage_ftg "Log monthly wage (SWS)"
	lab var lnwage_ast "Log monthly wage (SWS)"
	lab var minwage "Minumum wages according to Skedinger (2008 SEK)"
	
	save modified/sample`i', replace
}	

* Final sample`i' save: Create indicators for different samples (note that for size>=50 this is already done
set more off
forvalues i=1985(1)2009{
use modified/sample`i'.dta,clear

	foreach x in ftg ast {
		foreach j in 10 25 100 200 {
		gen sample_3035_`j'_`x'=0
		gen in_sample_3035_`j'_`x'=0
		
		replace sample_3035_`j'_`x'=1 if age>= 30 & age<= 35 & ftgstorl_`x'>=`j' & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_`x'==1 & year==`i'
		bysort `x'nr: egen sample_`x'=sum(sample_3035_`j'_`x') 
		* At least two employees
		replace sample_3035_`j'_`x'=0 if sample_`x'<=1
		replace sample_3035_`j'_`x'=0 if privfirm_`x'~=1 & privfirm_`x'~=.
		drop sample_`x'

		bysort `x'nr: egen sample_`x'=mean(sample_3035_`j'_`x')
		replace in_sample_3035_`j'_`x'=1 if sample_`x'>0 & sample_`x'~=. 
		replace in_sample_3035_`j'_`x'=0 if sample_`x'==0 
		drop sample_`x' 
		}
	}
save modified/sample`i'.dta,replace
}	



*** 8 Firm level production data. 
* Generates modified/firmdata8508.dta
* Industry level: modified/firm_aggregates_sni2.dta
* Industry level: modified/firm_aggregates_50emp_sni2.dta
* Based on productiondata_JHR.do
* This part picks up all relevant firmlevel data from the industry statistics 


* Building capital stocks starts hete
clear
use fek/industristat_ftg_1985_2002.dta
keep ftglopnr_su ar foradlingsvarde sni92 omsattning lon arbetskraftskostnad maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
destring ar,replace
rename ar year
*replace lon=lon/10 if year<=1995  
rename ftglopnr_su ftgnr
sort ftgnr year
save temp/firm8502,replace
clear
use fek/industristat_ftg_2003.dta
keep ftglopnr_su foradlingsvarde sni92 omsattning lon arbetskraftskostnad maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
gen year=2003
rename ftglopnr_su ftgnr
sort ftgnr year
save temp/firm03,replace
clear
use fek/industristat_ftg_2004.dta
keep ftglopnr_su foradlingsvarde sni92  omsattning lon arbetskraftskostnad maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
gen year=2004
rename ftglopnr_su ftgnr
sort ftgnr year
save temp/firm04,replace
clear
use fek/industristat_ftg_2005.dta
keep ftglopnr_su foradlingsvarde sni92 omsattning lon arbetskraftskostnad maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
g year=2005
rename ftglopnr_su ftgnr
sort ftgnr year
save temp/firm05,replace
clear
use fek/industristat_ftg_2006.dta
keep ftglopnr_su foradlingsvarde sni92  omsattning lon arbetskraftskostnad maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
gen year=2006
rename ftglopnr_su ftgnr
sort ftgnr year
save temp/firm06,replace
clear
use fek/industristat_ftg_2007.dta
keep ftglopnr_su foradlingsvarde sni92 omsattning lon sociala_och_andra_personalkostna maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
gen year=2007
rename ftglopnr_su ftgnr
sort ftgnr year
g arbetskraftskostnad=sociala_och_andra_personalkostna+lon
drop sociala_och_andra_personalkostna
save temp/firm07,replace
clear
use fek/industristat_ftg_2008.dta
keep ftglopnr_su foradlingsvarde  foradlingsvarde sni2002 omsattning lon sociala_och_andra_personalkostna maskiner_inventarier ant_anst byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark
gen year=2008
rename ftglopnr_su ftgnr
rename sni2002 sni92
sort ftgnr year
g arbetskraftskostnad=sociala_och_andra_personalkostna+lon
drop sociala_och_andra_personalkostna
save temp/firm08,replace

clear
use temp/firm8502
append using temp/firm03
append using temp/firm04
append using temp/firm05
append using temp/firm06
destring sni92,replace force
append using temp/firm07
append using temp/firm08


gen deflator=.
replace deflator=0.511617312	 if year==1985
replace deflator=0.533257403	 if year==1986
replace deflator=0.555808656	 if year==1987
replace deflator=0.588154897	 if year==1988
replace deflator=0.625968109	 if year==1989
replace deflator=0.691571754	 if year==1990
replace deflator=0.756036446	 if year==1991
replace deflator=0.773348519	 if year==1992
replace deflator=0.809339408	 if year==1993
replace deflator=0.827107062	 if year==1994
replace deflator=0.848063781	 if year==1995
replace deflator=0.851936219	 if year==1996
replace deflator=0.856492027	 if year==1997
replace deflator=0.855125285	 if year==1998
replace deflator=0.859225513	 if year==1999
replace deflator=0.867653759	 if year==2000
replace deflator=0.888838269	 if year==2001
replace deflator=0.907972665	 if year==2002
replace deflator=0.925512528	 if year==2003
replace deflator=0.928929385	 if year==2004
replace deflator=0.933257403	 if year==2005
replace deflator=0.946013667	 if year==2006
replace deflator=0.966514806	 if year==2007
replace deflator=1		 if year==2008
replace deflator=0.997266515	 if year==2009

gsort ftgnr year -foradlingsvarde
duplicates drop ftgnr year,force

*imputing sni prio 1 write back actual
codebook sni92
gsort ftgnr -year
by ftgnr: replace  sni92= sni92[_n-1] if missing(sni92) 
codebook sni92
*imputing sni prio 2 translate from sni69?
sort ftgnr year
merge 1:1 ftgnr year using temp/impute_sni69_ftg
drop if _merge==2
drop _merge
g sni2=int(sni92/1000)
codebook sni2
replace sni2=ftgsni2_fek if missing(sni2)
codebook sni2

*now we are down to 18 missing values
*impute back
gsort ftgnr -year
by ftgnr: replace  sni2= sni2[_n-1] if missing(sni2) & year<1990
*now we are down to 17 of wich 14 have between 1-13 employees
drop sni92_fek ftgsni2_fek 

*production data: 1st choice: snikod from RAMS; 2nd choice from FEK 
sort ftgnr year
merge 1:1 ftgnr year using modified/sniftg
drop if _merge==2
drop _merge

g x=1 if missing(ftgsni) & sni92!=.
replace x=1 if missing(ftgsni2) & sni2!=.
replace ftgsni=sni92 if missing(ftgsni)
replace ftgsni4=int(sni92/10) if missing(ftgsni4)
replace ftgsni3=int(sni92/100) if missing(ftgsni3)
replace ftgsni2=sni2 if missing(ftgsni2)

replace D_replace_ftgsni=4 if x==1
drop x
drop if ant_anst<=0

*note: firm_var carries sni2 and sni92 wich are industry codes according to FEK. We are using classification according to RAMS through out though.

*merge prices 
sort year
merge m:1 year using prices/im
drop if _merge==2
drop _merge
sort year
merge m:1 year using prices/ib
drop if _merge==2
drop _merge

*implicit depreciation rates per type of capital (dm machinary and equipment; db buildings). Averages 1993-2004. (from implicit_depreciation_JHR.do)
gen sni3=ftgsni3
gen sni4=ftgsni4
gen sni5=ftgsni

g db=.
replace db=	0.0242		 if sni2==01
replace db=	0.024183333	 if sni2==02
*replace db=	. 		 if sni2==05
replace db=	0.0785		 if sni2==10
replace db=	0.0785		 if sni2==11
replace db=	0.0785		 if sni2==12
replace db=	0.078066667	 if sni2==13
replace db=	0.07795		 if sni2==14
replace db=	0.0319		 if sni2==15
replace db=	0.0319		 if sni2==16
replace db=	0.031875	 if sni2==17
replace db=	0.0318		 if sni2==18
replace db=	0.031591667	 if sni2==19
replace db=	0.031908333	 if sni3==201
replace db=	0.031925	 if sni3==202
replace db=	0.031925	 if sni3==203
replace db=	0.031925	 if sni3==204
replace db=	0.031925	 if sni3==205
replace db=	0.032		 if sni2==21
replace db=	0.031908333	 if sni2==22
replace db=	0.032016667	 if sni2==23
replace db=	0.031941667	 if sni3==241
replace db=	0.031941667	 if sni3==242
replace db=	0.031941667	 if sni3==243
replace db=	0.0319		 if sni3==244
replace db=	0.03165		 if sni3==245
replace db=	0.031675	 if sni3==246
replace db=	0.031675	 if sni3==247
replace db=	0.031916667	 if sni2==25
replace db=	0.0319		 if sni2==26
replace db=	0.0319		 if sni3==271
replace db=	0.0319		 if sni3==272
replace db=	0.0319		 if sni3==273
replace db=	0.031933333	 if sni3==274
replace db=	0.031933333	 if sni3==275
replace db=	0.031916667	 if sni2==28
replace db=	0.0319		 if sni2==29
replace db=	0.0319		 if sni2==30
replace db=	0.031875	 if sni2==31
replace db=	0.0319		 if sni2==32
replace db=	0.032041667	 if sni2==33
replace db=	0.0319		 if sni2==34
replace db=	0.031908333	 if sni2==35
replace db=	0.031891667	 if sni2==36
replace db=	0.0321375	 if sni2==37
replace db=	0.021816667	 if sni3==401
replace db=	0.0213		 if sni3==403
replace db=	0.021358333	 if sni3==402
replace db=	0.024		 if sni2==41
replace db=	0.0319		 if sni2==45
replace db=	0.026533333	 if sni2==50
replace db=	0.026533333	 if sni2==51
replace db=	0.026533333	 if sni2==52
replace db=	0.0285		 if sni2==55
replace db=	0.017791667	 if sni3==601
replace db=	0.02593		 if sni3==602
*replace db=	.		 if sni3==603
replace db=	0.019766667	 if sni2==61
replace db=	0.026533333	 if sni2==62
replace db=	0.02495		 if sni3==631
replace db=	0.025525	 if sni3==632
replace db=	0.026316667	 if sni3==633
replace db=	0.02505		 if sni3==634
replace db=	0.025016667	 if sni3==641
replace db=	0.024		 if sni3==642
replace db=	0.02655		 if sni2==65
replace db=	0.025		 if sni2==66
replace db=	0.0240625	 if sni2==67
replace db=	0.0189		 if sni3==702
*replace db=	.			 if sni3==701
replace db=	0.026508333	 if sni2==71
replace db=	0.02485		 if sni2==72
replace db=	0.025008333	 if sni2==73
replace db=	0.025008333	 if sni2==74
*replace db=	.			 if sni2==75
replace db=	0.018891667	 if sni2==80
replace db=	0.018983333	 if sni3==851
replace db=	0.0197		 if sni3==852
replace db=	0.018925	 if sni3==853
replace db=	0.024991667	 if sni2==90
*replace db=	.			 if sni2==91
replace db=	0.030441667	 if sni2==92
replace db=	0.026508333	 if sni2==93
*replace db=	.			 if sni2==95

*for missing depriciation is set to 3.1% which is overall average
replace db=0.031  if missing(db)

g dm=.
replace dm=	0.137558333	 if sni2==	01
replace dm=	0.137		 if sni2==	02
replace dm=	0.07225		 if sni2==	05
replace dm=	0.149633333	 if sni2==	10
replace dm=	0.149633333	 if sni2==	11
replace dm=	0.149633333	 if sni2==	12
replace dm=	0.131475	 if sni2==	13
replace dm=	0.170441667	 if sni2==	14
replace dm=	0.22715		 if sni2==	15
replace dm=	0.22715		 if sni2==	16
replace dm=	0.137716667	 if sni2==	17
replace dm=	0.147733333	 if sni2==	18
replace dm=	0.134816667	 if sni2==	19
replace dm=	0.166441667	 if sni3==	201
replace dm=	0.1446		 if sni3==	202
replace dm=	0.1446		 if sni3==	203
replace dm=	0.1446		 if sni3==	204
replace dm=	0.1446		 if sni3==	205
replace dm=	0.13575		 if sni3==	211
replace dm=	0.138925	 if sni3==	212
replace dm=	0.283933333	 if sni2==	22
replace dm=	0.261516667	 if sni2==	23
replace dm=	0.286391667	 if sni3==	241
replace dm=	0.286391667	 if sni3==	242
replace dm=	0.286391667	 if sni3==	243
replace dm=	0.155325	 if sni3==	244
replace dm=	0.173233333	 if sni3==	245
replace dm=	0.178166667	 if sni3==	246
replace dm=	0.178166667	 if sni3==	247
replace dm=	0.146966667	 if sni2==	25
replace dm=	0.149483333	 if sni2==	26
replace dm=	0.158458333	 if sni3==	271
replace dm=	0.158458333	 if sni3==	272
replace dm=	0.158458333	 if sni3==	273
replace dm=	0.1863		 if sni3==	274
replace dm=	0.200766667	 if sni2==	28
replace dm=	0.176233333	 if sni2==	29
replace dm=	0.176566667	 if sni2==	30
replace dm=	0.227933333	 if sni2==	31
replace dm=	0.252733333	 if sni2==	32
replace dm=	0.159516667	 if sni2==	33
replace dm=	0.166508333	 if sni2==	34
replace dm=	0.154841667	 if sni2==	35
replace dm=	0.1461		 if sni2==	36
replace dm=	0.2196		 if sni2==	37
replace dm=	0.1297		 if sni3==	401
replace dm=	0.127366667	 if sni3==	403
replace dm=	0.376933333	 if sni3==	402
replace dm=	0.135233333	 if sni2==	41
replace dm=	0.156441667	 if sni2==	45
replace dm=	0.1925		 if sni2==	50
replace dm=	0.1925		 if sni2==	51
replace dm=	0.1925		 if sni2==	52
replace dm=	0.165991667	 if sni2==	55
replace dm=	0.1184		 if sni3==	601
replace dm=	0.202345833	 if sni3==	602
*replace dm=	.		 if sni3==	603
replace dm=	0.0758		 if sni2==	61
replace dm=	0.108258333	 if sni2==	62
replace dm=	0.215391667	 if sni3==	631
replace dm=	0.243897222	 if sni3==	632
replace dm=	0.263333333	 if sni3==	633
replace dm=	0.207641667	 if sni3==	634
replace dm=	0.193091667	 if sni3==	641
replace dm=	0.157783333	 if sni3==	642
replace dm=	0.3286		 if sni2==	65
replace dm=	0.335816667	 if sni2==	66
replace dm=	0.508216667	 if sni2==	67
replace dm=	0.114333333	 if sni3==	702
replace dm=	0.141925	 if sni3==	701
replace dm=	0.206408333	 if sni2==	71
replace dm=	0.296325	 if sni2==	72
replace dm=	0.250366667	 if sni2==	73
replace dm=	0.319441667	 if sni2==	74
*replace dm=	.		 if sni2==	75
replace dm=	0.225541667	 if sni2==	80
replace dm=	0.206333333	 if sni3==	851
replace dm=	0.335508333	 if sni3==	852
replace dm=	0.201733333	 if sni3==	853
replace dm=	0.231483333	 if sni2==	90 
replace dm=	0.182591667	 if sni2==	91
replace dm=	0.195233333	 if sni2==	92
replace dm=	0.136325	 if sni2==	93
*replace dm=	.		 if sni2==	95

*for missing depriciation is set to 19.4% which is overall average
replace dm=0.194  if missing(dm)

sort year
merge m:1 year using prices/ifv
drop if _merge==2
drop _merge

*Link implicit price indexes to sni92 (t/(t-1)) (from implicitprices_JHR.do)

g im=.
replace im=	im11000	  if sni2==1	
replace im=	im12000	  if sni2==2	
replace im=	im13000	  if sni2==5	
replace im=	im21000	  if (sni2==10|sni2==11|sni2==12)	
replace im=	im22100	  if sni3==131	
replace im=	im22200	  if sni3==132	
replace im=	im23000	  if sni2==14	
replace im=	im31100	  if sni2==15	
replace im=	im31200	  if sni2==16	
replace im=	im32100	  if sni2==17	
replace im=	im32210	  if sni2==18	
replace im=	im32220	  if sni2==19	
replace im=	im33100	  if sni3==201	
replace im=	im33200	  if (sni3==202|sni3==203|sni3==204|sni3==205)	
replace im=	im34111	  if sni4==2111	
replace im=	im34112	  if sni4==2112	
replace im=	im34120	  if sni3==212	
replace im=	im34200	  if sni2==22	
replace im=	im35100	  if sni2==23	
replace im=	im35210	  if (sni3==241|sni3==242|sni3==243)	
replace im=	im35221	  if sni3==244	
replace im=	im35222	  if sni3==245	
replace im=	im35230	  if (sni3==246|sni3==247)	
replace im=	im35300	  if sni2==25	
replace im=	im36000	  if sni2==26	
replace im=	im37100	  if (sni3==271|sni3==272|sni3==273)	
replace im=	im37200	  if (sni3==274|sni3==275)	
replace im=	im38100	  if sni2==28	
replace im=	im38200	  if sni2==29	
replace im=	im38300	  if sni2==30	
replace im=	im38400	  if sni2==31	
replace im=	im38500	  if sni2==32	
replace im=	im38600	  if sni2==33	
replace im=	im38700	  if sni2==34	
replace im=	im38800	  if sni2==35	
replace im=	im39100	  if sni2==36	
replace im=	im39200	  if sni2==37	
replace im=	im41110	  if sni3==401	
replace im=	im41130	  if sni3==403	
replace im=	im41200	  if sni3==402	
replace im=	im42000	  if (sni2==41|sni5==90001)
replace im=	im50000	  if sni2==45	
replace im=	im61000	  if (sni2==50|sni2==51|sni2==52)	
replace im=	im62000	  if sni2==55	
replace im=	im71100	  if sni3==601	
replace im=	im71211	  if sni4==6021	
replace im=	im71212	  if sni4==6022	
replace im=	im71213	  if sni4==6023	
replace im=	im71221	  if sni4==6024	
*replace im=	im71222	  if sni3==603	
replace im=	im72100	  if sni2==61	
replace im=	im72200	  if sni2==62	
replace im=	im72311	  if sni3==631	
replace im=	im72312	  if sni4==6321	
replace im=	im72321	  if sni4==6322	
replace im=	im72322	  if sni4==6323	
replace im=	im72331	  if sni3==633	
replace im=	im72332	  if sni3==634	
replace im=	im73100	  if sni3==641	
replace im=	im73200	  if sni3==642	
replace im=	im81100	  if sni2==65	
replace im=	im81200	  if sni2==66	
replace im=	im81300	  if sni2==67	
replace im=	im82100	  if sni3==702	
replace im=	im82220	  if (sni3==701|sni3==703)	
replace im=	im83110	  if sni2==71	
replace im=	im83120	  if sni2==72	
replace im=	im83210	  if sni2==73	
replace im=	im83220	  if sni2==74	
replace im=	im91000	  if sni2==75	
replace im=	im92120	  if sni2==80	
replace im=	im92131	  if sni3==851	
replace im=	im92132	  if sni3==852	
replace im=	im92133	  if sni3==853	
replace im=	im92210	  if (sni2==90 & sni5!=90001)	
replace im=	im92220	  if sni2==91	
replace im=	im92230	  if sni2==92	
replace im=	im92240	  if sni2==93	
*replace im=	im92300	  if sni2==95	
* second replacement   if less level of detail available			
replace im=	im20000	  if (sni2==10|sni2==11|sni2==12|sni2==13|sni2==14)	& im==.
replace im=	im30000	  if (sni2==15|sni2==16|sni2==17|sni2==18|sni2==19|sni2==20|sni2==21|sni2==22|sni2==23|sni2==24|sni2==25|sni2==26|sni2==27|sni2==28|sni2==29|sni2==30|sni2==31|sni2==32|sni2==33|sni2==34|sni2==35|sni2==36|sni2==37)	& im==.
replace im=	im41000	  if (sni2==40)	&  im==.
replace im=	im71200	  if (sni3==602|sni3==603)	& im==.
replace im=	im72300	  if (sni2==63)	&  im==.
replace im=	im81000	  if (sni2==65|sni2==66|sni2==67)	& im==.
replace im=	im82200	  if (sni2==70)	& im==.
replace im=	im83000	  if (sni2==71|sni2==72|sni2==73|sni2==74)	& im==.
replace im=	im92000	  if (sni2==80|sni2==85|sni2==90|sni2==91|sni2==92|sni2==93|sni2==94|sni2==95)	& im==.

g ib=.			
replace ib=	ib11000	  if sni2==1	
replace ib=	ib12000	  if sni2==2	
replace ib=	ib13000	  if sni2==5	
replace ib=	ib21000	  if (sni2==10|sni2==11|sni2==12)	
replace ib=	ib22100	  if sni3==131	
replace ib=	ib22200	  if sni3==132	
replace ib=	ib23000	  if sni2==14	
replace ib=	ib31100	  if sni2==15	
replace ib=	ib31200	  if sni2==16	
replace ib=	ib32100	  if sni2==17	
replace ib=	ib32210	  if sni2==18	
replace ib=	ib32220	  if sni2==19	
replace ib=	ib33100	  if sni3==201	
replace ib=	ib33200	  if (sni3==202|sni3==203|sni3==204|sni3==205)	
replace ib=	ib34111	  if sni4==2111	
replace ib=	ib34112	  if sni4==2112	
replace ib=	ib34120	  if sni3==212	
replace ib=	ib34200	  if sni2==22	
replace ib=	ib35100	  if sni2==23	
replace ib=	ib35210	  if (sni3==241|sni3==242|sni3==243)	
replace ib=	ib35221	  if sni3==244	
replace ib=	ib35222	  if sni3==245	
replace ib=	ib35230	  if (sni3==246|sni3==247)	
replace ib=	ib35300	  if sni2==25	
replace ib=	ib36000	  if sni2==26	
replace ib=	ib37100	  if (sni3==271|sni3==272|sni3==273)	
replace ib=	ib37200	  if (sni3==274|sni3==275)	
replace ib=	ib38100	  if sni2==28	
replace ib=	ib38200	  if sni2==29	
replace ib=	ib38300	  if sni2==30	
replace ib=	ib38400	  if sni2==31	
replace ib=	ib38500	  if sni2==32	
replace ib=	ib38600	  if sni2==33	
replace ib=	ib38700	  if sni2==34	
replace ib=	ib38800	  if sni2==35	
replace ib=	ib39100	  if sni2==36	
replace ib=	ib39200	  if sni2==37	
replace ib=	ib41110	  if sni3==401	
replace ib=	ib41130	  if sni3==403	
replace ib=	ib41200	  if sni3==402	
replace ib=	ib42000	  if (sni2==41|sni5==90001)	
replace ib=	ib50000	  if sni2==45	
replace ib=	ib61000	  if (sni2==50|sni2==51|sni2==52)	
replace ib=	ib62000	  if sni2==55	
replace ib=	ib71100	  if sni3==601	
replace ib=	ib71211	  if sni4==6021	
replace ib=	ib71212	  if sni4==6022	
replace ib=	ib71213	  if sni4==6023	
replace ib=	ib71221	  if sni4==6024	
*replace ib=	ib71222	  if sni3==603	
replace ib=	ib72100	  if sni2==61	
replace ib=	ib72200	  if sni2==62	
replace ib=	ib72311	  if sni3==631	
replace ib=	ib72312	  if sni4==6321	
replace ib=	ib72321	  if sni4==6322	
replace ib=	ib72322	  if sni4==6323	
replace ib=	ib72331	  if sni3==633	
replace ib=	ib72332	  if sni3==634	
replace ib=	ib73100	  if sni3==641	
replace ib=	ib73200	  if sni3==642	
replace ib=	ib81100	  if sni2==65	
replace ib=	ib81200	  if sni2==66	
replace ib=	ib81300	  if sni2==67	
replace ib=	ib82100	  if sni3==702	
replace ib=	ib82220	  if (sni3==701|sni3==703)	
replace ib=	ib83110	  if sni2==71	
replace ib=	ib83120	  if sni2==72	
replace ib=	ib83210	  if sni2==73	
replace ib=	ib83220	  if sni2==74	
replace ib=	ib91000	  if sni2==75	
replace ib=	ib92120	  if sni2==80	
replace ib=	ib92131	  if sni3==851	
replace ib=	ib92132	  if sni3==852	
replace ib=	ib92133	  if sni3==853	
replace ib=	ib92210	  if (sni2==90 & sni5!=90001)	
replace ib=	ib92220	  if sni2==91	
replace ib=	ib92230	  if sni2==92	
replace ib=	ib92240	  if sni2==93	
*replace ib=	ib92300	  if sni2==95	
* second replacement  if less level of detail available			
replace ib=	ib20000	  if (sni2==10|sni2==11|sni2==12|sni2==13|sni2==14) & ib==.
replace ib=	ib30000	  if (sni2==15|sni2==16|sni2==17|sni2==18|sni2==19|sni2==20|sni2==21|sni2==22|sni2==23|sni2==24|sni2==25|sni2==26|sni2==27|sni2==28|sni2==29|sni2==30|sni2==31|sni2==32|sni2==33|sni2==34|sni2==35|sni2==36|sni2==37)	& ib==.
replace ib=	ib41000	  if (sni2==40)	& ib==.
replace ib=	ib71200	  if (sni3==602|sni3==603)	&  ib==.
replace ib=	ib72300	  if (sni2==63)	& ib==.
replace ib=	ib81000	  if (sni2==65|sni2==66|sni2==67)	& ib==.
replace ib=	ib82200	  if (sni2==70)	& ib==.
replace ib=	ib83000	  if (sni2==71|sni2==72|sni2==73|sni2==74)	& ib==.
replace ib=	ib92000	  if (sni2==80|sni2==85|sni2==90|sni2==91|sni2==92|sni2==93|sni2==94|sni2==95)	& ib==.

g  ifv=.		
replace  ifv=	 ifv_01_05	  if sni2==01|sni2==02|sni2==03|sni2==04|sni2==05
replace  ifv=	 ifv_10_37	  if sni2==10|sni2==11|sni2==12|sni2==13|sni2==14|sni2==15|sni2==15|sni2==16|sni2==17|sni2==18|sni2==19|sni2==20|sni2==21|sni2==22|sni2==23|sni2==24|sni2==25|sni2==26|sni2==27|sni2==28|sni2==29|sni2==30|sni2==31|sni2==32|sni2==33|sni2==34|sni2==35|sni2==36|sni2==37
replace  ifv=	 ifv_40_41	  if sni2==40|sni2==41
replace  ifv=	 ifv_45	  if sni2==45
replace  ifv=	 ifv_50_52	  if sni2==50|sni2==51|sni2==52
replace  ifv=	 ifv_55_60_64	  if sni2==55|sni2==60|sni2==61|sni2==62|sni2==63|sni2==64
replace  ifv=	 ifv_65_67	  if sni2==65|sni2==66|sni2==67
replace  ifv=	 ifv_70	  if sni2==70
replace  ifv=	 ifv_71_74	  if sni2==71|sni2==72|sni2==73|sni2==74
replace  ifv=	 ifv_80_95	  if sni2==80|sni2==85|sni2==90|sni2==91|sni2==92|sni2==94|sni2==94|sni2==95

drop if sni2==0
replace im=im/100
replace ib=ib/100
rename ib xib
rename im xim
rename ifv xifv
drop ib* im* ifv* pfv*
rename xib ib
rename xim im
rename xifv ifv

lab var foradlingsvarde "value added current prices"
lab var omsattning "turn over current prices"
lab var lon "wage cost ex social security contributions current prices"
lab var arbetskraftskostnad "total labor cost (wage + social security contributions) current prices"
lab var ant_anst "number of employees"
lab var maskiner_inventarier "machinery & equipment, book value current prices"
lab var byggnader_mark "buildings & land, book value current prices"
lab var binv_maskinv "gross investment machinery & equipment, current prices"
lab var binv_bygg_mark "gross investment buildings & land, current prices"
lab var ninv_maskinv "net investment machinery & equipment, current prices"
lab var ninv_bygg_mark "net investment buildings & land, current prices"

***sidecode***
preserve
keep im ib ifv ftgsni2 year
collapse (mean) im ib ifv, by(ftgsni2 year)
g m0=1
g b0=1
g f0=1
g m1=m0/im
g b1=b0/ib
g f1=f0/ifv 
g mf=m0 if year==2000
g bf=b0 if year==2000
g ff=f0 if year==2000

tsset ftgsni2 year
forvalues i=2001(1)2008{
replace mf=L.mf*m1/L.m0 if year==`i'
replace bf=L.bf*b1/L.b0 if year==`i'
replace ff=L.ff*f1/L.f0 if year==`i'
}

forvalues j=1999(-1)1986{
replace mf=F.mf*m0/F.m1 if year==`j'
replace bf=F.bf*b0/F.b1 if year==`j'
replace ff=F.ff*f0/F.f1 if year==`j'
}
g Pim=m0/mf
g Pib=b0/bf
g Pfv=f0/ff
keep ftgsni2 year Pim Pib Pfv
sort ftgsni2 year
save prices/deflators,replace
restore

sort ftgsni2 year
merge m:1 ftgsni2 year using prices/deflators
drop _merge

replace byggnader_mark=0 if byggnader_mark<0
replace maskiner_inventarier=0 if maskiner_inventarier<0

sort ftgnr year
egen nftgnr=group(ftgnr)
tsset nftgnr year

*note: wage och arbetskostnad deflateras with gdp-deflator
g real_wagecost=-lon/deflator
g real_laborcost=-arbetskraftskostnad/deflator 

*fasta referenprisserier
sort nftgnr year
g double bvb=byggnader_mark/Pib
g double bib=binv_bygg_mark/Pib
g double nib=ninv_bygg_mark/Pib

g double bvm=maskiner_inventarier/Pim
g double bim=binv_maskinv/Pim
g double nim=ninv_maskinv/Pim

g double fv=foradlingsvarde/Pfv
g double oms=omsattning/Pfv

*stockar enl carlsson (utg榮de)
g Km1=max(0, bvm, nim) if year==1986
g Kb1=max(0, bvb, nib) if year==1986

replace nim=0 if missing(nim)
replace nib=0 if missing(nib)

forvalues i=1987(1)2008{
replace Km1=max(L.Km1*(1-dm)+nim,bvm) if year==`i'
replace Kb1=max(L.Kb1*(1-db)+nib,bvb) if year==`i'
}

g Km=Km1 if year==2008
g Kb=Kb1 if year==2008
forvalues i=2007(-1)1985{
replace Km=(F.Km1-F.nim)/(1-dm) if year==`i'
replace Km=Km1 if missing(Km) & year==`i'
replace Kb=(F.Kb1-F.nib)/(1-db) if year==`i'
replace Kb=Kb1 if missing(Kb) & year==`i' 
}

replace Km=0 if Km<0
replace Kb=0 if Kb<0

lab var Km "Capital stock: machinery"
lab var Kb "Capital stock: buildings"
lab var ant_anst "Number of employees (ftg stats)"

drop if missing(foradlingsvarde)
drop if missing(lon)
drop if missing(omsattning)
drop if missing(maskiner_inventarier)
sort ftgnr year

*capital intensity
g kma=Km/ant_anst
g lkma=ln(kma)

lab var kma "Capital intensity (machinery)"
lab var lkma "Log capital intensity (machinery)"

*trim
g trim_kma=1
forvalues i=1985(1)2008{
display `i'
xtile prank_`i'=kma if year==`i', nq(100)
replace trim_kma=0 if prank_`i'==100 & year==`i'
}

gen prank=.
forvalues i=1985(1)2008{
replace prank=prank_`i' if year==`i'
drop prank_`i'
}

replace trim_kma=0 if kma==0
lab var prank "Annual rank of capital intensity"
lab var trim_kma "Trim capital int=1 if kma<prank=100 and kma>0"

* Value added and turnover per employee
gen va_emp=(foradlingsvarde/deflator)/ant_anst
gen to_emp=(omsattning/deflator)/ant_anst

lab var va_emp "Value added per employee (GDP-deflated)"
lab var to_emp "Turnover per employee (GDP-deflated)"

g trim_va=1
g trim_to=1
forvalues i=1985(1)2008{
	display `i'
	xtile prank_va_`i'=va_emp if year==`i', nq(100)
	replace trim_va=0 if prank_va_`i'==100 & year==`i'
	replace trim_va=0 if prank_va_`i'==1 & year==`i'
	xtile prank_to_`i'=to_emp if year==`i', nq(100)
	replace trim_to=0 if prank_to_`i'==100 & year==`i'
	replace trim_to=0 if prank_to_`i'==1 & year==`i'
}


gen prank_va=.
gen prank_to=.
forvalues i=1985(1)2008{
	replace prank_va=prank_va_`i' if year==`i'
	drop prank_va_`i'
	replace prank_to=prank_to_`i' if year==`i'
	drop prank_to_`i'
	}

lab var prank_va "Annual rank of value added per employee"
lab var prank_to "Annual rank of turnover per employee"
lab var trim_va "Trim value added per emp =1 if 100>prank_va>1"
lab var trim_to "Trim turnover per emp =1 if 100>prank_va>1"

* Side code: aggregate to industry level: modified/firm_aggregates_sni2.dta
preserve
	gen valueadded=foradlingsvarde/deflator
	gen turnover=omsattning/deflator
	replace kma=. if trim_kma==0
	collapse (sum) cap_sni2=Km va_sni2=valueadded to_sni2=turnover wages_sni2=real_wagecost laborcosts_sni2=real_laborcost emp_sni2=ant_anst (mean) mkma_sni2=kma mva_emp_sni2=va_emp mto_emp_sni2=to_emp memp_sni2=ant_anst (median) medkma_sni2=kma medva_emp_sni2=va_emp medto_emp_sni2=to_emp medemp_sni2=ant_anst, by(ftgsni2 year)
	gen capint_sni2=cap_sni2/emp_sni2
	lab var capint_sni2 "Capital per employee (sni2, real)"
	lab var cap_sni2 "Capital stock (sni2, real)"
	lab var va_sni2 "Value added (sni2, real)"
	lab var to_sni2 "Turnover (sni2, real)"
	lab var wages_sni2 "Wages (sni2, real)"
	lab var laborcosts_sni2 "Labor costs (sni2, real)"
	lab var emp_sni2 "Number of employees (sni2, real)"
	lab var mkma_sni2 "Mean capital intensity (sni2, unweighted)"
	lab var mva_emp_sni2 "Mean value added per employee (sni2, unweighted)"
	lab var mto_emp_sni2 "Mean turnover per employee (sni2, unweighted)" 
	lab var memp_sni2 "Mean number of employees (sni2, unweighted)" 
	lab var medkma_sni2 "Median capital intensity (sni2)"
	lab var medva_emp_sni2 "Median value added per employee (sni2)"
	lab var medto_emp_sni2 "Median turnover per employee (sni2)"
	lab var medemp_sni2 "Median number of employees (sni2)"
	gen sni2=ftgsni2
	gen astsni2=ftgsni2
	drop if ftgsni2==.
	sort ftgsni2 year
	save modified/firm_aggregates_sni2.dta,replace
restore

* Side code: aggregate to industry level (At least 50 employees): modified/firm_aggregates_50emp_sni2.dta
preserve
	drop if ant_anst<50
	gen valueadded=foradlingsvarde/deflator
	gen turnover=omsattning/deflator
	replace kma=. if trim_kma==0
	collapse (sum) cap_sni2=Km va_sni2=valueadded to_sni2=turnover wages_sni2=real_wagecost laborcosts_sni2=real_laborcost emp_sni2=ant_anst (mean) mkma_sni2=kma mva_emp_sni2=va_emp mto_emp_sni2=to_emp memp_sni2=ant_anst (median) medkma_sni2=kma medva_emp_sni2=va_emp medto_emp_sni2=to_emp medemp_sni2=ant_anst, by(ftgsni2 year)
	gen capint_sni2=cap_sni2/emp_sni2
	lab var capint_sni2 "Capital per employee (sni2, real)"
	lab var cap_sni2 "Capital stock (sni2, real)"
	lab var va_sni2 "Value added (sni2, real)"
	lab var to_sni2 "Turnover (sni2, real)"
	lab var wages_sni2 "Wages (sni2, real)"
	lab var laborcosts_sni2 "Labor costs (sni2, real)"
	lab var emp_sni2 "Number of employees (sni2, real)"
	lab var mkma_sni2 "Mean capital intensity (sni2, unweighted)"
	lab var mva_emp_sni2 "Mean value added per employee (sni2, unweighted)"
	lab var mto_emp_sni2 "Mean turnover per employee (sni2, unweighted)" 
	lab var memp_sni2 "Mean number of employees (sni2, unweighted)" 
	lab var medkma_sni2 "Median capital intensity (sni2)"
	lab var medva_emp_sni2 "Median value added per employee (sni2)"
	lab var medto_emp_sni2 "Median turnover per employee (sni2)"
	lab var medemp_sni2 "Median number of employees (sni2)"
	gen sni2=ftgsni2
	gen astsni2=ftgsni2
	drop if ftgsni2==.
	sort ftgsni2 year
	save modified/firm_aggregates_50emp_sni2.dta,replace
restore

gen valueadded=foradlingsvarde/deflator
lab var valueadded "Value added (firm, GDP-deflated)"
gen turnover=omsattning/deflator
lab var turnover "Turnover (firm, GDP-deflated)"
lab var fv "Value added (firm, firm deflators)"
lab var oms "Turnover (firm, firm deflators)"

gen ast_ftg=ftgnr
lab var ast_ftg "Firm matched to higest income plant"
drop sni92 foradlingsvarde omsattning lon arbetskraftskostnad maskiner_inventarier byggnader_mark binv_maskinv binv_bygg_mark ninv_maskinv ninv_bygg_mark deflator sni2 sni3 sni4 sni5 db dm im ib ifv Pim Pib Pfv nftgnr bvb bib nib bvm bim nim Km1 Kb1
sort ftgnr year
save modified/firmdata8508.dta,replace

*** 10. Organize trade data: modified/trade_sni2_8608.dta

use trade/Trade_SCB_sni4_1986_1994.dta, clear

merge m:1 sni69 using temp/egen_nyckel_sni69_sni92_4stall.dta
drop if _merge==2
drop _merge

sort sni69
g ftgsni2=int(sni92/100)
g sni69_2=int(sni69/100)

* Corrections
replace ftgsni2=1 if sni69_2==11
replace ftgsni2=2 if sni69_2==12
replace ftgsni2=5 if sni69_2==13
replace ftgsni2=10 if sni69_2==21
replace ftgsni2=11 if sni69_2==22
replace ftgsni2=14 if sni69==2903
replace ftgsni2=15 if sni69==3132
replace ftgsni2=17 if (sni69>=3211 & sni69<=3219)
replace ftgsni2=18 if sni69==3220 | sni69==3232
replace ftgsni2=19 if sni69==3231 | sni69==3233
replace ftgsni2=20 if sni69>=3311 & sni69<=3319
replace ftgsni2=21 if sni69>=3411 & sni69<=3419
replace ftgsni2=22 if sni69==3420
replace ftgsni2=25 if sni69==3513
replace ftgsni2=24 if sni69==3529
replace ftgsni2=23 if sni69==3530
replace ftgsni2=23 if sni69==3540
replace ftgsni2=25 if sni69==3551 | sni69==3559 | sni69==3560
replace ftgsni2=26 if sni69==3691
replace ftgsni2=27 if sni69==3710 | sni69==3720
replace ftgsni2=28 if sni69==3811 
replace ftgsni2=36 if sni69==3812
replace ftgsni2=28 if sni69==3813
replace ftgsni2=28 if sni69==3819
replace ftgsni2=29 if sni69==3823
replace ftgsni2=29 if sni69==3824
replace ftgsni2=30 if sni69==3825
replace ftgsni2=29 if sni69==3829
replace ftgsni2=31 if sni69==3831
replace ftgsni2=32 if sni69==3832
replace ftgsni2=29 if sni69==3833
replace ftgsni2=31 if sni69==3839
replace ftgsni2=34 if sni69==3843
replace ftgsni2=35 if sni69==3849
replace ftgsni2=33 if sni69==3851
replace ftgsni2=40 if sni69==4101 | sni69==4102
replace ftgsni2=41 if sni69==4200
replace ftgsni2=92 if sni69==9411 | sni69==9415
replace ftgsni2=74 if sni69==9592

replace ftgsni2=22 if sni69==9414
replace ftgsni2=33 if sni69==9331
replace ftgsni2=22 if sni69==8329
replace ftgsni2=50 if sni69==6129

replace ftgsni2=16 if sni69==9911
replace ftgsni2=5 if sni69==9931
replace ftgsni2=17 if sni69==9932
replace ftgsni2=20 if sni69==9933
replace ftgsni2=21 if sni69==9934
replace ftgsni2=25 if sni69==9935
replace ftgsni2=26 if sni69==9936
replace ftgsni2=27 if sni69==9937
replace ftgsni2=29 if sni69==9938
replace ftgsni2=36 if sni69==9939
drop if ftgsni2==.

collapse (sum) imports_from_china exports_to_china imports_from_world exports_to_world, by(ftgsni2 year) 
sort ftgsni2 year
save temp/trade8694.dta,replace

use trade/Trade_astsni2_1995_1997.dta, clear
rename astsni2 ftgsni2
sort ftgsni2 year
save temp/trade9597.dta,replace

use trade/Trade_astsni2_1998_2008.dta,clear
rename astsni2 ftgsni2
sort ftgsni2 year
save temp/trade9808.dta,replace

use temp/trade8694.dta,clear
append using temp/trade9597.dta
append using temp/trade9808.dta
gen deflator=.
replace deflator=0.533257403	 if year==1986
replace deflator=0.555808656	 if year==1987
replace deflator=0.588154897	 if year==1988
replace deflator=0.625968109	 if year==1989
replace deflator=0.691571754	 if year==1990
replace deflator=0.756036446	 if year==1991
replace deflator=0.773348519	 if year==1992
replace deflator=0.809339408	 if year==1993
replace deflator=0.827107062	 if year==1994
replace deflator=0.848063781	 if year==1995
replace deflator=0.851936219	 if year==1996
replace deflator=0.856492027	 if year==1997
replace deflator=0.855125285	 if year==1998
replace deflator=0.859225513	 if year==1999
replace deflator=0.867653759	 if year==2000
replace deflator=0.888838269	 if year==2001
replace deflator=0.907972665	 if year==2002
replace deflator=0.925512528	 if year==2003
replace deflator=0.928929385	 if year==2004
replace deflator=0.933257403	 if year==2005
replace deflator=0.946013667	 if year==2006
replace deflator=0.966514806	 if year==2007
replace deflator=1				 if year==2008

replace imports_from_china=imports_from_china/deflator 
replace exports_to_china=exports_to_china/deflator 
replace imports_from_world=imports_from_world/deflator 
replace exports_to_world=exports_to_world/deflator

lab var imports_from_china "Imports from China, SCB, '000 SEK"
lab var exports_to_china "Exports to China, SCB, '000 SEK"
lab var imports_from_world "Imports from world, SCB, '000 SEK"
lab var exports_to_world "Exports to world, SCB, '000 SEK"

sort ftgsni2 year
save temp/trade8608.dta,replace

use modified/firm_aggregates_sni2.dta,clear
sort ftgsni2 year
merge 1:1 ftgsni2 year using temp/trade8608.dta
drop if year==1985
drop if year==2009
drop if _merge==2
drop _merge

xtset ftgsni2 year
sort ftgsni2 year

g imp_china=imports_from_china/to_sni2
g exp_china=exports_to_china/to_sni2
g imp_world=imports_from_world/to_sni2
g exp_world=exports_to_world/to_sni2

gen trade_world=exp_world+imp_world
lab var trade_world "(Exports+imports)/turnover"
lab var imp_china "Imports from China/turnover"

gen trend=year-1985

* Flag variable
g trade_impute=0
replace trade_impute=1 if trade_world==.
lab var trade_impute "Indicator for imputed trade values"

* SNI55
reg imp_china trend if ftgsni2==55
predict imp_china_hat if ftgsni2==55, xb
replace imp_china=imp_china_hat if ftgsni2==55 & imp_china==.
drop imp_china_hat

reg exp_china trend if ftgsni2==55
predict exp_china_hat if ftgsni2==55, xb
replace exp_china=exp_china_hat if ftgsni2==55 & exp_china==.
drop exp_china_hat

reg trade_world trend if ftgsni2==55
predict trade_world_hat if ftgsni2==55, xb
replace trade_world=trade_world_hat if ftgsni2==55 & trade_world==.
drop trade_world_hat

reg imp_world trend if ftgsni2==55
predict imp_world_hat if ftgsni2==55, xb
replace imp_world=imp_world_hat if ftgsni2==55 & imp_world==.
drop imp_world_hat

reg exp_world trend if ftgsni2==55
predict exp_world_hat if ftgsni2==55, xb
replace exp_world=exp_world_hat if ftgsni2==55 & exp_world==.
drop exp_world_hat

* SNI37
replace imp_china=0 if ftgsni2==37
replace trade_world=0 if ftgsni2==37
replace imp_world=0 if ftgsni2==37
replace exp_world=0 if ftgsni2==37

* SNI41
replace imp_china=0 if ftgsni2==41
replace trade_world=0 if ftgsni2==41
replace imp_world=0 if ftgsni2==41
replace exp_world=0 if ftgsni2==41

* SNI45
replace imp_china=0 if ftgsni2==45
replace trade_world=0 if ftgsni2==45
replace imp_world=0 if ftgsni2==45
replace exp_world=0 if ftgsni2==45

* SNI50
replace imp_china=0 if ftgsni2==50
replace trade_world=0 if ftgsni2==50
replace imp_world=0 if ftgsni2==50
replace exp_world=0 if ftgsni2==50

* SNI51
replace imp_china=0 if ftgsni2==51
replace trade_world=0 if ftgsni2==51
replace imp_world=0 if ftgsni2==51
replace exp_world=0 if ftgsni2==51

* SNI52
replace imp_china=0 if ftgsni2==52
replace trade_world=0 if ftgsni2==52
replace imp_world=0 if ftgsni2==52
replace exp_world=0 if ftgsni2==52

* SNI60-67
replace imp_china=0 if ftgsni2==60|ftgsni2==61|ftgsni2==62|ftgsni2==62|ftgsni2==64|ftgsni2==65|ftgsni2==66|ftgsni2==67
replace trade_world=0 if ftgsni2==60|ftgsni2==61|ftgsni2==62|ftgsni2==62|ftgsni2==64|ftgsni2==65|ftgsni2==66|ftgsni2==67
replace imp_world=0 if ftgsni2==60|ftgsni2==61|ftgsni2==62|ftgsni2==62|ftgsni2==64|ftgsni2==65|ftgsni2==66|ftgsni2==67
replace exp_world=0 if ftgsni2==60|ftgsni2==61|ftgsni2==62|ftgsni2==62|ftgsni2==64|ftgsni2==65|ftgsni2==66|ftgsni2==67

* SNI63
replace imp_china=0 if ftgsni2==63
replace trade_world=0 if ftgsni2==63
replace imp_world=0 if ftgsni2==63
replace exp_world=0 if ftgsni2==63

* SNI70
replace imp_china=0 if ftgsni2==70
replace trade_world=0 if ftgsni2==70
replace imp_world=0 if ftgsni2==70
replace exp_world=0 if ftgsni2==70

* SNI71
replace imp_china=0 if ftgsni2==71
replace trade_world=0 if ftgsni2==71
replace imp_world=0 if ftgsni2==71
replace exp_world=0 if ftgsni2==71

* SNI72
replace imp_china=0 if ftgsni2==72 & imp_china==.
replace trade_world=0 if ftgsni2==72 & trade_world==.
replace imp_world=0 if ftgsni2==72
replace exp_world=0 if ftgsni2==72

* SNI73
replace imp_china=0 if ftgsni2==73
replace trade_world=0 if ftgsni2==73
replace imp_world=0 if ftgsni2==73
replace exp_world=0 if ftgsni2==73

* SNI75
replace imp_china=0 if ftgsni2==75
replace trade_world=0 if ftgsni2==75
replace imp_world=0 if ftgsni2==75
replace exp_world=0 if ftgsni2==75

* SNI80
replace imp_china=0 if ftgsni2==80
replace trade_world=0 if ftgsni2==80
replace imp_world=0 if ftgsni2==80
replace exp_world=0 if ftgsni2==80

* SNI85
replace imp_china=0 if ftgsni2==85
replace trade_world=0 if ftgsni2==85
replace imp_world=0 if ftgsni2==85
replace exp_world=0 if ftgsni2==85

* SNI90
replace imp_china=0 if ftgsni2==90 & imp_china==.
replace trade_world=0 if ftgsni2==90 & trade_world==.
replace imp_world=0 if ftgsni2==90 & imp_world==.
replace exp_world=0 if ftgsni2==90 & exp_world==.

* SNI91
replace imp_china=0 if ftgsni2==91 & imp_china==.
replace trade_world=0 if ftgsni2==91 & trade_world==.
replace imp_world=0 if ftgsni2==91 & imp_world==.
replace exp_world=0 if ftgsni2==91 & exp_world==.

* SNI93
replace imp_china=0 if ftgsni2==93 & imp_china==.
replace trade_world=0 if ftgsni2==93 & trade_world==.
replace imp_world=0 if ftgsni2==93 & imp_world==.
replace exp_world=0 if ftgsni2==93 & exp_world==.

* SNI95
replace imp_china=0 if ftgsni2==95 & imp_china==.
replace trade_world=0 if ftgsni2==95 & trade_world==.
replace imp_world=0 if ftgsni2==95 & imp_world==.
replace exp_world=0 if ftgsni2==95 & exp_world==.

* SNI99
replace imp_china=0 if ftgsni2==99 & imp_china==.
replace trade_world=0 if ftgsni2==99 & trade_world==.
replace imp_world=0 if ftgsni2==99 & imp_world==.
replace exp_world=0 if ftgsni2==99 & exp_world==.

* SNI5 (shaky trade data prior to 1993)
replace imp_china=0 if ftgsni2==5 & year<=1992
replace trade_world=0 if ftgsni2==5 & year<=1992
replace imp_world=0 if ftgsni2==5 & year<=1992
replace exp_world=0 if ftgsni2==5 & year<=1992
replace trade_impute=1 if ftgsni2==5 & year<=1992

* SNI11 (shaky trade data)
replace imp_china=0 if ftgsni2==11
replace trade_world=0 if ftgsni2==11
replace imp_world=0 if ftgsni2==11
replace exp_world=0 if ftgsni2==11
replace trade_impute=1 if ftgsni2==11

keep year ftgsni2 sni2 astsni2 imp_china exp_china imp_world exp_world trade_world trade_impute
sort ftgsni2 year
save modified/trade_sni2_8608.dta,replace

*** 11. Aggregate skills to industry level
* a) for all men 30-35 years old with all skill measures: modified/industry_skills_3035.dta
* b) for men 30-35 years old with all skill measures in firms>=50 employees: modified/industry_skills_3035_ftg.dta 
* c) for men 30-35 years old with all skill measures in firms>=50 employees but based on plant affilition: modified/industry_skills_3035_ast.dta

* a) modified/industry_skills_3035.dta
forvalues i=1985(1)2009{
	display `i'
	use modified/sample`i',clear
	keep if sex=="1" & age>=30 & age<=35 & c~=. & n~=. & edyr~=.
	drop if ftgsni2==.
	collapse (mean) year c n edyr zedyr lnwpred=lnwpred_ftg (count) N2ka=lnwpred_ftg, by(ftgsni2)
	lab var lnwpred "Log wage (industry mean)"
	lab var c "Cognitive (industry mean)"
	lab var n "Non-cognitive (industry mean)"
	lab var edyr "Edyrs (industry mean)"
	lab var zedyr "Std edyrs (industry mean)"
	lab var N2ka "Number in 30-35-sample. Check with N2k"
	save temp/industry_skills_3035_`i'.dta,replace
	}
use temp/industry_skills_3035_1985.dta,clear	
forvalues i=1986(1)2009{
	append using temp/industry_skills_3035_`i'.dta
	}
gen astsni2=ftgsni2
save modified/industry_skills_3035.dta,replace
	
* b) modified/industry_skills_ftg_3035.dta 
forvalues i=1985(1)2009{
	display `i'
	use modified/sample`i',clear
	keep if sample_3035_50_ftg==1
	drop if ftgsni2==.
	collapse (mean) year c n edyr zedyr lnwpred=lnwpred_ftg (count) N2ka=lnwpred_ftg, by(ftgsni2)
	lab var lnwpred "Log wage (industry mean)"
	lab var c "Cognitive (industry mean)"
	lab var n "Non-cognitive (industry mean)"
	lab var edyr "Edyrs (industry mean)"
	lab var zedyr "Std edyrs (industry mean)"
	lab var N2ka "Number in 30-35-sample. Check with N2k"
	save temp/industry_skills_3035_ftg_`i'.dta,replace
	}
use temp/industry_skills_3035_ftg_1985.dta,clear	
forvalues i=1986(1)2009{
	append using temp/industry_skills_3035_ftg_`i'.dta
	}
gen astsni2=ftgsni2
save modified/industry_skills_3035_ftg.dta,replace	

* c) modified/industry_skills_ast_3035.dta	
forvalues i=1985(1)2009{
	display `i'
	use modified/sample`i',clear
	keep if sample_3035_50_ast==1
	drop if astsni2==.
	collapse (mean) year c n edyr zedyr lnwpred=lnwpred_ftg (count) N2ka=lnwpred_ast, by(astsni2)
	lab var lnwpred "Log wage (industry mean)"
	lab var c "Cognitive (industry mean)"
	lab var n "Non-cognitive (industry mean)"
	lab var edyr "Edyrs (industry mean)"
	lab var zedyr "Std edyrs (industry mean)"
	lab var N2ka "Number in 30-35-sample. Check with N2k"
	save temp/industry_skills_3035_ast_`i'.dta,replace
	}
use temp/industry_skills_3035_ast_1985.dta,clear	
forvalues i=1986(1)2009{
	append using temp/industry_skills_3035_ast_`i'.dta
	}
gen ftgsni2=astsni2
save modified/industry_skills_3035_ast.dta,replace	
	
*****************************
*** 12. Wage dispersion. ****
*****************************

* Generates firm and plant based files, both at the firm(ftg)/plant(ast) level and at the aggregate level
* modified/wage_dispersion_`x'.dta (one for firms (ftg) and one for plants (ast))
* modified/wage_dispersion_agg.dta (combines firm and plant level data)

* lnwpred is (log) imputed wages based on sws
* lnwage is (log) SWS-wages earnings, converted to monthly equavalents

* SAMPLES
* wa1_10: all 20-65 in private firms with at least 10 employees based on lnwpred
* wa1_25: all 20-65 in private firms with at least 25 employees based on lnwpred
* wa1_50: all 20-65 in private firms with at least 50 employees based on lnwpred
* wa1_100: all 20-65 in private firms with at least 100 employees based on lnwpred

* wa2_10: men 20-65 in private firms with at least 10 employees based on lnwpred
* wa2_25: men 20-65 in private firms with at least 25 employees based on lnwpred
* wa2_50: men 20-65 in private firms with at least 50 employees based on lnwpred
* wa2_100: men 20-65 in private firms with at least 100 employees based on lnwpred

* wa3_10: men 30-35 in private firms with at least 10 employees based on lnwpred
* wa3_25: men 30-35 in private firms with at least 25 employees based on lnwpred
* wa3_50: men 30-35 in private firms with at least 50 employees based on lnwpred: MAIN SAMPLE!
* wa3_100: 30-35 in private firms with at least 100 employees based on lnwpred
* wa3_200: 30-35 in private firms with at least 100 employees based on lnwpred

* wa4_10: all 20-65 in private firms with at least 10 employees based on SWS-wages
* wa4_25: all 20-65 in private firms with at least 25 employees based on SWS-wages
* wa4_50: all 20-65 in private firms with at least 50 employees based on SWS-wages

* wa5_10: men 20-65 in private firms with at least 10 employees based on SWS-wages
* wa5_25: men 20-65 in private firms with at least 25 employees based on SWS-wages
* wa5_50: men 20-65 in private firms with at least 50 employees based on SWS-wages

* wa6_10: men 30-35 in private firms with at least 10 employees based on SWS-wages
* wa6_25: men 30-35 in private firms with at least 25 employees based on SWS-wages
* wa6_50: men 30-35 in private firms with at least 50 employees based on SWS-wages
* wa6_100: men 30-35 in private firms with at least 100 employees based on SWS-wages
* wa6_200: men 30-35 in private firms with at least 200 employees based on SWS-wages

set more off
foreach x in ftg ast {
	forvalues i=1985(1)2009 {
	use lopnr fos fos_detail edyr zedyr c n sex age lnwage_`x' lnwpred_`x'  sample_3035_10_`x' sample_3035_25_`x' sample_3035_50_`x' sample_3035_100_`x' sample_3035_200_`x' in_sample_3035_50_`x' sample_3045_50_`x' in_sample_3045_50_`x' sample_3035_50f_`x' in_sample_3035_50f_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""
	
	* Keep 20-65 year olds
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
	destring sex, replace

	* Keep private firms larger than 10 employees
	keep if privfirm_`x'==1
	keep if ftgstorl_`x'>=10 & ftgstorl_`x'~=.

	* Mean sample wages
	bysort year: egen wa1m10=mean(lnwpred_`x')
	bysort year: egen wa1m25=mean(lnwpred_`x') if ftgstorl_`x'>=25
	bysort year: egen wa1m50=mean(lnwpred_`x') if ftgstorl_`x'>=50
	bysort year: egen wa1m100=mean(lnwpred_`x') if ftgstorl_`x'>=100
	bysort year: egen wa2m10=mean(lnwpred_`x') if sex==1
	bysort year: egen wa2m25=mean(lnwpred_`x') if sex==1 & ftgstorl_`x'>=25
	bysort year: egen wa2m50=mean(lnwpred_`x') if sex==1 & ftgstorl_`x'>=50
	bysort year: egen wa2m100=mean(lnwpred_`x') if sex==1 & ftgstorl_`x'>=100
	bysort year: egen wa3m50=mean(lnwpred_`x') if sample_3035_50_`x'==1
	bysort year: egen wa3m10=mean(lnwpred_`x') if sample_3035_10_`x'==1
	bysort year: egen wa3m25=mean(lnwpred_`x') if sample_3035_25_`x'==1
	bysort year: egen wa3m100=mean(lnwpred_`x') if sample_3035_100_`x'==1
	bysort year: egen wa3m200=mean(lnwpred_`x') if sample_3035_200_`x'==1
	bysort year: egen wa4m10=mean(lnwage_`x')
	bysort year: egen wa4m25=mean(lnwage_`x') if ftgstorl_`x'>=25
	bysort year: egen wa4m50=mean(lnwage_`x') if ftgstorl_`x'>=50
	bysort year: egen wa5m10=mean(lnwage_`x') if sex==1
	bysort year: egen wa5m25=mean(lnwage_`x') if sex==1 & ftgstorl_`x'>=25
	bysort year: egen wa5m50=mean(lnwage_`x') if sex==1 &  ftgstorl_`x'>=50
	bysort year: egen wa6m50=mean(lnwage_`x') if sample_3035_50_`x'==1
	bysort year: egen wa6m10=mean(lnwage_`x') if sample_3035_10_`x'==1
	bysort year: egen wa6m25=mean(lnwage_`x') if sample_3035_25_`x'==1
	bysort year: egen wa6m100=mean(lnwage_`x') if sample_3035_100_`x'==1
	bysort year: egen wa6m200=mean(lnwage_`x') if sample_3035_200_`x'==1
	
	* Mean by firm/plant
	bysort `x'nr year: egen wa1j10=mean(lnwpred_`x')
	bysort `x'nr year: egen wa1j25=mean(lnwpred_`x') if ftgstorl_`x'>=25
	bysort `x'nr year: egen wa1j50=mean(lnwpred_`x') if ftgstorl_`x'>=50
	bysort `x'nr year: egen wa1j100=mean(lnwpred_`x') if ftgstorl_`x'>=100
	bysort `x'nr year: egen wa2j10=mean(lnwpred_`x') if sex==1
	bysort `x'nr year: egen wa2j25=mean(lnwpred_`x') if sex==1 & ftgstorl_`x'>=25
	bysort `x'nr year: egen wa2j50=mean(lnwpred_`x') if sex==1 & ftgstorl_`x'>=50
	bysort `x'nr year: egen wa2j100=mean(lnwpred_`x') if sex==1 & ftgstorl_`x'>=100
	bysort `x'nr year: egen wa3j50=mean(lnwpred_`x') if sample_3035_50_`x'==1
	bysort `x'nr year: egen wa3j10=mean(lnwpred_`x') if sample_3035_10_`x'==1
	bysort `x'nr year: egen wa3j25=mean(lnwpred_`x') if sample_3035_25_`x'==1
	bysort `x'nr year: egen wa3j100=mean(lnwpred_`x') if sample_3035_100_`x'==1
	bysort `x'nr year: egen wa3j200=mean(lnwpred_`x') if sample_3035_200_`x'==1
	bysort `x'nr year: egen wa4j10=mean(lnwage_`x')
	bysort `x'nr year: egen wa4j25=mean(lnwage_`x') if ftgstorl_`x'>=25
	bysort `x'nr year: egen wa4j50=mean(lnwage_`x') if ftgstorl_`x'>=50
	bysort `x'nr year: egen wa5j10=mean(lnwage_`x') if sex==1
	bysort `x'nr year: egen wa5j25=mean(lnwage_`x') if sex==1 & ftgstorl_`x'>=25
	bysort `x'nr year: egen wa5j50=mean(lnwage_`x') if sex==1 & ftgstorl_`x'>=50
	bysort `x'nr year: egen wa6j50=mean(lnwage_`x') if sample_3035_50_`x'==1
	bysort `x'nr year: egen wa6j10=mean(lnwage_`x') if sample_3035_10_`x'==1
	bysort `x'nr year: egen wa6j25=mean(lnwage_`x') if sample_3035_25_`x'==1
	bysort `x'nr year: egen wa6j100=mean(lnwage_`x') if sample_3035_100_`x'==1
	bysort `x'nr year: egen wa6j200=mean(lnwage_`x') if sample_3035_200_`x'==1

	* Mean sample skills (among 30-35 year old men)
	bysort year: egen cm50=mean(c) if sample_3035_50_`x'==1
	bysort year: egen nm50=mean(n) if sample_3035_50_`x'==1
	bysort year: egen edyrm_3035_50=mean(edyr) if sample_3035_50_`x'==1
	bysort year: egen cm10=mean(c) if sample_3035_10_`x'==1
	bysort year: egen nm10=mean(n) if sample_3035_10_`x'==1
	bysort year: egen edyrm_3035_10=mean(edyr) if sample_3035_10_`x'==1
	bysort year: egen cm25=mean(c) if sample_3035_25_`x'==1
	bysort year: egen nm25=mean(n) if sample_3035_25_`x'==1
	bysort year: egen edyrm_3035_25=mean(edyr) if sample_3035_25_`x'==1
	bysort year: egen cm100=mean(c) if sample_3035_100_`x'==1
	bysort year: egen nm100=mean(n) if sample_3035_100_`x'==1
	bysort year: egen edyrm_3035_100=mean(edyr) if sample_3035_100_`x'==1
	bysort year: egen cm200=mean(c) if sample_3035_200_`x'==1
	bysort year: egen nm200=mean(n) if sample_3035_200_`x'==1
	bysort year: egen edyrm_3035_200=mean(edyr) if sample_3035_200_`x'==1
	bysort year: egen edyrm10=mean(edyr)
	bysort year: egen edyrm25=mean(edyr) if ftgstorl_`x'>=25
	bysort year: egen edyrm50=mean(edyr) if ftgstorl_`x'>=50
	bysort year: egen edyrm100=mean(edyr) if ftgstorl_`x'>=100
	bysort year: egen edyrm200=mean(edyr) if ftgstorl_`x'>=200
	bysort year: egen zedyrm_3035_50=mean(zedyr) if sample_3035_50_`x'==1
	bysort year: egen zedyrm_3035_10=mean(zedyr) if sample_3035_10_`x'==1
	bysort year: egen zedyrm_3035_25=mean(zedyr) if sample_3035_25_`x'==1
	bysort year: egen zedyrm_3035_100=mean(zedyr) if sample_3035_100_`x'==1	
	bysort year: egen zedyrm_3035_200=mean(zedyr) if sample_3035_200_`x'==1
	bysort year: egen zedyrm10=mean(zedyr)
	bysort year: egen zedyrm25=mean(zedyr) if ftgstorl_`x'>=25
	bysort year: egen zedyrm50=mean(zedyr) if ftgstorl_`x'>=50
	bysort year: egen zedyrm100=mean(zedyr) if ftgstorl_`x'>=100
	bysort year: egen zedyrm200=mean(zedyr) if ftgstorl_`x'>=200

	* Mean skills by firm/plant (among 30-35 year old men)
	bysort `x'nr year: egen cj50=mean(c) if sample_3035_50_`x'==1
	bysort `x'nr year: egen nj50=mean(n) if sample_3035_50_`x'==1
	bysort `x'nr year: egen edyrj_3035_50=mean(edyr) if sample_3035_50_`x'==1
	bysort `x'nr year: egen cj10=mean(c) if sample_3035_10_`x'==1
	bysort `x'nr year: egen nj10=mean(n) if sample_3035_10_`x'==1
	bysort `x'nr year: egen edyrj_3035_10=mean(edyr) if sample_3035_10_`x'==1
	bysort `x'nr year: egen cj25=mean(c) if sample_3035_25_`x'==1
	bysort `x'nr year: egen nj25=mean(n) if sample_3035_25_`x'==1
	bysort `x'nr year: egen edyrj_3035_25=mean(edyr) if sample_3035_25_`x'==1
	bysort `x'nr year: egen cj100=mean(c) if sample_3035_100_`x'==1
	bysort `x'nr year: egen nj100=mean(n) if sample_3035_100_`x'==1
	bysort `x'nr year: egen edyrj_3035_100=mean(edyr) if sample_3035_100_`x'==1
	bysort `x'nr year: egen cj200=mean(c) if sample_3035_200_`x'==1
	bysort `x'nr year: egen nj200=mean(n) if sample_3035_200_`x'==1
	bysort `x'nr year: egen edyrj_3035_200=mean(edyr) if sample_3035_200_`x'==1
	bysort `x'nr year: egen edyrj=mean(edyr)
	bysort `x'nr year: egen zedyrj_3035_50=mean(zedyr) if sample_3035_50_`x'==1
	bysort `x'nr year: egen zedyrj_3035_10=mean(zedyr) if sample_3035_10_`x'==1
	bysort `x'nr year: egen zedyrj_3035_25=mean(zedyr) if sample_3035_25_`x'==1
	bysort `x'nr year: egen zedyrj_3035_100=mean(zedyr) if sample_3035_100_`x'==1
	bysort `x'nr year: egen zedyrj_3035_200=mean(zedyr) if sample_3035_200_`x'==1
	bysort `x'nr year: egen zedyrj=mean(zedyr)

	* Number of observations by year
	bysort year: egen nobs1_10=count(lnwpred_`x')
	bysort year: egen nobs1_25=count(lnwpred_`x') if ftgstorl_`x'>=25
	bysort year: egen nobs1_50=count(lnwpred_`x') if ftgstorl_`x'>=50
	bysort year: egen nobs1_100=count(lnwpred_`x') if ftgstorl_`x'>=100
	bysort year: egen nobs2_10=count(lnwpred_`x') if sex==1
	bysort year: egen nobs2_25=count(lnwpred_`x') if sex==1 & ftgstorl_`x'>=25
	bysort year: egen nobs2_50=count(lnwpred_`x') if sex==1 & ftgstorl_`x'>=50
	bysort year: egen nobs2_100=count(lnwpred_`x') if sex==1 & ftgstorl_`x'>=100
	bysort year: egen nobs3_50=count(lnwpred_`x') if sample_3035_50_`x'==1
	bysort year: egen nobs3_10=count(lnwpred_`x') if sample_3035_10_`x'==1
	bysort year: egen nobs3_25=count(lnwpred_`x') if sample_3035_25_`x'==1
	bysort year: egen nobs3_100=count(lnwpred_`x') if sample_3035_100_`x'==1
	bysort year: egen nobs3_200=count(lnwpred_`x') if sample_3035_200_`x'==1
	bysort year: egen nobs4_10=count(lnwage_`x')
	bysort year: egen nobs4_25=count(lnwage_`x') if ftgstorl_`x'>=25
	bysort year: egen nobs4_50=count(lnwage_`x') if ftgstorl_`x'>=50
	bysort year: egen nobs5_10=count(lnwage_`x') if sex==1
	bysort year: egen nobs5_25=count(lnwage_`x') if sex==1 & ftgstorl_`x'>=25
	bysort year: egen nobs5_50=count(lnwage_`x') if sex==1 & ftgstorl_`x'>=50
	bysort year: egen nobs6_50=count(lnwage_`x') if sample_3035_50_`x'==1
	bysort year: egen nobs6_10=count(lnwage_`x') if sample_3035_10_`x'==1
	bysort year: egen nobs6_25=count(lnwage_`x') if sample_3035_25_`x'==1
	bysort year: egen nobs6_100=count(lnwage_`x') if sample_3035_100_`x'==1
	bysort year: egen nobs6_200=count(lnwage_`x') if sample_3035_200_`x'==1

	* Number of observations by firm/plant-year
	bysort `x'nr year: egen nobs1j10=count(lnwpred_`x')
	bysort `x'nr year: egen nobs1j25=count(lnwpred_`x') if ftgstorl_`x'>=25
	bysort `x'nr year: egen nobs1j50=count(lnwpred_`x') if ftgstorl_`x'>=50
	bysort `x'nr year: egen nobs1j100=count(lnwpred_`x') if ftgstorl_`x'>=100
	bysort `x'nr year: egen nobs2j10=count(lnwpred_`x') if sex==1
	bysort `x'nr year: egen nobs2j25=count(lnwpred_`x') if sex==1 & ftgstorl_`x'>=25
	bysort `x'nr year: egen nobs2j50=count(lnwpred_`x') if sex==1 & ftgstorl_`x'>=50
	bysort `x'nr year: egen nobs2j100=count(lnwpred_`x') if sex==1 & ftgstorl_`x'>=100
	bysort `x'nr year: egen nobs3j50=count(lnwpred_`x') if sample_3035_50_`x'==1
	bysort `x'nr year: egen nobs3j10=count(lnwpred_`x') if sample_3035_10_`x'==1
	bysort `x'nr year: egen nobs3j25=count(lnwpred_`x') if sample_3035_25_`x'==1
	bysort `x'nr year: egen nobs3j100=count(lnwpred_`x') if sample_3035_100_`x'==1
	bysort `x'nr year: egen nobs3j200=count(lnwpred_`x') if sample_3035_200_`x'==1
	bysort `x'nr year: egen nobs4j10=count(lnwage_`x')
	bysort `x'nr year: egen nobs4j25=count(lnwage_`x') if ftgstorl_`x'>=25
	bysort `x'nr year: egen nobs4j50=count(lnwage_`x') if ftgstorl_`x'>=50
	bysort `x'nr year: egen nobs5j10=count(lnwage_`x') if sex==1
	bysort `x'nr year: egen nobs5j25=count(lnwage_`x') if sex==1 & ftgstorl_`x'>=25
	bysort `x'nr year: egen nobs5j50=count(lnwage_`x') if sex==1 & ftgstorl_`x'>=50
	bysort `x'nr year: egen nobs6j50=count(lnwage_`x') if sample_3035_50_`x'==1
	bysort `x'nr year: egen nobs6j10=count(lnwage_`x') if sample_3035_10_`x'==1
	bysort `x'nr year: egen nobs6j25=count(lnwage_`x') if sample_3035_25_`x'==1
	bysort `x'nr year: egen nobs6j100=count(lnwage_`x') if sample_3035_100_`x'==1
	bysort `x'nr year: egen nobs6j200=count(lnwage_`x') if sample_3035_200_`x'==1

	* Total wage variance by year
	bysort year: egen w1sd10=sd(lnwpred_`x')
	bysort year: gen w1var10=w1sd10*w1sd10
	bysort year: egen w1sd25=sd(lnwpred_`x') if ftgstorl_`x'>=25
	bysort year: gen w1var25=w1sd25*w1sd25 if ftgstorl_`x'>=25
	bysort year: egen w1sd50=sd(lnwpred_`x') if ftgstorl_`x'>=50
	bysort year: gen w1var50=w1sd50*w1sd50 if ftgstorl_`x'>=50
	bysort year: egen w1sd100=sd(lnwpred_`x') if ftgstorl_`x'>=100
	bysort year: gen w1var100=w1sd100*w1sd100 if ftgstorl_`x'>=100
	bysort year: egen w2sd10=sd(lnwpred_`x') if sex==1
	bysort year: gen w2var10=w2sd10*w2sd10 if sex==1
	bysort year: egen w2sd25=sd(lnwpred_`x') if sex==1 & ftgstorl_`x'>=25
	bysort year: gen w2var25=w2sd25*w2sd25 if sex==1 & ftgstorl_`x'>=25
	bysort year: egen w2sd50=sd(lnwpred_`x') if sex==1 & ftgstorl_`x'>=50
	bysort year: gen w2var50=w2sd50*w2sd50 if sex==1 & ftgstorl_`x'>=50
	bysort year: egen w2sd100=sd(lnwpred_`x') if sex==1 & ftgstorl_`x'>=100
	bysort year: gen w2var100=w2sd100*w2sd100 if sex==1 & ftgstorl_`x'>=100
	bysort year: egen w3sd50=sd(lnwpred_`x') if sample_3035_50_`x'==1
	bysort year: gen w3var50=w3sd50*w3sd50 if sample_3035_50_`x'==1
	bysort year: egen w3sd10=sd(lnwpred_`x') if sample_3035_10_`x'==1
	bysort year: gen w3var10=w3sd10*w3sd10 if sample_3035_10_`x'==1
	bysort year: egen w3sd25=sd(lnwpred_`x') if sample_3035_25_`x'==1
	bysort year: gen w3var25=w3sd25*w3sd25 if sample_3035_25_`x'==1
	bysort year: egen w3sd100=sd(lnwpred_`x') if sample_3035_100_`x'==1
	bysort year: gen w3var100=w3sd100*w3sd100 if sample_3035_100_`x'==1
	bysort year: egen w3sd200=sd(lnwpred_`x') if sample_3035_200_`x'==1
	bysort year: gen w3var200=w3sd200*w3sd200 if sample_3035_200_`x'==1	
	bysort year: egen w4sd10=sd(lnwage_`x')
	bysort year: gen w4var10=w4sd10*w4sd10
	bysort year: egen w4sd25=sd(lnwage_`x') if ftgstorl_`x'>=25
	bysort year: gen w4var25=w4sd25*w4sd25 if ftgstorl_`x'>=25
	bysort year: egen w4sd50=sd(lnwage_`x') if ftgstorl_`x'>=50
	bysort year: gen w4var50=w4sd50*w4sd50 if ftgstorl_`x'>=50
	bysort year: egen w5sd10=sd(lnwage_`x') if sex==1
	bysort year: gen w5var10=w5sd10*w5sd10 if sex==1
	bysort year: egen w5sd25=sd(lnwage_`x') if sex==1 & ftgstorl_`x'>=25
	bysort year: gen w5var25=w5sd25*w5sd25 if sex==1 & ftgstorl_`x'>=25
	bysort year: egen w5sd50=sd(lnwage_`x') if sex==1 & ftgstorl_`x'>=50
	bysort year: gen w5var50=w5sd50*w5sd50 if sex==1 & ftgstorl_`x'>=50
	bysort year: egen w6sd50=sd(lnwage_`x') if sample_3035_50_`x'==1
	bysort year: gen w6var50=w6sd50*w6sd50 if sample_3035_50_`x'==1
	bysort year: egen w6sd10=sd(lnwage_`x') if sample_3035_10_`x'==1
	bysort year: gen w6var10=w6sd10*w6sd10 if sample_3035_10_`x'==1
	bysort year: egen w6sd25=sd(lnwage_`x') if sample_3035_25_`x'==1
	bysort year: gen w6var25=w6sd25*w6sd25 if sample_3035_25_`x'==1
	bysort year: egen w6sd100=sd(lnwage_`x') if sample_3035_100_`x'==1
	bysort year: gen w6var100=w6sd100*w6sd100 if sample_3035_100_`x'==1
	bysort year: egen w6sd200=sd(lnwage_`x') if sample_3035_200_`x'==1
	bysort year: gen w6var200=w6sd200*w6sd200 if sample_3035_200_`x'==1

	* Collapse to firm/plant-year level
	drop w1sd10 w1sd25 w1sd50 w1sd100 w2sd10 w2sd25 w2sd50 w2sd100 w3sd50 w3sd10 w3sd25 w3sd100 w3sd200 w4sd10 w4sd25 w4sd50 w5sd10 w5sd25 w5sd50 w6sd50 w6sd10 w6sd25 w6sd100 w6sd200
	duplicates drop `x'nr year w1var10 w1var25 w1var50 w1var100 w2var10 w2var25 w2var50 w2var100 w3var50 w3var10 w3var25 w3var100 w3var200 w4var10 w4var25 w4var50 w5var10 w5var25 w5var50 w6var50 w6var10 w6var25 w6var100 w6var200 wa1m10 wa1m25 wa1m50 wa1m100 wa2m10 wa2m25 wa2m50 wa2m100 wa3m50 wa3m10 wa3m25 wa3m100 wa3m200 wa4m10 wa4m25 wa4m50 wa5m10 wa5m25 wa5m50 wa6m50 wa6m10 wa6m25 wa6m100 wa6m200 wa1j10 wa1j25 wa1j50 wa1j100 wa2j10 wa2j25 wa2j50 wa2j100 wa3j50 wa3j10 wa3j25 wa3j100 wa3j200 wa4j10 wa4j25 wa4j50 wa5j10 wa5j25 wa5j50 wa6j50 wa6j10 wa6j25 wa6j100 wa6j200 cm50 cm10 cm25 cm100 cm200 nm50 nm10 nm25 nm100 nm200 edyrm10 edyrm25 edyrm50 edyrm100 edyrm200 zedyrm10 zedyrm25 zedyrm50 zedyrm100 zedyrm200 edyrm_3035_50 edyrm_3035_10 edyrm_3035_25 edyrm_3035_100 edyrm_3035_200 zedyrm_3035_50 zedyrm_3035_10 zedyrm_3035_25 zedyrm_3035_100 zedyrm_3035_200 cj50 cj10 cj25 cj100 cj200 nj50 nj10 nj25 nj100 nj200 edyrj zedyrj edyrj_3035_50 edyrj_3035_10 edyrj_3035_25 edyrj_3035_100 edyrj_3035_200 zedyrj_3035_50 zedyrj_3035_10 zedyrj_3035_25 zedyrj_3035_100 zedyrj_3035_200 ftgstorl_`x' nobs1_10 nobs1_25 nobs1_50 nobs1_100 nobs2_10 nobs2_25 nobs2_50 nobs2_100 nobs3_50 nobs3_10 nobs3_25 nobs3_100 nobs3_200 nobs4_10 nobs4_25 nobs4_50 nobs5_10 nobs5_25 nobs5_50 nobs6_50 nobs6_10 nobs6_25 nobs6_100 nobs6_200 nobs1j10 nobs1j25 nobs1j50 nobs1j100 nobs2j10 nobs2j25 nobs2j50 nobs2j100 nobs3j50 nobs3j10 nobs3j25 nobs3j100 nobs3j200 nobs4j10 nobs4j25 nobs4j50 nobs5j10 nobs5j25 nobs5j50 nobs6j50 nobs6j10 nobs6j25 nobs6j100 nobs6j200, force
	sort `x'nr year
	collapse w1var10 w1var25 w1var50 w1var100 w2var10 w2var25 w2var50 w2var100 w3var50 w3var10 w3var25 w3var100 w3var200 w4var10 w4var25 w4var50 w5var10 w5var25 w5var50 w6var50 w6var10 w6var25 w6var100 w6var200 wa1m10 wa1m25 wa1m50 wa1m100 wa2m10 wa2m25 wa2m50 wa2m100 wa3m50 wa3m10 wa3m25 wa3m100 wa3m200 wa4m10 wa4m25 wa4m50 wa5m10 wa5m25 wa5m50 wa6m50 wa6m10 wa6m25 wa6m100 wa6m200 wa1j10 wa1j25 wa1j50 wa1j100 wa2j10 wa2j25 wa2j50 wa2j100 wa3j50 wa3j10 wa3j25 wa3j100 wa3j200 wa4j10 wa4j25 wa4j50 wa5j10 wa5j25 wa5j50 wa6j50 wa6j10 wa6j25 wa6j100 wa6j200 cm50 cm10 cm25 cm100 cm200 nm50 nm10 nm25 nm100 nm200 edyrm10 edyrm25 edyrm50 edyrm100 edyrm200 zedyrm10 zedyrm25 zedyrm50 zedyrm100 zedyrm200 edyrm_3035_50 edyrm_3035_10 edyrm_3035_25 edyrm_3035_100 edyrm_3035_200 zedyrm_3035_50 zedyrm_3035_10 zedyrm_3035_25 zedyrm_3035_100 zedyrm_3035_200 cj50 cj10 cj25 cj100 cj200 nj50 nj10 nj25 nj100 nj200 edyrj zedyrj edyrj_3035_50 edyrj_3035_10 edyrj_3035_25 edyrj_3035_100 edyrj_3035_200 zedyrj_3035_50 zedyrj_3035_10 zedyrj_3035_25 zedyrj_3035_100 zedyrj_3035_200 ftgstorl_`x' nobs1_10 nobs1_25 nobs1_50 nobs1_100 nobs2_10 nobs2_25 nobs2_50 nobs2_100 nobs3_50 nobs3_10 nobs3_25 nobs3_100 nobs3_200 nobs4_10 nobs4_25 nobs4_50 nobs5_10 nobs5_25 nobs5_50 nobs6_50 nobs6_10 nobs6_25 nobs6_100 nobs6_200 nobs1j10 nobs1j25 nobs1j50 nobs1j100 nobs2j10 nobs2j25 nobs2j50 nobs2j100 nobs3j50 nobs3j10 nobs3j25 nobs3j100 nobs3j200 nobs4j10 nobs4j25 nobs4j50 nobs5j10 nobs5j25 nobs5j50 nobs6j50 nobs6j10 nobs6j25 nobs6j100 nobs6j200, by(`x'nr year)

	*** Between firm/plant variance 
	bysort year: egen BFt1_10=sum(nobs1j10*((wa1j10-wa1m10)*(wa1j10-wa1m10)))
	replace BFt1_10=BFt1_10/nobs1_10
	bysort year: egen BFt1_25=sum(nobs1j25*((wa1j25-wa1m25)*(wa1j25-wa1m25)))
	replace BFt1_25=BFt1_25/nobs1_25
	bysort year: egen BFt1_50=sum(nobs1j50*((wa1j50-wa1m50)*(wa1j50-wa1m50)))
	replace BFt1_50=BFt1_50/nobs1_50
	bysort year: egen BFt1_100=sum(nobs1j100*((wa1j100-wa1m100)*(wa1j100-wa1m100)))
	replace BFt1_100=BFt1_100/nobs1_100
	bysort year: egen BFt2_10=sum(nobs2j10*((wa2j10-wa2m10)*(wa2j10-wa2m10)))
	replace BFt2_10=BFt2_10/nobs2_10
	bysort year: egen BFt2_25=sum(nobs2j25*((wa2j25-wa2m25)*(wa2j25-wa2m25)))
	replace BFt2_25=BFt2_25/nobs2_25
	bysort year: egen BFt2_50=sum(nobs2j50*((wa2j50-wa2m50)*(wa2j50-wa2m50)))
	replace BFt2_50=BFt2_50/nobs2_50
	bysort year: egen BFt2_100=sum(nobs2j100*((wa2j100-wa2m100)*(wa2j100-wa2m100)))
	replace BFt2_100=BFt2_100/nobs2_100
	bysort year: egen BFt3_50=sum(nobs3j50*((wa3j50-wa3m50)*(wa3j50-wa3m50)))
	replace BFt3_50=BFt3_50/nobs3_50
	bysort year: egen BFt3_10=sum(nobs3j10*((wa3j10-wa3m10)*(wa3j10-wa3m10)))
	replace BFt3_10=BFt3_10/nobs3_10
	bysort year: egen BFt3_25=sum(nobs3j25*((wa3j25-wa3m25)*(wa3j25-wa3m25)))
	replace BFt3_25=BFt3_25/nobs3_25
	bysort year: egen BFt3_100=sum(nobs3j100*((wa3j100-wa3m100)*(wa3j100-wa3m100)))
	replace BFt3_100=BFt3_100/nobs3_100
	bysort year: egen BFt3_200=sum(nobs3j200*((wa3j200-wa3m200)*(wa3j200-wa3m200)))
	replace BFt3_200=BFt3_200/nobs3_200
	bysort year: egen BFt4_10=sum(nobs4j10*((wa4j10-wa4m10)*(wa4j10-wa4m10)))
	replace BFt4_10=BFt4_10/nobs4_10
	bysort year: egen BFt4_25=sum(nobs4j25*((wa4j25-wa4m25)*(wa4j25-wa4m25)))
	replace BFt4_25=BFt4_25/nobs4_25
	bysort year: egen BFt4_50=sum(nobs4j50*((wa4j50-wa4m50)*(wa4j50-wa4m50)))
	replace BFt4_50=BFt4_50/nobs4_50
	bysort year: egen BFt5_10=sum(nobs5j10*((wa5j10-wa5m10)*(wa5j10-wa5m10)))
	replace BFt5_10=BFt5_10/nobs5_10
	bysort year: egen BFt5_25=sum(nobs5j25*((wa5j25-wa5m25)*(wa5j25-wa5m25)))
	replace BFt5_25=BFt5_25/nobs5_25
	bysort year: egen BFt5_50=sum(nobs5j50*((wa5j50-wa5m50)*(wa5j50-wa5m50)))
	replace BFt5_50=BFt5_50/nobs5_50
	bysort year: egen BFt6_50=sum(nobs6j50*((wa6j50-wa6m50)*(wa6j50-wa6m50)))
	replace BFt6_50=BFt6_50/nobs6_50
	bysort year: egen BFt6_10=sum(nobs6j10*((wa6j10-wa6m10)*(wa6j10-wa6m10)))
	replace BFt6_10=BFt6_10/nobs6_10
	bysort year: egen BFt6_25=sum(nobs6j25*((wa6j25-wa6m25)*(wa6j25-wa6m25)))
	replace BFt6_25=BFt6_25/nobs6_25	
	bysort year: egen BFt6_100=sum(nobs6j100*((wa6j100-wa6m100)*(wa6j100-wa6m100)))
	replace BFt6_100=BFt6_100/nobs6_100	
	bysort year: egen BFt6_200=sum(nobs6j200*((wa6j200-wa6m200)*(wa6j200-wa6m200)))
	replace BFt6_200=BFt6_200/nobs6_200
	
	lab var wa1m10 "Mean wages, all, private firms>=10 emp"
	lab var wa1m25 "Mean wages, all, private firms>=25 emp"
	lab var wa1m50 "Mean wages, all, private firms>=50 emp"
	lab var wa1m100 "Mean wages, all, private firms>=100 emp"
	lab var wa2m10 "Mean wages, men, private firms>=10 emp"
	lab var wa2m25 "Mean wages, men, private firms>=25 emp"
	lab var wa2m50 "Mean wages, men, private firms>=50 emp"
	lab var wa2m100 "Mean wages, men in private firms>=100 emp"
	lab var wa3m50 "Mean wages, men 30-35, >=50 emp"
	lab var wa3m10 "Mean wages, men 30-35, >=10 emp"
	lab var wa3m25 "Mean wages, men 30-35, >=25 emp"
	lab var wa3m100 "Mean wages, men 30-35, >=100 emp"
	lab var wa3m200 "Mean wages, men 30-35, >=200 emp"
	lab var wa4m10 "Mean SWS, all, private firms>=10 emp"
	lab var wa4m25 "Mean SWS, all, private firms>=25 emp"
	lab var wa4m50 "Mean SWS, all, private firms>=50 emp"
	lab var wa5m10 "Mean SWS, men, private firms>=10 emp"
	lab var wa5m25 "Mean SWS, men, private firms>=25 emp"
	lab var wa5m50 "Mean SWS, men, private firms>=50 emp"
	lab var wa6m50 "Mean SWS, men 30-35, >=50 emp"
	lab var wa6m10 "Mean SWS, men 30-35, >=10 emp"
	lab var wa6m25 "Mean SWS, men 30-35, >=25 emp"
	lab var wa6m100 "Mean SWS, men 30-35, >=100 emp"
	lab var wa6m200 "Mean SWS, men 30-35, >=200 emp"

	lab var wa1j10 "Firm/Plant mean wages, all, private firms>=10 emp"
	lab var wa1j25 "Firm/Plant mean wages, all, private firms>=25 emp"
	lab var wa1j50 "Firm/Plant mean wages, all, private firms>=50 emp"
	lab var wa1j100 "Firm/Plant mean wages, all, private firms>=100 emp"
	lab var wa2j10 "Firm/Plant mean wages, men, private firms>=10 emp"
	lab var wa2j25 "Firm/Plant mean wages, men, private firms>=25 emp"
	lab var wa2j50 "Firm/Plant mean wages, men, private firms>=50 emp"
	lab var wa2j100 "Firm/Plant mean wages, men, private firms>=100 emp"
	lab var wa3j50 "Firm/Plant mean wages, men 30-35, >=50 emp"
	lab var wa3j10 "Firm/Plant mean wages, men 30-35, >=10 emp"
	lab var wa3j25 "Firm/Plant mean wages, men 30-35, >=25 emp"
	lab var wa3j100 "Firm/Plant monthly wages, men 30-35, >=100 emp"
	lab var wa3j200 "Firm/Plant mean wages, men 30-35, >=200 emp"
	lab var wa4j10 "Firm/Plant mean SWS, all, private firms>=10 emp"
	lab var wa4j25 "Firm/Plant mean SWS, all, private firms>=25 emp"
	lab var wa4j50 "Firm/Plant mean SWS, all, private firms>=50 emp"
	lab var wa5j10 "Firm/Plant mean SWS, men, private firms>=10 emp"
	lab var wa5j25 "Firm/Plant mean SWS, men, private firms>=25 emp"
	lab var wa5j50 "Firm/Plant mean SWS, men, private firms>=50 emp"
	lab var wa6j50 "Firm/Plant mean SWS, men 30-35, >=50 emp"
	lab var wa6j10 "Firm/Plant mean SWS, men 30-35, >=10 emp"
	lab var wa6j25 "Firm/Plant mean SWS, men 30-35, >=25 emp"
	lab var wa6j100 "Firm/Plant mean SWS, men 30-35, >=100 emp"
	lab var wa6j200 "Firm/Plant mean SWS, men 30-35, >=200 emp"

	lab var nobs1_10 "Total obs, wages, all, private firms>=10 emp"
	lab var nobs1_25 "Total obs, wages, all, private firms>=25 emp"
	lab var nobs1_50 "Total obs, wages, all, private firms>=50 emp"
	lab var nobs1_100 "Total obs, wages, all, private firms>=100 emp"
	lab var nobs2_10 "Total obs, wages, men, private firms>=10 emp"
	lab var nobs2_25 "Total obs, wages, men, private firms>=25 emp"
	lab var nobs2_50 "Total obs, wages, men, private firms>=50 emp"
	lab var nobs2_100 "Total obs, wages, men, private firms>=100 emp"
	lab var nobs3_50 "Total obs, wages, men 30-35, >=50 emp"
	lab var nobs3_10 "Total obs, wages, men 30-35, >=10 emp"
	lab var nobs3_25 "Total obs, wages, men 30-35, >=25 emp"
	lab var nobs3_100 "Total obs, wages, men 30-35, >=100 emp"
	lab var nobs3_200 "Total obs, wages, men 30-35, >=200 emp"
	lab var nobs4_10 "Total obs, SWS, all, private firms>=10 emp"
	lab var nobs4_25 "Total obs, SWS, all, private firms>=25 emp"
	lab var nobs4_50 "Total obs, SWS, all, private firms>=50 emp"
	lab var nobs5_10 "Total obs, SWS, men, private firms>=10 emp"
	lab var nobs5_25 "Total obs, SWS, men, private firms>=25 emp"
	lab var nobs5_50 "Total obs, SWS, men, private firms>=50 emp"
	lab var nobs6_50 "Total obs, SWS, men 30-35, >=50 emp"
	lab var nobs6_10 "Total obs, SWS, men 30-35, >=10 emp"
	lab var nobs6_25 "Total obs, SWS, men 30-35, >=25 emp"
	lab var nobs6_100 "Total obs, SWS, men 30-35, >=100 emp"
	lab var nobs6_200 "Total obs, SWS, men 30-35, >=200 emp"

	lab var ftgstorl_`x' "Firm number of employees (RAMS)"
	lab var nobs1j10 "Firm/Plant obs, wages, all, private firms>=10 emp"
	lab var nobs1j25 "Firm/Plant obs, wages, all, private firms>=25 emp"
	lab var nobs1j50 "Firm/Plant obs, wages, all, private firms>=50 emp"
	lab var nobs1j100 "Firm/Plant obs, wages, all, private firms>=100 emp"
	lab var nobs2j10 "Firm/Plant obs, wages, men, private firms>=10 emp"
	lab var nobs2j25 "Firm/Plant obs, wages, men, private firms>=25 emp"
	lab var nobs2j50 "Firm/Plant obs, wages, men, private firms>=50 emp"
	lab var nobs2j100 "Firm/Plant obs, wages, men, private firms>=100 emp"
	lab var nobs3j50 "Firm/Plant obs, wages, men 30-35, >=50 emp"
	lab var nobs3j10 "Firm/Plant obs, wages, men 30-35, >=10 emp"
	lab var nobs3j25 "Firm/Plant obs, wages, men 30-35, >=25 emp"
	lab var nobs3j100 "Firm/Plant obs, wages, men 30-35, >=100 emp"
	lab var nobs3j200 "Firm/Plant obs, wages, men 30-35, >=200 emp"
	lab var nobs4j10 "Firm/Plant obs, SWS, all, private firms>=10 emp"
	lab var nobs4j25 "Firm/Plant obs, SWS, all, private firms>=25 emp"
	lab var nobs4j50 "Firm/Plant obs, SWS, all, private firms>=50 emp"
	lab var nobs5j10 "Firm/Plant obs, SWS, men, private firms>=10 emp"
	lab var nobs5j25 "Firm/Plant obs, SWS, men, private firms>=25 emp"
	lab var nobs5j50 "Firm/Plant obs, SWS, men, private firms>=50 emp"
	lab var nobs6j50 "Firm/Plant obs, SWS, men 30-35, >=50 emp"
	lab var nobs6j10 "Firm/Plant obs, SWS, men 30-35, >=10 emp"
	lab var nobs6j25 "Firm/Plant obs, SWS, men 30-35, >=25 emp"
	lab var nobs6j100 "Firm/Plant obs, SWS, men 30-35, >=100 emp"
	lab var nobs6j200 "Firm/Plant obs, SWS, men 30-35, >=200 emp"

	lab var cm50 "Mean cognitive, men 30-35, >=50 emp"
	lab var cm10 "Mean cognitive, men 30-35, >=10 emp"
	lab var cm25 "Mean cognitive, men 30-35, >=25 emp"
	lab var cm100 "Mean cognitive, men 30-35, >=100 emp"
	lab var cm200 "Mean cognitive, men 30-35, >=200 emp"
	lab var nm50 "Mean non-cognitive, men 30-35, >=50 emp"
	lab var nm10 "Mean non-cognitive, men 30-35, >=10 emp"
	lab var nm25 "Mean non-cognitive, men 30-35, >=25 emp"
	lab var nm100 "Mean non-cognitive, men 30-35, >=100 emp"
	lab var nm200 "Mean non-cognitive, men 30-35, >=200 emp"
	
	lab var edyrm10 "Mean edyr, all, private firms>=10 emp"
	lab var edyrm25 "Mean edyr, all, private firms>=25 emp"
	lab var edyrm50 "Mean edyr, all, private firms>=50 emp"
	lab var edyrm100 "Mean edyr, all, private firms>=100 emp"
	lab var edyrm200 "Mean edyr, all, private firms>=200 emp"
	lab var edyrm_3035_50 "Mean edyr, men 30-35, >=50 emp"
	lab var edyrm_3035_10 "Mean edyr, men 30-35, >=10 emp"
	lab var edyrm_3035_25 "Mean edyr, men 30-35, >=25 emp"
	lab var edyrm_3035_100 "Mean edyr, men 30-35, >=100 emp"
	lab var edyrm_3035_200 "Mean edyr, men 30-35, >=200 emp"
	lab var zedyrm10 "Mean zedyr, all, private firms>=10 emp"
	lab var zedyrm25 "Mean zedyr, all, private firms>=25 emp"
	lab var zedyrm50 "Mean zedyr, all, private firms>=50 emp"
	lab var zedyrm100 "Mean zedyr, all, private firms>=100 emp"
	lab var zedyrm200 "Mean zedyr, all, private firms>=200 emp"
	lab var zedyrm_3035_50 "Mean zedyr, men 30-35, >=50 emp"
	lab var zedyrm_3035_10 "Mean zedyr, men 30-35, >=10 emp"
	lab var zedyrm_3035_25 "Mean zedyr, men 30-35, >=25 emp"
	lab var zedyrm_3035_100 "Mean zedyr, men 30-35, >=100 emp"
	lab var zedyrm_3035_200 "Mean zedyr, men 30-35, >=200 emp"

	lab var cj50 "Firm/Plant cognitive, men 30-35, >=50 emp"
	lab var cj10 "Firm/Plant cognitive, men 30-35, >=10 emp"
	lab var cj25 "Firm/Plant cognitive, men 30-35, >=25 emp"
	lab var cj100 "Firm/Plant cognitive, men 30-35, >=100 emp"
	lab var cj200 "Firm/Plant cognitive, men 30-35, >=200 emp"
	lab var nj50 "Firm/Plant non-cognitive, men 30-35, >=50 emp"
	lab var nj10 "Firm/Plant non-cognitive, men 30-35, >=10 emp"
	lab var nj25 "Firm/Plant non-cognitive, men 30-35, >=25 emp"
	lab var nj100 "Firm/Plant non-cognitive, men 30-35, >=100 emp"
	lab var nj200 "Firm/Plant non-cognitive, men 30-35, >=200 emp"
	lab var edyrj "Firm/Plant edyr, all, private firms>=10 emp"
	lab var edyrj_3035_50 "Firm/Plant edyr, men 30-35, >=50 emp"
	lab var edyrj_3035_10 "Firm/Plant edyr, men 30-35, >=10 emp"
	lab var edyrj_3035_25 "Firm/Plant edyr, men 30-35, >=25 emp"
	lab var edyrj_3035_100 "Firm/Plant edyr, men 30-35, >=100 emp"
	lab var edyrj_3035_200 "Firm/Plant edyr, men 30-35, >=200 emp"
	lab var zedyrj "Firm/Plant zedyr, all in private firms>=10 emp"
	lab var zedyrj_3035_50 "Firm/Plant zedyr, men 30-35, >=50 emp"
	lab var zedyrj_3035_10 "Firm/Plant zedyr, men 30-35, >=10 emp"
	lab var zedyrj_3035_25 "Firm/Plant zedyr, men 30-35, >=25 emp"
	lab var zedyrj_3035_100 "Firm/Plant zedyr, men 30-35, >=100 emp"
	lab var zedyrj_3035_200 "Firm/Plant zedyr, men 30-35, >=200 emp"

	lab var w1var10 "Total wage variance, all, private firms>=10 emp"
	lab var w1var25 "Total wage variance, all, private firms>=25 emp"
	lab var w1var50 "Total wage variance, all, private firms>=50 emp"
	lab var w1var100 "Total wage variance, all, private firms>=100 emp"
	lab var w2var10 "Total wage variance, men, private firms>=10 emp"
	lab var w2var25 "Total wage variance, men, private firms>=25 emp"
	lab var w2var50 "Total wage variance, men, private firms>=50 emp"
	lab var w2var100 "Total wage variance, men, private firms>=100 emp"
	lab var w3var50 "Total wage variance, men 30-35, >=50 emp"
	lab var w3var10 "Total wage variance, men 30-35, >=10 emp"
	lab var w3var25 "Total wage variance, men 30-35, >=25 emp"
	lab var w3var100 "Total wage variance, men 30-35, >=100 emp"
	lab var w3var200 "Total wage variance, men 30-35, >=200 emp"
	lab var w4var10 "Total SWS variance, all, private firms>=10 emp"
	lab var w4var25 "Total SWS variance, all, private firms>=25 emp"
	lab var w4var50 "Total SWS variance, all, private firms>=50 emp"
	lab var w5var10 "Total SWS variance, men, private firms>=10 emp"
	lab var w5var25 "Total SWS variance, men, private firms>=25 emp"
	lab var w5var50 "Total SWS variance, men, private firms>=50 emp"
	lab var w6var50 "Total SWS variance, men 30-35, >=50 emp"
	lab var w6var10 "Total SWS variance, men 30-35, >=10 emp"
	lab var w6var25 "Total SWS variance, men 30-35, >=25 emp"
	lab var w6var100 "Total SWS variance, men 30-35, >=100 emp"
	lab var w6var200 "Total SWS variance, men 30-35, >=200 emp"

	lab var BFt1_10 "Between firm/plant wage variance, all, private firms>=10 emp"
	lab var BFt1_25 "Between firm/plant wage variance, all, private firms>=25 emp"
	lab var BFt1_50 "Between firm/plant wage variance, all, private firms>=50 emp"
	lab var BFt1_100 "Between firm/plant wage variance, all, private firms>=100 emp"
	lab var BFt2_10 "Between firm/plant wage variance, men, private firms>=10 emp"
	lab var BFt2_25 "Between firm/plant wage variance, men, private firms>=25 emp"
	lab var BFt2_50 "Between firm/plant wage variance, men, private firms>=50 emp"
	lab var BFt2_100 "Between firm/plant wage variance, men, private firms>=100 emp"
	lab var BFt3_50 "Between firm/plant wage variance, men 30-35, >=50 emp"
	lab var BFt3_10 "Between firm/plant wage variance, men 30-35, >=10 emp"
	lab var BFt3_25 "Between firm/plant wage variance, men 30-35, >=25 emp"
	lab var BFt3_100 "Between firm/plant wage variance, men 30-35, >=100 emp"
	lab var BFt3_200 "Between firm/plant wage variance, men 30-35, >=200 emp"
	lab var BFt4_10 "Between firm/plant SWS variance, all, private firms>=10 emp"
	lab var BFt4_25 "Between firm/plant SWS variance, all, private firms>=25 emp"
	lab var BFt4_50 "Between firm/plant SWS variance, all, private firms>=50 emp"
	lab var BFt5_10 "Between firm/plant SWS variance, men, private firms>=10 emp"
	lab var BFt5_25 "Between firm/plant SWS variance, men, private firms>=25 emp"
	lab var BFt5_50 "Between firm/plant SWS variance, men, private firms>=50 emp"
	lab var BFt6_50 "Between firm/plant SWS variance, men 30-35, >=50 emp"
	lab var BFt6_10 "Between firm/plant SWS variance, men 30-35, >=10 emp"
	lab var BFt6_25 "Between firm/plant SWS variance, men 30-35, >=25 emp"
	lab var BFt6_100 "Between firm/plant SWS variance, men 30-35, >=100 emp"
	lab var BFt6_200 "Between firm/plant SWS variance, men 30-35, >=200 emp"

	save temp/wage_dispersion_`x'_`i'.dta, replace
	
	collapse ftgstorl_`x' cm10 cm25 cm50 cm100 cm200 nm10 nm25 nm50 nm100 nm200 edyrm10 edyrm25 edyrm50 edyrm100 edyrm200 zedyrm10 zedyrm25 zedyrm50 zedyrm100 edyrm_3035_10 edyrm_3035_25 edyrm_3035_50 edyrm_3035_100 edyrm_3035_200 zedyrm_3035_10 zedyrm_3035_25 zedyrm_3035_50 zedyrm_3035_100 zedyrm_3035_200 zedyrm200 wa1m10 wa1m25 wa1m50 wa1m100 wa2m10 wa2m25 wa2m50 wa2m100 wa3m50 wa3m10 wa3m25 wa3m100 wa3m200 wa4m10 wa4m25 wa4m50 wa5m10 wa5m25 wa5m50 wa6m50 wa6m10 wa6m25 wa6m100 wa6m200 w1var10 w1var25 w1var50 w1var100 w2var10 w2var25 w2var50 w2var100 w3var50 w3var10 w3var25 w3var100 w3var200 w4var10 w4var25 w4var50 w5var10 w5var25 w5var50 w6var50 w6var10 w6var25 w6var100 w6var200 BF* nobs1j10 nobs1j25 nobs1j50 nobs1j100 nobs2j10 nobs2j25 nobs2j50 nobs2j100 nobs3j50 nobs3j10 nobs3j25 nobs3j100 nobs3j200 nobs4j10 nobs4j25 nobs4j50 nobs5j10 nobs5j25 nobs5j50 nobs6j50 nobs6j10 nobs6j25 nobs6j100 nobs6j200 (sum) nobs1_10=nobs1j10 nobs1_25=nobs1j25 nobs1_50=nobs1j50 nobs1_100=nobs1j100 nobs2_10=nobs2j10 nobs2_25=nobs2j25 nobs2_50=nobs2j50 nobs2_100=nobs2j100 nobs3_50=nobs3j50 nobs3_10=nobs3j10 nobs3_25=nobs3j25 nobs3_100=nobs3j100 nobs3_200=nobs3j200 nobs4_10=nobs4j10 nobs4_25=nobs4j25 nobs4_50=nobs4j50 nobs5_10=nobs5j10 nobs5_25=nobs5j25 nobs5_50=nobs5j50 nobs6_50=nobs6j50 nobs6_10=nobs6j10 nobs6_25=nobs6j25 nobs6_100=nobs6j100 nobs6_200=nobs6j200 (count) n`x'1_10=nobs1j10 n`x'1_25=nobs1j25 n`x'1_50=nobs1j50 n`x'1_100=nobs1j100 n`x'2_10=nobs2j10 n`x'2_25=nobs2j25 n`x'2_50=nobs2j50 n`x'2_100=nobs2j100 n`x'3_50=nobs3j50 n`x'3_10=nobs3j10 n`x'3_25=nobs3j25 n`x'3_100=nobs3j100 n`x'3_200=nobs3j200 n`x'4_10=nobs4j10 n`x'4_25=nobs4j25 n`x'4_50=nobs4j50 n`x'5_10=nobs5j10 n`x'5_25=nobs5j25 n`x'5_50=nobs5j50 n`x'6_50=nobs6j50 n`x'6_10=nobs6j10 n`x'6_25=nobs6j25 n`x'6_100=nobs6j100 n`x'6_200=nobs6j200, by(year)

	gen WFt1_10=w1var10-BFt1_10
	gen WFt1_25=w1var25-BFt1_25
	gen WFt1_50=w1var50-BFt1_50
	gen WFt1_100=w1var100-BFt1_100
	gen WFt2_10=w2var10-BFt2_10
	gen WFt2_25=w2var25-BFt2_25
	gen WFt2_50=w2var50-BFt2_50
	gen WFt2_100=w2var100-BFt2_100
	gen WFt3_50=w3var50-BFt3_50
	gen WFt3_10=w3var10-BFt3_10
	gen WFt3_25=w3var25-BFt3_25
	gen WFt3_100=w3var100-BFt3_100
	gen WFt3_200=w3var200-BFt3_200
	gen WFt4_10=w4var10-BFt4_10
	gen WFt4_25=w4var25-BFt4_25
	gen WFt4_50=w4var50-BFt4_50
	gen WFt5_10=w5var10-BFt5_10
	gen WFt5_25=w5var25-BFt5_25
	gen WFt5_50=w5var50-BFt5_50
	gen WFt6_50=w6var50-BFt6_50
	gen WFt6_10=w6var10-BFt6_10
	gen WFt6_25=w6var25-BFt6_25
	gen WFt6_100=w6var100-BFt6_100
	gen WFt6_200=w6var200-BFt6_200

	lab var cm10 "Mean cognitive, >=10 emp"
	lab var cm25 "Mean cognitive, >=25 emp"
	lab var cm50 "Mean cognitive, >=50 emp"
	lab var cm100 "Mean cognitive, >=100 emp"
	lab var cm200 "Mean cognitive, >=200 emp"
	lab var nm10 "Mean non-cognitive, >=10 emp"
	lab var nm25 "Mean non-cognitive, >=25 emp"
	lab var nm50 "Mean non-cognitive, >=50 emp"
	lab var nm100 "Mean non-cognitive, >=100 emp"
	lab var nm200 "Mean non-cognitive, >=200 emp"
	lab var edyrm10 "Mean edyr, >=10 emp"
	lab var edyrm25 "Mean edyr, >=25 emp"
	lab var edyrm50 "Mean edyr, >=50 emp"
	lab var edyrm100 "Mean edyr, >=100 emp"
	lab var edyrm200 "Mean edyr, >=200 emp"
	lab var zedyrm10 "Mean zedyr, >=10 emp"
	lab var zedyrm25 "Mean zedyr, >=25 emp"
	lab var zedyrm50 "Mean zedyr, >=50 emp"
	lab var zedyrm100 "Mean zedyr, >=100 emp"
	lab var zedyrm200 "Mean zedyr, >=200 emp"
	lab var edyrm_3035_10 "Mean edyr, men 30-35, >=10 emp"
	lab var edyrm_3035_25 "Mean edyr, men 30-35, >=25 emp"
	lab var edyrm_3035_50 "Mean edyr, men 30-35, >=50 emp"
	lab var edyrm_3035_100 "Mean edyr, men 30-35, >=100 emp"
	lab var edyrm_3035_200 "Mean edyr, men 30-35, >=200 emp"
	lab var zedyrm_3035_10 "Mean zedyr, men 30-35, >=10 emp"
	lab var zedyrm_3035_25 "Mean zedyr, men 30-35, >=25 emp"
	lab var zedyrm_3035_50 "Mean zedyr, men 30-35, >=50 emp"
	lab var zedyrm_3035_100 "Mean zedyr, men 30-35, >=100 emp"
	lab var zedyrm_3035_200 "Mean zedyr, men 30-35, >=200 emp"

	lab var wa1m10 "Mean monthly wages, all, private firms>=10 emp"
	lab var wa1m25 "Mean monthly wages, all, private firms>=25 emp"
	lab var wa1m50 "Mean monthly wages, all, private firms>=50 emp"
	lab var wa1m100 "Mean monthly wages, all, private firms>=100 emp"
	lab var wa2m10 "Mean monthly wages, men, private firms>=10 emp"
	lab var wa2m25 "Mean monthly wages, men, private firms>=25 emp"
	lab var wa2m50 "Mean monthly wages, men, private firms>=50 emp"
	lab var wa2m100 "Mean monthly wages, men, private firms>=100 emp"
	lab var wa3m50 "Mean monthly wages, men 30-35, >=50 emp"
	lab var wa3m10 "Mean monthly wages, men 30-35, >=10 emp"
	lab var wa3m25 "Mean monthly wages, men 30-35, >=25 emp"
	lab var wa3m100 "Mean monthly wages, men 30-35, >=100 emp"
	lab var wa3m200 "Mean monthly wages, men 30-35, >=200 emp"
	lab var wa4m10 "Mean monthly SWS, all, private firms>=10 emp"
	lab var wa4m25 "Mean monthly SWS, all, private firms>=25 emp"
	lab var wa4m50 "Mean monthly SWS, all, private firms>=50 emp"
	lab var wa5m10 "Mean monthly SWS, men, private firms>=10 emp"
	lab var wa5m25 "Mean monthly SWS, men, private firms>=25 emp"
	lab var wa5m50 "Mean monthly SWS, men, private firms>=50 emp"
	lab var wa6m50 "Mean monthly SWS, men 30-35, >=50 emp"
	lab var wa6m10 "Mean monthly SWS, men 30-35, >=10 emp"
	lab var wa6m25 "Mean monthly SWS, men 30-35, >=25 emp"
	lab var wa6m100 "Mean monthly SWS, men 30-35, >=100 emp"
	lab var wa6m200 "Mean monthly SWS, men 30-35, >=200 emp"

	lab var w1var10 "Total wage variance, all, private firms>=10 emp"
	lab var w1var25 "Total wage variance, all, private firms>=25 emp"
	lab var w1var50 "Total wage variance, all, private firms>=50 emp"
	lab var w1var100 "Total wage variance, all, private firms>=100 emp"
	lab var w2var10 "Total wage variance, men, private firms>=10 emp"
	lab var w2var25 "Total wage variance, men, private firms>=25 emp"
	lab var w2var50 "Total wage variance, men, private firms>=50 emp"
	lab var w2var100 "Total wage variance, men, private firms>=100 emp"
	lab var w3var50 "Total wage variance, men 30-35, >=50 emp"
	lab var w3var10 "Total wage variance, men 30-35, >=10 emp"
	lab var w3var25 "Total wage variance, men 30-35, >=25 emp"
	lab var w3var100 "Total wage variance, men 30-35, >=100 emp"
	lab var w3var200 "Total wage variance, men 30-35, >=200 emp"
	lab var w4var10 "Total SWS variance, all, private firms>=10 emp"
	lab var w4var25 "Total SWS variance, all, private firms>=25 emp"
	lab var w4var50 "Total SWS variance, all, private firms>=50 emp"
	lab var w5var10 "Total SWS variance, men, private firms>=10 emp"
	lab var w5var25 "Total SWS variance, men, private firms>=25 emp"
	lab var w5var50 "Total SWS variance, men, private firms>=50 emp"
	lab var w6var50 "Total SWS variance, men 30-35, >=50 emp"
	lab var w6var10 "Total SWS variance, men 30-35, >=10 emp"
	lab var w6var25 "Total SWS variance, men 30-35, >=25 emp"
	lab var w6var100 "Total SWS variance, men 30-35, >=100 emp"
	lab var w6var200 "Total SWS variance, men 30-35, >=200 emp"

	lab var WFt1_10 "Within firm/plant wage variance, all, private firms>=10 emp"
	lab var WFt1_25 "Within firm/plant wage variance, all, private firms>=25 emp"
	lab var WFt1_50 "Within firm/plant wage variance, all, private firms>=50 emp"
	lab var WFt1_100 "Within firm/plant wage variance, all, private firms>=100 emp"
	lab var WFt2_10 "Within firm/plant wage variance, men, private firms>=10 emp"
	lab var WFt2_25 "Within firm/plant wage variance, men, private firms>=25 emp"
	lab var WFt2_50 "Within firm/plant wage variance, men, private firms>=50 emp"
	lab var WFt2_100 "Within firm/plant wage variance, men, private firms>=100 emp"
	lab var WFt3_50 "Within firm/plant wage variance, men 30-35, >=50 emp"
	lab var WFt3_10 "Within firm/plant wage variance, men 30-35, >=10 emp"
	lab var WFt3_25 "Within firm/plant wage variance, men 30-35, >=25 emp"
	lab var WFt3_100 "Within firm/plant wage variance, men 30-35, >=100 emp"
	lab var WFt3_200 "Within firm/plant wage variance, men 30-35, >=200 emp"
	lab var WFt4_10 "Within firm/plant SWS variance, all, private firms>=10 emp"
	lab var WFt4_25 "Within firm/plant SWS variance, all, private firms>=25 emp"
	lab var WFt4_50 "Within firm/plant SWS variance, all, private firms>=50 emp"
	lab var WFt5_10 "Within firm/plant SWS variance, men, private firms>=10 emp"
	lab var WFt5_25 "Within firm/plant SWS variance, men, private firms>=25 emp"
	lab var WFt5_50 "Within firm/plant SWS variance, men, private firms>=50 emp"
	lab var WFt6_50 "Within firm/plant SWS variance, men 30-35, >=50 emp"
	lab var WFt6_10 "Within firm/plant SWS variance, men 30-35, >=10 emp"
	lab var WFt6_25 "Within firm/plant SWS variance, men 30-35, >=25 emp"
	lab var WFt6_100 "Within firm/plant SWS variance, men 30-35, >=100 emp"
	lab var WFt6_200 "Within firm/plant SWS variance, men 30-35, >=200 emp"

	lab var BFt1_10 "Between firm/plant wage variance, all, private firms>=10 emp"
	lab var BFt1_25 "Between firm/plant wage variance, all, private firms>=25 emp"
	lab var BFt1_50 "Between firm/plant wage variance, all, private firms>=50 emp"
	lab var BFt1_100 "Between firm/plant wage variance, all, private firms>=100 emp"
	lab var BFt2_10 "Between firm/plant wage variance, men, private firms>=10 emp"
	lab var BFt2_25 "Between firm/plant wage variance, men, private firms>=25 emp"
	lab var BFt2_50 "Between firm/plant wage variance, men, private firms>=50 emp"
	lab var BFt2_100 "Between firm/plant wage variance, men, private firms>=100 emp"
	lab var BFt3_50 "Between firm/plant wage variance, men 30-35, >=50 emp"
	lab var BFt3_10 "Between firm/plant wage variance, men 30-35, >=10 emp"
	lab var BFt3_25 "Between firm/plant wage variance, men 30-35, >=25 emp"
	lab var BFt3_100 "Between firm/plant wage variance, men 30-35, >=100 emp"
	lab var BFt3_200 "Between firm/plant wage variance, men 30-35, >=200 emp"
	lab var BFt4_10 "Between firm/plant SWS variance, all, private firms>=10 emp"
	lab var BFt4_25 "Between firm/plant SWS variance, all, private firms>=25 emp"
	lab var BFt4_50 "Between firm/plant SWS variance, all, private firms>=50 emp"
	lab var BFt5_10 "Between firm/plant SWS variance, men, private firms>=10 emp"
	lab var BFt5_25 "Between firm/plant SWS variance, men, private firms>=25 emp"
	lab var BFt5_50 "Between firm/plant SWS variance, men, private firms>=50 emp"
	lab var BFt6_50 "Between firm/plant SWS variance, men 30-35, >=50 emp"
	lab var BFt6_10 "Between firm/plant SWS variance, men 30-35, >=10 emp"
	lab var BFt6_25 "Between firm/plant SWS variance, men 30-35, >=25 emp"
	lab var BFt6_100 "Between firm/plant SWS variance, men 30-35, >=100 emp"
	lab var BFt6_200 "Between firm/plant SWS variance, men 30-35, >=200 emp"

	lab var ftgstorl_`x' "Mean firm size (RAMS)"
	
	lab var nobs1j10 "Mean obs per firm/plant, wages, all, private firms >=10 emp"
	lab var nobs1j25 "Mean obs per firm/plant, wages, all, private firms >=25 emp"
	lab var nobs1j50 "Mean obs per firm/plant, wages, all, private firms >=50 emp"
	lab var nobs1j100 "Mean obs per firm/plant, wages, all, private firms >=100 emp"
	lab var nobs2j10 "Mean obs per firm/plant, wages, men, private firms >=10 emp"
	lab var nobs2j25 "Mean obs per firm/plant, wages, men, private firms >=25 emp"
	lab var nobs2j50 "Mean obs per firm/plant, wages, men, private firms >=50 emp"
	lab var nobs2j100 "Mean obs per firm/plant, wages, men, private firms >=100 emp"
	lab var nobs3j50 "Mean obs per firm/plant, wages, men 30-35 private firms >=50 emp"
	lab var nobs3j10 "Mean obs per firm/plant, wages, men 30-35 private firms >=10 emp"
	lab var nobs3j25 "Mean obs per firm/plant, wages, men 30-35 private firms >=25 emp"
	lab var nobs3j100 "Mean obs per firm/plant, wages, men 30-35 private firms >=100 emp"
	lab var nobs3j200 "Mean obs per firm/plant, wages, men 30-35 private firms >=200 emp"
	lab var nobs4j10 "Mean obs per firm/plant, SWS, all, private firms >=10 emp"
	lab var nobs4j25 "Mean obs per firm/plant, SWS, all, private firms >=25 emp"
	lab var nobs4j50 "Mean obs per firm/plant, SWS, all, private firms >=50 emp"
	lab var nobs5j10 "Mean obs per firm/plant, SWS, men, private firms >=10 emp"
	lab var nobs5j25 "Mean obs per firm/plant, SWS, men, private firms >=25 emp"
	lab var nobs5j50 "Mean obs per firm/plant, SWS, men, private firms >=50 emp"
	lab var nobs6j50 "Mean obs per firm/plant, SWS, men 30-35 private firms >=50 emp"
	lab var nobs6j10 "Mean obs per firm/plant, SWS, men 30-35 private firms >=10 emp"
	lab var nobs6j25 "Mean obs per firm/plant, SWS, men 30-35 private firms >=25 emp"
	lab var nobs6j100 "Mean obs per firm/plant, SWS, men 30-35 private firms >=100 emp"
	lab var nobs6j200 "Mean obs per firm/plant, SWS, men 30-35 private firms >=200 emp"
	
	lab var nobs1_10 "Total obs, wages, all, private firms >=10 emp"
	lab var nobs1_25 "Total obs, wages, all, private firms >=25 emp"
	lab var nobs1_50 "Total obs, wages, all, private firms >=50 emp"
	lab var nobs1_100 "Total obs, wages, all, private firms >=100 emp"
	lab var nobs2_10 "Total obs, wages, men, private firms >=10 emp"
	lab var nobs2_25 "Total obs, wages, men, private firms >=25 emp"
	lab var nobs2_50 "Total obs, wages, men, private firms >=50 emp"
	lab var nobs2_100 "Total obs, wages, men, private firms >=100 emp"
	lab var nobs3_50 "Total obs, wages, men 30-35 private firms >=50 emp"
	lab var nobs3_10 "Total obs, wages, men 30-35 private firms >=10 emp"
	lab var nobs3_25 "Total obs, wages, men 30-35 private firms >=25 emp"
	lab var nobs3_100 "Total obs, wages, men 30-35 private firms >=100 emp"
	lab var nobs3_200 "Total obs, wages, men 30-35 private firms >=200 emp"
	lab var nobs4_10 "Total obs, SWS, all, private firms >=10 emp"
	lab var nobs4_25 "Total obs, SWS, all, private firms >=25 emp"
	lab var nobs4_50 "Total obs, SWS, all, private firms >=50 emp"
	lab var nobs5_10 "Total obs, SWS, men, private firms >=10 emp"
	lab var nobs5_25 "Total obs, SWS, men, private firms >=25 emp"
	lab var nobs5_50 "Total obs, SWS, men, private firms >=50 emp"
	lab var nobs6_50 "Total obs, SWS, men 30-35 private firms >=50 emp"
	lab var nobs6_10 "Total obs, SWS, men 30-35 private firms >=10 emp"
	lab var nobs6_25 "Total obs, SWS, men 30-35 private firms >=25 emp"
	lab var nobs6_100 "Total obs, SWS, men 30-35 private firms >=100 emp"
	lab var nobs6_200 "Total obs, SWS, men 30-35 private firms >=200 emp"
	
	lab var n`x'1_10 "Number of firms/plants, wages, all, private firms >=10 emp"
	lab var n`x'1_25 "Number of firms/plants, wages, all, private firms >=25 emp"
	lab var n`x'1_50 "Number of firms/plants, wages, all, private firms >=50 emp"
	lab var n`x'1_100 "Number of firms/plants, wages, all, private firms >=100 emp"
	lab var n`x'2_10 "Number of firms/plants, wages, men, private firms >=10 emp"
	lab var n`x'2_25 "Number of firms/plants, wages, men, private firms >=25 emp"
	lab var n`x'2_50 "Number of firms/plants, wages, men, private firms >=50 emp"
	lab var n`x'2_100 "Number of firms/plants, wages, men, private firms >=100 emp"
	lab var n`x'3_50 "Number of firms/plants, wages, men 30-35 private firms >=50 emp"
	lab var n`x'3_10 "Number of firms/plants, wages, men 30-35 private firms >=10 emp"
	lab var n`x'3_25 "Number of firms/plants, wages, men 30-35 private firms >=25 emp"
	lab var n`x'3_100 "Number of firms/plants, wages, men 30-35 private firms >=100 emp"
	lab var n`x'3_200 "Number of firms/plants, wages, men 30-35 private firms >=200 emp"
	lab var n`x'4_10 "Number of firms/plants, SWS, all, private firms >=10 emp"
	lab var n`x'4_25 "Number of firms/plants, SWS, all, private firms >=25 emp"
	lab var n`x'4_50 "Number of firms/plants, SWS, all, private firms >=50 emp"
	lab var n`x'5_10 "Number of firms/plants, SWS, men, private firms >=10 emp"
	lab var n`x'5_25 "Number of firms/plants, SWS, men, private firms >=25 emp"
	lab var n`x'5_50 "Number of firms/plants, SWS, men, private firms >=50 emp"
	lab var n`x'6_50 "Number of firms/plants, SWS, men 30-35 private firms >=50 emp"
	lab var n`x'6_10 "Number of firms/plants, SWS, men 30-35 private firms >=10 emp"
	lab var n`x'6_25 "Number of firms/plants, SWS, men 30-35 private firms >=25 emp"
	lab var n`x'6_100 "Number of firms/plants, SWS, men 30-35 private firms >=100 emp"
	lab var n`x'6_200 "Number of firms/plants, SWS, men 30-35 private firms >=200 emp"
	
	save temp/wage_dispersion_agg_`x'_`i'.dta, replace
	}
}

*** Combine annual files into firm/plant files and aggregate files for all years 1985-2009

* Combine annual firm/plant level files into one: modified/wage_dispersion_`x'
foreach x in ftg ast {
	use temp/wage_dispersion_`x'_1985.dta,clear
	forvalues i=1986(1)2009 {
		append using temp/wage_dispersion_`x'_`i'.dta
	}
	save modified/wage_dispersion_`x'.dta,replace
}
*

* Combine annual aggregate files into one: modified/wage_dispersion_agg
foreach x in ftg ftg {
	use temp/wage_dispersion_agg_`x'_1985.dta,clear
	forvalues i=1986(1)2009 {
		append using temp/wage_dispersion_agg_`x'_`i'.dta
	}
	save modified/wage_dispersion_agg_`x'.dta,replace
}

foreach x in ftg ast {
	use modified/wage_dispersion_agg_`x', clear
	foreach v in cm10 cm25 cm50 cm100 cm200 nm10 nm25 nm50 nm100 nm200 edyrm10 edyrm25 edyrm50 edyrm100 edyrm200 zedyrm10 zedyrm25 zedyrm50 zedyrm100 edyrm_3035_10 edyrm_3035_25 edyrm_3035_50 edyrm_3035_100 edyrm_3035_200 zedyrm_3035_10 zedyrm_3035_25 zedyrm_3035_50 zedyrm_3035_100 zedyrm_3035_200 zedyrm200 wa1m10 wa1m25 wa1m50 wa1m100 wa2m10 wa2m25 wa2m50 wa2m100 wa3m50 wa3m10 wa3m25 wa3m100 wa3m200 wa4m10 wa4m25 wa4m50 wa5m10 wa5m25 wa5m50 wa6m50 wa6m10 wa6m25 wa6m100 wa6m200 w1var10 w1var25 w1var50 w1var100 w2var10 w2var25 w2var50 w2var100 w3var50 w3var10 w3var25 w3var100 w3var200 w4var10 w4var25 w4var50 w5var10 w5var25 w5var50 w6var50 w6var10 w6var25 w6var100 w6var200 BFt1_10 BFt1_25 BFt1_50 BFt1_100 BFt2_10 BFt2_25 BFt2_50 BFt2_100 BFt3_50 BFt3_10 BFt3_25 BFt3_100 BFt3_200 BFt4_10 BFt4_25 BFt4_50 BFt5_10 BFt5_25 BFt5_50 BFt6_50 BFt6_10 BFt6_25 BFt6_100 BFt6_200 nobs1j10 nobs1j25 nobs1j50 nobs1j100 nobs2j10 nobs2j25 nobs2j50 nobs2j100 nobs3j50 nobs3j10 nobs3j25 nobs3j100 nobs3j200 nobs4j10 nobs4j25 nobs4j50 nobs5j10 nobs5j25 nobs5j50 nobs6j50 nobs6j10 nobs6j25 nobs6j100 nobs6j200 nobs1_10 nobs1_25 nobs1_50 nobs1_100 nobs2_10 nobs2_25 nobs2_50 nobs2_100 nobs3_50 nobs3_10 nobs3_25 nobs3_100 nobs3_200 nobs4_10 nobs4_25 nobs4_50 nobs5_10 nobs5_25 nobs5_50 nobs6_50 nobs6_10 nobs6_25 nobs6_100 nobs6_200 WFt1_10 WFt1_25 WFt1_50 WFt1_100 WFt2_10 WFt2_25 WFt2_50 WFt2_100 WFt3_50 WFt3_10 WFt3_25 WFt3_100 WFt3_200 WFt4_10 WFt4_25 WFt4_50 WFt5_10 WFt5_25 WFt5_50 WFt6_50 WFt6_10 WFt6_25 WFt6_100 WFt6_200 {
		rename `v' `v'_`x'
	}
	save temp/wagedisp_`x', replace
}	

use temp/wagedisp_ftg, clear
merge 1:1 year using temp/wagedisp_ast
drop _merge
save modified/wage_dispersion_agg, replace
*


*************************************************	
*** 13. Create files for sorting analysis  ******
*************************************************

* Here we should perhaps loop over samples in order
* to create separate files for separate parts of 
* the analysis.
* Notation: `x' refers to ftg (firm) and ast (plant)
* 			`j' refers to sample (eg firm size 10, 25, 50, 100, 200)
*			`i' refers to year 
*
* Main aggegate files: modified/vardecomp_aggregate
* 2:nd aggregate files: modified/vardecomp_bfwi_bi
* Main industry files: modified/vardecomp_industry_`x'_`j' 
* Firm/plant level files: modified/vardecomp_unit_`x'_`j' 

foreach x in ftg ast {
	foreach j in 10 25 50 100 200 {
		forvalues i=1985(1)2009 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample
		keep if sample_3035_`j'_`x'==1
		
		*This part generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		***Actual skill means
		*industry
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*firm/plant yrke
		bysort `x'nr yrke: egen chj=mean(c) 
		bysort `x'nr yrke: egen nhj=mean(n) 
		bysort `x'nr yrke: egen ehj=mean(edyr)
		bysort `x'nr yrke: egen zehj=mean(zedyr) 

		*yrke
		bysort yrke: egen ch=mean(c) 
		bysort yrke: egen nh=mean(n) 
		bysort yrke: egen eh=mean(edyr) 
		bysort yrke: egen zeh=mean(zedyr) 

		*sample
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		*Observed samples and sizes
		* rename ftgstorl_`x' Nj
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		bysort `x'nr: egen N2j=total(count) 
		egen N2=total(count) 

		***Predicted skills
		*individual
		areg c, absorb(yrke)
		predict cijtilde if e(sample),xbd
		predict cijres if e(sample), resid
		areg n, absorb(yrke)
		predict nijtilde if e(sample),xbd
		predict nijres if e(sample), resid
		areg edyr, absorb(yrke)
		predict eijtilde if e(sample), xbd
		predict eijres if e(sample), resid
		areg zedyr, absorb(yrke)
		predict zeijtilde if e(sample), xbd
		predict zeijres if e(sample), resid

		bysort `x'nr: egen cjres=mean(cijres)
		bysort `x'nr: egen njres=mean(nijres)
		bysort `x'nr: egen ejres=mean(eijres)
		bysort `x'nr: egen zejres=mean(zeijres)

		g cjtilde=cj-cjres
		g njtilde=nj-njres
		g ejtilde=ej-ejres
		g zejtilde=zej-zejres

		rename edyr e
		rename zedyr ze

		***Components for (corrected and uncorrected) variances (to be collapsed)

		*between occupation within firm/plant  
		g wt_c=(cijtilde-cjtilde)^2
		g wt_n=(nijtilde-njtilde)^2
		g wt_e=(eijtilde-ejtilde)^2
		g wt_ze=(zeijtilde-zejtilde)^2

		*within occupation within plant 
		g wa_c=((c-cijtilde)-(cj-cjtilde))^2
		g wa_n=((n-nijtilde)-(nj-njtilde))^2
		g wa_e=((e-eijtilde)-(ej-ejtilde))^2
		g wa_ze=((ze-zeijtilde)-(zej-zejtilde))^2

		*within firm total variance (consistancy check)
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*within firm covariance (between and witin occ) 
		g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
		g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
		g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))
		g wat_ze=(zeijtilde-zejtilde)*((ze-zeijtilde)-(zej-zejtilde))

		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_c=wt_c+wa_c+2*wat_c
		g wtot_n=wt_n+wa_n+2*wat_n
		g wtot_e=wt_e+wa_e+2*wat_e
		g wtot_ze=wt_ze+wa_ze+2*wat_ze

		* between occupation between firm
		g bt_c=(cjtilde-cbar)^2
		g bt_n=(njtilde-nbar)^2
		g bt_e=(ejtilde-ebar)^2
		g bt_ze=(zejtilde-zebar)^2

		*within occupation between firm 
		g ba_c=(cj-cjtilde)^2
		g ba_n=(nj-njtilde)^2
		g ba_e=(ej-ejtilde)^2
		g ba_ze=(zej-zejtilde)^2

		*between firm total variance (consistancy check)
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*between firm covariance (within andd between occ)
		g bat_c=(cjtilde-cbar)*(cj-cjtilde)
		g bat_n=(njtilde-nbar)*(nj-njtilde)
		g bat_e=(ejtilde-ebar)*(ej-ejtilde)
		g bat_ze=(zejtilde-zebar)*(zej-zejtilde)

		*between firm total variance 
		g btot_c=bt_c+ba_c+2*bat_c
		g btot_n=bt_n+ba_n+2*bat_n
		g btot_e=bt_e+ba_e+2*bat_e
		g btot_ze=bt_ze+ba_ze+2*bat_ze

		*total between occupation
		g tt_c=(cijtilde-cbar)^2 
		g tt_n=(nijtilde-nbar)^2 
		g tt_e=(eijtilde-ebar)^2 
		g tt_ze=(zeijtilde-zebar)^2 

		*total within occupation
		g ta_c=(c-cijtilde)^2
		g ta_n=(n-nijtilde)^2
		g ta_e=(e-eijtilde)^2
		g ta_ze=(ze-zeijtilde)^2

		*total variance (consistancy check)
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level
		collapse (sum) w* t* cijtilde nijtilde eijtilde zeijtilde cijres nijres eijres zeijres c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 cj nj ej zej cjtilde njtilde ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		* between occ within firm/plant corrected
		g corr_wt_c=wt_c*thetaj_w*N2j
		g corr_wt_n=wt_n*thetaj_w*N2j
		g corr_wt_e=wt_e*thetaj_w*N2j
		g corr_wt_ze=wt_ze*thetaj_w*N2j

		*within occ within firm/plant corrected
		g corr_wa_c=wa_c*thetaj_w*N2j
		g corr_wa_n=wa_n*thetaj_w*N2j
		g corr_wa_e=wa_e*thetaj_w*N2j
		g corr_wa_ze=wa_ze*thetaj_w*N2j

		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_c=wat_c*thetaj_w*N2j
		g corr_wat_n=wat_n*thetaj_w*N2j
		g corr_wat_e=wat_e*thetaj_w*N2j
		g corr_wat_ze=wat_ze*thetaj_w*N2j

		*within firm/plant total variance corrected
		g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
		g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
		g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e
		g corr_wtot_ze=corr_wt_ze+corr_wa_ze+2*corr_wat_ze

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*between occ between firm/plant corrected
		g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
		g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
		g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)
		g corr_bt_ze=N2j*(bt_ze-thetaj_b*wt_ze)

		*within occ between firm/plant corrected
		g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
		g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
		g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)
		g corr_ba_ze=N2j*(ba_ze-thetaj_b*wa_ze)

		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
		g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
		g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)
		g corr_bat_ze=N2j*(bat_ze-thetaj_b*wat_ze)

		*between firm/plant total variance corrected
		g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
		g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
		g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e
		g corr_btot_ze=corr_bt_ze+corr_ba_ze+2*corr_bat_ze

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*** Firm/plant level data set for use in regressions. 
		preserve
			keep corr* b* w* t* cjtilde njtilde cj nj ej zej lnwpredj lnwagej cbar nbar ebar zebar lnwpredbar lnwagebar ftgstorl_`x' Nj N2j N2 `x'nr ast_ftg year `x'sni2
			* NOT: dividera alla "within" ska delas med N2j
			lab var lnwpredj "Firm/plant wpred, 30-35 men"
			lab var lnwagej "Firm/plant SWS wage, 30-35 men"
			lab var lnwpredbar "Sample mean wpred, 30-35 men"
			lab var lnwagebar "Sample mean SWS wage, 30-35 men"
			sort `x'nr -ftgstorl_`x'
			duplicates drop `x'nr, force 
			save temp/vardecomp_unit_`x'_`j'_`i',replace
		restore

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_c=bt_c*N2j
		replace bt_n=bt_n*N2j
		replace bt_e=bt_e*N2j
		replace bt_ze=bt_ze*N2j

		* within occupation between firm/plant
		replace ba_c=ba_c*N2j
		replace ba_n=ba_n*N2j
		replace ba_e=ba_e*N2j
		replace ba_ze=ba_ze*N2j

		*between firm/plant covariance (between and within occupation)
		replace bat_c=bat_c*N2j
		replace bat_n=bat_n*N2j
		replace bat_e=bat_e*N2j
		replace bat_ze=bat_ze*N2j

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*between firm/plant total variance
		replace btot_c=btot_c*N2j
		replace btot_n=btot_n*N2j
		replace btot_e=btot_e*N2j
		replace btot_ze=btot_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)

		*** D. Collapse to industry level for use in regressions. 
		preserve
			*components for between-firm/plant within-industry variance
			g bfwi_c=N2j*(cj-ck)^2
			g bfwi_n=N2j*(nj-nk)^2
			g bfwi_e=N2j*(ej-ek)^2
			g bfwi_ze=N2j*(zej-zek)^2

			collapse (sum) w* b* t* corr* cktilde=cijtilde nktilde=nijtilde ektilde=eijtilde zektilde=zeijtilde ckres=cijres nkres=nijres ekres=eijres zekres=zeijres Nk=Nj N2k=N2j (mean) N2 ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by(year `x'sni2)

			*sample correction industry level
			g thetak=((Nk-N2k)/(N2k*Nk))*(1/(N2k-1))

			*components for bfwi variance and bi variance
			replace corr_bi_c=N2k*((ck-cbar)^2-thetak*corr_bi_c)
			replace corr_bi_n=N2k*((nk-nbar)^2-thetak*corr_bi_n)
			replace corr_bi_e=N2k*((ek-ebar)^2-thetak*corr_bi_e)
			replace corr_bi_ze=N2k*((zek-zebar)^2-thetak*corr_bi_ze)

			g bi_c=N2k*(ck-cbar)^2
			g bi_n=N2k*(nk-nbar)^2
			g bi_e=N2k*(ek-ebar)^2
			g bi_ze=N2k*(zek-zebar)^2

			save temp/vardecomp_bfwi_bi_`x'_`j'_`i',replace
			drop bi* bfwi* corr_bi* 

			*note: predicted skills have been summed up from individual level => divide by N2K to get average industry skill
			replace cktilde=cktilde/N2k
			replace nktilde=nktilde/N2k
			replace ektilde=ektilde/N2k
			replace zektilde=zektilde/N2k

			replace ckres=ckres/N2k
			replace nkres=nkres/N2k
			replace ekres=ekres/N2k
			replace zekres=zekres/N2k

			***final industry level uncorrected variances

			* between occupation within firm/plant
			replace wt_c=wt_c*1/N2k
			replace wt_n=wt_n*1/N2k
			replace wt_e=wt_e*1/N2k
			replace wt_ze=wt_ze*1/N2k

			* within occupation within firm/plant
			replace wa_c=wa_c*1/N2k
			replace wa_n=wa_n*1/N2k
			replace wa_e=wa_e*1/N2k
			replace wa_ze=wa_ze*1/N2k

			*within firm/plant covariance (between and within occupation)
			replace wat_c=wat_c*2/N2k
			replace wat_n=wat_n*2/N2k
			replace wat_e=wat_e*2/N2k
			replace wat_ze=wat_ze*2/N2k

			*within firm/plant total variance 
			replace wtot_c=wtot_c*1/N2k
			replace wtot_n=wtot_n*1/N2k
			replace wtot_e=wtot_e*1/N2k
			replace wtot_ze=wtot_ze*1/N2k

			*within firm/plant total (consistancy check of above)
			replace ws_c=ws_c*1/N2k
			replace ws_n=ws_n*1/N2k
			replace ws_e=ws_e*1/N2k
			replace ws_ze=ws_ze*1/N2k

			*between occupation between firm/plant
			replace bt_c=bt_c*1/N2k
			replace bt_n=bt_n*1/N2k
			replace bt_e=bt_e*1/N2k
			replace bt_ze=bt_ze*1/N2k

			*within occupation between firm/plant
			replace ba_c=ba_c*1/N2k
			replace ba_n=ba_n*1/N2k
			replace ba_e=ba_e*1/N2k
			replace ba_ze=ba_ze*1/N2k

			*between firm/plant covariance (between and within occ) 
			replace bat_c=bat_c*2/N2k
			replace bat_n=bat_n*2/N2k
			replace bat_e=bat_e*2/N2k
			replace bat_ze=bat_ze*2/N2k

			*between firm/plant total variance (consistancy check)
			replace bs_c=bs_c*1/N2k
			replace bs_n=bs_n*1/N2k
			replace bs_e=bs_e*1/N2k
			replace bs_ze=bs_ze*1/N2k

			*between firm/plant total variance
			replace btot_c=btot_c*1/N2k
			replace btot_n=btot_n*1/N2k
			replace btot_e=btot_e*1/N2k
			replace btot_ze=btot_ze*1/N2k

			*total between occupation
			replace tt_c=tt_c*1/N2k
			replace tt_n=tt_n*1/N2k
			replace tt_e=tt_e*1/N2k
			replace tt_ze=tt_ze*1/N2k

			*total within occupation
			replace ta_c=ta_c*1/N2k
			replace ta_n=ta_n*1/N2k
			replace ta_e=ta_e*1/N2k
			replace ta_ze=ta_ze*1/N2k

			*total variance (consistancy)
			replace ts_c=ts_c*1/N2k
			replace ts_n=ts_n*1/N2k
			replace ts_e=ts_e*1/N2k
			replace ts_ze=ts_ze*1/N2k

			*** Final industry level sample corrected variances 

			*between occupation within firm/plant corrected
			replace corr_wt_c=corr_wt_c*1/N2k
			replace corr_wt_n=corr_wt_n*1/N2k
			replace corr_wt_e=corr_wt_e*1/N2k
			replace corr_wt_ze=corr_wt_ze*1/N2k

			*within occupation within firm/plant corrected
			replace corr_wa_c=corr_wa_c*1/N2k
			replace corr_wa_n=corr_wa_n*1/N2k
			replace corr_wa_e=corr_wa_e*1/N2k
			replace corr_wa_ze=corr_wa_ze*1/N2k

			*within firm/plant covariance (between and within occ)  
			replace corr_wat_c=corr_wat_c*2/N2k
			replace corr_wat_n=corr_wat_n*2/N2k
			replace corr_wat_e=corr_wat_e*2/N2k
			replace corr_wat_ze=corr_wat_ze*2/N2k

			*within firm/plant total varinace corrected
			replace corr_wtot_c=corr_wtot_c*1/N2k
			replace corr_wtot_n=corr_wtot_n*1/N2k
			replace corr_wtot_e=corr_wtot_e*1/N2k
			replace corr_wtot_ze=corr_wtot_ze*1/N2k

			*within firm/plant total variance corrected (consistancy)
			replace corr_ws_c=corr_ws_c*1/N2k
			replace corr_ws_n=corr_ws_n*1/N2k
			replace corr_ws_e=corr_ws_e*1/N2k
			replace corr_ws_ze=corr_ws_ze*1/N2k

			*between occupation between firm/plant
			replace corr_bt_c=corr_bt_c*1/N2k
			replace corr_bt_n=corr_bt_n*1/N2k
			replace corr_bt_e=corr_bt_e*1/N2k
			replace corr_bt_ze=corr_bt_ze*1/N2k

			*within occupation between firm/plant
			replace corr_ba_c=corr_ba_c*1/N2k
			replace corr_ba_n=corr_ba_n*1/N2k
			replace corr_ba_e=corr_ba_e*1/N2k
			replace corr_ba_ze=corr_ba_ze*1/N2k

			*between firm/plant covariance (between and  within occ)  
			replace corr_bat_c=corr_bat_c*2/N2k
			replace corr_bat_n=corr_bat_n*2/N2k
			replace corr_bat_e=corr_bat_e*2/N2k
			replace corr_bat_ze=corr_bat_ze*2/N2k

			*between firm/plant total variance (consistancy)
			replace corr_bs_c=corr_bs_c*1/N2k
			replace corr_bs_n=corr_bs_n*1/N2k
			replace corr_bs_e=corr_bs_e*1/N2k
			replace corr_bs_ze=corr_bs_ze*1/N2k

			*between firm/plant total variance
			replace corr_btot_c=corr_btot_c*1/N2k
			replace corr_btot_n=corr_btot_n*1/N2k
			replace corr_btot_e=corr_btot_e*1/N2k
			replace corr_btot_ze=corr_btot_ze*1/N2k

			save temp/vardecomp_industry_`x'_`j'_`i',replace
		restore

		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*final uncorrected variances 

		*between occupation within firm/plant
		replace wt_c=wt_c*1/N2
		replace wt_n=wt_n*1/N2
		replace wt_e=wt_e*1/N2
		replace wt_ze=wt_ze*1/N2

		*within occupation within firm/plant
		replace wa_c=wa_c*1/N2
		replace wa_n=wa_n*1/N2
		replace wa_e=wa_e*1/N2
		replace wa_ze=wa_ze*1/N2

		*within firm/plant covariance (between and within occ)  
		replace wat_c=wat_c*2/N2
		replace wat_n=wat_n*2/N2
		replace wat_e=wat_e*2/N2
		replace wat_ze=wat_ze*2/N2

		*within firm/plant total variance
		replace wtot_c=wtot_c*1/N2
		replace wtot_n=wtot_n*1/N2
		replace wtot_e=wtot_e*1/N2
		replace wtot_ze=wtot_ze*1/N2

		*within firm/plant total variance (consistancy)
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between occupation between firm
		replace bt_c=bt_c*1/N2
		replace bt_n=bt_n*1/N2
		replace bt_e=bt_e*1/N2
		replace bt_ze=bt_ze*1/N2

		*within occupation between firm/plant 
		replace ba_c=ba_c*1/N2
		replace ba_n=ba_n*1/N2
		replace ba_e=ba_e*1/N2
		replace ba_ze=ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace bat_c=bat_c*2/N2
		replace bat_n=bat_n*2/N2
		replace bat_e=bat_e*2/N2
		replace bat_ze=bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*between firm/plant total variance
		replace btot_c=btot_c*1/N2
		replace btot_n=btot_n*1/N2
		replace btot_e=btot_e*1/N2
		replace btot_ze=btot_ze*1/N2

		*total between occ
		replace tt_c=tt_c*1/N2
		replace tt_n=tt_n*1/N2
		replace tt_e=tt_e*1/N2
		replace tt_ze=tt_ze*1/N2

		*total within occ
		replace ta_c=ta_c*1/N2
		replace ta_n=ta_n*1/N2
		replace ta_e=ta_e*1/N2
		replace ta_ze=ta_ze*1/N2

		*total variance (consistancy)
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*between occ within firm corrected
		replace corr_wt_c=corr_wt_c*1/N2
		replace corr_wt_n=corr_wt_n*1/N2
		replace corr_wt_e=corr_wt_e*1/N2
		replace corr_wt_ze=corr_wt_ze*1/N2

		*within occ within firm corrected
		replace corr_wa_c=corr_wa_c*1/N2
		replace corr_wa_n=corr_wa_n*1/N2
		replace corr_wa_e=corr_wa_e*1/N2
		replace corr_wa_ze=corr_wa_ze*1/N2

		*within firm covariance (between and within occ)  
		replace corr_wat_c=corr_wat_c*2/N2
		replace corr_wat_n=corr_wat_n*2/N2
		replace corr_wat_e=corr_wat_e*2/N2
		replace corr_wat_ze=corr_wat_ze*2/N2

		*within firm/plant total variance corrected
		replace corr_wtot_c=corr_wtot_c*1/N2
		replace corr_wtot_n=corr_wtot_n*1/N2
		replace corr_wtot_e=corr_wtot_e*1/N2
		replace corr_wtot_ze=corr_wtot_ze*1/N2

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between occupation between firm/plant
		replace corr_bt_c=corr_bt_c*1/N2
		replace corr_bt_n=corr_bt_n*1/N2
		replace corr_bt_e=corr_bt_e*1/N2
		replace corr_bt_ze=corr_bt_ze*1/N2

		*within occupation between firm/plant
		replace corr_ba_c=corr_ba_c*1/N2
		replace corr_ba_n=corr_ba_n*1/N2
		replace corr_ba_e=corr_ba_e*1/N2
		replace corr_ba_ze=corr_ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace corr_bat_c=corr_bat_c*2/N2
		replace corr_bat_n=corr_bat_n*2/N2
		replace corr_bat_e=corr_bat_e*2/N2
		replace corr_bat_ze=corr_bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*between firm/plant total variance
		replace corr_btot_c=corr_btot_c*1/N2
		replace corr_btot_n=corr_btot_n*1/N2
		replace corr_btot_e=corr_btot_e*1/N2
		replace corr_btot_ze=corr_btot_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/vardecomp_aggregate_`x'_`j'_`i',replace
		}
	}
}
	

*** Combine annual files to a main file
* Main aggregates to modified/vardecomp_aggregate_`x'_`j'

foreach x in ftg ast {
	foreach j in 10 25 50 100 200  {
	use temp/vardecomp_aggregate_`x'_`j'_1985,clear
		forvalues i=1986(1)2009{
		append using temp/vardecomp_aggregate_`x'_`j'_`i'
		}
	lab var ba_c "Within occupation between firm/plant"
	lab var bt_c "Between occupation between firm/plant"
	lab var bat_c "Between firm/plant covariance"
	lab var bs_c "Between firm/plant total"
	lab var btot_c "Between firm/plant total (consistancy)"

	lab var wa_c "Within occupation within firm/plant"
	lab var wt_c "Between occupation within firm/plant"
	lab var wat_c "Within firm/plant covariance"
	lab var ws_c "Within firm/plant total"
	lab var wtot_c "Within firm/plant total (consistancy)"

	lab var ta_c "Within occupation total"
	lab var tt_c "Between occupation total"
	lab var ts_c "Total"

	lab var ba_n "Within occupation between firm/plant"
	lab var bt_n "Between occupation between firm/plant"
	lab var bat_n "Between firm/plant covariance"
	lab var bs_n "Between firm/plant total"
	lab var btot_n "Between firm/plant total (consistancy)"

	lab var wa_n "Within occupation within firm/plant"
	lab var wt_n "Between occupation within firm/plant"
	lab var wat_n "Within firm/plant covariance"
	lab var ws_n "Within firm/plant total"
	lab var wtot_n "Within firm/plant total (consistancy)"

	lab var ta_n "Within occupation total"
	lab var tt_n "Between occupation total"
	lab var ts_n "Total"

	lab var ba_e "Within occupation between firm/plant"
	lab var bt_e "Between occupation between firm/plant"
	lab var bat_e "Between firm/plant covariance"
	lab var bs_e "Between firm/plant total"
	lab var btot_e "Between firm/plant total (consistancy)"

	lab var wa_e "Within occupation within firm/plant"
	lab var wt_e "Between occupation within firm/plant"
	lab var wat_e "Between firm/plant covariance"
	lab var ws_e "Within firm/plant total"
	lab var wtot_e "Within firm/plant total (consistancy)"

	lab var ta_e "Within occupation total"
	lab var tt_e "Between occupation total"
	lab var ts_e "Total"

	lab var ba_ze "Within occupation between firm/plant"
	lab var bt_ze "Between occupation between firm/plant"
	lab var bat_ze "Between firm/plant covariance"
	lab var bs_ze "Between firm/plant total"
	lab var btot_ze "Between firm/plant total (consistancy)"

	lab var wa_ze "Within occupation within firm/plant"
	lab var wt_ze "Between occupation within firm/plant"
	lab var wat_ze "Between firm/plant covariance"
	lab var ws_ze "Within firm/plant total"
	lab var wtot_ze "Within firm/plant total (consistancy)"

	lab var ta_ze "Within occupation total"
	lab var tt_ze "Between occupation total"
	lab var ts_ze "Total"

	lab var corr_ba_c "Within occupation between firm/plant (corrected)"
	lab var corr_bt_c "Between occupation between firm/plant (corrected)"
	lab var corr_bat_c "Between firm/plant covariance (corrected)"
	lab var corr_bs_c "Between firm/plant total (corrected)"
	lab var corr_btot_c "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_c "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_c "Between occupation within firm/plant (corrected)"
	lab var corr_wat_c "Within firm/plant covariance (corrected)"
	lab var corr_ws_c "Within firm/plant total (corrected)"
	lab var corr_wtot_c "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_n "Within occupation between firm/plant (corrected)"
	lab var corr_bt_n "Between occupation between firm/plant (corrected)"
	lab var corr_bat_n "Between firm covariance/plant (corrected)"
	lab var corr_bs_n "Between firm total/plant (corrected)"
	lab var corr_btot_n "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_n "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_n "Between occupation within firm/plant (corrected)"
	lab var corr_wat_n "Within firm/plant covariance (corrected)"
	lab var corr_ws_n "Within firm/plant total (corrected)"
	lab var corr_wtot_n "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_e "Within occupation between firm/plant (corrected)"
	lab var corr_bt_e "Between occupation between firm/plant (corrected)"
	lab var corr_bat_e "Between firm/plant covariance (corrected)"
	lab var corr_bs_e "Between firm/plant total (corrected)"
	lab var corr_btot_e "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_e "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_e "Between occupation within firm/plant (corrected)"
	lab var corr_wat_e "Within firm/plant covariance (corrected)"
	lab var corr_ws_e "Within firm/plant total (corrected)"
	lab var corr_wtot_e "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_ze "Within occupation between firm/plant (corrected)"
	lab var corr_bt_ze "Between occupation between firm/plant (corrected)"
	lab var corr_bat_ze "Between firm/plant covariance (corrected)"
	lab var corr_bs_ze "Between firm/plant total (corrected)"
	lab var corr_btot_ze "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_ze "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_ze "Between occupation within firm/plant (corrected)"
	lab var corr_wat_ze "Within firm/plant covariance (corrected)"
	lab var corr_ws_ze "Within firm/plant total (corrected)"
	lab var corr_wtot_ze "Within firm/plant total (consistancy) (corrected)"

	save modified/vardecomp_aggregate_`x'_`j',replace
	}
}		
		
		
		
*** Append 2:nd aggregates files to modified/vardecomp_bfwi_bi_`x'_`j'
clear
foreach x in ftg ast {
	foreach j in 10 25 50 100 200 {
	use temp/vardecomp_bfwi_bi_`x'_`j'_1985,clear
		forvalues i=1986(1)2009{
		append using temp/vardecomp_bfwi_bi_`x'_`j'_`i'
		}
	keep bi* btot* bfwi* corr_bi* corr_btot* year N2
	collapse (sum) btot* bfwi* corr_bi* corr_btot* bi* (mean) N2, by (year)

	replace btot_c=btot_c/N2
	replace bfwi_c=bfwi_c/N2
	replace bi_c=bi_c/N2
	replace corr_btot_c=corr_btot_c/N2
	replace corr_bi_c=corr_bi_c/N2

	replace btot_n=btot_n/N2
	replace bfwi_n=bfwi_n/N2
	replace bi_n=bi_n/N2
	replace corr_btot_n=corr_btot_n/N2
	replace corr_bi_n=corr_bi_n/N2

	replace btot_e=btot_e/N2
	replace bfwi_e=bfwi_e/N2
	replace bi_e=bi_e/N2
	replace corr_btot_e=corr_btot_e/N2
	replace corr_bi_e=corr_bi_e/N2

	replace btot_ze=btot_ze/N2
	replace bfwi_ze=bfwi_ze/N2
	replace bi_ze=bi_ze/N2
	replace corr_btot_ze=corr_btot_ze/N2
	replace corr_bi_ze=corr_bi_ze/N2
	
	g corr_bfwi_c=corr_btot_c-corr_bi_c
	g corr_bfwi_n=corr_btot_n-corr_bi_n
	g corr_bfwi_e=corr_btot_e-corr_bi_e
	g corr_bfwi_ze=corr_btot_ze-corr_bi_ze
	
	lab var btot_c "Between firm/plant total"
	lab var bfwi_c "Between firm/plant within industry"
	lab var bi_c "Between industry"
	lab var corr_btot_c "Between firm/plant total (corrected)"
	lab var corr_bi_c "Between industry (corrected)"
	lab var corr_bfwi_c "Between firm/plant within industry (corrected)"
	
	lab var btot_n "Between firm/plant total"
	lab var bfwi_n "Between firm/plant within industry"
	lab var bi_n "Between industry"
	lab var corr_btot_n "Between firm/plant total (corrected)"
	lab var corr_bi_n "Between industry (corrected)"
	lab var corr_bfwi_n "Between firm/plant within industry (corrected)"

	lab var btot_e "Between firm/plant total"
	lab var bfwi_e "Between firm/plant within industry"
	lab var bi_e "Between industry"
	lab var corr_btot_e "Between firm/plant total (corrected)"
	lab var corr_bi_e "Between industry (corrected)"
	lab var corr_bfwi_e "Between firm/plant within industry (corrected)"
	
	lab var btot_ze "Between firm/plant total"
	lab var bfwi_ze "Between firm/plant within industry"
	lab var bi_ze "Between industry"
	lab var corr_btot_ze "Between firm/plant total (corrected)"
	lab var corr_bi_ze "Between industry (corrected)"
	lab var corr_bfwi_ze "Between firm/plant within industry (corrected)"
	
	save modified/vardecomp_bfwi_bi_`x'_`j', replace	
	}
}

*** Append annual industry files to modified/vardecomp_industry_`x'_`j'
clear
foreach x in ftg ast {
	foreach j in 10  25 50 100 200 {
	use temp/vardecomp_industry_`x'_`j'_1985,clear
		forvalues i=1986(1)2009{
		append using temp/vardecomp_industry_`x'_`j'_`i'
		}
	keep b* w* t* c* n* e* z* corr* lnwpred* lnwage* year N* `x'sni2
	lab var ba_c "Within occupation between firm/plant. `x'size `j'"
	lab var bt_c "Between occupation between firm/plant. `x'size `j'"
	lab var bat_c "Between firm/plant covariance. `x'size `j'"
	lab var bs_c "Between firm/plant total. `x'size `j'"
	lab var btot_c "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_c "Within occupation within firm/plant. `x'size `j'"
	lab var wt_c "Between occupation within firm/plant. `x'size `j'"
	lab var wat_c "Within firm/plant covariance. `x'size `j'"
	lab var ws_c "Within firm/plant total. `x'size `j'"
	lab var wtot_c "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_c "Within occupation total. `x'size `j'"
	lab var tt_c "Between occupation total. `x'size `j'"
	lab var ts_c "Total. `x'size `j'"

	lab var ba_n "Within occupation between firm/plant. `x'size `j'"
	lab var bt_n "Between occupation between firm/plant. `x'size `j'"
	lab var bat_n "Between firm/plant covariance. `x'size `j'"
	lab var bs_n "Between firm/plant total. `x'size `j'"
	lab var btot_n "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_n "Within occupation within firm/plant. `x'size `j'"
	lab var wt_n "Between occupation within firm/plant. `x'size `j'"
	lab var wat_n "Within firm/plant covariance. `x'size `j'"
	lab var ws_n "Within firm/plant total. `x'size `j'"
	lab var wtot_n "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_n "Within occupation total. `x'size `j'"
	lab var tt_n "Between occupation total. `x'size `j'"
	lab var ts_n "Total. `x'size `j'"

	lab var ba_e "Within occupation between firm/plant. `x'size `j'"
	lab var bt_e "Between occupation between firm/plant. `x'size `j'"
	lab var bat_e "Between firm/plant covariance. `x'size `j'"
	lab var bs_e "Between firm/plant total. `x'size `j'"
	lab var btot_e "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_e "Within occupation within firm/plant. `x'size `j'"
	lab var wt_e "Between occupation within firm/plant. `x'size `j'"
	lab var wat_e "Between firm/plant covariance. `x'size `j'"
	lab var ws_e "Within firm/plant total. `x'size `j'"
	lab var wtot_e "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_e "Within occupation total. `x'size `j'"
	lab var tt_e "Between occupation total. `x'size `j'"
	lab var ts_e "Total. `x'size `j'"

	lab var ba_ze "Within occupation between firm/plant. `x'size `j'"
	lab var bt_ze "Between occupation between firm/plant. `x'size `j'"
	lab var bat_ze "Between firm/plant covariance. `x'size `j'"
	lab var bs_ze "Between firm/plant total. `x'size `j'"
	lab var btot_ze "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_ze "Within occupation within firm/plant. `x'size `j'"
	lab var wt_ze "Between occupation within firm/plant. `x'size `j'"
	lab var wat_ze "Between firm/plant covariance. `x'size `j'"
	lab var ws_ze "Within firm/plant total. `x'size `j'"
	lab var wtot_ze "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_ze "Within occupation total. `x'size `j'"
	lab var tt_ze "Between occupation total. `x'size `j'"
	lab var ts_ze "Total. `x'size `j'"

	lab var corr_ba_c "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_c "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_c "Between firm/plant covariance (corrected). `x'size `j'"
	lab var corr_bs_c "Between firm/plant total (corrected). `x'size `j'"
	lab var corr_btot_c "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_c "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_c "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_c "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_c "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_c "Within firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_ba_n "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_n "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_n "Between firm covariance/plant (corrected). `x'size `j'"
	lab var corr_bs_n "Between firm total/plant (corrected). `x'size `j'"
	lab var corr_btot_n "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_n "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_n "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_n "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_n "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_n "Within firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_ba_e "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_e "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_e "Between firm/plant covariance (corrected). `x'size `j'"
	lab var corr_bs_e "Between firm/plant total (corrected). `x'size `j'"
	lab var corr_btot_e "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_e "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_e "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_e "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_e "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_e "Within firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_ba_ze "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_ze "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_ze "Between firm/plant covariance (corrected). `x'size `j'"
	lab var corr_bs_ze "Between firm/plant total (corrected). `x'size `j'"
	lab var corr_btot_ze "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_ze "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_ze "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_ze "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_ze "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_ze "Within firm/plant total (consistancy) (corrected). `x'size `j'"
	save modified/vardecomp_industry_`x'_`j', replace	
	}
}

*** Append annual firm/plant files to modified/vardecomp_unit_`x'_`j'

foreach x in ast ftg {
	foreach j in 10 25 50 100 200 {
	use temp/vardecomp_unit_`x'_`j'_1985,clear
		forvalues i=1986(1)2009{
		append using temp/vardecomp_unit_`x'_`j'_`i'
		}
	keep b* w* t* c* n* e* z* corr* lnwpred* lnwage* year ftgstorl_`x' N* `x'nr ast_ftg `x'sni2
	lab var ast_ftg "Firm matched to highest income plant"
	lab var ba_c "Within occupation between firm/plant. `x'size `j'"
	lab var bt_c "Between occupation between firm/plant. `x'size `j'"
	lab var bat_c "Between firm/plant covariance. `x'size `j'"
	lab var bs_c "Between firm/plant total. `x'size `j'"
	lab var btot_c "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_c "Within occupation within firm/plant. `x'size `j'"
	lab var wt_c "Between occupation within firm/plant. `x'size `j'"
	lab var wat_c "Within firm/plant covariance. `x'size `j'"
	lab var ws_c "Within firm/plant total. `x'size `j'"
	lab var wtot_c "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_c "Within occupation total. `x'size `j'"
	lab var tt_c "Between occupation total. `x'size `j'"
	lab var ts_c "Total. `x'size `j'"

	lab var ba_n "Within occupation between firm/plant. `x'size `j'"
	lab var bt_n "Between occupation between firm/plant. `x'size `j'"
	lab var bat_n "Between firm/plant covariance. `x'size `j'"
	lab var bs_n "Between firm/plant total. `x'size `j'"
	lab var btot_n "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_n "Within occupation within firm/plant. `x'size `j'"
	lab var wt_n "Between occupation within firm/plant. `x'size `j'"
	lab var wat_n "Within firm/plant covariance. `x'size `j'"
	lab var ws_n "Within firm/plant total. `x'size `j'"
	lab var wtot_n "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_n "Within occupation total. `x'size `j'"
	lab var tt_n "Between occupation total. `x'size `j'"
	lab var ts_n "Total. `x'size `j'"

	lab var ba_e "Within occupation between firm/plant. `x'size `j'"
	lab var bt_e "Between occupation between firm/plant. `x'size `j'"
	lab var bat_e "Between firm/plant covariance. `x'size `j'"
	lab var bs_e "Between firm/plant total. `x'size `j'"
	lab var btot_e "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_e "Within occupation within firm/plant. `x'size `j'"
	lab var wt_e "Between occupation within firm/plant. `x'size `j'"
	lab var wat_e "Between firm/plant covariance. `x'size `j'"
	lab var ws_e "Within firm/plant total. `x'size `j'"
	lab var wtot_e "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_e "Within occupation total. `x'size `j'"
	lab var tt_e "Between occupation total. `x'size `j'"
	lab var ts_e "Total. `x'size `j'"

	lab var ba_ze "Within occupation between firm/plant. `x'size `j'"
	lab var bt_ze "Between occupation between firm/plant. `x'size `j'"
	lab var bat_ze "Between firm/plant covariance. `x'size `j'"
	lab var bs_ze "Between firm/plant total. `x'size `j'"
	lab var btot_ze "Between firm/plant total (consistancy). `x'size `j'"

	lab var wa_ze "Within occupation within firm/plant. `x'size `j'"
	lab var wt_ze "Between occupation within firm/plant. `x'size `j'"
	lab var wat_ze "Between firm/plant covariance. `x'size `j'"
	lab var ws_ze "Within firm/plant total. `x'size `j'"
	lab var wtot_ze "Within firm/plant total (consistancy). `x'size `j'"

	lab var ta_ze "Within occupation total. `x'size `j'"
	lab var tt_ze "Between occupation total. `x'size `j'"
	lab var ts_ze "Total. `x'size `j'"

	lab var corr_ba_c "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_c "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_c "Between firm/plant covariance (corrected). `x'size `j'"
	lab var corr_bs_c "Between firm/plant total (corrected). `x'size `j'"
	lab var corr_btot_c "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_c "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_c "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_c "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_c "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_c "Within firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_ba_n "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_n "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_n "Between firm covariance/plant (corrected). `x'size `j'"
	lab var corr_bs_n "Between firm total/plant (corrected). `x'size `j'"
	lab var corr_btot_n "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_n "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_n "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_n "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_n "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_n "Within firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_ba_e "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_e "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_e "Between firm/plant covariance (corrected). `x'size `j'"
	lab var corr_bs_e "Between firm/plant total (corrected). `x'size `j'"
	lab var corr_btot_e "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_e "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_e "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_e "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_e "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_e "Within firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_ba_ze "Within occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bt_ze "Between occupation between firm/plant (corrected). `x'size `j'"
	lab var corr_bat_ze "Between firm/plant covariance (corrected). `x'size `j'"
	lab var corr_bs_ze "Between firm/plant total (corrected). `x'size `j'"
	lab var corr_btot_ze "Between firm/plant total (consistancy) (corrected). `x'size `j'"

	lab var corr_wa_ze "Within occupation witin firm/plant (corrected). `x'size `j'"
	lab var corr_wt_ze "Between occupation within firm/plant (corrected). `x'size `j'"
	lab var corr_wat_ze "Within firm/plant covariance (corrected). `x'size `j'"
	lab var corr_ws_ze "Within firm/plant total (corrected). `x'size `j'"
	lab var corr_wtot_ze "Within firm/plant total (consistancy) (corrected). `x'size `j'"	
	save modified/vardecomp_unit_`x'_`j', replace	
	}
}

*** Combine aggregate annual files into one
* vardecomp
foreach x in ftg ast {
	foreach j in 10 25 50 100 200 {
	use modified/vardecomp_aggregate_`x'_`j',clear
	keep year tt_c tt_n tt_e tt_ze ta_c ta_n ta_e ta_ze ts_c ts_n ts_e ts_ze corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_ws_c corr_ws_n corr_ws_e corr_ws_ze corr_wt_c corr_wt_n corr_wt_e corr_wt_ze corr_wa_c corr_wa_n corr_wa_e corr_wa_ze corr_wat_c corr_wat_n corr_wat_e corr_wat_ze corr_wtot_c corr_wtot_n corr_wtot_e corr_wtot_ze corr_bs_c corr_bs_n corr_bs_e corr_bs_ze corr_bt_c corr_bt_n corr_bt_e corr_bt_ze corr_ba_c corr_ba_n corr_ba_e corr_ba_ze corr_bat_c corr_bat_n corr_bat_e corr_bat_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze corr_bcov corr_wcov N lnwpred lnwage N2
	foreach v in tt_c tt_n tt_e tt_ze ta_c ta_n ta_e ta_ze ts_c ts_n ts_e ts_ze corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_ws_c corr_ws_n corr_ws_e corr_ws_ze corr_wt_c corr_wt_n corr_wt_e corr_wt_ze corr_wa_c corr_wa_n corr_wa_e corr_wa_ze corr_wat_c corr_wat_n corr_wat_e corr_wat_ze corr_wtot_c corr_wtot_n corr_wtot_e corr_wtot_ze corr_bs_c corr_bs_n corr_bs_e corr_bs_ze corr_bt_c corr_bt_n corr_bt_e corr_bt_ze corr_ba_c corr_ba_n corr_ba_e corr_ba_ze corr_bat_c corr_bat_n corr_bat_e corr_bat_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze corr_bcov corr_wcov N lnwpred lnwage N2 {
		rename `v' `v'_`x'_`j'
		}
	save temp/vardecomp_aggregate_`x'_`j', replace
	}
}	

use temp/vardecomp_aggregate_ftg_10,clear
merge 1:1 year using temp/vardecomp_aggregate_ast_10
drop _merge
foreach x in ftg ast {
	foreach j in 25 50 100 200 {
	merge 1:1 year using temp/vardecomp_aggregate_`x'_`j'
	drop _merge
	}
}	
save modified/vardecomp_aggregate,replace

* vardecomp_bfwi_bi
foreach x in ftg ast {
	foreach j in 10 25 50 100 200 {
	use modified/vardecomp_bfwi_bi_`x'_`j',clear
	keep year corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze N2 corr_bfwi_c corr_bfwi_n corr_bfwi_e corr_bfwi_ze
	foreach v in corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze N2 corr_bfwi_c corr_bfwi_n corr_bfwi_e corr_bfwi_ze {
		rename `v' `v'_`x'_`j'
		}
	save temp/vardecomp_bfwi_bi_`x'_`j', replace
	}
}	

use temp/vardecomp_bfwi_bi_ftg_10,clear
merge 1:1 year using temp/vardecomp_bfwi_bi_ast_10
drop _merge
foreach x in ftg ast {
	foreach j in 25 50 100 200 {
	merge 1:1 year using temp/vardecomp_bfwi_bi_`x'_`j'
	drop _merge
	}
}	
save modified/vardecomp_bfwi_bi,replace

	
* Various alternative sample restrictions
* All done for both ftg and ast
* All done with firm size restrictions 10 and 50
* modified/vardecomp_aggregate_robust
* modified/vardecomp_bfwi_bi_robust

* Sample restrictions s:
* A: Skill distribution beta24
* B: Skill distribution beta42
* C: Skill distribution uniforms
* D: Dropping Computer and related activities (SNI2=72)
* E: Dropping Computer and related activities (SNI2=72 and SNI2=32)
* F: Dropping eningeers 
* G: Dropping eningeers and technicians
* H: Dropping Business Administration and law professionals
* I: Only manufacturing SNI2>=15 & SNI2<=37
* J: Only services SNI2>37
* K: 30-45 year olds (only years 1996-2008) 
* L: Including females
* M: Including non-private firms, removing care, education and gov't services (SNI2=75, 80, 85, 99)  
* N: Excluding financial sector (SNI65-67)
* O: Dropping pg (cog) <2
* P: Dropping pf (noncog) <2
	
  
set more off

****** Rewieghted analysis based on cog and concog weights to match population samples *****

foreach s in Q {
	* ast
	foreach x in ftg {
		* 50
		foreach j in 10 {
			* 2009
			forvalues i=1985(1)2009 {
				use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' `x'nr `x'sni* year using modified/sample`i', clear
				*** Generic manipulations
				gen s="`s'"
				* Drop firms/plants without identifiers
				drop if `x'nr==""
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
				* Generate count variable
				g count=1
				* Generate the equivalence of Nj (all employees in sample firms/plants)
				bysort `x'nr: egen Nj=total(count)	
				
				* Keep sample
				keep if sample_3035_`j'_`x'==1

				* Merge pg
				merge 1:1 lopnr using modified/enlistment.dta, keepus(pg pf enlistyr)
				keep if _merge==3
				drop _merge

				* Drop enlistment years with very few obs
				bysort enlistyr: egen empty=count(c)
				drop if empty<150
				
				* Count number in each enlistment cohort/c/n group
				bysort enlistyr pg: egen c_group_count_sample=count(c)
				bysort enlistyr pf: egen n_group_count_sample=count(n)
								
				* Add population number in each cohort/c/n group
				merge m:1 enlistyr pg using modified/c_weights
				keep if _merge==3
				drop _merge
				merge m:1 enlistyr pf using modified/n_weights
				keep if _merge==3
				drop _merge
				
				* Generate weights
				gen cogw_t=c_group_count_pop/c_group_count_sample
				egen cogw_m=mean(cogw_t)
				gen cogw=cogw_t/cogw_m
				drop cogw_t cogw_m
				gen noncogw_t=n_group_count_pop/n_group_count_sample
				egen noncogw_m=mean(noncogw_t)
				gen noncogw=noncogw_t/noncogw_m
				drop noncogw_t noncogw_m
				
				* Generate weighted components
				gen cw=c*cogw
				gen nw=n*noncogw
				gen count_cw=count*cogw
				gen count_nw=count*noncogw
				
				***Actual skill means
				*industry
				bysort `x'sni2: egen ck=mean(cw) 
				bysort `x'sni2: egen nk=mean(nw) 

				*firm/plant
				bysort `x'nr: egen cj=mean(cw) 
				bysort `x'nr: egen nj=mean(nw) 

				*sample
				egen cbar=mean(cw)
				egen nbar=mean(nw)

				*Observed samples and sizes
				bysort `x'nr: egen N2j_cw=sum(count_cw)
				bysort `x'nr: egen N2j_nw=sum(count_nw)
				egen N2_cw=sum(count_cw) 
				egen N2_nw=sum(count_nw)

				***Components for (corrected and uncorrected) variances (to be collapsed)

				*within firm total variance (consistancy check)
				g ws_c=cogw*(c-cj)^2
				g ws_n=noncogw*(n-nj)^2

				*between firm total variance (consistancy check)
				g bs_c=(cj-cbar)^2
				g bs_n=(nj-nbar)^2

				*total variance (consistancy check)
				g ts_c=cogw*(c-cbar)^2
				g ts_n=noncogw*(n-nbar)^2

				*** B.Collapse to firm/plant level
				collapse (sum) w* t* c n cw nw (mean) b* ftgstorl_`x' Nj N2j_* N2_* cj nj ck nk cbar nbar, by (year `x'nr `x'sni2)

				*sample correction firm/plant level
				g thetaj_w_cw=((Nj-1)/Nj)*(1/(N2j_cw-1))
				g thetaj_w_nw=((Nj-1)/Nj)*(1/(N2j_nw-1))
				
				g thetaj_b_cw=((Nj-N2j_cw)/(Nj*N2j_cw))*(1/(N2j_cw-1))
				g thetaj_b_nw=((Nj-N2j_nw)/(Nj*N2j_nw))*(1/(N2j_nw-1))

				*components for corrected variances

				*within firm/plant total variance corrected 
				g corr_ws_c=ws_c*thetaj_w_cw*N2j_cw
				g corr_ws_n=ws_n*thetaj_w_nw*N2j_nw

				*between firm/plant total variance corrected (consistancy check)
				g corr_bs_c=N2j_cw*(bs_c-thetaj_b_cw*ws_c)
				g corr_bs_n=N2j_nw*(bs_n-thetaj_b_nw*ws_n)


				*** Components for uncorrected variances

				*between firm/plant total variance (consistancy check of total variance demcomp)
				replace bs_c=bs_c*N2j_cw
				replace bs_n=bs_n*N2j_nw

				*** 4. Overall collapse

				collapse (sum) w* b* t* corr* N=Nj (mean) N2_cw N2_nw, by(year)

				*final uncorrected variances 

				*within firm/plant total variance (consistancy)
				replace ws_c=ws_c*1/N2_cw
				replace ws_n=ws_n*1/N2_nw

				*between firm/plant total variance (consistancy)
				replace bs_c=bs_c*1/N2_cw
				replace bs_n=bs_n*1/N2_nw

				*total variance (consistancy)
				replace ts_c=ts_c*1/N2_cw
				replace ts_n=ts_n*1/N2_nw

				*within firm/plant total variance corrected (concistancy)
				replace corr_ws_c=corr_ws_c*1/N2_cw
				replace corr_ws_n=corr_ws_n*1/N2_nw

				*between firm/plant total variance (consistancy)
				replace corr_bs_c=corr_bs_c*1/N2_cw
				replace corr_bs_n=corr_bs_n*1/N2_nw

				save temp/vardecomp_aggregate_`s'_`x'_`j'_`i',replace
			}
		}
	}
}

use temp/vardecomp_aggregate_Q_ftg_10_1985,clear
	forvalues i=1986(1)2009 {
	append using  temp/vardecomp_aggregate_Q_ftg_10_`i'
}
	
*   
foreach s in A B C D E F G H I J K L M N O P {
	foreach x in ftg ast {
		foreach j in 10 50 {
			forvalues i=1985(1)2009 {
				use lopnr fos fos_detail edyr zedyr c n n_uni c_uni n_beta24 c_beta24 n_beta42 c_beta42 sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' `x'nr `x'sni* year using modified/sample`i', clear	
				*** Generic manipulations
				gen s="`s'"
				* Drop firms/plants without identifiers
				drop if `x'nr==""
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
				* Generate count variable
				g count=1
				* Generate the equivalence of Nj (all employees in sample firms/plants)
				bysort `x'nr: egen Nj=total(count)	
				
				* Sample restrictions
				if s=="A" {
					drop c n
					rename c_beta24 c
					rename n_beta24 n
					keep if sample_3035_`j'_`x'==1
					}
				if s=="B" {	
					drop c n
					rename c_beta42 c
					rename n_beta42 n
					keep if sample_3035_`j'_`x'==1
					}
				if s=="C" {
					drop c n c_uni n_uni
					merge 1:1 lopnr temp/alternative_skills.dta, keepus(c_uni n_uni)
					drop if _merge==2
					drop _merge
					rename c_uni c
					rename n_uni n
					keep if sample_3035_`j'_`x'==1
					}
				if s=="D" {
					drop if `x'sni2==72
					keep if sample_3035_`j'_`x'==1
					}
				if s=="E" {
					drop if `x'sni2==72
					drop if `x'sni2==32
					keep if sample_3035_`j'_`x'==1
					}
				if s=="F" {
					keep if sample_3035_`j'_`x'==1
					gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
					replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
					replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
					replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
					replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.

					gen engineer=0 if edyr~=. & fos~=.
					replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
					label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"

					gen technician=0 if edyr~=. & fos~=.
					replace technician=1 if edlevel>=3 & (fos_detail==48 | fos_detail==52 | fos_detail==54 | fos_detail==58)
					label var technician "At least 3-year secondary. Includes both 'engeneering' and 'computing'"

					drop if engineer==1
					drop edlevel engineer technician
					}
				if s=="G" {
					keep if sample_3035_`j'_`x'==1
					gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
					replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
					replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
					replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
					replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.

					gen engineer=0 if edyr~=. & fos~=.
					replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
					label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"

					gen technician=0 if edyr~=. & fos~=.
					replace technician=1 if edlevel>=3 & (fos_detail==48 | fos_detail==52 | fos_detail==54 | fos_detail==58)
					label var technician "At least 3-year secondary. Includes both 'engeneering' and 'computing'"

					drop if engineer==1
					drop if technician==1
					drop edlevel engineer technician
					}
				if s=="H" {
					keep if sample_3035_`j'_`x'==1
					g ba_law=0
					replace ba_law=1 if (fos_detail==38|fos_detail==34) & edyr>=15 
					drop if ba_law==1
					drop ba_law
					}
				if s=="I" {
					keep if sample_3035_`j'_`x'==1
					drop if `x'sni2<15
					drop if `x'sni2>37
					}
				if s=="J" {
					keep if sample_3035_`j'_`x'==1
					keep if `x'sni2>37
					}
				if s=="K" {	
					gen sample_`x'_`j'=0
					replace sample_`x'_`j'=1 if age>= 30 & age<= 45 & ftgstorl_`x'>=`j' & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_`x'==1
					drop if sample_`x'_`j'==0
					* At least two employees
					bysort `x'nr: egen sample_`x'=sum(sample_`x'_`j') 
					replace sample_`x'_`j'=0 if sample_`x'<=1
					drop if sample_`x'_`j'==0
					drop sample_`x'_`j' sample_`x'
					}
				if s=="L" {
					gen sample_`x'_`j'=0
					replace sample_`x'_`j'=1 if age>= 30 & age<=35 & ftgstorl_`x'>=`j' & ftgstorl_`x'~=. & n!=. & c!=. & edyr!=. & privfirm_`x'==1
					drop if sample_`x'_`j'==0
					* At least two employees
					bysort `x'nr: egen sample_`x'=sum(sample_`x'_`j')
					replace sample_`x'_`j'=0 if sample_`x'<=1
					drop if sample_`x'_`j'==0
					drop sample_`x'_`j' sample_`x'
					}
				if s=="M" {	
					drop if `x'sni2==75 |`x'sni2==80 |`x'sni2==85 | `x'sni2==99 
					gen sample_`x'_`j'=0
					replace sample_`x'_`j'=1 if age>= 30 & age<= 35 & ftgstorl_`x'>=`j' & ftgstorl_`x'~=. & sex=="1" & n!=. & c!=. & edyr!=.
					drop if sample_`x'_`j'==0
					* At least two employees
					bysort `x'nr: egen sample_`x'=sum(sample_`x'_`j')
					replace sample_`x'_`j'=0 if sample_`x'<=1
					drop if sample_`x'_`j'==0
					drop sample_`x'_`j' sample_`x'
					}
				if s=="N" {
					keep if sample_3035_`j'_`x'==1
					drop if `x'sni2>=65 & `x'sni2<=67
					}
				if s=="O" {
					keep if sample_3035_`j'_`x'==1
					merge 1:1 lopnr using modified/enlistment.dta, keepus(pg)
					keep if _merge==3
					drop _merge
					drop if pg<2
					}
				if s=="P" {
					keep if sample_3035_`j'_`x'==1
					merge 1:1 lopnr using modified/enlistment.dta, keepus(pf)
					keep if _merge==3
					drop _merge
					drop if pf<2
					}

				
				*This part generate occupation proxy by combining field of study and level of education
				gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
				replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
				replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
				replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
				replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
				lab def edlevellab 1 "Compulsory schooling or less"
				lab def edlevellab 2 "2-year secondary",add 
				lab def edlevellab 3 "3-year secondary",add 
				lab def edlevellab 4 "Some tertiary",add 
				lab def edlevellab 5 "At least 3-year tertiary",add 
				lab val edlevel edlevellab
				egen yrke=group(edlevel fos_detail)

				***Actual skill means
				*industry
				bysort `x'sni2: egen ck=mean(c) 
				bysort `x'sni2: egen nk=mean(n) 
				bysort `x'sni2: egen ek=mean(edyr)
				bysort `x'sni2: egen zek=mean(zedyr)
				bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
				bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

				*firm/plant
				bysort `x'nr: egen cj=mean(c) 
				bysort `x'nr: egen nj=mean(n) 
				bysort `x'nr: egen ej=mean(edyr)
				bysort `x'nr: egen zej=mean(zedyr) 
				bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
				bysort `x'nr: egen lnwagej=mean(lnwage_`x')

				*firm/plant yrke
				bysort `x'nr yrke: egen chj=mean(c) 
				bysort `x'nr yrke: egen nhj=mean(n) 
				bysort `x'nr yrke: egen ehj=mean(edyr)
				bysort `x'nr yrke: egen zehj=mean(zedyr) 

				*yrke
				bysort yrke: egen ch=mean(c) 
				bysort yrke: egen nh=mean(n) 
				bysort yrke: egen eh=mean(edyr) 
				bysort yrke: egen zeh=mean(zedyr) 

				*sample
				egen cbar=mean(c)
				egen nbar=mean(n)
				egen ebar=mean(edyr)
				egen zebar=mean(zedyr)
				egen lnwpredbar=mean(lnwpred_`x')
				egen lnwagebar=mean(lnwage_`x')

				*Observed samples and sizes
				bysort `x'nr yrke: egen N2hj=total(count) 
				bysort yrke: egen N2h=total(count) 
				bysort `x'nr: egen N2j=total(count) 
				egen N2=total(count) 

				***Predicted skills
				*individual
				areg c, absorb(yrke)
				predict cijtilde if e(sample),xbd
				predict cijres if e(sample), resid
				areg n, absorb(yrke)
				predict nijtilde if e(sample),xbd
				predict nijres if e(sample), resid
				areg edyr, absorb(yrke)
				predict eijtilde if e(sample), xbd
				predict eijres if e(sample), resid
				areg zedyr, absorb(yrke)
				predict zeijtilde if e(sample), xbd
				predict zeijres if e(sample), resid

				bysort `x'nr: egen cjres=mean(cijres)
				bysort `x'nr: egen njres=mean(nijres)
				bysort `x'nr: egen ejres=mean(eijres)
				bysort `x'nr: egen zejres=mean(zeijres)

				g cjtilde=cj-cjres
				g njtilde=nj-njres
				g ejtilde=ej-ejres
				g zejtilde=zej-zejres

				rename edyr e
				rename zedyr ze

				***Components for (corrected and uncorrected) variances (to be collapsed)

				*between occupation within firm/plant  
				g wt_c=(cijtilde-cjtilde)^2
				g wt_n=(nijtilde-njtilde)^2
				g wt_e=(eijtilde-ejtilde)^2
				g wt_ze=(zeijtilde-zejtilde)^2

				*within occupation within plant 
				g wa_c=((c-cijtilde)-(cj-cjtilde))^2
				g wa_n=((n-nijtilde)-(nj-njtilde))^2
				g wa_e=((e-eijtilde)-(ej-ejtilde))^2
				g wa_ze=((ze-zeijtilde)-(zej-zejtilde))^2

				*within firm total variance (consistancy check)
				g ws_c=(c-cj)^2
				g ws_n=(n-nj)^2
				g ws_e=(e-ej)^2
				g ws_ze=(ze-zej)^2

				*within firm covariance (between and witin occ) 
				g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
				g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
				g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))
				g wat_ze=(zeijtilde-zejtilde)*((ze-zeijtilde)-(zej-zejtilde))

				*within firm total variance (to check results should after collapsed be equal to ws_X )
				g wtot_c=wt_c+wa_c+2*wat_c
				g wtot_n=wt_n+wa_n+2*wat_n
				g wtot_e=wt_e+wa_e+2*wat_e
				g wtot_ze=wt_ze+wa_ze+2*wat_ze

				* between occupation between firm
				g bt_c=(cjtilde-cbar)^2
				g bt_n=(njtilde-nbar)^2
				g bt_e=(ejtilde-ebar)^2
				g bt_ze=(zejtilde-zebar)^2

				*within occupation between firm 
				g ba_c=(cj-cjtilde)^2
				g ba_n=(nj-njtilde)^2
				g ba_e=(ej-ejtilde)^2
				g ba_ze=(zej-zejtilde)^2

				*between firm total variance (consistancy check)
				g bs_c=(cj-cbar)^2
				g bs_n=(nj-nbar)^2
				g bs_e=(ej-ebar)^2
				g bs_ze=(zej-zebar)^2

				*between firm covariance (within andd between occ)
				g bat_c=(cjtilde-cbar)*(cj-cjtilde)
				g bat_n=(njtilde-nbar)*(nj-njtilde)
				g bat_e=(ejtilde-ebar)*(ej-ejtilde)
				g bat_ze=(zejtilde-zebar)*(zej-zejtilde)

				*between firm total variance 
				g btot_c=bt_c+ba_c+2*bat_c
				g btot_n=bt_n+ba_n+2*bat_n
				g btot_e=bt_e+ba_e+2*bat_e
				g btot_ze=bt_ze+ba_ze+2*bat_ze

				*total between occupation
				g tt_c=(cijtilde-cbar)^2 
				g tt_n=(nijtilde-nbar)^2 
				g tt_e=(eijtilde-ebar)^2 
				g tt_ze=(zeijtilde-zebar)^2 

				*total within occupation
				g ta_c=(c-cijtilde)^2
				g ta_n=(n-nijtilde)^2
				g ta_e=(e-eijtilde)^2
				g ta_ze=(ze-zeijtilde)^2

				*total variance (consistancy check)
				g ts_c=(c-cbar)^2
				g ts_n=(n-nbar)^2
				g ts_e=(e-ebar)^2
				g ts_ze=(ze-zebar)^2
	
				*covariance CS NCS
				g wcov=(c-cj)*(n-nj)	

				*component for corr_between industry (this goes into the industry matrix)
				g corr_bi_c=(c-ck)^2
				g corr_bi_n=(n-nk)^2
				g corr_bi_e=(e-ek)^2
				g corr_bi_ze=(ze-zek)^2

				*** B.Collapse to firm/plant level
				collapse (sum) w* t* cijtilde nijtilde eijtilde zeijtilde cijres nijres eijres zeijres c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 cj nj ej zej cjtilde njtilde ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

				*sample correction firm/plant level
				g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
				g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

				*components for corrected variances

				*within firm/plant total variance corrected 
				g corr_ws_c=ws_c*thetaj_w*N2j
				g corr_ws_n=ws_n*thetaj_w*N2j
				g corr_ws_e=ws_e*thetaj_w*N2j
				g corr_ws_ze=ws_ze*thetaj_w*N2j

				* between occ within firm/plant corrected
				g corr_wt_c=wt_c*thetaj_w*N2j
				g corr_wt_n=wt_n*thetaj_w*N2j
				g corr_wt_e=wt_e*thetaj_w*N2j
				g corr_wt_ze=wt_ze*thetaj_w*N2j

				*within occ within firm/plant corrected
				g corr_wa_c=wa_c*thetaj_w*N2j
				g corr_wa_n=wa_n*thetaj_w*N2j
				g corr_wa_e=wa_e*thetaj_w*N2j
				g corr_wa_ze=wa_ze*thetaj_w*N2j

				*within firm/plant covariance (between and within occ) corrected
				g corr_wat_c=wat_c*thetaj_w*N2j
				g corr_wat_n=wat_n*thetaj_w*N2j
				g corr_wat_e=wat_e*thetaj_w*N2j
				g corr_wat_ze=wat_ze*thetaj_w*N2j

				*within firm/plant total variance corrected
				g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
				g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
				g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e
				g corr_wtot_ze=corr_wt_ze+corr_wa_ze+2*corr_wat_ze

				*between firm/plant total variance corrected (consistancy check)
				g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
				g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
				g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
				g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

				*between occ between firm/plant corrected
				g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
				g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
				g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)
				g corr_bt_ze=N2j*(bt_ze-thetaj_b*wt_ze)

				*within occ between firm/plant corrected
				g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
				g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
				g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)
				g corr_ba_ze=N2j*(ba_ze-thetaj_b*wa_ze)

				*between firm/plant covariance (between and within occ)  corrected
				g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
				g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
				g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)
				g corr_bat_ze=N2j*(bat_ze-thetaj_b*wat_ze)

				*between firm/plant total variance corrected
				g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
				g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
				g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e
				g corr_btot_ze=corr_bt_ze+corr_ba_ze+2*corr_bat_ze

				*covariance CS NCS corrected
				g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
				g corr_wcov=N2j*thetaj_w*wcov

				*** Firm/plant level data set for use in regressions. 
				preserve
					keep corr* b* w* t* cjtilde njtilde cj nj ej zej lnwpredj lnwagej cbar nbar ebar zebar lnwpredbar lnwagebar ftgstorl_`x' Nj N2j N2 `x'nr year `x'sni2
					lab var lnwpredj "Firm/plant wpred. Sample `s', `x'size `j'"
					lab var lnwagej "Firm/plant SWS wage. Sample `s', `x'size `j'"
					lab var lnwpredbar "Sample mean wpred. Sample `s', `x'size `j'"
					lab var lnwagebar "Sample mean SWS wage. Sample `s', `x'size `j'"
					save temp/vardecomp_unit_`s'_`x'_`j'_`i',replace
				restore

				*** Components for uncorrected variances
				* between occupation between firm/plant
				replace bt_c=bt_c*N2j
				replace bt_n=bt_n*N2j
				replace bt_e=bt_e*N2j
				replace bt_ze=bt_ze*N2j

				* within occupation between firm/plant
				replace ba_c=ba_c*N2j
				replace ba_n=ba_n*N2j
				replace ba_e=ba_e*N2j
				replace ba_ze=ba_ze*N2j

				*between firm/plant covariance (between and within occupation)
				replace bat_c=bat_c*N2j
				replace bat_n=bat_n*N2j
				replace bat_e=bat_e*N2j
				replace bat_ze=bat_ze*N2j

				*between firm/plant total variance (consistancy check of total variance demcomp)
				replace bs_c=bs_c*N2j
				replace bs_n=bs_n*N2j
				replace bs_e=bs_e*N2j
				replace bs_ze=bs_ze*N2j

				*between firm/plant total variance
				replace btot_c=btot_c*N2j
				replace btot_n=btot_n*N2j
				replace btot_e=btot_e*N2j
				replace btot_ze=btot_ze*N2j

				*covariance CS NCS
				g bcov=N2j*(cj-cbar)*(nj-nbar)

				*** D. Collapse to industry level for use in regressions. 
				preserve
		
				*components for between-firm/plant within-industry variance
				g bfwi_c=N2j*(cj-ck)^2
				g bfwi_n=N2j*(nj-nk)^2
				g bfwi_e=N2j*(ej-ek)^2
				g bfwi_ze=N2j*(zej-zek)^2

				collapse (sum) w* b* t* corr* cktilde=cijtilde nktilde=nijtilde ektilde=eijtilde zektilde=zeijtilde ckres=cijres nkres=nijres ekres=eijres zekres=zeijres Nk=Nj N2k=N2j (mean) N2 ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by(year `x'sni2)

				*sample correction industry level
				g thetak=((Nk-N2k)/(N2k*Nk))*(1/(N2k-1))

				*components for bfwi variance and bi variance
				replace corr_bi_c=N2k*((ck-cbar)^2-thetak*corr_bi_c)
				replace corr_bi_n=N2k*((nk-nbar)^2-thetak*corr_bi_n)
				replace corr_bi_e=N2k*((ek-ebar)^2-thetak*corr_bi_e)
				replace corr_bi_ze=N2k*((zek-zebar)^2-thetak*corr_bi_ze)

				g bi_c=N2k*(ck-cbar)^2
				g bi_n=N2k*(nk-nbar)^2
				g bi_e=N2k*(ek-ebar)^2
				g bi_ze=N2k*(zek-zebar)^2

				save temp/vardecomp_bfwi_bi_`s'_`x'_`j'_`i',replace
				drop bi* bfwi* corr_bi* 

				*note: predicted skills have been summed up from individual level => divide by N2K to get average industry skill
				replace cktilde=cktilde/N2k
				replace nktilde=nktilde/N2k
				replace ektilde=ektilde/N2k
				replace zektilde=zektilde/N2k

				replace ckres=ckres/N2k
				replace nkres=nkres/N2k
				replace ekres=ekres/N2k
				replace zekres=zekres/N2k

				***final industry level uncorrected variances

				* between occupation within firm/plant
				replace wt_c=wt_c*1/N2k
				replace wt_n=wt_n*1/N2k
				replace wt_e=wt_e*1/N2k
				replace wt_ze=wt_ze*1/N2k

				* within occupation within firm/plant
				replace wa_c=wa_c*1/N2k
				replace wa_n=wa_n*1/N2k
				replace wa_e=wa_e*1/N2k
				replace wa_ze=wa_ze*1/N2k

				*within firm/plant covariance (between and within occupation)
				replace wat_c=wat_c*2/N2k
				replace wat_n=wat_n*2/N2k
				replace wat_e=wat_e*2/N2k
				replace wat_ze=wat_ze*2/N2k

				*within firm/plant total variance 
				replace wtot_c=wtot_c*1/N2k
				replace wtot_n=wtot_n*1/N2k
				replace wtot_e=wtot_e*1/N2k
				replace wtot_ze=wtot_ze*1/N2k

				*within firm/plant total (consistancy check of above)
				replace ws_c=ws_c*1/N2k
				replace ws_n=ws_n*1/N2k
				replace ws_e=ws_e*1/N2k
				replace ws_ze=ws_ze*1/N2k

				*between occupation between firm/plant
				replace bt_c=bt_c*1/N2k
				replace bt_n=bt_n*1/N2k
				replace bt_e=bt_e*1/N2k
				replace bt_ze=bt_ze*1/N2k

				*within occupation between firm/plant
				replace ba_c=ba_c*1/N2k
				replace ba_n=ba_n*1/N2k
				replace ba_e=ba_e*1/N2k
				replace ba_ze=ba_ze*1/N2k

				*between firm/plant covariance (between and within occ) 
				replace bat_c=bat_c*2/N2k
				replace bat_n=bat_n*2/N2k
				replace bat_e=bat_e*2/N2k
				replace bat_ze=bat_ze*2/N2k

				*between firm/plant total variance (consistancy check)
				replace bs_c=bs_c*1/N2k
				replace bs_n=bs_n*1/N2k
				replace bs_e=bs_e*1/N2k
				replace bs_ze=bs_ze*1/N2k

				*between firm/plant total variance
				replace btot_c=btot_c*1/N2k
				replace btot_n=btot_n*1/N2k
				replace btot_e=btot_e*1/N2k
				replace btot_ze=btot_ze*1/N2k

				*total between occupation
				replace tt_c=tt_c*1/N2k
				replace tt_n=tt_n*1/N2k
				replace tt_e=tt_e*1/N2k
				replace tt_ze=tt_ze*1/N2k

				*total within occupation
				replace ta_c=ta_c*1/N2k
				replace ta_n=ta_n*1/N2k
				replace ta_e=ta_e*1/N2k
				replace ta_ze=ta_ze*1/N2k

				*total variance (consistancy)
				replace ts_c=ts_c*1/N2k
				replace ts_n=ts_n*1/N2k
				replace ts_e=ts_e*1/N2k
				replace ts_ze=ts_ze*1/N2k

				*** Final industry level sample corrected variances 

				*between occupation within firm/plant corrected
				replace corr_wt_c=corr_wt_c*1/N2k
				replace corr_wt_n=corr_wt_n*1/N2k
				replace corr_wt_e=corr_wt_e*1/N2k
				replace corr_wt_ze=corr_wt_ze*1/N2k

				*within occupation within firm/plant corrected
				replace corr_wa_c=corr_wa_c*1/N2k
				replace corr_wa_n=corr_wa_n*1/N2k
				replace corr_wa_e=corr_wa_e*1/N2k
				replace corr_wa_ze=corr_wa_ze*1/N2k

				*within firm/plant covariance (between and within occ)  
				replace corr_wat_c=corr_wat_c*2/N2k
				replace corr_wat_n=corr_wat_n*2/N2k
				replace corr_wat_e=corr_wat_e*2/N2k
				replace corr_wat_ze=corr_wat_ze*2/N2k

				*within firm/plant total varinace corrected
				replace corr_wtot_c=corr_wtot_c*1/N2k
				replace corr_wtot_n=corr_wtot_n*1/N2k
				replace corr_wtot_e=corr_wtot_e*1/N2k
				replace corr_wtot_ze=corr_wtot_ze*1/N2k

				*within firm/plant total variance corrected (consistancy)
				replace corr_ws_c=corr_ws_c*1/N2k
				replace corr_ws_n=corr_ws_n*1/N2k
				replace corr_ws_e=corr_ws_e*1/N2k
				replace corr_ws_ze=corr_ws_ze*1/N2k

				*between occupation between firm/plant
				replace corr_bt_c=corr_bt_c*1/N2k
				replace corr_bt_n=corr_bt_n*1/N2k
				replace corr_bt_e=corr_bt_e*1/N2k
				replace corr_bt_ze=corr_bt_ze*1/N2k

				*within occupation between firm/plant
				replace corr_ba_c=corr_ba_c*1/N2k
				replace corr_ba_n=corr_ba_n*1/N2k
				replace corr_ba_e=corr_ba_e*1/N2k
				replace corr_ba_ze=corr_ba_ze*1/N2k

				*between firm/plant covariance (between and  within occ)  
				replace corr_bat_c=corr_bat_c*2/N2k
				replace corr_bat_n=corr_bat_n*2/N2k
				replace corr_bat_e=corr_bat_e*2/N2k
				replace corr_bat_ze=corr_bat_ze*2/N2k

				*between firm/plant total variance (consistancy)
				replace corr_bs_c=corr_bs_c*1/N2k
				replace corr_bs_n=corr_bs_n*1/N2k
				replace corr_bs_e=corr_bs_e*1/N2k
				replace corr_bs_ze=corr_bs_ze*1/N2k

				*between firm/plant total variance
				replace corr_btot_c=corr_btot_c*1/N2k
				replace corr_btot_n=corr_btot_n*1/N2k
				replace corr_btot_e=corr_btot_e*1/N2k
				replace corr_btot_ze=corr_btot_ze*1/N2k

				save temp/vardecomp_industry_`s'_`x'_`j'_`i',replace

				restore

				*** 4. Overall collapse

				collapse (sum) w* b* t* corr* N=Nj (mean) lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

				*final uncorrected variances 

				*between occupation within firm/plant
				replace wt_c=wt_c*1/N2
				replace wt_n=wt_n*1/N2
				replace wt_e=wt_e*1/N2
				replace wt_ze=wt_ze*1/N2

				*within occupation within firm/plant
				replace wa_c=wa_c*1/N2
				replace wa_n=wa_n*1/N2
				replace wa_e=wa_e*1/N2
				replace wa_ze=wa_ze*1/N2

				*within firm/plant covariance (between and within occ)  
				replace wat_c=wat_c*2/N2
				replace wat_n=wat_n*2/N2
				replace wat_e=wat_e*2/N2
				replace wat_ze=wat_ze*2/N2

				*within firm/plant total variance
				replace wtot_c=wtot_c*1/N2
				replace wtot_n=wtot_n*1/N2
				replace wtot_e=wtot_e*1/N2
				replace wtot_ze=wtot_ze*1/N2

				*within firm/plant total variance (consistancy)
				replace ws_c=ws_c*1/N2
				replace ws_n=ws_n*1/N2
				replace ws_e=ws_e*1/N2
				replace ws_ze=ws_ze*1/N2

				*between occupation between firm
				replace bt_c=bt_c*1/N2
				replace bt_n=bt_n*1/N2
				replace bt_e=bt_e*1/N2
				replace bt_ze=bt_ze*1/N2

				*within occupation between firm/plant 
				replace ba_c=ba_c*1/N2
				replace ba_n=ba_n*1/N2
				replace ba_e=ba_e*1/N2
				replace ba_ze=ba_ze*1/N2

				*between firm/plant covariance (between and within occ)  
				replace bat_c=bat_c*2/N2
				replace bat_n=bat_n*2/N2
				replace bat_e=bat_e*2/N2
				replace bat_ze=bat_ze*2/N2

				*between firm/plant total variance (consistancy)
				replace bs_c=bs_c*1/N2
				replace bs_n=bs_n*1/N2
				replace bs_e=bs_e*1/N2
				replace bs_ze=bs_ze*1/N2

				*between firm/plant total variance
				replace btot_c=btot_c*1/N2
				replace btot_n=btot_n*1/N2
				replace btot_e=btot_e*1/N2
				replace btot_ze=btot_ze*1/N2

				*total between occ
				replace tt_c=tt_c*1/N2
				replace tt_n=tt_n*1/N2
				replace tt_e=tt_e*1/N2
				replace tt_ze=tt_ze*1/N2

				*total within occ
				replace ta_c=ta_c*1/N2
				replace ta_n=ta_n*1/N2
				replace ta_e=ta_e*1/N2
				replace ta_ze=ta_ze*1/N2

				*total variance (consistancy)
				replace ts_c=ts_c*1/N2
				replace ts_n=ts_n*1/N2
				replace ts_e=ts_e*1/N2
				replace ts_ze=ts_ze*1/N2

				*covariances skill
				replace bcov=bcov*1/N2
				replace wcov=wcov*1/N2

				*** Final sample corrected variances 

				*between occ within firm corrected
				replace corr_wt_c=corr_wt_c*1/N2
				replace corr_wt_n=corr_wt_n*1/N2
				replace corr_wt_e=corr_wt_e*1/N2
				replace corr_wt_ze=corr_wt_ze*1/N2

				*within occ within firm corrected
				replace corr_wa_c=corr_wa_c*1/N2
				replace corr_wa_n=corr_wa_n*1/N2
				replace corr_wa_e=corr_wa_e*1/N2
				replace corr_wa_ze=corr_wa_ze*1/N2

				*within firm covariance (between and within occ)  
				replace corr_wat_c=corr_wat_c*2/N2
				replace corr_wat_n=corr_wat_n*2/N2
				replace corr_wat_e=corr_wat_e*2/N2
				replace corr_wat_ze=corr_wat_ze*2/N2

				*within firm/plant total variance corrected
				replace corr_wtot_c=corr_wtot_c*1/N2
				replace corr_wtot_n=corr_wtot_n*1/N2
				replace corr_wtot_e=corr_wtot_e*1/N2
				replace corr_wtot_ze=corr_wtot_ze*1/N2

				*within firm/plant total variance corrected (concistancy)
				replace corr_ws_c=corr_ws_c*1/N2
				replace corr_ws_n=corr_ws_n*1/N2
				replace corr_ws_e=corr_ws_e*1/N2
				replace corr_ws_ze=corr_ws_ze*1/N2

				*between occupation between firm/plant
				replace corr_bt_c=corr_bt_c*1/N2
				replace corr_bt_n=corr_bt_n*1/N2
				replace corr_bt_e=corr_bt_e*1/N2
				replace corr_bt_ze=corr_bt_ze*1/N2

				*within occupation between firm/plant
				replace corr_ba_c=corr_ba_c*1/N2
				replace corr_ba_n=corr_ba_n*1/N2
				replace corr_ba_e=corr_ba_e*1/N2
				replace corr_ba_ze=corr_ba_ze*1/N2

				*between firm/plant covariance (between and within occ)  
				replace corr_bat_c=corr_bat_c*2/N2
				replace corr_bat_n=corr_bat_n*2/N2
				replace corr_bat_e=corr_bat_e*2/N2
				replace corr_bat_ze=corr_bat_ze*2/N2

				*between firm/plant total variance (consistancy)
				replace corr_bs_c=corr_bs_c*1/N2
				replace corr_bs_n=corr_bs_n*1/N2
				replace corr_bs_e=corr_bs_e*1/N2
				replace corr_bs_ze=corr_bs_ze*1/N2

				*between firm/plant total variance
				replace corr_btot_c=corr_btot_c*1/N2
				replace corr_btot_n=corr_btot_n*1/N2
				replace corr_btot_e=corr_btot_e*1/N2
				replace corr_btot_ze=corr_btot_ze*1/N2

				*covariances skill
				replace corr_bcov=corr_bcov*1/N2
				replace corr_wcov=corr_wcov*1/N2

				save temp/vardecomp_aggregate_`s'_`x'_`j'_`i',replace
			}
		}
	}			
}

*  			
foreach s in A B C D E F G H I J K L M N O P {			
	foreach x in ftg ast {
		foreach j in 10 50 {
			use temp/vardecomp_aggregate_`s'_`x'_`j'_1985,clear
			forvalues i=1986(1)2009 {
				append using temp/vardecomp_aggregate_`s'_`x'_`j'_`i'
			}
			lab var ba_c "Within occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bt_c "Between occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bat_c "Between firm/plant covariance. Sample `s', `x'size `j'"
			lab var bs_c "Between firm/plant total. Sample `s', `x'size `j'"
			lab var btot_c "Between firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var wa_c "Within occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wt_c "Between occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wat_c "Within firm/plant covariance. Sample `s', `x'size `j'"
			lab var ws_c "Within firm/plant total. Sample `s', `x'size `j'"
			lab var wtot_c "Within firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var ta_c "Within occupation total. Sample `s', `x'size `j'"
			lab var tt_c "Between occupation total. Sample `s', `x'size `j'"
			lab var ts_c "Total. Sample `s', `x'size `j'"

			lab var ba_n "Within occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bt_n "Between occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bat_n "Between firm/plant covariance. Sample `s', `x'size `j'"
			lab var bs_n "Between firm/plant total. Sample `s', `x'size `j'"
			lab var btot_n "Between firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var wa_n "Within occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wt_n "Between occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wat_n "Within firm/plant covariance. Sample `s', `x'size `j'"
			lab var ws_n "Within firm/plant total. Sample `s', `x'size `j'"
			lab var wtot_n "Within firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var ta_n "Within occupation total. Sample `s', `x'size `j'"
			lab var tt_n "Between occupation total. Sample `s', `x'size `j'"
			lab var ts_n "Total. Sample `s', `x'size `j'"

			lab var ba_e "Within occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bt_e "Between occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bat_e "Between firm/plant covariance. Sample `s', `x'size `j'"
			lab var bs_e "Between firm/plant total. Sample `s', `x'size `j'"
			lab var btot_e "Between firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var wa_e "Within occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wt_e "Between occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wat_e "Between firm/plant covariance. Sample `s', `x'size `j'"
			lab var ws_e "Within firm/plant total. Sample `s', `x'size `j'"
			lab var wtot_e "Within firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var ta_e "Within occupation total. Sample `s', `x'size `j'"
			lab var tt_e "Between occupation total. Sample `s', `x'size `j'"
			lab var ts_e "Total. Sample `s', `x'size `j'"

			lab var ba_ze "Within occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bt_ze "Between occupation between firm/plant. Sample `s', `x'size `j'"
			lab var bat_ze "Between firm/plant covariance. Sample `s', `x'size `j'"
			lab var bs_ze "Between firm/plant total. Sample `s', `x'size `j'"
			lab var btot_ze "Between firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var wa_ze "Within occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wt_ze "Between occupation within firm/plant. Sample `s', `x'size `j'"
			lab var wat_ze "Between firm/plant covariance. Sample `s', `x'size `j'"
			lab var ws_ze "Within firm/plant total. Sample `s', `x'size `j'"
			lab var wtot_ze "Within firm/plant total (consistancy). Sample `s', `x'size `j'"

			lab var ta_ze "Within occupation total. Sample `s', `x'size `j'"
			lab var tt_ze "Between occupation total. Sample `s', `x'size `j'"
			lab var ts_ze "Total. Sample `s', `x'size `j'"

			lab var corr_ba_c "Within occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bt_c "Between occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bat_c "Between firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_bs_c "Between firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_btot_c "Between firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_wa_c "Within occupation witin firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wt_c "Between occupation within firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wat_c "Within firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_ws_c "Within firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_wtot_c "Within firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_ba_n "Within occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bt_n "Between occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bat_n "Between firm covariance/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bs_n "Between firm total/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_btot_n "Between firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_wa_n "Within occupation witin firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wt_n "Between occupation within firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wat_n "Within firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_ws_n "Within firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_wtot_n "Within firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_ba_e "Within occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bt_e "Between occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bat_e "Between firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_bs_e "Between firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_btot_e "Between firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_wa_e "Within occupation witin firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wt_e "Between occupation within firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wat_e "Within firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_ws_e "Within firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_wtot_e "Within firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_ba_ze "Within occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bt_ze "Between occupation between firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_bat_ze "Between firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_bs_ze "Between firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_btot_ze "Between firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			lab var corr_wa_ze "Within occupation witin firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wt_ze "Between occupation within firm/plant (corrected). Sample `s', `x'size `j'"
			lab var corr_wat_ze "Within firm/plant covariance (corrected). Sample `s', `x'size `j'"
			lab var corr_ws_ze "Within firm/plant total (corrected). Sample `s', `x'size `j'"
			lab var corr_wtot_ze "Within firm/plant total (consistancy) (corrected). Sample `s', `x'size `j'"

			save modified/vardecomp_aggregate_`s'_`x'_`j',replace
		}
	}	
}		
		
*** Combine aggregate annual files into one
* vardecomp
*  
foreach s in A B C D E F G H I J K L M N O P {
	foreach x in ftg ast {
		foreach j in 10 50 {
			use modified/vardecomp_aggregate_`s'_`x'_`j',clear
			keep year tt_c tt_n tt_e tt_ze ta_c ta_n ta_e ta_ze ts_c ts_n ts_e ts_ze corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_ws_c corr_ws_n corr_ws_e corr_ws_ze corr_wt_c corr_wt_n corr_wt_e corr_wt_ze corr_wa_c corr_wa_n corr_wa_e corr_wa_ze corr_wat_c corr_wat_n corr_wat_e corr_wat_ze corr_wtot_c corr_wtot_n corr_wtot_e corr_wtot_ze corr_bs_c corr_bs_n corr_bs_e corr_bs_ze corr_bt_c corr_bt_n corr_bt_e corr_bt_ze corr_ba_c corr_ba_n corr_ba_e corr_ba_ze corr_bat_c corr_bat_n corr_bat_e corr_bat_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze corr_bcov corr_wcov N lnwpred lnwage N2
			foreach v in tt_c tt_n tt_e tt_ze ta_c ta_n ta_e ta_ze ts_c ts_n ts_e ts_ze corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_ws_c corr_ws_n corr_ws_e corr_ws_ze corr_wt_c corr_wt_n corr_wt_e corr_wt_ze corr_wa_c corr_wa_n corr_wa_e corr_wa_ze corr_wat_c corr_wat_n corr_wat_e corr_wat_ze corr_wtot_c corr_wtot_n corr_wtot_e corr_wtot_ze corr_bs_c corr_bs_n corr_bs_e corr_bs_ze corr_bt_c corr_bt_n corr_bt_e corr_bt_ze corr_ba_c corr_ba_n corr_ba_e corr_ba_ze corr_bat_c corr_bat_n corr_bat_e corr_bat_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze corr_bcov corr_wcov N lnwpred lnwage N2 {
				rename `v' `v'_`s'_`x'_`j'
			}
		save temp/vardecomp_aggregate_`s'_`x'_`j', replace
		}
	}	
}	

use temp/vardecomp_aggregate_A_ftg_10,clear
merge 1:1 year using temp/vardecomp_aggregate_A_ast_10
drop _merge
foreach s in B C D E F G H I J K L M N O P {
	foreach x in ftg ast {
		foreach j in 10 50 {
			merge 1:1 year using temp/vardecomp_aggregate_`s'_`x'_`j'
			drop _merge
		}
	}	
}	
save modified/vardecomp_aggregate_robust,replace

*** Append 2:nd aggregates files to modified/vardecomp_bfwi_bi_`s'_`x'_`j'
clear
foreach s in A B C D E F G H I J K L M N O P {
	foreach x in ftg ast {
		foreach j in 10 50 {
			use temp/vardecomp_bfwi_bi_`s'_`x'_`j'_1985,clear
			forvalues i=1986(1)2009 {
				append using temp/vardecomp_bfwi_bi_`s'_`x'_`j'_`i'
			}
		keep bi* btot* bfwi* corr_bi* corr_btot* year N2
		collapse (sum) btot* bfwi* corr_bi* corr_btot* bi* (mean) N2, by (year)

		replace btot_c=btot_c/N2
		replace bfwi_c=bfwi_c/N2
		replace bi_c=bi_c/N2
		replace corr_btot_c=corr_btot_c/N2
		replace corr_bi_c=corr_bi_c/N2

		replace btot_n=btot_n/N2
		replace bfwi_n=bfwi_n/N2
		replace bi_n=bi_n/N2
		replace corr_btot_n=corr_btot_n/N2
		replace corr_bi_n=corr_bi_n/N2

		replace btot_e=btot_e/N2
		replace bfwi_e=bfwi_e/N2
		replace bi_e=bi_e/N2
		replace corr_btot_e=corr_btot_e/N2
		replace corr_bi_e=corr_bi_e/N2

		replace btot_ze=btot_ze/N2
		replace bfwi_ze=bfwi_ze/N2
		replace bi_ze=bi_ze/N2
		replace corr_btot_ze=corr_btot_ze/N2
		replace corr_bi_ze=corr_bi_ze/N2
	
		g corr_bfwi_c=corr_btot_c-corr_bi_c
		g corr_bfwi_n=corr_btot_n-corr_bi_n
		g corr_bfwi_e=corr_btot_e-corr_bi_e
		g corr_bfwi_ze=corr_btot_ze-corr_bi_ze
	
		lab var btot_c "Between firm/plant total. Sample `s', `x'size `j'"
		lab var bfwi_c "Between firm/plant within industry. Sample `s', `x'size `j'"
		lab var bi_c "Between industry. Sample `s', `x'size `j'"
		lab var corr_btot_c "Between firm/plant total (corrected). Sample `s', `x'size `j'"
		lab var corr_bi_c "Between industry (corrected). Sample `s', `x'size `j'"
		lab var corr_bfwi_c "Between firm/plant within industry (corrected). Sample `s', `x'size `j'"
	
		lab var btot_n "Between firm/plant total. Sample `s', `x'size `j'"
		lab var bfwi_n "Between firm/plant within industry. Sample `s', `x'size `j'"
		lab var bi_n "Between industry. Sample `s', `x'size `j'"
		lab var corr_btot_n "Between firm/plant total (corrected). Sample `s', `x'size `j'"
		lab var corr_bi_n "Between industry (corrected). Sample `s', `x'size `j'"
		lab var corr_bfwi_n "Between firm/plant within industry (corrected). Sample `s', `x'size `j'"

		lab var btot_e "Between firm/plant total. Sample `s', `x'size `j'"
		lab var bfwi_e "Between firm/plant within industry. Sample `s', `x'size `j'"
		lab var bi_e "Between industry. Sample `s', `x'size `j'"
		lab var corr_btot_e "Between firm/plant total (corrected). Sample `s', `x'size `j'"
		lab var corr_bi_e "Between industry (corrected). Sample `s', `x'size `j'"
		lab var corr_bfwi_e "Between firm/plant within industry (corrected). Sample `s', `x'size `j'"
	
		lab var btot_ze "Between firm/plant total. Sample `s', `x'size `j'"
		lab var bfwi_ze "Between firm/plant within industry. Sample `s', `x'size `j'"
		lab var bi_ze "Between industry. Sample `s', `x'size `j'"
		lab var corr_btot_ze "Between firm/plant total (corrected). Sample `s', `x'size `j'"
		lab var corr_bi_ze "Between industry (corrected). Sample `s', `x'size `j'"
		lab var corr_bfwi_ze "Between firm/plant within industry (corrected). Sample `s', `x'size `j'"
	
		save modified/vardecomp_bfwi_bi_`s'_`x'_`j', replace	
		}
	}
}

* Combine into one: modified/vardecomp_bfwi_bi_robust
foreach s in A B C D E F G H I J K L M N O P {
	foreach x in ftg ast {
		foreach j in 10 50 {
			use modified/vardecomp_bfwi_bi_`s'_`x'_`j',clear
			keep year corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze N2 corr_bfwi_c corr_bfwi_n corr_bfwi_e corr_bfwi_ze
			foreach v in corr_bi_c corr_bi_n corr_bi_e corr_bi_ze corr_btot_c corr_btot_n corr_btot_e corr_btot_ze N2 corr_bfwi_c corr_bfwi_n corr_bfwi_e corr_bfwi_ze {
				rename `v' `v'_`s'_`x'_`j'
			}
		save temp/vardecomp_bfwi_bi_`s'_`x'_`j', replace
		}
	}	
}	

use temp/vardecomp_bfwi_bi_A_ftg_10,clear
merge 1:1 year using temp/vardecomp_bfwi_bi_A_ast_10
drop _merge
foreach s in B C D E F G H I J K L M N O P {
	foreach x in ftg ast {
		foreach j in 10 50 {
			merge 1:1 year using temp/vardecomp_bfwi_bi_`s'_`x'_`j'
			drop _merge
		}
	}
}	
save modified/vardecomp_bfwi_bi_robust,replace
		

**************************************************************
*** 14. Generate betas at individual and firm/plant level ****
**************************************************************

* Firm/plant
foreach x in ftg ast {
	use year `x'nr wa3j10 wa3j50 wa6j10 wa6j50 cj10 cj50 nj10 nj50 nobs3j10 nobs3j50 nobs6j10 nobs6j50 using modified/wage_dispersion_`x', clear
	gen cnj10=cj10*nj10
	gen cnj50=cj50*nj50
	drop if `x'nr==""
		foreach j in 10 50 {
			forvalues i=1985(1)2009 {
				* Bi-variate: wages
				reg wa3j`j' cj`j' [aw=nobs3j`j'] if year==`i',r
				gen betac`j'_`x'_`i'=_b[cj`j']
				lab var betac`j'_`x'_`i' "Cog gradient (bivariate, `x'size `j', year `i')"
				reg wa3j`j' nj`j' [aw=nobs3j`j'] if year==`i',r
				gen betan`j'_`x'_`i'=_b[nj`j']
				lab var betan`j'_`x'_`i' "Noncog gradient (bivariate, `x'size `j', year `i')"
				
				* Multivariate and interaction
				reg wa3j`j' cj`j' nj`j' cnj`j' [aw=nobs3j`j'] if year==`i',r
				gen betamc`j'_`x'_`i'=_b[cj`j']
				lab var betamc`j'_`x'_`i' "Cog gradient (multivariate, `x'size `j', year `i')"
				gen betamn`j'_`x'_`i'=_b[nj`j']
				lab var betamn`j'_`x'_`i' "Noncog gradient (multivariate, `x'size `j', year `i')"
				gen betamcn`j'_`x'_`i'=_b[cnj`j']
				lab var betamcn`j'_`x'_`i' "Cog-by-noncog gradient (multivariate, `x'size `j', year `i')"

				* Bi-variate: sws
				reg wa6j`j' cj`j' [aw=nobs6j`j'] if year==`i',r
				gen betac`j'_sws_`x'_`i'=_b[cj`j']
				lab var betac`j'_sws_`x'_`i' "Cog SWS gradient (bivariate, `x'size `j', year `i')"
				reg wa6j`j' nj`j' [aw=nobs6j`j'] if year==`i',r
				gen betan`j'_sws_`x'_`i'=_b[nj`j']
				lab var betan`j'_sws_`x'_`i' "Noncog SWS gradient (bivariate, `x'size `j', year `i')"
				
				* Multivariate and interaction
				reg wa6j`j' cj`j' nj`j' cnj`j' [aw=nobs6j`j'] if year==`i',r
				gen betamc`j'_sws_`x'_`i'=_b[cj`j']
				lab var betamc`j'_sws_`x'_`i' "Cog SWS gradient (multivariate, `x'size `j', year `i')"
				gen betamn`j'_sws_`x'_`i'=_b[nj`j']
				lab var betamn`j'_sws_`x'_`i' "Noncog SWS gradient (multivariate, `x'size `j', year `i')"
				gen betamcn`j'_sws_`x'_`i'=_b[cnj`j']
				lab var betamcn`j'_sws_`x'_`i' "Cog-by-noncog SWS gradient (multivariate, `x'size `j', year `i')"				
				
			}
			gen betac`j'_`x'=.
			lab var betac`j'_`x' "Cog gradient (bivariate, `x'size `j')"
			gen betan`j'_`x'=.
			lab var betan`j'_`x' "Noncog gradient (bivariate, `x'size `j')"
			gen betamc`j'_`x'=.
			lab var betamc`j'_`x' "Cog gradient (multivariate, `x'size `j')"
			gen betamn`j'_`x'=.
			lab var betamn`j'_`x' "Noncog gradient (multivariate, `x'size `j')"
			gen betamcn`j'_`x'=.
			lab var betamcn`j'_`x' "Cog-by-noncog gradient (multivariate, `x'size `j')"

			gen betac`j'_sws_`x'=.
			lab var betac`j'_sws_`x' "Cog SWS gradient (bivariate, `x'size `j')"
			gen betan`j'_sws_`x'=.
			lab var betan`j'_sws_`x' "Noncog SWS gradient (bivariate, `x'size `j')"
			gen betamc`j'_sws_`x'=.
			lab var betamc`j'_sws_`x' "Cog SWS gradient (multivariate, `x'size `j')"
			gen betamn`j'_sws_`x'=.
			lab var betamn`j'_sws_`x' "Noncog SWS gradient (multivariate, `x'size `j')"
			gen betamcn`j'_sws_`x'=.
			lab var betamcn`j'_`x' "Cog-by-noncog SWS gradient (multivariate, `x'size `j')"			
			
			forvalues i=1985(1)2009 {
					replace betac`j'_`x'=betac`j'_`x'_`i' if year==`i'
					replace betan`j'_`x'=betan`j'_`x'_`i' if year==`i'
					
					replace betamc`j'_`x'=betamc`j'_`x'_`i' if year==`i'
					replace betamn`j'_`x'=betamn`j'_`x'_`i' if year==`i'
					replace betamcn`j'_`x'=betamcn`j'_`x'_`i' if year==`i'

					replace betac`j'_sws_`x'=betac`j'_sws_`x'_`i' if year==`i'
					replace betan`j'_sws_`x'=betan`j'_sws_`x'_`i' if year==`i'
					
					replace betamc`j'_sws_`x'=betamc`j'_sws_`x'_`i' if year==`i'
					replace betamn`j'_sws_`x'=betamn`j'_sws_`x'_`i' if year==`i'
					replace betamcn`j'_sws_`x'=betamcn`j'_sws_`x'_`i' if year==`i'					
					
				}	
		}	
	duplicates drop year, force 
	keep year beta*
	save temp/betas_unit_`x',replace
}
use temp/betas_unit_ftg,clear
merge 1:1 year using temp/betas_unit_ast
drop _merge
foreach i in 1985 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2009 {
	drop *_`i'
}	
save modified/betas_unit,replace

* Individuals
forvalues i=1985(1)2009 {
	use year lopnr lnwpred* lnwage* c n edyr zedyr age sex sample* astnr ftgnr using modified/sample`i',clear
	gen cn=c*n
		foreach x in ftg ast {
			foreach j in 10 50 {
				areg lnwpred_`x' c if `x'nr~="" & sample_3035_`j'_`x'==1, a(`x'nr) r
				gen betac`j'ind_`x'=_b[c]
				gen sec`j'ind_`x'=_se[c]
				areg lnwpred_`x' n if `x'nr~="" & sample_3035_`j'_`x'==1, a(`x'nr) r
				gen betan`j'ind_`x'=_b[n]
				gen sen`j'ind_`x'=_se[n]
				areg lnwpred_`x' c n cn if `x'nr~="" & sample_3035_`j'_`x'==1, a(`x'nr) r
				gen betamc`j'ind_`x'=_b[c]
				gen semc`j'ind_`x'=_se[c]
				gen betamn`j'ind_`x'=_b[n]
				gen semn`j'ind_`x'=_se[n]
				gen betamcn`j'ind_`x'=_b[cn]
				gen semcn`j'ind_`x'=_se[cn]
			
				lab var betac`j'ind_`x' "Cognitive gradient (bivariate, `x' FEs, `x'size `j')"
				lab var betan`j'ind_`x' "Non-cognitive gradient (bivariate, `x' FEs, `x'size `j')"
				lab var betamc`j'ind_`x' "Cognitive gradient (multivariate, `x' FEs, `x'size `j')"
				lab var betamn`j'ind_`x' "Non-cognitive gradient (multivariate, `x' FEs, `x'size `j')"
				lab var betamcn`j'ind_`x' "Cog-by-noncog gradient (multivariate, `x' FEs, `x'size `j')"
			}	
		}	
	duplicates drop year, force
	drop lopnr lnwpred* lnwage* c n cn edyr zedyr age sex sample* astnr ftgnr
	save temp/betas_ind_`i',replace
}

use temp/betas_ind_1985,clear
forvalues i=1986(1)2009 {
	append using temp/betas_ind_`i'
}	
save modified/betas_ind,replace	

***************************************************************************************************
*** Estimating betas for 1986 and 2008: individual, firm, and sector level. Years 1986 and 2008 ***
***************************************************************************************************

*** Generate betas to predict wage
foreach x in ftg ast {
	foreach j in 10 50 {
		forvalues i=1985(1)2009 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
			
				* Mean sample wages
				egen wm=mean(lnwpred_`x')
				* Mean wages by firm/plant
				bysort `x'nr year: egen wj=mean(lnwpred_`x')
				* Mean wages by sector
				bysort `x'sni2: egen wk=mean(lnwpred_`x')
				
				* Mean sample skills
				egen cm=mean(c)
				egen nm=mean(n)
				* Mean firm/plant skills
				bysort `x'nr year: egen cj=mean(c)
				bysort `x'nr year: egen nj=mean(n)
				* Mean sector skills
				bysort `x'sni2: egen ck=mean(c)
				bysort `x'sni2: egen nk=mean(n)
				
				* Number of sample observations
				egen nobs=count(lnwpred_`x')
				* Number of firm/plant observations
				bysort `x'nr: egen nobsj=count(lnwpred_`x')
				* Number of sector observations
				bysort `x'sni2: egen nobsk=count(lnwpred_`x')
				
				* Demean by firm
				gen cdm=c-cj
				gen ndm=n-nj
				gen wdm=lnwpred_`x'-wj

				* Demean by industry
				gen wdmj=wj-wk
				gen cdmj=cj-ck
				gen ndmj=nj-nk
				
				* Betas: between individuals (beta_c)
				reg lnwpred_`x' c n, r
				predict what_`j'_`x'_`i'
				gen beta_c_`j'_`x'_`i'=_b[c]
				gen beta_n_`j'_`x'_`i'=_b[n]
								
				* Betas: between individuals within firms/plants (beta_cwf)
				reg wdm cdm ndm, r
				predict whatwf_`j'_`x'_`i'
				gen beta_cwf_`j'_`x'_`i'=_b[cdm]
				gen beta_nwf_`j'_`x'_`i'=_b[ndm]
								
				* Betas: between firm (beta_cj)
				reg wj cj nj, cluster(`x'nr)
				predict whatj_`j'_`x'_`i'
				gen beta_cj_`j'_`x'_`i'=_b[cj]
				gen beta_nj_`j'_`x'_`i'=_b[nj]
								
				* Betas: between-firm within-industries (beta_cjwi)
				reg wdmj cdmj ndmj, cluster(`x'nr)
				predict whatjwi_`j'_`x'_`i'
				gen beta_cjwi_`j'_`x'_`i'=_b[cdmj]
				gen beta_njwi_`j'_`x'_`i'=_b[ndmj]
								
				* Betas: between industry (beta_ck)
				reg wk ck nk, cluster(`x'sni2)
				predict whatk_`j'_`x'_`i'
				gen beta_ck_`j'_`x'_`i'=_b[ck]
				gen beta_nk_`j'_`x'_`i'=_b[nk]

				duplicates drop year, force
				keep year beta_c_`j'_`x'_`i' beta_n_`j'_`x'_`i' beta_cwf_`j'_`x'_`i' beta_nwf_`j'_`x'_`i' beta_cj_`j'_`x'_`i' beta_nj_`j'_`x'_`i' beta_cjwi_`j'_`x'_`i' beta_njwi_`j'_`x'_`i' beta_ck_`j'_`x'_`i' beta_nk_`j'_`x'_`i' 
				gen matchvar=15
				save temp/beta_`j'_`x'_`i',replace
				}
			}
		}

*** Generating annual dataset with all betas
clear
set obs 25
gen id=_n
gen year=1984+id
drop id
gen matchvar=15
foreach x in ftg ast {
	foreach j in 10 50 {
		gen beta_c_`j'_`x'=.
		gen beta_n_`j'_`x'=.
		gen beta_cwf_`j'_`x'=.
		gen beta_nwf_`j'_`x'=.
		gen beta_cj_`j'_`x'=.
		gen beta_nj_`j'_`x'=.
		gen beta_cjwi_`j'_`x'=.
		gen beta_njwi_`j'_`x'=.
		gen beta_ck_`j'_`x'=.
		gen beta_nk_`j'_`x'=.
		forvalues i=1985(1)2009 {
			merge m:1 matchvar using temp/beta_`j'_`x'_`i'
			drop _merge
			replace beta_c_`j'_`x'=beta_c_`j'_`x'_`i' if year==`i'
			replace beta_n_`j'_`x'=beta_n_`j'_`x'_`i' if year==`i'
			replace beta_cwf_`j'_`x'=beta_cwf_`j'_`x'_`i' if year==`i'
			replace beta_nwf_`j'_`x'=beta_nwf_`j'_`x'_`i' if year==`i'
			replace beta_cj_`j'_`x'=beta_cj_`j'_`x'_`i' if year==`i'
			replace beta_nj_`j'_`x'=beta_nj_`j'_`x'_`i' if year==`i'
			replace beta_cjwi_`j'_`x'=beta_cjwi_`j'_`x'_`i' if year==`i'
			replace beta_njwi_`j'_`x'=beta_njwi_`j'_`x'_`i' if year==`i'
			replace beta_ck_`j'_`x'=beta_ck_`j'_`x'_`i' if year==`i'
			replace beta_nk_`j'_`x'=beta_nk_`j'_`x'_`i' if year==`i'
			
			lab var beta_c_`j'_`x' "Cognitive skill gradient. Individual level"
			lab var beta_n_`j'_`x' "Non-cognitive skill gradient. Individual level"
			lab var beta_cwf_`j'_`x' "Cognitive skill gradient. Within-firm individual level"
			lab var beta_nwf_`j'_`x' "Non-cognitive skill gradient. Within-firm individual level"
			lab var beta_cj_`j'_`x' "Cognitive skill gradient. Firm level"
			lab var beta_nj_`j'_`x' "Non-cognitive skill gradient. Firm level"
			lab var beta_cjwi_`j'_`x' "Cognitive skill gradient. Between-firm within industry level"
			lab var beta_njwi_`j'_`x' "Non-cognitive skill gradient. Between-firm within industry level"
			lab var beta_ck_`j'_`x' "Cognitive skill gradient. Industry level"
			lab var beta_nk_`j'_`x' "Non-cognitive skill gradient. Industry level"
			
			
		}
	}
}

drop matchvar
save modified/betas_all, replace		

*************************************************
*** Generate betas and combined skill measure ***
*************************************************
cd /home/workgroups/firmiq/data/ 
set more off
use modified/sample1986.dta,clear
keep if age>= 30 & age<= 35 & ftgstorl_ftg~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_ftg==1
keep lopnr age year lnwpred_ftg c n sex  ftgstorl_ftg edyr privfirm_ftg

forvalues i=1987(1)2008 {
	append using modified/sample`i'.dta, keep(age sex year lnwpred_ftg c n ftgstorl_ftg edyr privfirm_ftg)
	keep if age>= 30 & age<= 35 & ftgstorl_ftg~=. & sex=="1" & n!=. & c!=. & edyr!=. & privfirm_ftg==1
}

gen c2=c*c
gen n2=n*n
gen cn=c*n

* We take out year effects to account for overall wage growth. We also take out age effects, which has a trivial impact on coefficients
xi: reg lnwpred_ftg c c2 n n2 cn age i.year
gen beta_c=_b[c]
gen beta_c2=_b[c2]
gen beta_n=_b[n]
gen beta_n2=_b[n2]
gen beta_cn=_b[cn]

gen match=1
duplicates drop match, force
keep beta_c beta_c2 beta_n beta_n2 beta_cn match
save modified/betas_skill_measure.dta, replace

* Use enlistment data to generate combined, standardized skill measure
	use modified/enlistment.dta, clear
	gen match=1
	merge m:1 match using modified/betas_skill_measure.dta
	
	gen c2=c*c
	gen n2=n*n
	gen cn=c*n
	
	gen combskill= beta_c*c + beta_c2*c2 + beta_n*n + beta_n2*n2 + beta_cn*cn

	bysort enlistyr: egen combmean=mean(combskill)
	bysort enlistyr: egen combsd=sd(combskill)
	gen skill=(combskill-combmean)/combsd
	
	drop if skill==.
	keep lopnr skill
	lab var skill "Combined skill measure using c and n"
	sort lopnr
	
save modified/combskill_measure.dta, replace

************************************************************ 
*** Variance decomposition of actual and predicted wages ***
************************************************************

foreach x in ftg ast {
	foreach j in 10 50 {
		forvalues i=1986(22)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
			
				* Merge with betas to derive predicted wages
				merge m:1 year using modified/betas_all
				keep if _merge==3
				
				* Mean sample wages
				egen wm=mean(lnwpred_`x')
				
				* Mean wages by firm/plant
				bysort `x'nr year: egen wj=mean(lnwpred_`x')
				
				* Mean wages by sector
				bysort `x'sni2: egen wk=mean(lnwpred_`x')
				
				* Mean sample skills
				egen cm=mean(c)
				egen nm=mean(n)
				
				* Mean firm/plant skills
				bysort `x'nr year: egen cj=mean(c)
				bysort `x'nr year: egen nj=mean(n)
				
				* Mean sector skills
				bysort `x'sni2: egen ck=mean(c)
				bysort `x'sni2: egen nk=mean(n)
				
				* Number of sample observations
				egen nobs=count(lnwpred_`x')
				
				* Number of firm/plant observations
				bysort `x'nr: egen nobsj=count(lnwpred_`x')
				
				* Number of sector observations
				bysort `x'sni2: egen nobsk=count(lnwpred_`x')
				
				*** Predicted wages
				
				* Firm predicted wages: actual gradients
				gen wpredj=cj*beta_cj_`j'_`x'+nj*beta_nj_`j'_`x'
				* Firm predicted wages: 1986 gradients
				gen wpredj_1986=cj*beta_cj_`j'_`x'_1986+nj*beta_nj_`j'_`x'_1986
				* Firm predicted wages: 2008 gradients
				gen wpredj_2008=cj*beta_cj_`j'_`x'_2008+nj*beta_nj_`j'_`x'_2008
				
					* Sample means
					egen wpredjm=mean(wpredj)
					egen wpredjm_1986=mean(wpredj_1986)
					egen wpredjm_2008=mean(wpredj_2008)
					
					* Industry means
					bysort `x'sni2: egen wpredjk=mean(wpredj)
					bysort `x'sni2: egen wpredjk_1986=mean(wpredj_1986)
					bysort `x'sni2: egen wpredjk_2008=mean(wpredj_2008)
					
				* Industry predicted wages: actual gradients
				gen wpredk=ck*beta_ck_`j'_`x'+nk*beta_nk_`j'_`x'
				* Between industry: 1986 gradients
				gen wpredk_1986=ck*beta_ck_`j'_`x'_1986+nk*beta_nk_`j'_`x'_1986		
				* Between industry: 2008 gradients
				gen wpredk_2008=ck*beta_ck_`j'_`x'_2008+nk*beta_nk_`j'_`x'_2008
				
					* Sample means
					egen wpredkm=mean(wpredk)
					egen wpredkm_1986=mean(wpredk_1986)
					egen wpredkm_2008=mean(wpredk_2008)
				
				* Predicted firm wages within industry: actual gradients
				gen wpredjwi=(cj-ck)*beta_cjwi_`j'_`x'+(nj-nk)*beta_njwi_`j'_`x'
				* Between firms within industry: 1986 gradients
				gen wpredjwi_1986=(cj-ck)*beta_cjwi_`j'_`x'_1986+(nj-nk)*beta_njwi_`j'_`x'_1986
				* Between firms within industry: 2008 gradients
				gen wpredjwi_2008=(cj-ck)*beta_cjwi_`j'_`x'_2008+(nj-nk)*beta_njwi_`j'_`x'_2008
				
					* Sample means
					egen wpredjwim=mean(wpredjwi)
					egen wpredjwim_1986=mean(wpredjwi_1986)
					egen wpredjwim_2008=mean(wpredjwi_2008)
				
					* Industry means
					egen wpredjwik=mean(wpredjwi)
					egen wpredjwik_1986=mean(wpredjwi_1986)
					egen wpredjwik_2008=mean(wpredjwi_2008)
				
				* Individual predicted wages: actual gradients
				gen wpredi=c*beta_c_`j'_`x'+n*beta_n_`j'_`x'
				* Individual: 1986 gradients
				gen wpredi_1986=c*beta_c_`j'_`x'_1986+n*beta_n_`j'_`x'_1986
				* Individual: 2008 gradients
				gen wpredi_2008=c*beta_c_`j'_`x'_2008+n*beta_n_`j'_`x'_2008
				
					* Sample means
					egen wpredim=mean(wpredi)
					egen wpredim_1986=mean(wpredi_1986)
					egen wpredim_2008=mean(wpredi_2008)
					
					* Industry means
					bysort `x'sni2: egen wpredik=mean(wpredi)
					bysort `x'sni2: egen wpredik_1986=mean(wpredi_1986)
					bysort `x'sni2: egen wpredik_2008=mean(wpredi_2008)
					
					* Firm means
					bysort `x'nr: egen wpredij=mean(wpredi)
					bysort `x'nr: egen wpredij_1986=mean(wpredi_1986)
					bysort `x'nr: egen wpredij_2008=mean(wpredi_2008)
				
				* Individual predicted wages within firm: actual gradients
				gen wpredwf=c*beta_cwf_`j'_`x'+n*beta_nwf_`j'_`x'
				* Individual within firm: 1986 gradients
				gen wpredwf_1986=c*beta_cwf_`j'_`x'_1986+n*beta_nwf_`j'_`x'_1986
				* Individual within firm: 2008 gradients
				gen wpredwf_2008=c*beta_cwf_`j'_`x'_2008+n*beta_nwf_`j'_`x'_2008			

					* Sample means
					egen wpredwfm=mean(wpredwf)
					egen wpredwfm_1986=mean(wpredwf_1986)
					egen wpredwfm_2008=mean(wpredwf_2008)
					
					* Industry means
					bysort `x'sni2: egen wpredwfk=mean(wpredwf)
					bysort `x'sni2: egen wpredwfk_1986=mean(wpredwf_1986)
					bysort `x'sni2: egen wpredwfk_2008=mean(wpredwf_2008)
					
					* Firm means
					bysort `x'nr: egen wpredwfj=mean(wpredwf)
					bysort `x'nr: egen wpredwfj_1986=mean(wpredwf_1986)
					bysort `x'nr: egen wpredwfj_2008=mean(wpredwf_2008)
				
				
			*** Wage variance
			
				* Total actual wage variance 
				egen wagesd=sd(lnwpred_`x')
				gen wvartot_`j'_`x'=wagesd*wagesd
				drop wagesd
				
				* Between firm actual wage variance
				egen wvarbf_`j'_`x'=sum((wj-wm)*(wj-wm))
				replace wvarbf_`j'_`x'=wvarbf_`j'_`x'/nobs
				
					* Between firm predicted wage variance: Actual gradients
					egen wpredvarbf_`j'_`x'=sum((wpredj-wpredjm)*(wpredj-wpredjm))
					replace wpredvarbf_`j'_`x'=wpredvarbf_`j'_`x'/nobs
					
					* Between firm predicted wage variance: 1986 gradients
					egen wpredvarbf_1986_`j'_`x'=sum((wpredj_1986-wpredjm_1986)*(wpredj_1986-wpredjm_1986))
					replace wpredvarbf_1986_`j'_`x'=wpredvarbf_1986_`j'_`x'/nobs

					* Between firm predicted wage variance: 2008 gradients
					egen wpredvarbf_2008_`j'_`x'=sum((wpredj_2008-wpredjm_2008)*(wpredj_2008-wpredjm_2008))
					replace wpredvarbf_2008_`j'_`x'=wpredvarbf_2008_`j'_`x'/nobs
					
				* Within firm wage variance
				egen wvarwf_`j'_`x'=sum((lnwpred_`x'-wj)*(lnwpred_`x'-wj))
				replace wvarwf_`j'_`x'=wvarwf_`j'_`x'/nobs

					* Within firm predicted wage variance: actual gradients
					egen wpredvarwf_`j'_`x'=sum((wpredwf-wpredwfj)*(wpredwf-wpredwfj))
					replace wpredvarwf_`j'_`x'=wpredvarwf_`j'_`x'/nobs

					* Within firm predicted wage variance: 1986 gradients
					egen wpredvarwf_1986_`j'_`x'=sum((wpredwf_1986-wpredwfj_1986)*(wpredwf_1986-wpredwfj_1986))
					replace wpredvarwf_1986_`j'_`x'=wpredvarwf_1986_`j'_`x'/nobs

					* Within firm predicted wage variance: 2008 gradients
					egen wpredvarwf_2008_`j'_`x'=sum((wpredwf_2008-wpredwfj_2008)*(wpredwf_2008-wpredwfj_2008))
					replace wpredvarwf_2008_`j'_`x'=wpredvarwf_2008_`j'_`x'/nobs
					
				* Between industry wage variance
				egen wvarbi_`j'_`x'=sum((wk-wm)*(wk-wm))
				replace wvarbi_`j'_`x'=wvarbi_`j'_`x'/nobs

					* Between industry predicted wage variance: actual gradients
					egen wpredvarbi_`j'_`x'=sum((wpredk-wpredkm)*(wpredk-wpredkm))
					replace wpredvarbi_`j'_`x'=wpredvarbi_`j'_`x'/nobs
				
					* Between industry predicted wage variance: 1986 gradients
					egen wpredvarbi_1986_`j'_`x'=sum((wpredk_1986-wpredkm_1986)*(wpredk_1986-wpredkm_1986))
					replace wpredvarbi_1986_`j'_`x'=wpredvarbi_1986_`j'_`x'/nobs
				
					* Between industry predicted wage variance: 2008 gradients
					egen wpredvarbi_2008_`j'_`x'=sum((wpredk_2008-wpredkm_2008)*(wpredk_2008-wpredkm_2008))
					replace wpredvarbi_2008_`j'_`x'=wpredvarbi_2008_`j'_`x'/nobs
				
				* Between-firm within-industry wage variance
				egen wvarbfwi_`j'_`x'=sum((wj-wk)*(wj-wk))
				replace wvarbfwi_`j'_`x'=wvarbfwi_`j'_`x'/nobs

					* Between-firm within-industry predicted wage variance: actual gradients
					egen wpredvarbfwi_`j'_`x'=sum((wpredjwi-wpredjwik)*(wpredjwi-wpredjwik))
					replace wpredvarbfwi_`j'_`x'=wpredvarbfwi_`j'_`x'/nobs

					* Between-firm within-industry predicted wage variance: 1986 gradients
					egen wpredvarbfwi_1986_`j'_`x'=sum((wpredjwi_1986-wpredjwik_1986)*(wpredjwi_1986-wpredjwik_1986))
					replace wpredvarbfwi_1986_`j'_`x'=wpredvarbfwi_1986_`j'_`x'/nobs

					* Between-firm within-industry predicted wage variance: 2008 gradients
					egen wpredvarbfwi_2008_`j'_`x'=sum((wpredjwi_2008-wpredjwik_2008)*(wpredjwi_2008-wpredjwik_2008))
					replace wpredvarbfwi_2008_`j'_`x'=wpredvarbfwi_2008_`j'_`x'/nobs

				duplicates drop year, force
				keep year wvartot_`j'_`x' wvarbf_`j'_`x' wpredvarbf_`j'_`x' wpredvarbf_1986_`j'_`x' wpredvarbf_2008_`j'_`x' wvarwf_`j'_`x' wpredvarwf_`j'_`x' wpredvarwf_1986_`j'_`x' wpredvarwf_2008_`j'_`x' wvarbi_`j'_`x' wpredvarbi_`j'_`x' wpredvarbi_1986_`j'_`x' wpredvarbi_2008_`j'_`x' wvarbfwi_`j'_`x' wpredvarbfwi_`j'_`x' wpredvarbfwi_1986_`j'_`x' wpredvarbfwi_2008_`j'_`x'  beta_c_`j'_`x' beta_n_`j'_`x' beta_cwf_`j'_`x' beta_nwf_`j'_`x' beta_cj_`j'_`x' beta_nj_`j'_`x' beta_cjwi_`j'_`x' beta_njwi_`j'_`x' beta_ck_`j'_`x' beta_nk_`j'_`x'  
				save temp/wagedemposition_`j'_`x'_`i', replace
			
		}
	}
}

********************************************
*** Combine into wagedecomposition file ****
********************************************

use temp/wagedemposition_10_ftg_1986.dta, clear
append using temp/wagedemposition_10_ftg_2008.dta
append using temp/wagedemposition_50_ftg_1986.dta
append using temp/wagedemposition_50_ftg_2008.dta
append using temp/wagedemposition_10_ast_1986
append using temp/wagedemposition_10_ast_2008
append using temp/wagedemposition_50_ast_1986
append using temp/wagedemposition_50_ast_2008

* Label variables

foreach x in ftg ast {
	foreach j in 10 50 {
		forvalues i=1986(22)2008 {
		lab var beta_c_`j'_`x' "Beta cognitive. Individual"
		lab var beta_n_`j'_`x' "Beta non-cognitive. Individual"

		lab var beta_cwf_`j'_`x' "Beta cognitive. Individual, within firm"
		lab var beta_nwf_`j'_`x' "Beta non-cognitive. Individual, within firm"

		lab var beta_cj_`j'_`x' "Beta cognitive. Between firm"
		lab var beta_nj_`j'_`x' "Beta non-cognitive. Between firm"

		lab var beta_cjwi_`j'_`x' "Beta cognitive. Between firm, within industry"
		lab var beta_njwi_`j'_`x' "Beta non-cognitive. Between firm, within industry"

		lab var beta_ck_`j'_`x' "Beta cognitive. Between industry"
		lab var beta_nk_`j'_`x' "Beta non-cognitive. Between industry"
		
		lab var wvartot_`j'_`x' "Total wage variance"
		lab var wvarbf_`j'_`x' "Between-firm wage variance"
		lab var wvarbfwi_`j'_`x' "Between-firm within-industry wage variance"
		lab var wvarbi_`j'_`x' "Between-industry wage variance"
		lab var wvarwf_`j'_`x' "Within-firm wage variance"

		lab var wpredvarbf_`j'_`x' "Between-firm predicted wage variance"
		lab var wpredvarbfwi_`j'_`x' "Between-firm within-industry predicted wage variance"
		lab var wpredvarbi_`j'_`x' "Between-industry predicted wage variance"
		lab var wpredvarwf_`j'_`x' "Within-firm wage predicted variance"

		lab var wpredvarbf_1986_`j'_`x' "Between-firm predicted wage variance. 1986 skill gradients"
		lab var wpredvarbfwi_1986_`j'_`x' "Between-firm within-industry predicted wage variance. 1986 skill gradients"
		lab var wpredvarbi_1986_`j'_`x' "Between-industry predicted wage variance. 1986 skill gradients"
		lab var wpredvarwf_1986_`j'_`x' "Within-firm wage predicted variance. 1986 skill gradients"

		lab var wpredvarbf_2008_`j'_`x' "Between-firm predicted wage variance. 2008 skill gradients"
		lab var wpredvarbfwi_2008_`j'_`x' "Between-firm within-industry predicted wage variance. 2008 skill gradients"
		lab var wpredvarbi_2008_`j'_`x' "Between-industry predicted wage variance. 2008 skill gradients"
		lab var wpredvarwf_2008_`j'_`x' "Within-firm wage predicted variance. 2008 skill gradients"

		
		}
	}
}

save modified/wagedecomposition.dta, replace

***************************************************************
*** 15. Predicting wage variance using skills and gradients ***
***************************************************************

foreach x in ftg ast {
	use year `x'nr wa3m10 wa3m50 wa6m10 wa6m50 wa3j10 wa3j50 wa6j10 wa6j50 cj10 cj50 nj10 nj50 nobs3j10 nobs3j50 nobs6j10 nobs6j50 nobs3_10 nobs3_50 nobs6_10 nobs6_50 using modified/wage_dispersion_`x', clear
	drop if `x'nr==""
	gen cnj10=cj10*nj10
	gen cnj50=cj50*nj50
	* Get gradients
	merge m:1 year using modified/betas_unit, keepus(betamc10_`x' betamn10_`x' betamcn10_`x' betamc50_`x' betamn50_`x' betamcn50_`x' betamc10_`x'_1986 betamn10_`x'_1986 betamcn10_`x'_1986 betamc10_`x'_2008 betamn10_`x'_2008 betamcn10_`x'_2008 betamc50_`x'_1986 betamn50_`x'_1986 betamcn50_`x'_1986 betamc50_`x'_2008 betamn50_`x'_2008 betamcn50_`x'_2008 betamc10_sws_`x' betamn10_sws_`x' betamcn10_sws_`x' betamc50_sws_`x' betamn50_sws_`x' betamcn50_sws_`x' betamc10_sws_`x'_1986 betamn10_sws_`x'_1986 betamcn10_sws_`x'_1986 betamc10_sws_`x'_2008 betamn10_sws_`x'_2008 betamcn10_sws_`x'_2008 betamc50_sws_`x'_1986 betamn50_sws_`x'_1986 betamcn50_sws_`x'_1986 betamc50_sws_`x'_2008 betamn50_sws_`x'_2008 betamcn50_sws_`x'_2008)
	drop _merge
	* Predict wages
	gen wa3jhat10_`x'=cj10*betamc10_`x' + nj10*betamn10_`x' + cnj10*betamcn10_`x'
	gen wa3jhat50_`x'=cj50*betamc50_`x' + nj50*betamn50_`x' + cnj50*betamcn50_`x'
	gen wa3jhat10_1986_`x'=cj10*betamc10_`x'_1986 + nj10*betamn10_`x'_1986 + cnj10*betamcn10_`x'_1986
	gen wa3jhat50_1986_`x'=cj50*betamc50_`x'_1986 + nj50*betamn50_`x'_1986 + cnj50*betamcn50_`x'_1986
	gen wa3jhat10_2008_`x'=cj10*betamc10_`x'_2008 + nj10*betamn10_`x'_2008 + cnj10*betamcn10_`x'_2008
	gen wa3jhat50_2008_`x'=cj50*betamc50_`x'_2008 + nj50*betamn50_`x'_2008 + cnj50*betamcn50_`x'_2008
	lab var wa3jhat10_`x' "Predicted wages. `x'size 10"
	lab var wa3jhat50_`x' "Predicted wages. `x'size 50"
	lab var wa3jhat10_1986_`x' "Predicted wages, 1986 gradients. `x'size 10"
	lab var wa3jhat50_1986_`x' "Predicted wages, 1986 gradients. `x'size 50"
	lab var wa3jhat10_2008_`x' "Predicted wages, 2008 gradients. `x'size 10"
	lab var wa3jhat50_2008_`x' "Predicted wages, 2008 gradients. `x'size 50"
	* Predict SWS
	gen wa6jhat10_`x'=cj10*betamc10_sws_`x' + nj10*betamn10_sws_`x' + cnj10*betamcn10_sws_`x'
	gen wa6jhat50_`x'=cj50*betamc50_sws_`x' + nj50*betamn50_sws_`x' + cnj50*betamcn50_sws_`x'
	gen wa6jhat10_1986_`x'=cj10*betamc10_sws_`x'_1986 + nj10*betamn10_sws_`x'_1986 + cnj10*betamcn10_sws_`x'_1986
	gen wa6jhat50_1986_`x'=cj50*betamc50_sws_`x'_1986 + nj50*betamn50_sws_`x'_1986 + cnj50*betamcn50_sws_`x'_1986
	gen wa6jhat10_2008_`x'=cj10*betamc10_sws_`x'_2008 + nj10*betamn10_sws_`x'_2008 + cnj10*betamcn10_sws_`x'_2008
	gen wa6jhat50_2008_`x'=cj50*betamc50_sws_`x'_2008 + nj50*betamn50_sws_`x'_2008 + cnj50*betamcn50_sws_`x'_2008
	lab var wa6jhat10_`x' "Predicted SWS. `x'size 10"
	lab var wa6jhat50_`x' "Predicted SWS. `x'size 50"
	lab var wa6jhat10_1986_`x' "Predicted SWS, 1986 gradients. `x'size 10"
	lab var wa6jhat50_1986_`x' "Predicted SWS, 1986 gradients. `x'size 50"
	lab var wa6jhat10_2008_`x' "Predicted SWS, 2008 gradients. `x'size 10"
	lab var wa6jhat50_2008_`x' "Predicted SWS, 2008 gradients. `x'size 50"
	* Generate mean predicted wage (weighted by firm level obs)
	bysort year: egen wa3mhat10_`x'=sum((nobs3j10/nobs3_10)*wa3jhat10_`x')  
	bysort year: egen wa3mhat50_`x'=sum((nobs3j50/nobs3_50)*wa3jhat50_`x')  
	lab var wa3mhat10_`x' "Mean predicted wage. `x'size 10"
	lab var wa3mhat50_`x' "Mean predicted wage. `x'size 50"
	* Generate mean predicted SWS (weighted by firm level obs)
	bysort year: egen wa6mhat10_`x'=sum((nobs6j10/nobs6_10)*wa6jhat10_`x')  
	bysort year: egen wa6mhat50_`x'=sum((nobs6j50/nobs6_50)*wa6jhat50_`x')  
	lab var wa6mhat10_`x' "Mean predicted SWS. `x'size 10"
	lab var wa6mhat50_`x' "Mean predicted SWS. `x'size 50"
	* Generate mean predicted wage over firms by year based on 1986/2008 coefficients (weighted by firm level obs) 
	bysort year: egen wa3mhat10_1986_`x'=sum((nobs3j10/nobs3_10)*wa3jhat10_1986_`x') 
	bysort year: egen wa3mhat50_1986_`x'=sum((nobs3j50/nobs3_50)*wa3jhat50_1986_`x') 
	bysort year: egen wa3mhat10_2008_`x'=sum((nobs3j10/nobs3_10)*wa3jhat10_2008_`x') 
	bysort year: egen wa3mhat50_2008_`x'=sum((nobs3j50/nobs3_50)*wa3jhat50_2008_`x') 
	lab var wa3mhat10_1986_`x' "Mean predicted wage, 1986 gradients. `x'size 10"
	lab var wa3mhat50_1986_`x' "Mean predicted wage, 1986 gradients. `x'size 50"
	lab var wa3mhat10_2008_`x' "Mean predicted wage, 2008 gradients. `x'size 10"
	lab var wa3mhat50_2008_`x' "Mean predicted wage, 2008 gradients. `x'size 50"
	* Generate mean predicted SWS over firms by year based on 1986/2008 coefficients (weighted by firm level obs) 
	bysort year: egen wa6mhat10_1986_`x'=sum((nobs6j10/nobs6_10)*wa6jhat10_1986_`x') 
	bysort year: egen wa6mhat50_1986_`x'=sum((nobs6j50/nobs6_50)*wa6jhat50_1986_`x') 
	bysort year: egen wa6mhat10_2008_`x'=sum((nobs6j10/nobs6_10)*wa6jhat10_2008_`x') 
	bysort year: egen wa6mhat50_2008_`x'=sum((nobs6j50/nobs6_50)*wa6jhat50_2008_`x') 
	lab var wa6mhat10_1986_`x' "Mean predicted SWS, 1986 gradients. `x'size 10"
	lab var wa6mhat50_1986_`x' "Mean predicted SWS, 1986 gradients. `x'size 50"
	lab var wa6mhat10_2008_`x' "Mean predicted SWS, 2008 gradients. `x'size 10"
	lab var wa6mhat50_2008_`x' "Mean predicted SWS, 2008 gradients. `x'size 50"	
	* Between firm wage variance
	bysort year: egen BFw3_10_`x'=sum((nobs3j10/nobs3_10)*((wa3j10-wa3m10)*(wa3j10-wa3m10)))
	bysort year: egen BFw3_50_`x'=sum((nobs3j50/nobs3_50)*((wa3j50-wa3m50)*(wa3j50-wa3m50)))
	lab var BFw3_10_`x' "Between firm wage dispersion. `x'size 10"
	lab var BFw3_50_`x' "Between firm wage dispersion. `x'size 50"
	* Between firm SWS variance
	bysort year: egen BFw6_10_`x'=sum((nobs6j10/nobs6_10)*((wa6j10-wa6m10)*(wa6j10-wa6m10)))
	bysort year: egen BFw6_50_`x'=sum((nobs6j50/nobs6_50)*((wa6j50-wa6m50)*(wa6j50-wa6m50)))
	lab var BFw6_10_`x' "Between firm SWS dispersion. `x'size 10"
	lab var BFw6_50_`x' "Between firm SWS dispersion. `x'size 50"
	* Between firm prediced wage variance
	bysort year: egen BFhat3_10_`x'=sum((nobs3j10/nobs3_10)*((wa3jhat10_`x'-wa3mhat10_`x')*(wa3jhat10_`x'-wa3mhat10_`x')))
	bysort year: egen BFhat3_50_`x'=sum((nobs3j50/nobs3_50)*((wa3jhat50_`x'-wa3mhat50_`x')*(wa3jhat50_`x'-wa3mhat50_`x')))
	lab var BFhat3_10_`x' "Between firm predicted wage dispersion. `x'size 10"
	lab var BFhat3_50_`x' "Between firm predicted wage dispersion. `x'size 50"
	* Between firm prediced SWS variance
	bysort year: egen BFhat6_10_`x'=sum((nobs6j10/nobs6_10)*((wa6jhat10_`x'-wa6mhat10_`x')*(wa6jhat10_`x'-wa6mhat10_`x')))
	bysort year: egen BFhat6_50_`x'=sum((nobs6j50/nobs6_50)*((wa6jhat50_`x'-wa6mhat50_`x')*(wa6jhat50_`x'-wa6mhat50_`x')))
	lab var BFhat6_10_`x' "Between firm predicted SWS dispersion. `x'size 10"
	lab var BFhat6_50_`x' "Between firm predicted SWS dispersion. `x'size 50"	
	* Between firm prediced wage variance using 1986 and 2008 gradients
	bysort year: egen BFhat3_10_1986_`x'=sum((nobs3j10/nobs3_10)*((wa3jhat10_1986_`x'-wa3mhat10_1986_`x')*(wa3jhat10_1986_`x'-wa3mhat10_1986_`x')))
	bysort year: egen BFhat3_50_1986_`x'=sum((nobs3j50/nobs3_50)*((wa3jhat50_1986_`x'-wa3mhat50_1986_`x')*(wa3jhat50_1986_`x'-wa3mhat50_1986_`x')))
	bysort year: egen BFhat3_10_2008_`x'=sum((nobs3j10/nobs3_10)*((wa3jhat10_2008_`x'-wa3mhat10_2008_`x')*(wa3jhat10_2008_`x'-wa3mhat10_2008_`x')))
	bysort year: egen BFhat3_50_2008_`x'=sum((nobs3j50/nobs3_50)*((wa3jhat50_2008_`x'-wa3mhat50_2008_`x')*(wa3jhat50_2008_`x'-wa3mhat50_2008_`x')))
	lab var BFhat3_10_1986_`x' "Between firm predicted wage dispersion, 1986 gradients. `x'size 10"
	lab var BFhat3_50_1986_`x' "Between firm predicted wage dispersion, 1986 gradients. `x'size 50"
	lab var BFhat3_10_2008_`x' "Between firm predicted wage dispersion, 2008 gradients. `x'size 10"
	lab var BFhat3_50_2008_`x' "Between firm predicted wage dispersion, 2008 gradients. `x'size 50"
	* Between firm prediced SWS variance using 1986 and 2008 gradients
	bysort year: egen BFhat6_10_1986_`x'=sum((nobs6j10/nobs6_10)*((wa6jhat10_1986_`x'-wa6mhat10_1986_`x')*(wa6jhat10_1986_`x'-wa6mhat10_1986_`x')))
	bysort year: egen BFhat6_50_1986_`x'=sum((nobs6j50/nobs6_50)*((wa6jhat50_1986_`x'-wa6mhat50_1986_`x')*(wa6jhat50_1986_`x'-wa6mhat50_1986_`x')))
	bysort year: egen BFhat6_10_2008_`x'=sum((nobs6j10/nobs6_10)*((wa6jhat10_2008_`x'-wa6mhat10_2008_`x')*(wa6jhat10_2008_`x'-wa6mhat10_2008_`x')))
	bysort year: egen BFhat6_50_2008_`x'=sum((nobs6j50/nobs6_50)*((wa6jhat50_2008_`x'-wa6mhat50_2008_`x')*(wa6jhat50_2008_`x'-wa6mhat50_2008_`x')))
	lab var BFhat6_10_1986_`x' "Between firm predicted SWS dispersion, 1986 gradients. `x'size 10"
	lab var BFhat6_50_1986_`x' "Between firm predicted SWS dispersion, 1986 gradients. `x'size 50"
	lab var BFhat6_10_2008_`x' "Between firm predicted SWS dispersion, 2008 gradients. `x'size 10"
	lab var BFhat6_50_2008_`x' "Between firm predicted SWS dispersion, 2008 gradients. `x'size 50"	
	* Collapse to annual measures
	collapse BFw3_10_`x' BFw3_50_`x' BFhat3_10_`x' BFhat3_50_`x' BFhat3_10_1986_`x' BFhat3_50_1986_`x' BFhat3_10_2008_`x' BFhat3_50_2008_`x' BFw6_10_`x' BFw6_50_`x' BFhat6_10_`x' BFhat6_50_`x' BFhat6_10_1986_`x' BFhat6_50_1986_`x' BFhat6_10_2008_`x' BFhat6_50_2008_`x', by(year)
	lab var BFw3_10_`x' "Between firm wage dispersion. `x'size 10"
	lab var BFw3_50_`x' "Between firm wage dispersion. `x'size 50"
	lab var BFhat3_10_`x' "Between firm predicted wage dispersion. `x'size 10"
	lab var BFhat3_50_`x' "Between firm predicted wage dispersion. `x'size 50"
	lab var BFhat3_10_1986_`x' "Between firm predicted wage dispersion, 1986 gradients. `x'size 10"
	lab var BFhat3_50_1986_`x' "Between firm predicted wage dispersion, 1986 gradients. `x'size 50"
	lab var BFhat3_10_2008_`x' "Between firm predicted wage dispersion, 2008 gradients. `x'size 10"
	lab var BFhat3_50_2008_`x' "Between firm predicted wage dispersion, 2008 gradients. `x'size 50"
	lab var BFw6_10_`x' "Between firm SWS dispersion. `x'size 10"
	lab var BFw6_50_`x' "Between firm SWS dispersion. `x'size 50"
	lab var BFhat6_10_`x' "Between firm predicted SWS dispersion. `x'size 10"
	lab var BFhat6_50_`x' "Between firm predicted SWS dispersion. `x'size 50"
	lab var BFhat6_10_1986_`x' "Between firm predicted SWS dispersion, 1986 gradients. `x'size 10"
	lab var BFhat6_50_1986_`x' "Between firm predicted SWS dispersion, 1986 gradients. `x'size 50"
	lab var BFhat6_10_2008_`x' "Between firm predicted SWS dispersion, 2008 gradients. `x'size 10"
	lab var BFhat6_50_2008_`x' "Between firm predicted SWS dispersion, 2008 gradients. `x'size 50"
	save temp/predicted_variance_`x', replace
	}
use temp/predicted_variance_ftg,clear
merge 1:1 year using temp/predicted_variance_ast
drop _merge
sort year
save modified/predicted_variance, replace

**********************************************
****** Estimate AKM using rolling windows ****
**********************************************

clear
set mem 20g
cd /home/workgroups/firmiq/data/
set more off

log using results/akm_4_2_log, replace text

* Window size +/-4. Years 1989-2005.
forvalues j=1989(1)2005 {

* Put all obs in one file
use lopnr age sex lnwpred_ftg edyr zedyr c n sex age ftgnr ftg_ast astnr ast_ftg  ftgstorl_ftg year privfirm_ftg using modified/sample1985.dta, clear

forvalues i = 1986(1)2009 {
	append using modified/sample`i'.dta, keep(lopnr age sex lnwpred_ftg edyr zedyr c n sex age ftgnr ftg_ast astnr ast_ftg  ftgstorl_ftg year privfirm_ftg ) 
}

drop if year<(`j'-4)
drop if year>(`j'+4) 

* Drop small firms, women, young/old individuals, and obs without wages
keep if privfirm_ftg==1
drop if ftgstorl_ftg<=5
drop if sex=="2"
drop if age==.
gen age1=age
drop if age<=19
drop if age>=64
drop if lnwpred_ftg==.

sort lopnr ftgnr
egen new_person_id = group(lopnr)
egen new_firm_id = group(ftgnr)

* Preserve funkar inte (för stort) så jag sparar tempall istället
save tempall.dta, replace

*** Generating interconnected set
use tempall.dta,clear
keep new_person_id new_firm_id
duplicates drop
bysort new_firm_id: egen n_obs_wi_firm = count(new_person_id)
egen max_n_obs_wi_firm = max(n_obs_wi_firm)
*start with largest firm
gen interconnected = max_n_obs_wi_firm == n_obs_wi_firm
keep new_person_id new_firm_id interconnected
sort new_person_id new_firm_id interconnected
save interconnected.dta, replace
use interconnected.dta, clear
* Should this be loopend rather than looend?
local loopend= 0 
while `loopend' == 0 {
	local loopend = 1
	*keep ppl who work in the largest firm, and the firms where they work at other times in their life
	bysort new_person_id: egen inset = max(interconnected)
	keep if inset == 1 
	*get a new set of firm_ids and repeat the process, unless there are no new firms. 
	drop if interconnected == 1 
	drop interconnected
	sort new_person_id new_firm_id 
	count 
	local keep_going = r(N)
	if `keep_going' != 0 {
		local loopend = 0 
		merge 1:1 new_person_id new_firm_id using interconnected.dta
		replace interconnected = 1 if inset == 1 
		bysort new_firm_id: egen temp = max(interconnected)
		drop inset interconnected _merge
		rename temp interconnected
		sort new_person_id new_firm_id
		save interconnected.dta, replace
	}
}


* Put all obs in one file
use lopnr age sex lnwpred_ftg edyr zedyr c n sex age ftgnr ftg_ast astnr ast_ftg  ftgstorl_ftg privfirm_ftg year using modified/sample1985.dta, clear
forvalues i = 1986(1)2009 {
	append using modified/sample`i'.dta, keep(lopnr age sex lnwpred_ftg edyr zedyr c n sex age ftgnr ftg_ast astnr ast_ftg ftgstorl_ftg privfirm_ftg year ) 
}

drop if year<(`j'-4)
drop if year>(`j'+4) 

* Drop small firms, women, young/old individuals, and obs without wages
keep if privfirm_ftg==1
drop if ftgstorl_ftg<=5
drop if sex=="2"
drop if age<=19
drop if age>=64
drop if lnwpred_ftg==.
drop if age==.
gen age1=age
gen age2=age^2
*gen age3=age^3

sort lopnr ftgnr
egen new_person_id = group(lopnr)
egen new_firm_id = group(ftgnr)

tab year, gen(dy)

sort new_person_id new_firm_id
cap drop _merge
merge m:1 new_person_id new_firm_id using interconnected.dta
tab interconnected 

keep if interconnected == 1 
drop interconnected _merge

keep lnwpred_ftg age1 dy* year new_person_id new_firm_id lopnr

* residualize wages
reg lnwpred_ftg i.age1
predict wageres, resid

a2reg wageres dy*, individual(new_person_id) unit(new_firm_id) uniteffect(firm_FE_hat) indeffect(individual_FE_hat)

keep individual_FE_hat firm_FE_hat age1 year lopnr

keep if year==`j'
duplicates drop lopnr, force

* Standardize by year
egen p1mean=mean(individual_FE_hat)
egen p1sd=sd(individual_FE_hat)
gen p1z`j'=(individual_FE_hat-p1mean)/p1sd

* Standardize by year and cohort
bysort age1: egen p2mean=mean(individual_FE_hat)
bysort age1: egen p2sd=sd(individual_FE_hat)
gen p2z`j'=(individual_FE_hat-p2mean)/p2sd

lab var p1z`j' "AKM by year"
lab var p2z`j' "AKM by cohort-year"

rename individual_FE_hat praw`j'
rename firm_FE_hat fraw`j'

lab var praw`j' "AKM raw person effect"
lab var fraw`j' "AKM raw firm effect"

keep year lopnr p1z`j' p2z`j'  praw`j'  fraw`j'

sum year lopnr p1z`j' p2z`j'  praw`j'  fraw`j'

sort lopnr
save temp/akm_4_2_`j'.dta, replace
}


use temp/akm_4_2_1989.dta, clear
forvalues j=1990(1)2005 {
	merge 1:1 lopnr using temp/akm_4_2_`j'.dta
	drop _merge
}
* Saving AKM-version 2: age-dummy residualized wages
 
sort lopnr
save modified/akm_rolling_4_2.dta, replace

* Clean-up
forvalues j=1989(1)2005 {
	erase temp/akm_4_2_`j'.dta
	}
log close

*************************************
*** AKM sorting. 30-35 year olds ****
*************************************

set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1989(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'
				
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
				
		* Keep relevant sample
		keep if sample_3035_`j'_`x'==1
		keep if p~=.
		
		reg p c n
		gen betac=_b[c]
		gen betan=_b[n]
		gen r2=e(r2)
		sum p
		gen pmean=r(mean)
		gen psd=r(sd)
		gen pobs=r(N)
		sum c
		gen cmean=r(mean)
		gen csd=r(sd)
		gen cobs=r(N)
		sum n
		gen nmean=r(mean)
		gen nsd=r(sd)
		
		preserve 
			keep year betac betan r2 pmean psd cmean csd nmean nsd pobs cobs
			duplicates drop year, force
			save temp/akm_summary_stats_3035_`i'.dta, replace
		restore

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		***Actual skill means
		*industry
		bysort `x'sni2: egen pk=mean(p)
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen pj=mean(p)
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*firm/plant yrke
		bysort `x'nr yrke: egen phj=mean(p)
		bysort `x'nr yrke: egen chj=mean(c) 
		bysort `x'nr yrke: egen nhj=mean(n) 
		bysort `x'nr yrke: egen ehj=mean(edyr)
		bysort `x'nr yrke: egen zehj=mean(zedyr) 

		*yrke
		bysort yrke: egen ph=mean(p)
		bysort yrke: egen ch=mean(c) 
		bysort yrke: egen nh=mean(n) 
		bysort yrke: egen eh=mean(edyr) 
		bysort yrke: egen zeh=mean(zedyr) 

		*sample
		egen pbar=mean(p)
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		*Observed samples and sizes
		* rename ftgstorl_`x' Nj
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		bysort `x'nr: egen N2j=total(count) 
		egen N2=total(count) 

		***Predicted skills
		areg p, absorb(yrke)
		predict pijtilde if e(sample),xbd
		predict pijres if e(sample), resid
		areg c, absorb(yrke)
		predict cijtilde if e(sample),xbd
		predict cijres if e(sample), resid
		areg n, absorb(yrke)
		predict nijtilde if e(sample),xbd
		predict nijres if e(sample), resid
		areg edyr, absorb(yrke)
		predict eijtilde if e(sample), xbd
		predict eijres if e(sample), resid
		areg zedyr, absorb(yrke)
		predict zeijtilde if e(sample), xbd
		predict zeijres if e(sample), resid

		bysort `x'nr: egen pjres=mean(pijres)
		bysort `x'nr: egen cjres=mean(cijres)
		bysort `x'nr: egen njres=mean(nijres)
		bysort `x'nr: egen ejres=mean(eijres)
		bysort `x'nr: egen zejres=mean(zeijres)

		g pjtilde=pj-pjres
		g cjtilde=cj-cjres
		g njtilde=nj-njres
		g ejtilde=ej-ejres
		g zejtilde=zej-zejres

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*between occupation within firm/plant  
		g wt_p=(pijtilde-pjtilde)^2
		g wt_c=(cijtilde-cjtilde)^2
		g wt_n=(nijtilde-njtilde)^2
		g wt_e=(eijtilde-ejtilde)^2
		g wt_ze=(zeijtilde-zejtilde)^2

		*within occupation within plant 
		g wa_p=((p-pijtilde)-(pj-pjtilde))^2
		g wa_c=((c-cijtilde)-(cj-cjtilde))^2
		g wa_n=((n-nijtilde)-(nj-njtilde))^2
		g wa_e=((e-eijtilde)-(ej-ejtilde))^2
		g wa_ze=((ze-zeijtilde)-(zej-zejtilde))^2

		*within firm total variance (consistancy check)
		g ws_p=(p-pj)^2
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*within firm covariance (between and witin occ) 
		g wat_p=(pijtilde-pjtilde)*((p-pijtilde)-(pj-pjtilde))
		g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
		g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
		g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))
		g wat_ze=(zeijtilde-zejtilde)*((ze-zeijtilde)-(zej-zejtilde))

		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_p=wt_p+wa_p+2*wat_p
		g wtot_c=wt_c+wa_c+2*wat_c
		g wtot_n=wt_n+wa_n+2*wat_n
		g wtot_e=wt_e+wa_e+2*wat_e
		g wtot_ze=wt_ze+wa_ze+2*wat_ze

		* between occupation between firm
		g bt_p=(pjtilde-pbar)^2
		g bt_c=(cjtilde-cbar)^2
		g bt_n=(njtilde-nbar)^2
		g bt_e=(ejtilde-ebar)^2
		g bt_ze=(zejtilde-zebar)^2

		*within occupation between firm 
		g ba_p=(pj-pjtilde)^2
		g ba_c=(cj-cjtilde)^2
		g ba_n=(nj-njtilde)^2
		g ba_e=(ej-ejtilde)^2
		g ba_ze=(zej-zejtilde)^2

		*between firm total variance (consistancy check)
		g bs_p=(pj-pbar)^2
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*between firm covariance (within and between occ)
		g bat_p=(pjtilde-pbar)*(pj-pjtilde)
		g bat_c=(cjtilde-cbar)*(cj-cjtilde)
		g bat_n=(njtilde-nbar)*(nj-njtilde)
		g bat_e=(ejtilde-ebar)*(ej-ejtilde)
		g bat_ze=(zejtilde-zebar)*(zej-zejtilde)

		*between firm total variance 
		g btot_p=bt_p+ba_p+2*bat_p
		g btot_c=bt_c+ba_c+2*bat_c
		g btot_n=bt_n+ba_n+2*bat_n
		g btot_e=bt_e+ba_e+2*bat_e
		g btot_ze=bt_ze+ba_ze+2*bat_ze

		*total between occupation
		g tt_p=(pijtilde-pbar)^2
		g tt_c=(cijtilde-cbar)^2 
		g tt_n=(nijtilde-nbar)^2 
		g tt_e=(eijtilde-ebar)^2 
		g tt_ze=(zeijtilde-zebar)^2 

		*total within occupation
		g ta_p=(p-pijtilde)^2
		g ta_c=(c-cijtilde)^2
		g ta_n=(n-nijtilde)^2
		g ta_e=(e-eijtilde)^2
		g ta_ze=(ze-zeijtilde)^2

		*total variance (consistancy check)
		g ts_p=(p-pbar)^2
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_p=(p-pk)^2
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* t* pijtilde cijtilde nijtilde eijtilde zeijtilde pijres cijres nijres eijres zeijres p c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 pj cj nj ej zej pjtilde cjtilde njtilde pk ck nk ek zek lnwpredk lnwagek pbar cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_p=ws_p*thetaj_w*N2j
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		* between occ within firm/plant corrected
		g corr_wt_p=wt_p*thetaj_w*N2j
		g corr_wt_c=wt_c*thetaj_w*N2j
		g corr_wt_n=wt_n*thetaj_w*N2j
		g corr_wt_e=wt_e*thetaj_w*N2j
		g corr_wt_ze=wt_ze*thetaj_w*N2j

		*within occ within firm/plant corrected
		g corr_wa_p=wa_p*thetaj_w*N2j
		g corr_wa_c=wa_c*thetaj_w*N2j
		g corr_wa_n=wa_n*thetaj_w*N2j
		g corr_wa_e=wa_e*thetaj_w*N2j
		g corr_wa_ze=wa_ze*thetaj_w*N2j

		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_p=wat_p*thetaj_w*N2j
		g corr_wat_c=wat_c*thetaj_w*N2j
		g corr_wat_n=wat_n*thetaj_w*N2j
		g corr_wat_e=wat_e*thetaj_w*N2j
		g corr_wat_ze=wat_ze*thetaj_w*N2j

		*within firm/plant total variance corrected
		g corr_wtot_p=corr_wt_p+corr_wa_p+2*corr_wat_p
		g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
		g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
		g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e
		g corr_wtot_ze=corr_wt_ze+corr_wa_ze+2*corr_wat_ze

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_p=N2j*(bs_p-thetaj_b*ws_p)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*between occ between firm/plant corrected
		g corr_bt_p=N2j*(bt_p-thetaj_b*wt_p)
		g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
		g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
		g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)
		g corr_bt_ze=N2j*(bt_ze-thetaj_b*wt_ze)

		*within occ between firm/plant corrected
		g corr_ba_p=N2j*(ba_p-thetaj_b*wa_p)
		g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
		g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
		g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)
		g corr_ba_ze=N2j*(ba_ze-thetaj_b*wa_ze)

		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_p=N2j*(bat_p-thetaj_b*wat_p)
		g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
		g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
		g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)
		g corr_bat_ze=N2j*(bat_ze-thetaj_b*wat_ze)

		*between firm/plant total variance corrected
		g corr_btot_p=corr_bt_p+corr_ba_p+2*corr_bat_p
		g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
		g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
		g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e
		g corr_btot_ze=corr_bt_ze+corr_ba_ze+2*corr_bat_ze

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_p=bt_p*N2j
		replace bt_c=bt_c*N2j
		replace bt_n=bt_n*N2j
		replace bt_e=bt_e*N2j
		replace bt_ze=bt_ze*N2j

		* within occupation between firm/plant
		replace ba_p=ba_p*N2j
		replace ba_c=ba_c*N2j
		replace ba_n=ba_n*N2j
		replace ba_e=ba_e*N2j
		replace ba_ze=ba_ze*N2j

		*between firm/plant covariance (between and within occupation)
		replace bat_p=bat_p*N2j
		replace bat_c=bat_c*N2j
		replace bat_n=bat_n*N2j
		replace bat_e=bat_e*N2j
		replace bat_ze=bat_ze*N2j

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_p=bs_p*N2j
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*between firm/plant total variance
		replace btot_p=btot_p*N2j
		replace btot_c=btot_c*N2j
		replace btot_n=btot_n*N2j
		replace btot_e=btot_e*N2j
		replace btot_ze=btot_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)

		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*final uncorrected variances 

		*between occupation within firm/plant
		replace wt_p=wt_p*1/N2
		replace wt_c=wt_c*1/N2
		replace wt_n=wt_n*1/N2
		replace wt_e=wt_e*1/N2
		replace wt_ze=wt_ze*1/N2

		*within occupation within firm/plant
		replace wa_p=wa_p*1/N2
		replace wa_c=wa_c*1/N2
		replace wa_n=wa_n*1/N2
		replace wa_e=wa_e*1/N2
		replace wa_ze=wa_ze*1/N2

		*within firm/plant covariance (between and within occ)  
		replace wat_p=wat_p*2/N2
		replace wat_c=wat_c*2/N2
		replace wat_n=wat_n*2/N2
		replace wat_e=wat_e*2/N2
		replace wat_ze=wat_ze*2/N2

		*within firm/plant total variance
		replace wtot_p=wtot_p*1/N2
		replace wtot_c=wtot_c*1/N2
		replace wtot_n=wtot_n*1/N2
		replace wtot_e=wtot_e*1/N2
		replace wtot_ze=wtot_ze*1/N2

		*within firm/plant total variance (consistancy)
		replace ws_p=ws_p*1/N2
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between occupation between firm
		replace bt_p=bt_p*1/N2
		replace bt_c=bt_c*1/N2
		replace bt_n=bt_n*1/N2
		replace bt_e=bt_e*1/N2
		replace bt_ze=bt_ze*1/N2

		*within occupation between firm/plant 
		replace ba_p=ba_p*1/N2
		replace ba_c=ba_c*1/N2
		replace ba_n=ba_n*1/N2
		replace ba_e=ba_e*1/N2
		replace ba_ze=ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace bat_p=bat_p*2/N2
		replace bat_c=bat_c*2/N2
		replace bat_n=bat_n*2/N2
		replace bat_e=bat_e*2/N2
		replace bat_ze=bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace bs_p=bs_p*1/N2
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*between firm/plant total variance
		replace btot_p=btot_p*1/N2
		replace btot_c=btot_c*1/N2
		replace btot_n=btot_n*1/N2
		replace btot_e=btot_e*1/N2
		replace btot_ze=btot_ze*1/N2

		*total between occ
		replace tt_p=tt_p*1/N2
		replace tt_c=tt_c*1/N2
		replace tt_n=tt_n*1/N2
		replace tt_e=tt_e*1/N2
		replace tt_ze=tt_ze*1/N2

		*total within occ
		replace ta_p=ta_p*1/N2
		replace ta_c=ta_c*1/N2
		replace ta_n=ta_n*1/N2
		replace ta_e=ta_e*1/N2
		replace ta_ze=ta_ze*1/N2

		*total variance (consistancy)
		replace ts_p=ts_p*1/N2
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*between occ within firm corrected
		replace corr_wt_p=corr_wt_p*1/N2
		replace corr_wt_c=corr_wt_c*1/N2
		replace corr_wt_n=corr_wt_n*1/N2
		replace corr_wt_e=corr_wt_e*1/N2
		replace corr_wt_ze=corr_wt_ze*1/N2

		*within occ within firm corrected
		replace corr_wa_p=corr_wa_p*1/N2
		replace corr_wa_c=corr_wa_c*1/N2
		replace corr_wa_n=corr_wa_n*1/N2
		replace corr_wa_e=corr_wa_e*1/N2
		replace corr_wa_ze=corr_wa_ze*1/N2

		*within firm covariance (between and within occ)  
		replace corr_wat_p=corr_wat_p*2/N2
		replace corr_wat_c=corr_wat_c*2/N2
		replace corr_wat_n=corr_wat_n*2/N2
		replace corr_wat_e=corr_wat_e*2/N2
		replace corr_wat_ze=corr_wat_ze*2/N2

		*within firm/plant total variance corrected
		replace corr_wtot_p=corr_wtot_p*1/N2
		replace corr_wtot_c=corr_wtot_c*1/N2
		replace corr_wtot_n=corr_wtot_n*1/N2
		replace corr_wtot_e=corr_wtot_e*1/N2
		replace corr_wtot_ze=corr_wtot_ze*1/N2

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_p=corr_ws_p*1/N2
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between occupation between firm/plant
		replace corr_bt_p=corr_bt_p*1/N2
		replace corr_bt_c=corr_bt_c*1/N2
		replace corr_bt_n=corr_bt_n*1/N2
		replace corr_bt_e=corr_bt_e*1/N2
		replace corr_bt_ze=corr_bt_ze*1/N2

		*within occupation between firm/plant
		replace corr_ba_p=corr_ba_p*1/N2
		replace corr_ba_c=corr_ba_c*1/N2
		replace corr_ba_n=corr_ba_n*1/N2
		replace corr_ba_e=corr_ba_e*1/N2
		replace corr_ba_ze=corr_ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace corr_bat_p=corr_bat_p*2/N2
		replace corr_bat_c=corr_bat_c*2/N2
		replace corr_bat_n=corr_bat_n*2/N2
		replace corr_bat_e=corr_bat_e*2/N2
		replace corr_bat_ze=corr_bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_p=corr_bs_p*1/N2
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*between firm/plant total variance
		replace corr_btot_p=corr_btot_p*1/N2
		replace corr_btot_c=corr_btot_c*1/N2
		replace corr_btot_n=corr_btot_n*1/N2
		replace corr_btot_e=corr_btot_e*1/N2
		replace corr_btot_ze=corr_btot_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/akm_rolling4_vardecomp_3035_`x'_`j'_`i',replace
		}
	}
}
		
foreach x in ftg {
	foreach j in 10 {
	use temp/akm_rolling4_vardecomp_3035_`x'_`j'_1989,clear
		forvalues i=1990(1)2005{
		append using temp/akm_rolling4_vardecomp_3035_`x'_`j'_`i'
		}

	lab var ba_p "Within occupation between firm/plant"
	lab var bt_p "Between occupation between firm/plant"
	lab var bat_p "Between firm/plant covariance"
	lab var bs_p "Between firm/plant total"
	lab var btot_p "Between firm/plant total (consistancy)"

	lab var wa_p "Within occupation within firm/plant"
	lab var wt_p "Between occupation within firm/plant"
	lab var wat_p "Within firm/plant covariance"
	lab var ws_p "Within firm/plant total"
	lab var wtot_p "Within firm/plant total (consistancy)"

	lab var ta_p "Within occupation total"
	lab var tt_p "Between occupation total"
	lab var ts_p "Total"
	
	lab var ba_c "Within occupation between firm/plant"
	lab var bt_c "Between occupation between firm/plant"
	lab var bat_c "Between firm/plant covariance"
	lab var bs_c "Between firm/plant total"
	lab var btot_c "Between firm/plant total (consistancy)"

	lab var wa_c "Within occupation within firm/plant"
	lab var wt_c "Between occupation within firm/plant"
	lab var wat_c "Within firm/plant covariance"
	lab var ws_c "Within firm/plant total"
	lab var wtot_c "Within firm/plant total (consistancy)"

	lab var ta_c "Within occupation total"
	lab var tt_c "Between occupation total"
	lab var ts_c "Total"

	lab var ba_n "Within occupation between firm/plant"
	lab var bt_n "Between occupation between firm/plant"
	lab var bat_n "Between firm/plant covariance"
	lab var bs_n "Between firm/plant total"
	lab var btot_n "Between firm/plant total (consistancy)"

	lab var wa_n "Within occupation within firm/plant"
	lab var wt_n "Between occupation within firm/plant"
	lab var wat_n "Within firm/plant covariance"
	lab var ws_n "Within firm/plant total"
	lab var wtot_n "Within firm/plant total (consistancy)"

	lab var ta_n "Within occupation total"
	lab var tt_n "Between occupation total"
	lab var ts_n "Total"

	lab var ba_e "Within occupation between firm/plant"
	lab var bt_e "Between occupation between firm/plant"
	lab var bat_e "Between firm/plant covariance"
	lab var bs_e "Between firm/plant total"
	lab var btot_e "Between firm/plant total (consistancy)"

	lab var wa_e "Within occupation within firm/plant"
	lab var wt_e "Between occupation within firm/plant"
	lab var wat_e "Between firm/plant covariance"
	lab var ws_e "Within firm/plant total"
	lab var wtot_e "Within firm/plant total (consistancy)"

	lab var ta_e "Within occupation total"
	lab var tt_e "Between occupation total"
	lab var ts_e "Total"

	lab var ba_ze "Within occupation between firm/plant"
	lab var bt_ze "Between occupation between firm/plant"
	lab var bat_ze "Between firm/plant covariance"
	lab var bs_ze "Between firm/plant total"
	lab var btot_ze "Between firm/plant total (consistancy)"

	lab var wa_ze "Within occupation within firm/plant"
	lab var wt_ze "Between occupation within firm/plant"
	lab var wat_ze "Between firm/plant covariance"
	lab var ws_ze "Within firm/plant total"
	lab var wtot_ze "Within firm/plant total (consistancy)"

	lab var ta_ze "Within occupation total"
	lab var tt_ze "Between occupation total"
	lab var ts_ze "Total"

	lab var corr_ba_p "Within occupation between firm/plant (corrected)"
	lab var corr_bt_p "Between occupation between firm/plant (corrected)"
	lab var corr_bat_p "Between firm/plant covariance (corrected)"
	lab var corr_bs_p "Between firm/plant total (corrected)"
	lab var corr_btot_p "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_p "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_p "Between occupation within firm/plant (corrected)"
	lab var corr_wat_p "Within firm/plant covariance (corrected)"
	lab var corr_ws_p "Within firm/plant total (corrected)"
	lab var corr_wtot_p "Within firm/plant total (consistancy) (corrected)"
	
	lab var corr_ba_c "Within occupation between firm/plant (corrected)"
	lab var corr_bt_c "Between occupation between firm/plant (corrected)"
	lab var corr_bat_c "Between firm/plant covariance (corrected)"
	lab var corr_bs_c "Between firm/plant total (corrected)"
	lab var corr_btot_c "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_c "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_c "Between occupation within firm/plant (corrected)"
	lab var corr_wat_c "Within firm/plant covariance (corrected)"
	lab var corr_ws_c "Within firm/plant total (corrected)"
	lab var corr_wtot_c "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_n "Within occupation between firm/plant (corrected)"
	lab var corr_bt_n "Between occupation between firm/plant (corrected)"
	lab var corr_bat_n "Between firm covariance/plant (corrected)"
	lab var corr_bs_n "Between firm total/plant (corrected)"
	lab var corr_btot_n "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_n "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_n "Between occupation within firm/plant (corrected)"
	lab var corr_wat_n "Within firm/plant covariance (corrected)"
	lab var corr_ws_n "Within firm/plant total (corrected)"
	lab var corr_wtot_n "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_e "Within occupation between firm/plant (corrected)"
	lab var corr_bt_e "Between occupation between firm/plant (corrected)"
	lab var corr_bat_e "Between firm/plant covariance (corrected)"
	lab var corr_bs_e "Between firm/plant total (corrected)"
	lab var corr_btot_e "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_e "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_e "Between occupation within firm/plant (corrected)"
	lab var corr_wat_e "Within firm/plant covariance (corrected)"
	lab var corr_ws_e "Within firm/plant total (corrected)"
	lab var corr_wtot_e "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_ze "Within occupation between firm/plant (corrected)"
	lab var corr_bt_ze "Between occupation between firm/plant (corrected)"
	lab var corr_bat_ze "Between firm/plant covariance (corrected)"
	lab var corr_bs_ze "Between firm/plant total (corrected)"
	lab var corr_btot_ze "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_ze "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_ze "Between occupation within firm/plant (corrected)"
	lab var corr_wat_ze "Within firm/plant covariance (corrected)"
	lab var corr_ws_ze "Within firm/plant total (corrected)"
	lab var corr_wtot_ze "Within firm/plant total (consistancy) (corrected)"

	save modified/akm_vardecomp_3035,replace
	}
}		

** Summary stats: AKM 30-35
use temp/akm_summary_stats_3035_1989.dta, clear
	forvalues i=1990(1)2005 {
	append using temp/akm_summary_stats_3035_`i'
	}
save modified/akm_summary_stats_3035.dta, replace

*** AKM for men 24-60

set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1989(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'
				
		* Drop firms/plants without identifiers, impose size restrictions and keep only private firms
		drop if `x'nr==""
		keep if in_sample_3035_`j'_`x'==1
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10 & ftgstorl_`x'~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
				
		* Keep relevant sample
		keep if p~=.
		keep if sex=="1"
		keep if age>=24 & age~=.
		keep if age<=60 & age~=.
				
		reg p c n
		gen betac=_b[c]
		gen betan=_b[n]
		gen r2=e(r2)
		sum p
		gen pmean=r(mean)
		gen psd=r(sd)
		gen pobs=r(N)
		sum c
		gen cmean=r(mean)
		gen csd=r(sd)
		gen cobs=r(N)
		sum n
		gen nmean=r(mean)
		gen nsd=r(sd)
		
		preserve 
			keep year betac betan r2 pmean psd cmean csd nmean nsd pobs cobs
			duplicates drop year, force
			save temp/akm_summary_stats_2460_`i'.dta, replace
		restore

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		***Actual skill means
		*industry
		bysort `x'sni2: egen pk=mean(p)
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen pj=mean(p)
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*firm/plant yrke
		bysort `x'nr yrke: egen phj=mean(p)
		bysort `x'nr yrke: egen chj=mean(c) 
		bysort `x'nr yrke: egen nhj=mean(n) 
		bysort `x'nr yrke: egen ehj=mean(edyr)
		bysort `x'nr yrke: egen zehj=mean(zedyr) 

		*yrke
		bysort yrke: egen ph=mean(p)
		bysort yrke: egen ch=mean(c) 
		bysort yrke: egen nh=mean(n) 
		bysort yrke: egen eh=mean(edyr) 
		bysort yrke: egen zeh=mean(zedyr) 

		*sample
		egen pbar=mean(p)
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		*Observed samples and sizes
		* rename ftgstorl_`x' Nj
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		bysort `x'nr: egen N2j=total(count) 
		egen N2=total(count)
		drop if N2j<2

		***Predicted skills
		*individual
		areg p, absorb(yrke)
		predict pijtilde if e(sample),xbd
		predict pijres if e(sample), resid
		areg c, absorb(yrke)
		predict cijtilde if e(sample),xbd
		predict cijres if e(sample), resid
		areg n, absorb(yrke)
		predict nijtilde if e(sample),xbd
		predict nijres if e(sample), resid
		areg edyr, absorb(yrke)
		predict eijtilde if e(sample), xbd
		predict eijres if e(sample), resid
		areg zedyr, absorb(yrke)
		predict zeijtilde if e(sample), xbd
		predict zeijres if e(sample), resid

		bysort `x'nr: egen pjres=mean(pijres)
		bysort `x'nr: egen cjres=mean(cijres)
		bysort `x'nr: egen njres=mean(nijres)
		bysort `x'nr: egen ejres=mean(eijres)
		bysort `x'nr: egen zejres=mean(zeijres)

		g pjtilde=pj-pjres
		g cjtilde=cj-cjres
		g njtilde=nj-njres
		g ejtilde=ej-ejres
		g zejtilde=zej-zejres

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*between occupation within firm/plant  
		g wt_p=(pijtilde-pjtilde)^2
		g wt_c=(cijtilde-cjtilde)^2
		g wt_n=(nijtilde-njtilde)^2
		g wt_e=(eijtilde-ejtilde)^2
		g wt_ze=(zeijtilde-zejtilde)^2

		*within occupation within plant 
		g wa_p=((p-pijtilde)-(pj-pjtilde))^2
		g wa_c=((c-cijtilde)-(cj-cjtilde))^2
		g wa_n=((n-nijtilde)-(nj-njtilde))^2
		g wa_e=((e-eijtilde)-(ej-ejtilde))^2
		g wa_ze=((ze-zeijtilde)-(zej-zejtilde))^2

		*within firm total variance (consistancy check)
		g ws_p=(p-pj)^2
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*within firm covariance (between and witin occ) 
		g wat_p=(pijtilde-pjtilde)*((p-pijtilde)-(pj-pjtilde))
		g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
		g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
		g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))
		g wat_ze=(zeijtilde-zejtilde)*((ze-zeijtilde)-(zej-zejtilde))

		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_p=wt_p+wa_p+2*wat_p
		g wtot_c=wt_c+wa_c+2*wat_c
		g wtot_n=wt_n+wa_n+2*wat_n
		g wtot_e=wt_e+wa_e+2*wat_e
		g wtot_ze=wt_ze+wa_ze+2*wat_ze

		* between occupation between firm
		g bt_p=(pjtilde-pbar)^2
		g bt_c=(cjtilde-cbar)^2
		g bt_n=(njtilde-nbar)^2
		g bt_e=(ejtilde-ebar)^2
		g bt_ze=(zejtilde-zebar)^2

		*within occupation between firm 
		g ba_p=(pj-pjtilde)^2
		g ba_c=(cj-cjtilde)^2
		g ba_n=(nj-njtilde)^2
		g ba_e=(ej-ejtilde)^2
		g ba_ze=(zej-zejtilde)^2

		*between firm total variance (consistancy check)
		g bs_p=(pj-pbar)^2
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*between firm covariance (within and between occ)
		g bat_p=(pjtilde-pbar)*(pj-pjtilde)
		g bat_c=(cjtilde-cbar)*(cj-cjtilde)
		g bat_n=(njtilde-nbar)*(nj-njtilde)
		g bat_e=(ejtilde-ebar)*(ej-ejtilde)
		g bat_ze=(zejtilde-zebar)*(zej-zejtilde)

		*between firm total variance 
		g btot_p=bt_p+ba_p+2*bat_p
		g btot_c=bt_c+ba_c+2*bat_c
		g btot_n=bt_n+ba_n+2*bat_n
		g btot_e=bt_e+ba_e+2*bat_e
		g btot_ze=bt_ze+ba_ze+2*bat_ze

		*total between occupation
		g tt_p=(pijtilde-pbar)^2
		g tt_c=(cijtilde-cbar)^2 
		g tt_n=(nijtilde-nbar)^2 
		g tt_e=(eijtilde-ebar)^2 
		g tt_ze=(zeijtilde-zebar)^2 

		*total within occupation
		g ta_p=(p-pijtilde)^2
		g ta_c=(c-cijtilde)^2
		g ta_n=(n-nijtilde)^2
		g ta_e=(e-eijtilde)^2
		g ta_ze=(ze-zeijtilde)^2

		*total variance (consistancy check)
		g ts_p=(p-pbar)^2
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_p=(p-pk)^2
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* t* pijtilde cijtilde nijtilde eijtilde zeijtilde pijres cijres nijres eijres zeijres p c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 pj cj nj ej zej pjtilde cjtilde njtilde pk ck nk ek zek lnwpredk lnwagek pbar cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_p=ws_p*thetaj_w*N2j
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		* between occ within firm/plant corrected
		g corr_wt_p=wt_p*thetaj_w*N2j
		g corr_wt_c=wt_c*thetaj_w*N2j
		g corr_wt_n=wt_n*thetaj_w*N2j
		g corr_wt_e=wt_e*thetaj_w*N2j
		g corr_wt_ze=wt_ze*thetaj_w*N2j

		*within occ within firm/plant corrected
		g corr_wa_p=wa_p*thetaj_w*N2j
		g corr_wa_c=wa_c*thetaj_w*N2j
		g corr_wa_n=wa_n*thetaj_w*N2j
		g corr_wa_e=wa_e*thetaj_w*N2j
		g corr_wa_ze=wa_ze*thetaj_w*N2j

		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_p=wat_p*thetaj_w*N2j
		g corr_wat_c=wat_c*thetaj_w*N2j
		g corr_wat_n=wat_n*thetaj_w*N2j
		g corr_wat_e=wat_e*thetaj_w*N2j
		g corr_wat_ze=wat_ze*thetaj_w*N2j

		*within firm/plant total variance corrected
		g corr_wtot_p=corr_wt_p+corr_wa_p+2*corr_wat_p
		g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
		g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
		g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e
		g corr_wtot_ze=corr_wt_ze+corr_wa_ze+2*corr_wat_ze

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_p=N2j*(bs_p-thetaj_b*ws_p)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*between occ between firm/plant corrected
		g corr_bt_p=N2j*(bt_p-thetaj_b*wt_p)
		g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
		g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
		g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)
		g corr_bt_ze=N2j*(bt_ze-thetaj_b*wt_ze)

		*within occ between firm/plant corrected
		g corr_ba_p=N2j*(ba_p-thetaj_b*wa_p)
		g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
		g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
		g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)
		g corr_ba_ze=N2j*(ba_ze-thetaj_b*wa_ze)

		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_p=N2j*(bat_p-thetaj_b*wat_p)
		g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
		g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
		g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)
		g corr_bat_ze=N2j*(bat_ze-thetaj_b*wat_ze)

		*between firm/plant total variance corrected
		g corr_btot_p=corr_bt_p+corr_ba_p+2*corr_bat_p
		g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
		g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
		g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e
		g corr_btot_ze=corr_bt_ze+corr_ba_ze+2*corr_bat_ze

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_p=bt_p*N2j
		replace bt_c=bt_c*N2j
		replace bt_n=bt_n*N2j
		replace bt_e=bt_e*N2j
		replace bt_ze=bt_ze*N2j

		* within occupation between firm/plant
		replace ba_p=ba_p*N2j
		replace ba_c=ba_c*N2j
		replace ba_n=ba_n*N2j
		replace ba_e=ba_e*N2j
		replace ba_ze=ba_ze*N2j

		*between firm/plant covariance (between and within occupation)
		replace bat_p=bat_p*N2j
		replace bat_c=bat_c*N2j
		replace bat_n=bat_n*N2j
		replace bat_e=bat_e*N2j
		replace bat_ze=bat_ze*N2j

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_p=bs_p*N2j
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*between firm/plant total variance
		replace btot_p=btot_p*N2j
		replace btot_c=btot_c*N2j
		replace btot_n=btot_n*N2j
		replace btot_e=btot_e*N2j
		replace btot_ze=btot_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)

		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*between occupation within firm/plant
		replace wt_p=wt_p*1/N2
		replace wt_c=wt_c*1/N2
		replace wt_n=wt_n*1/N2
		replace wt_e=wt_e*1/N2
		replace wt_ze=wt_ze*1/N2

		*within occupation within firm/plant
		replace wa_p=wa_p*1/N2
		replace wa_c=wa_c*1/N2
		replace wa_n=wa_n*1/N2
		replace wa_e=wa_e*1/N2
		replace wa_ze=wa_ze*1/N2

		*within firm/plant covariance (between and within occ)  
		replace wat_p=wat_p*2/N2
		replace wat_c=wat_c*2/N2
		replace wat_n=wat_n*2/N2
		replace wat_e=wat_e*2/N2
		replace wat_ze=wat_ze*2/N2

		*within firm/plant total variance
		replace wtot_p=wtot_p*1/N2
		replace wtot_c=wtot_c*1/N2
		replace wtot_n=wtot_n*1/N2
		replace wtot_e=wtot_e*1/N2
		replace wtot_ze=wtot_ze*1/N2

		*within firm/plant total variance (consistancy)
		replace ws_p=ws_p*1/N2
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between occupation between firm
		replace bt_p=bt_p*1/N2
		replace bt_c=bt_c*1/N2
		replace bt_n=bt_n*1/N2
		replace bt_e=bt_e*1/N2
		replace bt_ze=bt_ze*1/N2

		*within occupation between firm/plant 
		replace ba_p=ba_p*1/N2
		replace ba_c=ba_c*1/N2
		replace ba_n=ba_n*1/N2
		replace ba_e=ba_e*1/N2
		replace ba_ze=ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace bat_p=bat_p*2/N2
		replace bat_c=bat_c*2/N2
		replace bat_n=bat_n*2/N2
		replace bat_e=bat_e*2/N2
		replace bat_ze=bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace bs_p=bs_p*1/N2
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*between firm/plant total variance
		replace btot_p=btot_p*1/N2
		replace btot_c=btot_c*1/N2
		replace btot_n=btot_n*1/N2
		replace btot_e=btot_e*1/N2
		replace btot_ze=btot_ze*1/N2

		*total between occ
		replace tt_p=tt_p*1/N2
		replace tt_c=tt_c*1/N2
		replace tt_n=tt_n*1/N2
		replace tt_e=tt_e*1/N2
		replace tt_ze=tt_ze*1/N2

		*total within occ
		replace ta_p=ta_p*1/N2
		replace ta_c=ta_c*1/N2
		replace ta_n=ta_n*1/N2
		replace ta_e=ta_e*1/N2
		replace ta_ze=ta_ze*1/N2

		*total variance (consistancy)
		replace ts_p=ts_p*1/N2
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*between occ within firm corrected
		replace corr_wt_p=corr_wt_p*1/N2
		replace corr_wt_c=corr_wt_c*1/N2
		replace corr_wt_n=corr_wt_n*1/N2
		replace corr_wt_e=corr_wt_e*1/N2
		replace corr_wt_ze=corr_wt_ze*1/N2

		*within occ within firm corrected
		replace corr_wa_p=corr_wa_p*1/N2
		replace corr_wa_c=corr_wa_c*1/N2
		replace corr_wa_n=corr_wa_n*1/N2
		replace corr_wa_e=corr_wa_e*1/N2
		replace corr_wa_ze=corr_wa_ze*1/N2

		*within firm covariance (between and within occ)  
		replace corr_wat_p=corr_wat_p*2/N2
		replace corr_wat_c=corr_wat_c*2/N2
		replace corr_wat_n=corr_wat_n*2/N2
		replace corr_wat_e=corr_wat_e*2/N2
		replace corr_wat_ze=corr_wat_ze*2/N2

		*within firm/plant total variance corrected
		replace corr_wtot_p=corr_wtot_p*1/N2
		replace corr_wtot_c=corr_wtot_c*1/N2
		replace corr_wtot_n=corr_wtot_n*1/N2
		replace corr_wtot_e=corr_wtot_e*1/N2
		replace corr_wtot_ze=corr_wtot_ze*1/N2

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_p=corr_ws_p*1/N2
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between occupation between firm/plant
		replace corr_bt_p=corr_bt_p*1/N2
		replace corr_bt_c=corr_bt_c*1/N2
		replace corr_bt_n=corr_bt_n*1/N2
		replace corr_bt_e=corr_bt_e*1/N2
		replace corr_bt_ze=corr_bt_ze*1/N2

		*within occupation between firm/plant
		replace corr_ba_p=corr_ba_p*1/N2
		replace corr_ba_c=corr_ba_c*1/N2
		replace corr_ba_n=corr_ba_n*1/N2
		replace corr_ba_e=corr_ba_e*1/N2
		replace corr_ba_ze=corr_ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace corr_bat_p=corr_bat_p*2/N2
		replace corr_bat_c=corr_bat_c*2/N2
		replace corr_bat_n=corr_bat_n*2/N2
		replace corr_bat_e=corr_bat_e*2/N2
		replace corr_bat_ze=corr_bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_p=corr_bs_p*1/N2
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*between firm/plant total variance
		replace corr_btot_p=corr_btot_p*1/N2
		replace corr_btot_c=corr_btot_c*1/N2
		replace corr_btot_n=corr_btot_n*1/N2
		replace corr_btot_e=corr_btot_e*1/N2
		replace corr_btot_ze=corr_btot_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/akm_rolling4_vardecomp_aggregate_2460_`x'_`j'_`i',replace
		}
	}
}
		
foreach x in ftg {
	foreach j in 10 {
	use temp/akm_rolling4_vardecomp_aggregate_2460_`x'_`j'_1989,clear
		forvalues i=1990(1)2005{
		append using temp/akm_rolling4_vardecomp_aggregate_2460_`x'_`j'_`i'
		}

	lab var ba_p "Within occupation between firm/plant"
	lab var bt_p "Between occupation between firm/plant"
	lab var bat_p "Between firm/plant covariance"
	lab var bs_p "Between firm/plant total"
	lab var btot_p "Between firm/plant total (consistancy)"

	lab var wa_p "Within occupation within firm/plant"
	lab var wt_p "Between occupation within firm/plant"
	lab var wat_p "Within firm/plant covariance"
	lab var ws_p "Within firm/plant total"
	lab var wtot_p "Within firm/plant total (consistancy)"

	lab var ta_p "Within occupation total"
	lab var tt_p "Between occupation total"
	lab var ts_p "Total"
	
	lab var ba_c "Within occupation between firm/plant"
	lab var bt_c "Between occupation between firm/plant"
	lab var bat_c "Between firm/plant covariance"
	lab var bs_c "Between firm/plant total"
	lab var btot_c "Between firm/plant total (consistancy)"

	lab var wa_c "Within occupation within firm/plant"
	lab var wt_c "Between occupation within firm/plant"
	lab var wat_c "Within firm/plant covariance"
	lab var ws_c "Within firm/plant total"
	lab var wtot_c "Within firm/plant total (consistancy)"

	lab var ta_c "Within occupation total"
	lab var tt_c "Between occupation total"
	lab var ts_c "Total"

	lab var ba_n "Within occupation between firm/plant"
	lab var bt_n "Between occupation between firm/plant"
	lab var bat_n "Between firm/plant covariance"
	lab var bs_n "Between firm/plant total"
	lab var btot_n "Between firm/plant total (consistancy)"

	lab var wa_n "Within occupation within firm/plant"
	lab var wt_n "Between occupation within firm/plant"
	lab var wat_n "Within firm/plant covariance"
	lab var ws_n "Within firm/plant total"
	lab var wtot_n "Within firm/plant total (consistancy)"

	lab var ta_n "Within occupation total"
	lab var tt_n "Between occupation total"
	lab var ts_n "Total"

	lab var ba_e "Within occupation between firm/plant"
	lab var bt_e "Between occupation between firm/plant"
	lab var bat_e "Between firm/plant covariance"
	lab var bs_e "Between firm/plant total"
	lab var btot_e "Between firm/plant total (consistancy)"

	lab var wa_e "Within occupation within firm/plant"
	lab var wt_e "Between occupation within firm/plant"
	lab var wat_e "Between firm/plant covariance"
	lab var ws_e "Within firm/plant total"
	lab var wtot_e "Within firm/plant total (consistancy)"

	lab var ta_e "Within occupation total"
	lab var tt_e "Between occupation total"
	lab var ts_e "Total"

	lab var ba_ze "Within occupation between firm/plant"
	lab var bt_ze "Between occupation between firm/plant"
	lab var bat_ze "Between firm/plant covariance"
	lab var bs_ze "Between firm/plant total"
	lab var btot_ze "Between firm/plant total (consistancy)"

	lab var wa_ze "Within occupation within firm/plant"
	lab var wt_ze "Between occupation within firm/plant"
	lab var wat_ze "Between firm/plant covariance"
	lab var ws_ze "Within firm/plant total"
	lab var wtot_ze "Within firm/plant total (consistancy)"

	lab var ta_ze "Within occupation total"
	lab var tt_ze "Between occupation total"
	lab var ts_ze "Total"

	lab var corr_ba_p "Within occupation between firm/plant (corrected)"
	lab var corr_bt_p "Between occupation between firm/plant (corrected)"
	lab var corr_bat_p "Between firm/plant covariance (corrected)"
	lab var corr_bs_p "Between firm/plant total (corrected)"
	lab var corr_btot_p "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_p "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_p "Between occupation within firm/plant (corrected)"
	lab var corr_wat_p "Within firm/plant covariance (corrected)"
	lab var corr_ws_p "Within firm/plant total (corrected)"
	lab var corr_wtot_p "Within firm/plant total (consistancy) (corrected)"
	
	lab var corr_ba_c "Within occupation between firm/plant (corrected)"
	lab var corr_bt_c "Between occupation between firm/plant (corrected)"
	lab var corr_bat_c "Between firm/plant covariance (corrected)"
	lab var corr_bs_c "Between firm/plant total (corrected)"
	lab var corr_btot_c "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_c "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_c "Between occupation within firm/plant (corrected)"
	lab var corr_wat_c "Within firm/plant covariance (corrected)"
	lab var corr_ws_c "Within firm/plant total (corrected)"
	lab var corr_wtot_c "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_n "Within occupation between firm/plant (corrected)"
	lab var corr_bt_n "Between occupation between firm/plant (corrected)"
	lab var corr_bat_n "Between firm covariance/plant (corrected)"
	lab var corr_bs_n "Between firm total/plant (corrected)"
	lab var corr_btot_n "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_n "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_n "Between occupation within firm/plant (corrected)"
	lab var corr_wat_n "Within firm/plant covariance (corrected)"
	lab var corr_ws_n "Within firm/plant total (corrected)"
	lab var corr_wtot_n "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_e "Within occupation between firm/plant (corrected)"
	lab var corr_bt_e "Between occupation between firm/plant (corrected)"
	lab var corr_bat_e "Between firm/plant covariance (corrected)"
	lab var corr_bs_e "Between firm/plant total (corrected)"
	lab var corr_btot_e "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_e "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_e "Between occupation within firm/plant (corrected)"
	lab var corr_wat_e "Within firm/plant covariance (corrected)"
	lab var corr_ws_e "Within firm/plant total (corrected)"
	lab var corr_wtot_e "Within firm/plant total (consistancy) (corrected)"

	lab var corr_ba_ze "Within occupation between firm/plant (corrected)"
	lab var corr_bt_ze "Between occupation between firm/plant (corrected)"
	lab var corr_bat_ze "Between firm/plant covariance (corrected)"
	lab var corr_bs_ze "Between firm/plant total (corrected)"
	lab var corr_btot_ze "Between firm/plant total (consistancy) (corrected)"

	lab var corr_wa_ze "Within occupation witin firm/plant (corrected)"
	lab var corr_wt_ze "Between occupation within firm/plant (corrected)"
	lab var corr_wat_ze "Within firm/plant covariance (corrected)"
	lab var corr_ws_ze "Within firm/plant total (corrected)"
	lab var corr_wtot_ze "Within firm/plant total (consistancy) (corrected)"

	save modified/akm_vardecomp_2460,replace
	}
}		

** Summary stats: AKM 24-60
use temp/akm_summary_stats_2460_1989.dta, clear
	forvalues i=1990(1)2005 {
	append using temp/akm_summary_stats_2460_`i'
	}
save modified/akm_summary_stats_2460.dta, replace

******************************************
*** AKM. between-firm/between-industry ***
******************************************
set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=2001(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear

		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'

		* Drop firms/plants without identifiers, impose size restrictions and keep only private firms
		drop if `x'nr==""
		keep if in_sample_3035_`j'_`x'==1
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10 & ftgstorl_`x'~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)

		* Keep only those with person effects
		keep if sample_3035_`j'_`x'==1
		drop if p==.

		*This part generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		*Observed samples and sizes
		bysort `x'nr: egen N2j=total(count)
		drop if N2j<2
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		egen N2=total(count) 
		
		***Actual skill means
		*industry
		bysort `x'sni2: egen pk=mean(p) 
		*firm/plant
		bysort `x'nr: egen pj=mean(p) 
		*firm/plant yrke
		bysort `x'nr yrke: egen phj=mean(p) 
		*yrke
		bysort yrke: egen ph=mean(p) 
		*sample
		egen pbar=mean(p)

		***Predicted skills
		*individual
		areg p, absorb(yrke)
		predict pijtilde if e(sample),xbd
		predict pijres if e(sample), resid
		bysort `x'nr: egen pjres=mean(pijres)
		g pjtilde=pj-pjres

		***Components for (corrected and uncorrected) variances (to be collapsed)
		*between occupation within firm/plant  
		g wt_p=(pijtilde-pjtilde)^2
		*within occupation within plant 
		g wa_p=((p-pijtilde)-(pj-pjtilde))^2
		*within firm total variance (consistancy check)
		g ws_p=(p-pj)^2
		*within firm covariance (between and witin occ) 
		g wat_p=(pijtilde-pjtilde)*((p-pijtilde)-(pj-pjtilde))
		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_p=wt_p+wa_p+2*wat_p
		* between occupation between firm
		g bt_p=(pjtilde-pbar)^2
		*within occupation between firm 
		g ba_p=(pj-pjtilde)^2
		*between firm total variance (consistancy check)
		g bs_p=(pj-pbar)^2
		*between firm covariance (within andd between occ)
		g bat_p=(pjtilde-pbar)*(pj-pjtilde)
		*between firm total variance 
		g btot_p=bt_p+ba_p+2*bat_p
		*total between occupation
		g tt_p=(pijtilde-pbar)^2 
		*total within occupation
		g ta_p=(p-pijtilde)^2		
		*total variance (consistancy check)
		g ts_p=(p-pbar)^2
		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_p=(p-pk)^2

		*** B.Collapse to firm/plant level 
		collapse (sum) w* t* pijtilde pijres p corr_bi* (mean) b* ftgstorl_`x' Nj N2j N2 pj pjtilde pk pbar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*** Components for corrected variances
		*within firm/plant total variance corrected 
		g corr_ws_p=ws_p*thetaj_w*N2j
		* between occ within firm/plant corrected
		g corr_wt_p=wt_p*thetaj_w*N2j
		*within occ within firm/plant corrected
		g corr_wa_p=wa_p*thetaj_w*N2j		
		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_p=wat_p*thetaj_w*N2j
		*within firm/plant total variance corrected
		g corr_wtot_c=corr_wt_p+corr_wa_p+2*corr_wat_p		
		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_p=N2j*(bs_p-thetaj_b*ws_p)
		*between occ between firm/plant corrected
		g corr_bt_p=N2j*(bt_p-thetaj_b*wt_p)		
		*within occ between firm/plant corrected
		g corr_ba_p=N2j*(ba_p-thetaj_b*wa_p)
		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_p=N2j*(bat_p-thetaj_b*wat_p)
		*between firm/plant total variance corrected
		g corr_btot_p=corr_bt_p+corr_ba_p+2*corr_bat_p		

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_p=bt_p*N2j
		* within occupation between firm/plant
		replace ba_p=ba_p*N2j		
		*between firm/plant covariance (between and within occupation)
		replace bat_p=bat_p*N2j		
		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_p=bs_p*N2j
		*between firm/plant total variance
		replace btot_p=btot_p*N2j		

		*** D. Collapse to industry level for use in regressions. 
		*components for between-firm/plant within-industry variance
	preserve
		g bfwi_p=N2j*(pj-pk)^2
		collapse (sum) w* b* t* corr* pktilde=pijtilde pkres=pijres Nk=Nj N2k=N2j (mean) N2 pk pbar, by(year `x'sni2)

		*sample correction industry level
		g thetak=((Nk-N2k)/(N2k*Nk))*(1/(N2k-1))

		*components for bfwi variance and bi variance
		replace corr_bi_p=N2k*((pk-pbar)^2-thetak*corr_bi_p)
		g bi_p=N2k*(pk-pbar)^2

		collapse (sum) btot* bfwi* corr_bi* corr_btot* bi* (mean) N2, by (year)

		replace btot_p=btot_p/N2
		replace bfwi_p=bfwi_p/N2
		replace bi_p=bi_p/N2
		replace corr_btot_p=corr_btot_p/N2
		replace corr_bi_p=corr_bi_p/N2

		g corr_bfwi_p=corr_btot_p-corr_bi_p
	
		lab var btot_p "Between firm/plant total"
		lab var bfwi_p "Between firm/plant within industry"
		lab var bi_p "Between industry"
		lab var corr_btot_p "Between firm/plant total (corrected)"
		lab var corr_bi_p "Between industry (corrected)"
		lab var corr_bfwi_p "Between firm/plant within industry (corrected)"
		save temp/akm_bfwi_bi_`i', replace	
	restore
		*** 4. Overall collapse
		collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)
		replace bs_p=bs_p/N2
		replace corr_bs_p=corr_bs_p/N2
		replace btot_p=btot_p/N2
		replace corr_btot_p=corr_btot_p/N2
		
		keep year bs_p corr_bs_p btot_p corr_btot_p
		save temp/akm_bf_`i', replace

}
}
}

* Between industry, between-firm, within industry
use temp/akm_bfwi_bi_1989, clear 
forvalues i=1990(1)2005 {
	append using temp/akm_bfwi_bi_`i'
}
save modified/akm_bfwi_bi, replace

* Between firm
use temp/akm_bf_1989, clear
forvalues i=1990(1)2005 {
	append using temp/akm_bf_`i'
}
save modified/akm_bf, replace

*******************************
*** AKM bf/wi excluding ICT ***
*******************************

set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1989(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear

		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'

		* Drop firms/plants without identifiers, impose size restrictions and keep only private firms
		drop if `x'nr==""
		keep if in_sample_3035_`j'_`x'==1
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10 & ftgstorl_`x'~=.
		
		* Generate count variable
		g count=1

		* Drop IT (72) and telecom (32) 
		drop if `x'sni2==72
		drop if `x'sni2==32

		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)

		* Keep only those with person effects
		keep if sample_3035_`j'_`x'==1
		drop if p==.

		*This part generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		*Observed samples and sizes
		bysort `x'nr: egen N2j=total(count)
		drop if N2j<2
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		egen N2=total(count) 
		
		***Actual skill means
		*industry
		bysort `x'sni2: egen pk=mean(p) 
		*firm/plant
		bysort `x'nr: egen pj=mean(p) 
		*firm/plant yrke
		bysort `x'nr yrke: egen phj=mean(p) 
		*yrke
		bysort yrke: egen ph=mean(p) 
		*sample
		egen pbar=mean(p)

		***Predicted skills
		*individual
		areg p, absorb(yrke)
		predict pijtilde if e(sample),xbd
		predict pijres if e(sample), resid
		bysort `x'nr: egen pjres=mean(pijres)
		g pjtilde=pj-pjres

		***Components for (corrected and uncorrected) variances (to be collapsed)
		*between occupation within firm/plant  
		g wt_p=(pijtilde-pjtilde)^2
		*within occupation within plant 
		g wa_p=((p-pijtilde)-(pj-pjtilde))^2
		*within firm total variance (consistancy check)
		g ws_p=(p-pj)^2
		*within firm covariance (between and witin occ) 
		g wat_p=(pijtilde-pjtilde)*((p-pijtilde)-(pj-pjtilde))
		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_p=wt_p+wa_p+2*wat_p
		* between occupation between firm
		g bt_p=(pjtilde-pbar)^2
		*within occupation between firm 
		g ba_p=(pj-pjtilde)^2
		*between firm total variance (consistancy check)
		g bs_p=(pj-pbar)^2
		*between firm covariance (within andd between occ)
		g bat_p=(pjtilde-pbar)*(pj-pjtilde)
		*between firm total variance 
		g btot_p=bt_p+ba_p+2*bat_p
		*total between occupation
		g tt_p=(pijtilde-pbar)^2 
		*total within occupation
		g ta_p=(p-pijtilde)^2		
		*total variance (consistancy check)
		g ts_p=(p-pbar)^2
		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_p=(p-pk)^2

		*** B.Collapse to firm/plant level 
		collapse (sum) w* t* pijtilde pijres p corr_bi* (mean) b* ftgstorl_`x' Nj N2j N2 pj pjtilde pk pbar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*** Components for corrected variances
		*within firm/plant total variance corrected 
		g corr_ws_p=ws_p*thetaj_w*N2j
		* between occ within firm/plant corrected
		g corr_wt_p=wt_p*thetaj_w*N2j
		*within occ within firm/plant corrected
		g corr_wa_p=wa_p*thetaj_w*N2j		
		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_p=wat_p*thetaj_w*N2j
		*within firm/plant total variance corrected
		g corr_wtot_c=corr_wt_p+corr_wa_p+2*corr_wat_p		
		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_p=N2j*(bs_p-thetaj_b*ws_p)
		*between occ between firm/plant corrected
		g corr_bt_p=N2j*(bt_p-thetaj_b*wt_p)		
		*within occ between firm/plant corrected
		g corr_ba_p=N2j*(ba_p-thetaj_b*wa_p)
		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_p=N2j*(bat_p-thetaj_b*wat_p)
		*between firm/plant total variance corrected
		g corr_btot_p=corr_bt_p+corr_ba_p+2*corr_bat_p		

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_p=bt_p*N2j
		* within occupation between firm/plant
		replace ba_p=ba_p*N2j		
		*between firm/plant covariance (between and within occupation)
		replace bat_p=bat_p*N2j		
		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_p=bs_p*N2j
		*between firm/plant total variance
		replace btot_p=btot_p*N2j		

		*** D. Collapse to industry level for use in regressions. 
		*components for between-firm/plant within-industry variance
	preserve
		g bfwi_p=N2j*(pj-pk)^2
		collapse (sum) w* b* t* corr* pktilde=pijtilde pkres=pijres Nk=Nj N2k=N2j (mean) N2 pk pbar, by(year `x'sni2)

		*sample correction industry level
		g thetak=((Nk-N2k)/(N2k*Nk))*(1/(N2k-1))

		*components for bfwi variance and bi variance
		replace corr_bi_p=N2k*((pk-pbar)^2-thetak*corr_bi_p)
		g bi_p=N2k*(pk-pbar)^2

		collapse (sum) btot* bfwi* corr_bi* corr_btot* bi* (mean) N2, by (year)

		replace btot_p=btot_p/N2
		replace bfwi_p=bfwi_p/N2
		replace bi_p=bi_p/N2
		replace corr_btot_p=corr_btot_p/N2
		replace corr_bi_p=corr_bi_p/N2

		g corr_bfwi_p=corr_btot_p-corr_bi_p
	
		lab var btot_p "Between firm/plant total"
		lab var bfwi_p "Between firm/plant within industry"
		lab var bi_p "Between industry"
		lab var corr_btot_p "Between firm/plant total (corrected)"
		lab var corr_bi_p "Between industry (corrected)"
		lab var corr_bfwi_p "Between firm/plant within industry (corrected)"
		save temp/akm_exICT_bfwi_bi_`i', replace	
	restore
		*** 4. Overall collapse
		collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)
		replace bs_p=bs_p/N2
		replace corr_bs_p=corr_bs_p/N2
		replace btot_p=btot_p/N2
		replace corr_btot_p=corr_btot_p/N2
		
		keep year bs_p corr_bs_p btot_p corr_btot_p
		save temp/akm_bf_exICT_`i', replace
		
}
}
}

* Between industry, between-firm, within industry exICT 
use temp/akm_exICT_bfwi_bi_1989, 
forvalues i=1990(1)2005 {
	append using temp/akm_exICT_bfwi_bi_`i'
}
rename btot_p btot_p_exICT 
rename bfwi_p bfwi_p_exICT 
rename corr_bi_p corr_bi_p_exICT 
rename corr_btot_p corr_btot_p_exICT 
rename bi_p bi_p_exICT 
rename N2 N2_exICT 
rename corr_bfwi_p corr_bfwi_p_exICT

save modified/akm_bfwi_bi_exICT, replace

* Between firm, exICT
use temp/akm_bf_exICT_1989, clear
forvalues i=1990(1)2005 {
	append using temp/akm_bf_exICT_`i'
}
rename bs_p bs_p_exICT 
rename corr_bs_p corr_bs_p_exICT 
rename btot_p btot_p_exICT 
rename corr_btot_p corr_btot_p_exICT

save modified/akm_bf_exICT, replace

********************************************
*** Decomposing the variance of wages ******
******************************************** 

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
		
				* Generate count variable
				g count=1
		
				* Actual firm employees
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
				rename lnwpred_`x' wage

				* Number of firm level observations 
				bysort `x'nr: egen nj=total(count)
				* Drop if less than two obs per firm (needed for size adjustments)
				drop if nj<2
				
				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(nj-1))
				g theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
				
				* Total number of observations
				egen n2=total(count)
								
				* Mean sample wages
				egen wbar=mean(wage)
				* Mean wages by firm/plant
				bysort `x'nr: egen wj=mean(wage)
				* Wages demeaned by firm
				gen wdm=wage-wj
				
				* Total wage variance: wvar
				egen wvar=sum((wage-wbar)^2)
				replace wvar=wvar/n2
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adj1=sum(wdm^2)
				gen wvarw=adj1/nj
								
				* Within firm variance by firm, sample size adjusted: wvarw_adj 
				gen wvarw_adj=adj1*theta_wf
				
				* Between firm wage variance: wvarb
				egen wvarb=sum((wj-wbar)^2)
				replace wvarb=wvarb/n2

				* Between firm wage variance, sample size adjusted: wvarb_adj
				egen wvarb_adj=sum((wj-wbar)^2 - (theta_bf*adj1))
				replace wvarb_adj=wvarb_adj/n2
				
				* Total within firm: sum unadjusted and adjusted, divide by total number of observations
				egen wvarwtot=sum(wvarw)
				replace wvarwtot=wvarwtot/n2

				egen wvarwtot_adj=sum(wvarw_adj)
				replace wvarwtot_adj=wvarwtot_adj/n2
				
				drop wvarw wvarw_adj
				rename wvarwtot wvarw
				rename wvarwtot_adj wvarw_adj
				keep year wvar wvarw wvarw_adj wvarb wvarb_adj n2
				duplicates drop year, force
		save temp/wagevardecomposition_`x'_`j'_`i'.dta,replace
		}
	}
}

* Append into one file
use temp/wagevardecomposition_ftg_10_1986.dta, clear
	forvalues i=1987(1)2008 {
	append using temp/wagevardecomposition_ftg_10_`i'.dta
}

lab var wvar "Wage variance"
lab var wvarb "Between firm"
lab var wvarb_adj "Between firm"
lab var wvarw "Within firm"
lab var wvarw_adj "Within firm"

save modified/wagevardecomposition_ftg_10.dta, replace



**********************************************************
*** Decomposing the variance of wages                  ***
*** between_within_actual_counterfactual.dta           ***
*** between_within_actual_counterfactual_exICT.dta	   ***
*** between_within_actual_counterfactual_exFinance.dta ***
**********************************************************

*************************************************************************************************************************
*** Between and within firm, actual and counterfactural variance of wages                                   *************
*** between_within_actual_counterfactual.dta Also versions excluding ICT and finance, respectively          *************
*************************************************************************************************************************

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	

				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
				
				* Generate count variable
				g count=1
				
				* Actual firm employees (for sampling error)
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
				merge 1:1 lopnr using modified/combskill_measure.dta
				drop if _merge==2
				
				* Number of firm/plant observations (nj>=2 needed for sampling error adjustments)
				bysort `x'nr: egen n2j=count(lnwpred_`x')
				drop if n2j<2

				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(n2j-1))
				g theta_bf=((Nj-n2j)/(Nj*n2j))*(1/(n2j-1))

				* Total number of observations
				egen n2=total(count)
				* Number of sector observations
				bysort `x'sni2: egen n2k=count(lnwpred_`x')
				
				* Mean sample wages
				egen wm=mean(lnwpred_`x')
				* Mean wages by firm/plant
				bysort `x'nr year: egen wj=mean(lnwpred_`x')
				* Mean wages by sector
				bysort `x'sni2: egen wk=mean(lnwpred_`x')
				* Wages demeaned by firm
				gen wdm=lnwpred_`x'-wj
				
				* Mean sample skills
				egen cm=mean(c)
				egen nm=mean(n)
				egen sm=mean(skill)
				
				* Mean firm/plant skills
				bysort `x'nr year: egen cj=mean(c)
				bysort `x'nr year: egen nj=mean(n)
				bysort `x'nr year: egen sj=mean(skill)
				
				* Mean sector skills
				bysort `x'sni2: egen ck=mean(c)
				bysort `x'sni2: egen nk=mean(n)
				bysort `x'sni2: egen sk=mean(skill)
				
				* Skills demeaned by firm
				gen cdm=c-cj
				gen ndm=n-nj
				gen sdm=skill-sj
				
				* Firm level skill regression
				reg wj cj
				gen beta_cj_`i'=_b[cj]
				reg wj nj
				gen beta_nj_`i'=_b[nj]
				reg wj sj
				gen beta_sj_`i'=_b[sj]
				predict whatj_`i'
				egen whatm=mean(whatj_`i')
				
				* Within firm skill regression
				reg wdm cdm
				gen beta_cw_`i'=_b[cdm]
				reg wdm ndm
				gen beta_nw_`i'=_b[ndm]				
				reg wdm sdm
				gen beta_sw_`i'=_b[sdm]
								
				* Individual level skill regression
				reg lnwpred_`x' c
				gen beta_c_`i'=_b[c]
				reg lnwpred_`x' n
				gen beta_n_`i'=_b[n]
				reg lnwpred_`x' skill
				gen beta_s_`i'=_b[skill]
				
				* Total wage and skill variance
				egen wvar=sd(lnwpred_`x')
				gen wvar_`i'=wvar*wvar
				egen cvar=sd(c)
				gen cvar_`i'=cvar*cvar
				egen nvar=sd(n)
				gen nvar_`i'=nvar*nvar
				egen svar=sd(skill)
				gen svar_`i'=svar*svar
				drop wvar cvar nvar svar
				
				* Within firm wage and skill variances
				egen wsd=sd(wdm)
				gen wvarw_`i'=wsd^2
				egen csd=sd(cdm)
				gen cvarw_`i'=csd^2
				egen nsd=sd(ndm)
				gen nvarw_`i'=nsd^2
				egen ssd=sd(sdm)
				gen svarw_`i'=ssd^2
				drop wsd csd nsd ssd

				* Between firm wage and skill variance
				egen whatb_`i'=sum((whatj_`i'-whatm)^2)
				replace whatb_`i'=whatb_`i'/n2
				egen wvarb_`i'=sum((wj-wm)^2) 
				replace wvarb_`i'=wvarb_`i'/n2
				egen cvarb_`i'=sum((cj-cm)^2) 
				replace cvarb_`i'=cvarb_`i'/n2
				egen nvarb_`i'=sum((nj-nm)^2) 
				replace nvarb_`i'=nvarb_`i'/n2
				egen svarb_`i'=sum((sj-sm)^2) 
				replace svarb_`i'=svarb_`i'/n2
				
				*** Sampling error correction
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adjw=sum(wdm^2)
				bysort `x'nr: egen adjc=sum(cdm^2)
				bysort `x'nr: egen adjn=sum(ndm^2)
				bysort `x'nr: egen adjs=sum(sdm^2)
				
				* sampling error term
				egen errorw_`i'=sum(theta_bf*adjw)
				replace errorw_`i'=errorw_`i'/n2
				egen errorc_`i'=sum(theta_bf*adjc)
				replace errorc_`i'=errorc_`i'/n2
				egen errorn_`i'=sum(theta_bf*adjn)
				replace errorn_`i'=errorn_`i'/n2
				egen errors_`i'=sum(theta_bf*adjs)
				replace errors_`i'=errors_`i'/n2
				
				keep year *_`i'
				drop whatj_`i'
				duplicates drop year, force
				
				* Generate sampling error adjustments
				gen wvarbhat_`i'=wvarb_`i'-errorw_`i'
				gen cvarbhat_`i'=cvarb_`i'-errorc_`i'
				gen nvarbhat_`i'=nvarb_`i'-errorn_`i'
				gen svarbhat_`i'=svarb_`i'-errors_`i'
				
				gen wvarwhat_`i'=wvarw_`i'+errorw_`i'
				gen cvarwhat_`i'=cvarw_`i'+errorc_`i'
				gen nvarwhat_`i'=nvarw_`i'+errorn_`i'
				gen svarwhat_`i'=svarw_`i'+errors_`i'
				
				gen beta_cjhat_`i' = beta_cj_`i' + (beta_cj_`i'-beta_cw_`i')*(errorc_`i'/cvarbhat_`i')
				gen beta_njhat_`i' = beta_nj_`i' + (beta_nj_`i'-beta_nw_`i')*(errorn_`i'/nvarbhat_`i')
				gen beta_sjhat_`i' = beta_sj_`i' + (beta_sj_`i'-beta_sw_`i')*(errors_`i'/svarbhat_`i')
				
				
				* Labels
				lab var beta_cj_`i' "Cognitive gradient, firm level" 
				lab var beta_nj_`i' "Non-cognitive gradient, firm level" 
				lab var beta_sj_`i' "Skill gradient, firm level" 
				lab var beta_cw_`i' "Cognitive gradient, within firm" 
				lab var beta_nw_`i' "Non-cognitive gradient, within firm" 
				lab var beta_sw_`i' "Skill gradient, within firm"
				lab var beta_c_`i' "Cognitive gradient, individual level"
				lab var beta_n_`i' "Non-cognitive gradient, individual level"
				lab var beta_s_`i' "Skill gradient, individual level"
				lab var wvar_`i' "Wage variance"
				lab var cvar_`i' "Cognitive skill variance"
				lab var nvar_`i' "Non-cognitive skill variance" 
				lab var svar_`i' "Skill variance"
				lab var wvarw_`i' "Within firm wage variance"
				lab var cvarw_`i' "Cognitive within firm variance"
				lab var nvarw_`i' "Non-cognitive within firm variance"
				lab var svarw_`i' "Skill within firm variance"
				lab var whatb_`i' "Between firm predicted wage variance"
				lab var wvarb_`i' "Between firm wage variance"
				lab var cvarb_`i' "Between firm cognitive variance"
				lab var nvarb_`i' "Between firm non-cognitive variance"
				lab var svarb_`i' "Between firm skill variance"
				lab var errorw_`i' "Sampling error (wage)"
				lab var errorc_`i' "Sampling error (cog)"
				lab var errorn_`i' "Sampling error (noncog)"
				lab var errors_`i' "Sampling error (skill)"
				lab var wvarbhat_`i' "Between-firm wage variance"
				lab var cvarbhat_`i' "Between-firm cognitive variance"
				lab var nvarbhat_`i' "Between-firm non-cognitive variance"
				lab var svarbhat_`i' "Between-firm skill variance"
				lab var wvarwhat_`i' "Within firm wage variance"
				lab var cvarwhat_`i' "Within firm cognitive variance"
				lab var nvarwhat_`i' "Within firm non-cognitive variance"
				lab var svarwhat_`i' "Within firm skill variance"
				lab var beta_cjhat_`i' "Cognitive gradient, firm level"
				lab var beta_njhat_`i' "Non-cognitive gradient, firm level"
				lab var beta_sjhat_`i' "Skill gradient, firm level"
				
				* Annual measures
				gen beta_cj=beta_cj_`i'
				gen beta_nj=beta_nj_`i' 
				gen beta_sj=beta_sj_`i' 
				gen beta_cw=beta_cw_`i' 
				gen beta_nw=beta_nw_`i' 
				gen beta_sw=beta_sw_`i' 
				gen beta_c=beta_c_`i' 
				gen beta_n=beta_n_`i'
				gen beta_s=beta_s_`i' 
				gen wvar=wvar_`i' 
				gen cvar=cvar_`i' 
				gen nvar=nvar_`i' 
				gen svar=svar_`i' 
				gen wvarw=wvarw_`i' 
				gen cvarw=cvarw_`i' 
				gen nvarw=nvarw_`i' 
				gen svarw=svarw_`i' 
				gen whatb=whatb_`i' 
				gen wvarb=wvarb_`i' 
				gen cvarb=cvarb_`i' 
				gen nvarb=nvarb_`i' 
				gen svarb=svarb_`i' 
				gen errorw=errorw_`i'
				gen errorc=errorc_`i'
				gen errorn=errorn_`i'
				gen errors=errors_`i'
				gen wvarbhat=wvarbhat_`i' 
				gen cvarbhat=cvarbhat_`i' 
				gen nvarbhat=nvarbhat_`i' 
				gen svarbhat=svarbhat_`i' 
				gen wvarwhat=wvarwhat_`i' 
				gen cvarwhat=cvarwhat_`i' 
				gen nvarwhat=nvarwhat_`i' 
				gen svarwhat=svarwhat_`i' 
				gen beta_cjhat=beta_cjhat_`i' 
				gen beta_njhat=beta_njhat_`i' 
				gen beta_sjhat=beta_sjhat_`i' 
				
				* Labels
				lab var beta_cj "Cognitive gradient, firm level" 
				lab var beta_nj "Non-cognitive gradient, firm level" 
				lab var beta_sj "Skill gradient, firm level" 
				lab var beta_cw "Cognitive gradient, within firm" 
				lab var beta_nw "Non-cognitive gradient, within firm" 
				lab var beta_sw "Skill gradient, within firm"
				lab var beta_c "Cognitive gradient"
				lab var beta_n "Non-cognitive gradient"
				lab var beta_s "Skill gradient"
				lab var wvar "Wage variance"
				lab var cvar "Cognitive skill variance"
				lab var nvar "Non-cognitive skill variance" 
				lab var svar "Skill variance"
				lab var wvarw "Within firm wage variance"
				lab var cvarw "Cognitive within firm variance"
				lab var nvarw "Non-cognitive within firm variance"
				lab var svarw "Within firm skill variance"
				lab var whatb "Between firm predicted wage variance"
				lab var wvarb "Between firm wage variance"
				lab var cvarb "Between firm cognitive variance"
				lab var nvarb "Between firm non-cognitive variance"
				lab var svarb "Between firm skill variance"
				lab var errorw "Sampling error (wage)"
				lab var errorc "Sampling error (cog)"
				lab var errorn "Sampling error (noncog)"
				lab var errors "Sampling error (skill)"
				lab var wvarbhat "Between-firm wage variance"
				lab var cvarbhat "Between-firm cognitive variance"
				lab var nvarbhat "Between-firm non-cognitive variance"
				lab var svarbhat "Between-firm skill variance"
				lab var wvarwhat "Within firm wage variance"
				lab var cvarwhat "Within firm cognitive variance"
				lab var nvarwhat "Within firm non-cognitive variance"
				lab var svarwhat "Within firm skill variance"
				lab var beta_cjhat "Cognitive gradient, firm level"
				lab var beta_njhat "Non-cognitive gradient, firm level"
				lab var beta_sjhat "Skill gradient, firm level"
			
				gen match=1
				
		save temp/betas_and_variances_rev2018_`x'_`j'_`i'.dta,replace
		}
	}
}

foreach x in ftg {
	foreach j in 10 {
		use year match beta_cj beta_nj beta_sj beta_cw beta_nw beta_sw beta_c beta_n beta_s wvar cvar nvar svar wvarw cvarw nvarw svarw whatb wvarb cvarb nvarb svarb    errorw errorc errorn errors wvarbhat cvarbhat nvarbhat svarbhat wvarwhat cvarwhat nvarwhat svarwhat beta_cjhat beta_njhat beta_sjhat using temp/betas_and_variances_rev2018_`x'_`j'_1986.dta,clear
			forvalues i=1987(1)2008 {
			append using temp/betas_and_variances_rev2018_`x'_`j'_`i'.dta, keep(year match beta_cj beta_nj beta_sj beta_cw beta_nw beta_sw beta_c beta_n beta_s wvar cvar nvar svar wvarw cvarw nvarw svarw whatb wvarb cvarb nvarb svarb errorw errorc errorn errors wvarbhat cvarbhat nvarbhat svarbhat wvarwhat cvarwhat nvarwhat svarwhat beta_cjhat beta_njhat beta_sjhat)
		}
	}
}
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			merge m:1 match using temp/betas_and_variances_rev2018_`x'_`j'_`i'.dta,keepus(beta_cj_`i' beta_nj_`i' beta_sj_`i' beta_cw_`i' beta_nw_`i' beta_sw_`i' beta_c_`i' beta_n_`i' beta_s_`i' wvar_`i' cvar_`i' nvar_`i' svar_`i' wvarw_`i' cvarw_`i' nvarw_`i' svarw_`i' whatb_`i' wvarb_`i' cvarb_`i' nvarb_`i' svarb_`i'  errorw_`i' errorc_`i' errorn_`i' errors_`i' wvarbhat_`i' cvarbhat_`i' nvarbhat_`i' svarbhat_`i' wvarwhat_`i' cvarwhat_`i' nvarwhat_`i' svarwhat_`i' beta_cjhat_`i' beta_njhat_`i' beta_sjhat_`i')
			drop _merge
		}
		save modified/betas_and_variances_rev2018_`x'_`j'.dta,replace
		}
}

use modified/betas_and_variances_rev2018_ftg_10.dta, clear
	lab var wvarbhat "Total variance"
	gen wvarb_exp=svarbhat*beta_sjhat^2
	lab var wvarb_exp "Predicted variance"
	gen wvarb_exp_1986gradients=svarbhat*beta_sjhat_1986^2
	lab var wvarb_exp_1986gradient "Predicted, 1986 gradient"
	gen wvarb_exp_1986sorting=svarbhat_1986*beta_sjhat^2
	lab var wvarb_exp_1986sorting "Predicted, 1986 sorting"
	lab var wvarwhat "Total variance"
	gen wvarw_exp=svarwhat*beta_sw^2
	lab var wvarw_exp "Predicted variance"
	gen wvarw_exp_1986gradients=svarwhat*beta_sw_1986^2
	lab var wvarw_exp_1986gradient "Predicted, 1986 gradient"
	gen wvarw_exp_1986sorting=svarwhat_1986*beta_sw^2
	lab var wvarw_exp_1986sorting "Predicted, 1986 sorting"
save modified/between_within_actual_counterfactual.dta, replace

*** Between and within, actual and counterfactucal. Excluding the ICT sector

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	

				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
		
				* Generate count variable
				g count=1

				* Drop IT (72) and telecom (32) 
				drop if `x'sni2==72
				drop if `x'sni2==32
				
				* Actual firm employees (for sampling error)
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
				merge 1:1 lopnr using modified/combskill_measure.dta
				drop if _merge==2
				
				* Number of firm/plant observations (nj>=2 needed for sampling error adjustments)
				bysort `x'nr: egen n2j=count(lnwpred_`x')
				drop if n2j<2

				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(n2j-1))
				g theta_bf=((Nj-n2j)/(Nj*n2j))*(1/(n2j-1))

				* Total number of observations
				egen n2=total(count)
				* Number of sector observations
				bysort `x'sni2: egen n2k=count(lnwpred_`x')
				
				* Mean sample wages
				egen wm=mean(lnwpred_`x')
				* Mean wages by firm/plant
				bysort `x'nr year: egen wj=mean(lnwpred_`x')
				* Mean wages by sector
				bysort `x'sni2: egen wk=mean(lnwpred_`x')
				* Wages demeaned by firm
				gen wdm=lnwpred_`x'-wj
				
				* Mean sample skills
				egen cm=mean(c)
				egen nm=mean(n)
				egen sm=mean(skill)
				
				* Mean firm/plant skills
				bysort `x'nr year: egen cj=mean(c)
				bysort `x'nr year: egen nj=mean(n)
				bysort `x'nr year: egen sj=mean(skill)
				
				* Mean sector skills
				bysort `x'sni2: egen ck=mean(c)
				bysort `x'sni2: egen nk=mean(n)
				bysort `x'sni2: egen sk=mean(skill)
				
				* Skills demeaned by firm
				gen cdm=c-cj
				gen ndm=n-nj
				gen sdm=skill-sj
				
				* Firm level skill regression
				reg wj cj
				gen beta_cj_`i'=_b[cj]
				reg wj nj
				gen beta_nj_`i'=_b[nj]
				reg wj sj
				gen beta_sj_`i'=_b[sj]
				predict whatj_`i'
				egen whatm=mean(whatj_`i')
				
				* Within firm skill regression
				reg wdm cdm
				gen beta_cw_`i'=_b[cdm]
				reg wdm ndm
				gen beta_nw_`i'=_b[ndm]				
				reg wdm sdm
				gen beta_sw_`i'=_b[sdm]
								
				* Individual level skill regression
				reg lnwpred_`x' c
				gen beta_c_`i'=_b[c]
				reg lnwpred_`x' n
				gen beta_n_`i'=_b[n]
				reg lnwpred_`x' skill
				gen beta_s_`i'=_b[skill]
				
				* Total wage and skill variance
				egen wvar=sd(lnwpred_`x')
				gen wvar_`i'=wvar*wvar
				egen cvar=sd(c)
				gen cvar_`i'=cvar*cvar
				egen nvar=sd(n)
				gen nvar_`i'=nvar*nvar
				egen svar=sd(skill)
				gen svar_`i'=svar*svar
				drop wvar cvar nvar svar
				
				* Within firm wage and skill variances
				egen wsd=sd(wdm)
				gen wvarw_`i'=wsd^2
				egen csd=sd(cdm)
				gen cvarw_`i'=csd^2
				egen nsd=sd(ndm)
				gen nvarw_`i'=nsd^2
				egen ssd=sd(sdm)
				gen svarw_`i'=ssd^2
				drop wsd csd nsd ssd

				* Between firm wage and skill variance
				egen whatb_`i'=sum((whatj_`i'-whatm)^2)
				replace whatb_`i'=whatb_`i'/n2
				egen wvarb_`i'=sum((wj-wm)^2) 
				replace wvarb_`i'=wvarb_`i'/n2
				egen cvarb_`i'=sum((cj-cm)^2) 
				replace cvarb_`i'=cvarb_`i'/n2
				egen nvarb_`i'=sum((nj-nm)^2) 
				replace nvarb_`i'=nvarb_`i'/n2
				egen svarb_`i'=sum((sj-sm)^2) 
				replace svarb_`i'=svarb_`i'/n2
				
				*** Sampling error correction
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adjw=sum(wdm^2)
				bysort `x'nr: egen adjc=sum(cdm^2)
				bysort `x'nr: egen adjn=sum(ndm^2)
				bysort `x'nr: egen adjs=sum(sdm^2)
				
				* sampling error term
				egen errorw_`i'=sum(theta_bf*adjw)
				replace errorw_`i'=errorw_`i'/n2
				egen errorc_`i'=sum(theta_bf*adjc)
				replace errorc_`i'=errorc_`i'/n2
				egen errorn_`i'=sum(theta_bf*adjn)
				replace errorn_`i'=errorn_`i'/n2
				egen errors_`i'=sum(theta_bf*adjs)
				replace errors_`i'=errors_`i'/n2
				
				keep year *_`i'
				drop whatj_`i'
				duplicates drop year, force
				
				* Generate sampling error adjustments
				gen wvarbhat_`i'=wvarb_`i'-errorw_`i'
				gen cvarbhat_`i'=cvarb_`i'-errorc_`i'
				gen nvarbhat_`i'=nvarb_`i'-errorn_`i'
				gen svarbhat_`i'=svarb_`i'-errors_`i'
				
				gen wvarwhat_`i'=wvarw_`i'+errorw_`i'
				gen cvarwhat_`i'=cvarw_`i'+errorc_`i'
				gen nvarwhat_`i'=nvarw_`i'+errorn_`i'
				gen svarwhat_`i'=svarw_`i'+errors_`i'
				
				gen beta_cjhat_`i' = beta_cj_`i' + (beta_cj_`i'-beta_cw_`i')*(errorc_`i'/cvarbhat_`i')
				gen beta_njhat_`i' = beta_nj_`i' + (beta_nj_`i'-beta_nw_`i')*(errorn_`i'/nvarbhat_`i')
				gen beta_sjhat_`i' = beta_sj_`i' + (beta_sj_`i'-beta_sw_`i')*(errors_`i'/svarbhat_`i')
				
				
				* Labels
				lab var beta_cj_`i' "Cognitive gradient, firm level" 
				lab var beta_nj_`i' "Non-cognitive gradient, firm level" 
				lab var beta_sj_`i' "Skill gradient, firm level" 
				lab var beta_cw_`i' "Cognitive gradient, within firm" 
				lab var beta_nw_`i' "Non-cognitive gradient, within firm" 
				lab var beta_sw_`i' "Skill gradient, within firm"
				lab var beta_c_`i' "Cognitive gradient, individual level"
				lab var beta_n_`i' "Non-cognitive gradient, individual level"
				lab var beta_s_`i' "Skill gradient, individual level"
				lab var wvar_`i' "Wage variance"
				lab var cvar_`i' "Cognitive skill variance"
				lab var nvar_`i' "Non-cognitive skill variance" 
				lab var svar_`i' "Skill variance"
				lab var wvarw_`i' "Within firm wage variance"
				lab var cvarw_`i' "Cognitive within firm variance"
				lab var nvarw_`i' "Non-cognitive within firm variance"
				lab var svarw_`i' "Skill within firm variance"
				lab var whatb_`i' "Between firm predicted wage variance"
				lab var wvarb_`i' "Between firm wage variance"
				lab var cvarb_`i' "Between firm cognitive variance"
				lab var nvarb_`i' "Between firm non-cognitive variance"
				lab var svarb_`i' "Between firm skill variance"
				lab var errorw_`i' "Sampling error (wage)"
				lab var errorc_`i' "Sampling error (cog)"
				lab var errorn_`i' "Sampling error (noncog)"
				lab var errors_`i' "Sampling error (skill)"
				lab var wvarbhat_`i' "Between-firm wage variance"
				lab var cvarbhat_`i' "Between-firm cognitive variance"
				lab var nvarbhat_`i' "Between-firm non-cognitive variance"
				lab var svarbhat_`i' "Between-firm skill variance"
				lab var wvarwhat_`i' "Within firm wage variance"
				lab var cvarwhat_`i' "Within firm cognitive variance"
				lab var nvarwhat_`i' "Within firm non-cognitive variance"
				lab var svarwhat_`i' "Within firm skill variance"
				lab var beta_cjhat_`i' "Cognitive gradient, firm level"
				lab var beta_njhat_`i' "Non-cognitive gradient, firm level"
				lab var beta_sjhat_`i' "Skill gradient, firm level"
				
				* Annual measures
				gen beta_cj=beta_cj_`i'
				gen beta_nj=beta_nj_`i' 
				gen beta_sj=beta_sj_`i' 
				gen beta_cw=beta_cw_`i' 
				gen beta_nw=beta_nw_`i' 
				gen beta_sw=beta_sw_`i' 
				gen beta_c=beta_c_`i' 
				gen beta_n=beta_n_`i'
				gen beta_s=beta_s_`i' 
				gen wvar=wvar_`i' 
				gen cvar=cvar_`i' 
				gen nvar=nvar_`i' 
				gen svar=svar_`i' 
				gen wvarw=wvarw_`i' 
				gen cvarw=cvarw_`i' 
				gen nvarw=nvarw_`i' 
				gen svarw=svarw_`i' 
				gen whatb=whatb_`i' 
				gen wvarb=wvarb_`i' 
				gen cvarb=cvarb_`i' 
				gen nvarb=nvarb_`i' 
				gen svarb=svarb_`i' 
				gen errorw=errorw_`i'
				gen errorc=errorc_`i'
				gen errorn=errorn_`i'
				gen errors=errors_`i'
				gen wvarbhat=wvarbhat_`i' 
				gen cvarbhat=cvarbhat_`i' 
				gen nvarbhat=nvarbhat_`i' 
				gen svarbhat=svarbhat_`i' 
				gen wvarwhat=wvarwhat_`i' 
				gen cvarwhat=cvarwhat_`i' 
				gen nvarwhat=nvarwhat_`i' 
				gen svarwhat=svarwhat_`i' 
				gen beta_cjhat=beta_cjhat_`i' 
				gen beta_njhat=beta_njhat_`i' 
				gen beta_sjhat=beta_sjhat_`i' 
				
				* Labels
				lab var beta_cj "Cognitive gradient, firm level" 
				lab var beta_nj "Non-cognitive gradient, firm level" 
				lab var beta_sj "Skill gradient, firm level" 
				lab var beta_cw "Cognitive gradient, within firm" 
				lab var beta_nw "Non-cognitive gradient, within firm" 
				lab var beta_sw "Skill gradient, within firm"
				lab var beta_c "Cognitive gradient"
				lab var beta_n "Non-cognitive gradient"
				lab var beta_s "Skill gradient"
				lab var wvar "Wage variance"
				lab var cvar "Cognitive skill variance"
				lab var nvar "Non-cognitive skill variance" 
				lab var svar "Skill variance"
				lab var wvarw "Within firm wage variance"
				lab var cvarw "Cognitive within firm variance"
				lab var nvarw "Non-cognitive within firm variance"
				lab var svarw "Within firm skill variance"
				lab var whatb "Between firm predicted wage variance"
				lab var wvarb "Between firm wage variance"
				lab var cvarb "Between firm cognitive variance"
				lab var nvarb "Between firm non-cognitive variance"
				lab var svarb "Between firm skill variance"
				lab var errorw "Sampling error (wage)"
				lab var errorc "Sampling error (cog)"
				lab var errorn "Sampling error (noncog)"
				lab var errors "Sampling error (skill)"
				lab var wvarbhat "Between-firm wage variance"
				lab var cvarbhat "Between-firm cognitive variance"
				lab var nvarbhat "Between-firm non-cognitive variance"
				lab var svarbhat "Between-firm skill variance"
				lab var wvarwhat "Within firm wage variance"
				lab var cvarwhat "Within firm cognitive variance"
				lab var nvarwhat "Within firm non-cognitive variance"
				lab var svarwhat "Within firm skill variance"
				lab var beta_cjhat "Cognitive gradient, firm level"
				lab var beta_njhat "Non-cognitive gradient, firm level"
				lab var beta_sjhat "Skill gradient, firm level"
			
				gen match=1
				
		save temp/betas_and_variances_rev2018_exICT_`x'_`j'_`i'.dta,replace
		}
	}
}

foreach x in ftg {
	foreach j in 10 {
		use year match beta_cj beta_nj beta_sj beta_cw beta_nw beta_sw beta_c beta_n beta_s wvar cvar nvar svar wvarw cvarw nvarw svarw whatb wvarb cvarb nvarb svarb    errorw errorc errorn errors wvarbhat cvarbhat nvarbhat svarbhat wvarwhat cvarwhat nvarwhat svarwhat beta_cjhat beta_njhat beta_sjhat using temp/betas_and_variances_rev2018_exICT_`x'_`j'_1986.dta,clear
			forvalues i=1987(1)2008 {
			append using temp/betas_and_variances_rev2018_exICT_`x'_`j'_`i'.dta, keep(year match beta_cj beta_nj beta_sj beta_cw beta_nw beta_sw beta_c beta_n beta_s wvar cvar nvar svar wvarw cvarw nvarw svarw whatb wvarb cvarb nvarb svarb errorw errorc errorn errors wvarbhat cvarbhat nvarbhat svarbhat wvarwhat cvarwhat nvarwhat svarwhat beta_cjhat beta_njhat beta_sjhat)
		}
	}
}
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			merge m:1 match using temp/betas_and_variances_rev2018_exICT_`x'_`j'_`i'.dta,keepus(beta_cj_`i' beta_nj_`i' beta_sj_`i' beta_cw_`i' beta_nw_`i' beta_sw_`i' beta_c_`i' beta_n_`i' beta_s_`i' wvar_`i' cvar_`i' nvar_`i' svar_`i' wvarw_`i' cvarw_`i' nvarw_`i' svarw_`i' whatb_`i' wvarb_`i' cvarb_`i' nvarb_`i' svarb_`i'  errorw_`i' errorc_`i' errorn_`i' errors_`i' wvarbhat_`i' cvarbhat_`i' nvarbhat_`i' svarbhat_`i' wvarwhat_`i' cvarwhat_`i' nvarwhat_`i' svarwhat_`i' beta_cjhat_`i' beta_njhat_`i' beta_sjhat_`i')
			drop _merge
		}
		save modified/betas_and_variances_rev2018_exICT_`x'_`j'.dta,replace
		}
}

use modified/betas_and_variances_rev2018_exICT_ftg_10.dta, clear
	lab var wvarbhat "Total variance"
	gen wvarb_exp=svarbhat*beta_sjhat^2
	lab var wvarb_exp "Predicted variance"
	gen wvarb_exp_1986gradients=svarbhat*beta_sjhat_1986^2
	lab var wvarb_exp_1986gradient "Only sorting"
	gen wvarb_exp_1986sorting=svarbhat_1986*beta_sjhat^2
	lab var wvarb_exp_1986sorting "Only gradient"
	lab var wvarwhat "Total variance"
	gen wvarw_exp=svarwhat*beta_sw^2
	lab var wvarw_exp "Predicted variance"
	gen wvarw_exp_1986gradients=svarwhat*beta_sw_1986^2
	lab var wvarw_exp_1986gradient "Only sorting"
	gen wvarw_exp_1986sorting=svarwhat_1986*beta_sw^2
	lab var wvarw_exp_1986sorting "Only gradient"
save modified/between_within_actual_counterfactual_exICT.dta, replace

**** Between and within, actual and counterfactucal. Excluding the Finance

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	

				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
		
				* Generate count variable
				g count=1

				* Finance 
				drop if `x'sni2==65
								
				* Actual firm employees (for sampling error)
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
				merge 1:1 lopnr using modified/combskill_measure.dta
				drop if _merge==2
				
				* Number of firm/plant observations (nj>=2 needed for sampling error adjustments)
				bysort `x'nr: egen n2j=count(lnwpred_`x')
				drop if n2j<2

				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(n2j-1))
				g theta_bf=((Nj-n2j)/(Nj*n2j))*(1/(n2j-1))

				* Total number of observations
				egen n2=total(count)
				* Number of sector observations
				bysort `x'sni2: egen n2k=count(lnwpred_`x')
				
				* Mean sample wages
				egen wm=mean(lnwpred_`x')
				* Mean wages by firm/plant
				bysort `x'nr year: egen wj=mean(lnwpred_`x')
				* Mean wages by sector
				bysort `x'sni2: egen wk=mean(lnwpred_`x')
				* Wages demeaned by firm
				gen wdm=lnwpred_`x'-wj
				
				* Mean sample skills
				egen cm=mean(c)
				egen nm=mean(n)
				egen sm=mean(skill)
				
				* Mean firm/plant skills
				bysort `x'nr year: egen cj=mean(c)
				bysort `x'nr year: egen nj=mean(n)
				bysort `x'nr year: egen sj=mean(skill)
				
				* Mean sector skills
				bysort `x'sni2: egen ck=mean(c)
				bysort `x'sni2: egen nk=mean(n)
				bysort `x'sni2: egen sk=mean(skill)
				
				* Skills demeaned by firm
				gen cdm=c-cj
				gen ndm=n-nj
				gen sdm=skill-sj
				
				* Firm level skill regression
				reg wj cj
				gen beta_cj_`i'=_b[cj]
				reg wj nj
				gen beta_nj_`i'=_b[nj]
				reg wj sj
				gen beta_sj_`i'=_b[sj]
				predict whatj_`i'
				egen whatm=mean(whatj_`i')
				
				* Within firm skill regression
				reg wdm cdm
				gen beta_cw_`i'=_b[cdm]
				reg wdm ndm
				gen beta_nw_`i'=_b[ndm]				
				reg wdm sdm
				gen beta_sw_`i'=_b[sdm]
								
				* Individual level skill regression
				reg lnwpred_`x' c
				gen beta_c_`i'=_b[c]
				reg lnwpred_`x' n
				gen beta_n_`i'=_b[n]
				reg lnwpred_`x' skill
				gen beta_s_`i'=_b[skill]
				
				* Total wage and skill variance
				egen wvar=sd(lnwpred_`x')
				gen wvar_`i'=wvar*wvar
				egen cvar=sd(c)
				gen cvar_`i'=cvar*cvar
				egen nvar=sd(n)
				gen nvar_`i'=nvar*nvar
				egen svar=sd(skill)
				gen svar_`i'=svar*svar
				drop wvar cvar nvar svar
				
				* Within firm wage and skill variances
				egen wsd=sd(wdm)
				gen wvarw_`i'=wsd^2
				egen csd=sd(cdm)
				gen cvarw_`i'=csd^2
				egen nsd=sd(ndm)
				gen nvarw_`i'=nsd^2
				egen ssd=sd(sdm)
				gen svarw_`i'=ssd^2
				drop wsd csd nsd ssd

				* Between firm wage and skill variance
				egen whatb_`i'=sum((whatj_`i'-whatm)^2)
				replace whatb_`i'=whatb_`i'/n2
				egen wvarb_`i'=sum((wj-wm)^2) 
				replace wvarb_`i'=wvarb_`i'/n2
				egen cvarb_`i'=sum((cj-cm)^2) 
				replace cvarb_`i'=cvarb_`i'/n2
				egen nvarb_`i'=sum((nj-nm)^2) 
				replace nvarb_`i'=nvarb_`i'/n2
				egen svarb_`i'=sum((sj-sm)^2) 
				replace svarb_`i'=svarb_`i'/n2
				
				*** Sampling error correction
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adjw=sum(wdm^2)
				bysort `x'nr: egen adjc=sum(cdm^2)
				bysort `x'nr: egen adjn=sum(ndm^2)
				bysort `x'nr: egen adjs=sum(sdm^2)
				
				* sampling error term
				egen errorw_`i'=sum(theta_bf*adjw)
				replace errorw_`i'=errorw_`i'/n2
				egen errorc_`i'=sum(theta_bf*adjc)
				replace errorc_`i'=errorc_`i'/n2
				egen errorn_`i'=sum(theta_bf*adjn)
				replace errorn_`i'=errorn_`i'/n2
				egen errors_`i'=sum(theta_bf*adjs)
				replace errors_`i'=errors_`i'/n2
				
				keep year *_`i'
				drop whatj_`i'
				duplicates drop year, force
				
				* Generate sampling error adjustments
				gen wvarbhat_`i'=wvarb_`i'-errorw_`i'
				gen cvarbhat_`i'=cvarb_`i'-errorc_`i'
				gen nvarbhat_`i'=nvarb_`i'-errorn_`i'
				gen svarbhat_`i'=svarb_`i'-errors_`i'
				
				gen wvarwhat_`i'=wvarw_`i'+errorw_`i'
				gen cvarwhat_`i'=cvarw_`i'+errorc_`i'
				gen nvarwhat_`i'=nvarw_`i'+errorn_`i'
				gen svarwhat_`i'=svarw_`i'+errors_`i'
				
				gen beta_cjhat_`i' = beta_cj_`i' + (beta_cj_`i'-beta_cw_`i')*(errorc_`i'/cvarbhat_`i')
				gen beta_njhat_`i' = beta_nj_`i' + (beta_nj_`i'-beta_nw_`i')*(errorn_`i'/nvarbhat_`i')
				gen beta_sjhat_`i' = beta_sj_`i' + (beta_sj_`i'-beta_sw_`i')*(errors_`i'/svarbhat_`i')
				
				
				* Labels
				lab var beta_cj_`i' "Cognitive gradient, firm level" 
				lab var beta_nj_`i' "Non-cognitive gradient, firm level" 
				lab var beta_sj_`i' "Skill gradient, firm level" 
				lab var beta_cw_`i' "Cognitive gradient, within firm" 
				lab var beta_nw_`i' "Non-cognitive gradient, within firm" 
				lab var beta_sw_`i' "Skill gradient, within firm"
				lab var beta_c_`i' "Cognitive gradient, individual level"
				lab var beta_n_`i' "Non-cognitive gradient, individual level"
				lab var beta_s_`i' "Skill gradient, individual level"
				lab var wvar_`i' "Wage variance"
				lab var cvar_`i' "Cognitive skill variance"
				lab var nvar_`i' "Non-cognitive skill variance" 
				lab var svar_`i' "Skill variance"
				lab var wvarw_`i' "Within firm wage variance"
				lab var cvarw_`i' "Cognitive within firm variance"
				lab var nvarw_`i' "Non-cognitive within firm variance"
				lab var svarw_`i' "Skill within firm variance"
				lab var whatb_`i' "Between firm predicted wage variance"
				lab var wvarb_`i' "Between firm wage variance"
				lab var cvarb_`i' "Between firm cognitive variance"
				lab var nvarb_`i' "Between firm non-cognitive variance"
				lab var svarb_`i' "Between firm skill variance"
				lab var errorw_`i' "Sampling error (wage)"
				lab var errorc_`i' "Sampling error (cog)"
				lab var errorn_`i' "Sampling error (noncog)"
				lab var errors_`i' "Sampling error (skill)"
				lab var wvarbhat_`i' "Between-firm wage variance"
				lab var cvarbhat_`i' "Between-firm cognitive variance"
				lab var nvarbhat_`i' "Between-firm non-cognitive variance"
				lab var svarbhat_`i' "Between-firm skill variance"
				lab var wvarwhat_`i' "Within firm wage variance"
				lab var cvarwhat_`i' "Within firm cognitive variance"
				lab var nvarwhat_`i' "Within firm non-cognitive variance"
				lab var svarwhat_`i' "Within firm skill variance"
				lab var beta_cjhat_`i' "Cognitive gradient, firm level"
				lab var beta_njhat_`i' "Non-cognitive gradient, firm level"
				lab var beta_sjhat_`i' "Skill gradient, firm level"
				
				* Annual measures
				gen beta_cj=beta_cj_`i'
				gen beta_nj=beta_nj_`i' 
				gen beta_sj=beta_sj_`i' 
				gen beta_cw=beta_cw_`i' 
				gen beta_nw=beta_nw_`i' 
				gen beta_sw=beta_sw_`i' 
				gen beta_c=beta_c_`i' 
				gen beta_n=beta_n_`i'
				gen beta_s=beta_s_`i' 
				gen wvar=wvar_`i' 
				gen cvar=cvar_`i' 
				gen nvar=nvar_`i' 
				gen svar=svar_`i' 
				gen wvarw=wvarw_`i' 
				gen cvarw=cvarw_`i' 
				gen nvarw=nvarw_`i' 
				gen svarw=svarw_`i' 
				gen whatb=whatb_`i' 
				gen wvarb=wvarb_`i' 
				gen cvarb=cvarb_`i' 
				gen nvarb=nvarb_`i' 
				gen svarb=svarb_`i' 
				gen errorw=errorw_`i'
				gen errorc=errorc_`i'
				gen errorn=errorn_`i'
				gen errors=errors_`i'
				gen wvarbhat=wvarbhat_`i' 
				gen cvarbhat=cvarbhat_`i' 
				gen nvarbhat=nvarbhat_`i' 
				gen svarbhat=svarbhat_`i' 
				gen wvarwhat=wvarwhat_`i' 
				gen cvarwhat=cvarwhat_`i' 
				gen nvarwhat=nvarwhat_`i' 
				gen svarwhat=svarwhat_`i' 
				gen beta_cjhat=beta_cjhat_`i' 
				gen beta_njhat=beta_njhat_`i' 
				gen beta_sjhat=beta_sjhat_`i' 
				
				* Labels
				lab var beta_cj "Cognitive gradient, firm level" 
				lab var beta_nj "Non-cognitive gradient, firm level" 
				lab var beta_sj "Skill gradient, firm level" 
				lab var beta_cw "Cognitive gradient, within firm" 
				lab var beta_nw "Non-cognitive gradient, within firm" 
				lab var beta_sw "Skill gradient, within firm"
				lab var beta_c "Cognitive gradient"
				lab var beta_n "Non-cognitive gradient"
				lab var beta_s "Skill gradient"
				lab var wvar "Wage variance"
				lab var cvar "Cognitive skill variance"
				lab var nvar "Non-cognitive skill variance" 
				lab var svar "Skill variance"
				lab var wvarw "Within firm wage variance"
				lab var cvarw "Cognitive within firm variance"
				lab var nvarw "Non-cognitive within firm variance"
				lab var svarw "Within firm skill variance"
				lab var whatb "Between firm predicted wage variance"
				lab var wvarb "Between firm wage variance"
				lab var cvarb "Between firm cognitive variance"
				lab var nvarb "Between firm non-cognitive variance"
				lab var svarb "Between firm skill variance"
				lab var errorw "Sampling error (wage)"
				lab var errorc "Sampling error (cog)"
				lab var errorn "Sampling error (noncog)"
				lab var errors "Sampling error (skill)"
				lab var wvarbhat "Between-firm wage variance"
				lab var cvarbhat "Between-firm cognitive variance"
				lab var nvarbhat "Between-firm non-cognitive variance"
				lab var svarbhat "Between-firm skill variance"
				lab var wvarwhat "Within firm wage variance"
				lab var cvarwhat "Within firm cognitive variance"
				lab var nvarwhat "Within firm non-cognitive variance"
				lab var svarwhat "Within firm skill variance"
				lab var beta_cjhat "Cognitive gradient, firm level"
				lab var beta_njhat "Non-cognitive gradient, firm level"
				lab var beta_sjhat "Skill gradient, firm level"
			
				gen match=1
				
		save temp/betas_and_variances_rev2018_exFinance_`x'_`j'_`i'.dta,replace
		}
	}
}

foreach x in ftg {
	foreach j in 10 {
		use year match beta_cj beta_nj beta_sj beta_cw beta_nw beta_sw beta_c beta_n beta_s wvar cvar nvar svar wvarw cvarw nvarw svarw whatb wvarb cvarb nvarb svarb    errorw errorc errorn errors wvarbhat cvarbhat nvarbhat svarbhat wvarwhat cvarwhat nvarwhat svarwhat beta_cjhat beta_njhat beta_sjhat using temp/betas_and_variances_rev2018_exFinance_`x'_`j'_1986.dta,clear
			forvalues i=1987(1)2008 {
			append using temp/betas_and_variances_rev2018_exFinance_`x'_`j'_`i'.dta, keep(year match beta_cj beta_nj beta_sj beta_cw beta_nw beta_sw beta_c beta_n beta_s wvar cvar nvar svar wvarw cvarw nvarw svarw whatb wvarb cvarb nvarb svarb errorw errorc errorn errors wvarbhat cvarbhat nvarbhat svarbhat wvarwhat cvarwhat nvarwhat svarwhat beta_cjhat beta_njhat beta_sjhat)
		}
	}
}
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			merge m:1 match using temp/betas_and_variances_rev2018_exFinance_`x'_`j'_`i'.dta,keepus(beta_cj_`i' beta_nj_`i' beta_sj_`i' beta_cw_`i' beta_nw_`i' beta_sw_`i' beta_c_`i' beta_n_`i' beta_s_`i' wvar_`i' cvar_`i' nvar_`i' svar_`i' wvarw_`i' cvarw_`i' nvarw_`i' svarw_`i' whatb_`i' wvarb_`i' cvarb_`i' nvarb_`i' svarb_`i'  errorw_`i' errorc_`i' errorn_`i' errors_`i' wvarbhat_`i' cvarbhat_`i' nvarbhat_`i' svarbhat_`i' wvarwhat_`i' cvarwhat_`i' nvarwhat_`i' svarwhat_`i' beta_cjhat_`i' beta_njhat_`i' beta_sjhat_`i')
			drop _merge
		}
		save modified/betas_and_variances_rev2018_exFinance_`x'_`j'.dta,replace
		}
}

use modified/betas_and_variances_rev2018_exFinance_ftg_10.dta, clear
	lab var wvarbhat "Total variance"
	gen wvarb_exp=svarbhat*beta_sjhat^2
	lab var wvarb_exp "Predicted variance"
	gen wvarb_exp_1986gradients=svarbhat*beta_sjhat_1986^2
	lab var wvarb_exp_1986gradient "Only sorting"
	gen wvarb_exp_1986sorting=svarbhat_1986*beta_sjhat^2
	lab var wvarb_exp_1986sorting "Only gradient"
	lab var wvarwhat "Total variance"
	gen wvarw_exp=svarwhat*beta_sw^2
	lab var wvarw_exp "Predicted variance"
	gen wvarw_exp_1986gradients=svarwhat*beta_sw_1986^2
	lab var wvarw_exp_1986gradient "Only sorting"
	gen wvarw_exp_1986sorting=svarwhat_1986*beta_sw^2
	lab var wvarw_exp_1986sorting "Only gradient"
save modified/between_within_actual_counterfactual_exFinance.dta, replace

*************************************
**** Sorting based on subscores  ****
*************************************

**** Constructing skill measures based on subscores 

use modified/topiq6994.dta, clear

bysort enlistyr: egen logmean=mean(log) 	
bysort enlistyr: egen logsd=sd(log)
gen logz=(log-logmean)/logsd
lab var logz "Logical"

bysort enlistyr: egen verbmean=mean(verb) 	
bysort enlistyr: egen verbsd=sd(verb)
gen verbz=(verb-verbmean)/verbsd
lab var verbz "Verbal"
	
bysort enlistyr: egen spatmean=mean(spat) 	
bysort enlistyr: egen spatsd=sd(spat)
gen spatz=(spat-spatmean)/spatsd
lab var spatz "Spatial"

bysort enlistyr: egen techmean=mean(tech) 	
bysort enlistyr: egen techsd=sd(tech)
gen techz=(tech-techmean)/techsd
lab var techz "Technical"

bysort enlistyr: egen nsmean=mean(n_s) 	
bysort enlistyr: egen nssd=sd(n_s)
gen nsz=(n_s-nsmean)/nssd
lab var nsz "NoncogS"

bysort enlistyr: egen nimean=mean(n_i) 	
bysort enlistyr: egen nisd=sd(n_i)
gen niz=(n_i-nimean)/nisd
lab var niz "NoncogI"

bysort enlistyr: egen npmean=mean(n_p) 	
bysort enlistyr: egen npsd=sd(n_p)
gen npz=(n_p-npmean)/npsd
lab var npz "NoncogP"

bysort enlistyr: egen nemean=mean(n_e) 	
bysort enlistyr: egen nesd=sd(n_e)
gen nez=(n_e-nemean)/nesd
lab var nez "NoncogE"

keep lopnr logz verbz spatz techz nsz niz npz nez
sort lopnr

save modified/detailedskills.dta,replace
	
*** Sorting files

clear
set mem 20g
cd /home/workgroups/firmiq/data/
set more off
	
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1985(1)2009 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		sort lopnr
		merge 1:1 lopnr using modified/detailedskills.dta, keepus(lopnr logz verbz spatz techz nsz niz npz nez)
		drop if _merge==2
		drop _merge
		
		rename logz l
		rename verbz v
		rename spatz s
		rename techz t
		rename nsz n1
		rename niz n2
		rename npz n3
		rename nez n4
		
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
				
		* Keep relevant sample
		keep if sample_3035_`j'_`x'==1
		keep if l~=.
		keep if v~=.
		keep if s~=.
		keep if t~=.
		
		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		***Actual skill means
		*industry
		bysort `x'sni2: egen lk=mean(l)
		bysort `x'sni2: egen vk=mean(v)
		bysort `x'sni2: egen sk=mean(s)
		bysort `x'sni2: egen tk=mean(t)
		
		bysort `x'sni2: egen n1k=mean(n1)
		bysort `x'sni2: egen n2k=mean(n2)
		bysort `x'sni2: egen n3k=mean(n3)
		bysort `x'sni2: egen n4k=mean(n4)
		
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen lj=mean(l)
		bysort `x'nr: egen vj=mean(v)
		bysort `x'nr: egen sj=mean(s)
		bysort `x'nr: egen tj=mean(t)
		
		bysort `x'nr: egen n1j=mean(n1)
		bysort `x'nr: egen n2j=mean(n2)
		bysort `x'nr: egen n3j=mean(n3)
		bysort `x'nr: egen n4j=mean(n4)
		
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*firm/plant yrke
		bysort `x'nr yrke: egen lhj=mean(l)
		bysort `x'nr yrke: egen vhj=mean(v)
		bysort `x'nr yrke: egen shj=mean(s)
		bysort `x'nr yrke: egen thj=mean(t)
		
		bysort `x'nr yrke: egen n1hj=mean(n1)
		bysort `x'nr yrke: egen n2hj=mean(n2)
		bysort `x'nr yrke: egen n3hj=mean(n3)
		bysort `x'nr yrke: egen n4hj=mean(n4)
		
		bysort `x'nr yrke: egen chj=mean(c) 
		bysort `x'nr yrke: egen nhj=mean(n) 
		bysort `x'nr yrke: egen ehj=mean(edyr)
		bysort `x'nr yrke: egen zehj=mean(zedyr) 

		*yrke
		bysort yrke: egen lh=mean(l)
		bysort yrke: egen vh=mean(v)
		bysort yrke: egen sh=mean(s)
		bysort yrke: egen th=mean(t)
		
		bysort yrke: egen n1h=mean(n1)
		bysort yrke: egen n2h=mean(n2)
		bysort yrke: egen n3h=mean(n3)
		bysort yrke: egen n4h=mean(n4)
		
		bysort yrke: egen ch=mean(c) 
		bysort yrke: egen nh=mean(n) 
		bysort yrke: egen eh=mean(edyr) 
		bysort yrke: egen zeh=mean(zedyr) 

		*sample
		egen lbar=mean(l)
		egen vbar=mean(v)
		egen sbar=mean(s)
		egen tbar=mean(t)
		
		egen n1bar=mean(n1)
		egen n2bar=mean(n2)
		egen n3bar=mean(n3)
		egen n4bar=mean(n4)
		
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		*Observed samples and sizes
		* rename ftgstorl_`x' Nj
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		bysort `x'nr: egen N2j=total(count) 
		egen N2=total(count) 

		***Predicted skills
		*individual
		areg l, absorb(yrke)
		predict lijtilde if e(sample),xbd
		predict lijres if e(sample), resid
		
		areg v, absorb(yrke)
		predict vijtilde if e(sample),xbd
		predict vijres if e(sample), resid
		
		areg s, absorb(yrke)
		predict sijtilde if e(sample),xbd
		predict sijres if e(sample), resid
		
		areg t, absorb(yrke)
		predict tijtilde if e(sample),xbd
		predict tijres if e(sample), resid
		
		areg n1, absorb(yrke)
		predict n1ijtilde if e(sample),xbd
		predict n1ijres if e(sample), resid
		
		areg n2, absorb(yrke)
		predict n2ijtilde if e(sample),xbd
		predict n2ijres if e(sample), resid

		areg n3, absorb(yrke)
		predict n3ijtilde if e(sample),xbd
		predict n3ijres if e(sample), resid

		areg n4, absorb(yrke)
		predict n4ijtilde if e(sample),xbd
		predict n4ijres if e(sample), resid
				
		areg c, absorb(yrke)
		predict cijtilde if e(sample),xbd
		predict cijres if e(sample), resid
		areg n, absorb(yrke)
		predict nijtilde if e(sample),xbd
		predict nijres if e(sample), resid
		areg edyr, absorb(yrke)
		predict eijtilde if e(sample), xbd
		predict eijres if e(sample), resid
		areg zedyr, absorb(yrke)
		predict zeijtilde if e(sample), xbd
		predict zeijres if e(sample), resid

		bysort `x'nr: egen ljres=mean(lijres)
		bysort `x'nr: egen vjres=mean(vijres)
		bysort `x'nr: egen sjres=mean(sijres)
		bysort `x'nr: egen tjres=mean(tijres)
		
		bysort `x'nr: egen n1jres=mean(n1ijres)
		bysort `x'nr: egen n2jres=mean(n2ijres)
		bysort `x'nr: egen n3jres=mean(n3ijres)
		bysort `x'nr: egen n4jres=mean(n4ijres)
		
		bysort `x'nr: egen cjres=mean(cijres)
		bysort `x'nr: egen njres=mean(nijres)
		bysort `x'nr: egen ejres=mean(eijres)
		bysort `x'nr: egen zejres=mean(zeijres)

		g ljtilde=lj-ljres
		g vjtilde=vj-vjres
		g sjtilde=sj-sjres
		g tjtilde=tj-tjres
		
		g n1jtilde=n1j-n1jres
		g n2jtilde=n2j-n2jres
		g n3jtilde=n3j-n3jres
		g n4jtilde=n4j-n4jres
		
		g cjtilde=cj-cjres
		g njtilde=nj-njres
		g ejtilde=ej-ejres
		g zejtilde=zej-zejres

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*between occupation within firm/plant  
		g wt_l=(lijtilde-ljtilde)^2
		g wt_v=(vijtilde-vjtilde)^2
		g wt_s=(sijtilde-sjtilde)^2
		g wt_t=(tijtilde-tjtilde)^2
		
		g wt_n1=(n1ijtilde-n1jtilde)^2
		g wt_n2=(n2ijtilde-n2jtilde)^2
		g wt_n3=(n3ijtilde-n3jtilde)^2
		g wt_n4=(n4ijtilde-n4jtilde)^2
		
		g wt_c=(cijtilde-cjtilde)^2
		g wt_n=(nijtilde-njtilde)^2
		g wt_e=(eijtilde-ejtilde)^2
		g wt_ze=(zeijtilde-zejtilde)^2

		*within occupation within plant 
		g wa_l=((l-lijtilde)-(lj-ljtilde))^2
		g wa_v=((v-vijtilde)-(vj-vjtilde))^2
		g wa_s=((s-sijtilde)-(sj-sjtilde))^2
		g wa_t=((t-tijtilde)-(tj-tjtilde))^2
		
		g wa_n1=((n1-n1ijtilde)-(n1j-n1jtilde))^2
		g wa_n2=((n2-n2ijtilde)-(n2j-n2jtilde))^2
		g wa_n3=((n3-n3ijtilde)-(n3j-n3jtilde))^2
		g wa_n4=((n4-n4ijtilde)-(n4j-n4jtilde))^2
		
		g wa_c=((c-cijtilde)-(cj-cjtilde))^2
		g wa_n=((n-nijtilde)-(nj-njtilde))^2
		g wa_e=((e-eijtilde)-(ej-ejtilde))^2
		g wa_ze=((ze-zeijtilde)-(zej-zejtilde))^2

		*within firm total variance (consistancy check)
		g ws_l=(l-lj)^2
		g ws_v=(v-vj)^2
		g ws_s=(s-sj)^2
		g ws_t=(t-tj)^2
		
		g ws_n1=(n1-n1j)^2
		g ws_n2=(n2-n2j)^2
		g ws_n3=(n3-n3j)^2
		g ws_n4=(n4-n4j)^2
		
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*within firm covariance (between and witin occ) 
		g wat_l=(lijtilde-ljtilde)*((l-lijtilde)-(lj-ljtilde))
		g wat_v=(vijtilde-vjtilde)*((v-vijtilde)-(vj-vjtilde))
		g wat_s=(sijtilde-sjtilde)*((s-sijtilde)-(sj-sjtilde))
		g wat_t=(tijtilde-tjtilde)*((t-tijtilde)-(tj-tjtilde))
		
		g wat_n1=(n1ijtilde-n1jtilde)*((n1-n1ijtilde)-(n1j-n1jtilde))
		g wat_n2=(n2ijtilde-n2jtilde)*((n2-n2ijtilde)-(n2j-n2jtilde))
		g wat_n3=(n3ijtilde-n3jtilde)*((n3-n3ijtilde)-(n3j-n3jtilde))
		g wat_n4=(n4ijtilde-n4jtilde)*((n4-n4ijtilde)-(n4j-n4jtilde))
		
		g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
		g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
		g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))
		g wat_ze=(zeijtilde-zejtilde)*((ze-zeijtilde)-(zej-zejtilde))

		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_l=wt_l+wa_l+2*wat_l
		g wtot_v=wt_v+wa_v+2*wat_v
		g wtot_s=wt_s+wa_s+2*wat_s
		g wtot_t=wt_t+wa_t+2*wat_t
		
		g wtot_n1=wt_n1+wa_n1+2*wat_n1
		g wtot_n2=wt_n2+wa_n2+2*wat_n2
		g wtot_n3=wt_n3+wa_n3+2*wat_n3
		g wtot_n4=wt_n4+wa_n4+2*wat_n4
		
		g wtot_c=wt_c+wa_c+2*wat_c
		g wtot_n=wt_n+wa_n+2*wat_n
		g wtot_e=wt_e+wa_e+2*wat_e
		g wtot_ze=wt_ze+wa_ze+2*wat_ze

		* between occupation between firm
		g bt_l=(ljtilde-lbar)^2
		g bt_v=(vjtilde-vbar)^2
		g bt_s=(sjtilde-sbar)^2
		g bt_t=(tjtilde-tbar)^2
		
		g bt_n1=(n1jtilde-n1bar)^2
		g bt_n2=(n2jtilde-n2bar)^2
		g bt_n3=(n3jtilde-n3bar)^2
		g bt_n4=(n4jtilde-n4bar)^2
		
		g bt_c=(cjtilde-cbar)^2
		g bt_n=(njtilde-nbar)^2
		g bt_e=(ejtilde-ebar)^2
		g bt_ze=(zejtilde-zebar)^2

		*within occupation between firm 
		g ba_l=(lj-ljtilde)^2
		g ba_v=(vj-vjtilde)^2
		g ba_s=(sj-sjtilde)^2
		g ba_t=(tj-tjtilde)^2
		
		g ba_n1=(n1j-n1jtilde)^2
		g ba_n2=(n2j-n2jtilde)^2
		g ba_n3=(n3j-n3jtilde)^2
		g ba_n4=(n4j-n4jtilde)^2
		
		g ba_c=(cj-cjtilde)^2
		g ba_n=(nj-njtilde)^2
		g ba_e=(ej-ejtilde)^2
		g ba_ze=(zej-zejtilde)^2

		*between firm total variance (consistancy check)
		g bs_l=(lj-lbar)^2
		g bs_v=(vj-vbar)^2
		g bs_s=(sj-sbar)^2
		g bs_t=(tj-tbar)^2
		
		g bs_n1=(n1j-n1bar)^2
		g bs_n2=(n2j-n2bar)^2
		g bs_n3=(n3j-n3bar)^2
		g bs_n4=(n4j-n4bar)^2
		
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*between firm covariance (within and between occ)
		g bat_l=(ljtilde-lbar)*(lj-ljtilde)
		g bat_v=(vjtilde-vbar)*(vj-vjtilde)
		g bat_s=(sjtilde-sbar)*(sj-sjtilde)
		g bat_t=(tjtilde-tbar)*(tj-tjtilde)
		
		g bat_n1=(n1jtilde-n1bar)*(n1j-n1jtilde)
		g bat_n2=(n2jtilde-n2bar)*(n2j-n2jtilde)
		g bat_n3=(n3jtilde-n3bar)*(n3j-n3jtilde)
		g bat_n4=(n4jtilde-n4bar)*(n4j-n4jtilde)
		
		g bat_c=(cjtilde-cbar)*(cj-cjtilde)
		g bat_n=(njtilde-nbar)*(nj-njtilde)
		g bat_e=(ejtilde-ebar)*(ej-ejtilde)
		g bat_ze=(zejtilde-zebar)*(zej-zejtilde)

		*between firm total variance 
		g btot_l=bt_l+ba_l+2*bat_l
		g btot_v=bt_v+ba_v+2*bat_v
		g btot_s=bt_s+ba_s+2*bat_s
		g btot_t=bt_t+ba_t+2*bat_t
		
		g btot_n1=bt_n1+ba_n1+2*bat_n1
		g btot_n2=bt_n2+ba_n2+2*bat_n2
		g btot_n3=bt_n3+ba_n3+2*bat_n3
		g btot_n4=bt_n4+ba_n4+2*bat_n4
		
		g btot_c=bt_c+ba_c+2*bat_c
		g btot_n=bt_n+ba_n+2*bat_n
		g btot_e=bt_e+ba_e+2*bat_e
		g btot_ze=bt_ze+ba_ze+2*bat_ze

		*total between occupation
		g tt_l=(lijtilde-lbar)^2
		g tt_v=(vijtilde-vbar)^2
		g tt_s=(sijtilde-sbar)^2
		g tt_t=(tijtilde-tbar)^2
		
		g tt_n1=(n1ijtilde-n1bar)^2
		g tt_n2=(n2ijtilde-n2bar)^2
		g tt_n3=(n3ijtilde-n3bar)^2
		g tt_n4=(n4ijtilde-n4bar)^2
		
		g tt_c=(cijtilde-cbar)^2 
		g tt_n=(nijtilde-nbar)^2 
		g tt_e=(eijtilde-ebar)^2 
		g tt_ze=(zeijtilde-zebar)^2 

		*total within occupation
		g ta_l=(l-lijtilde)^2
		g ta_v=(v-vijtilde)^2
		g ta_s=(s-sijtilde)^2
		g ta_t=(t-tijtilde)^2
		
		g ta_n1=(n1-n1ijtilde)^2
		g ta_n2=(n2-n2ijtilde)^2
		g ta_n3=(n3-n3ijtilde)^2
		g ta_n4=(n4-n4ijtilde)^2
		
		g ta_c=(c-cijtilde)^2
		g ta_n=(n-nijtilde)^2
		g ta_e=(e-eijtilde)^2
		g ta_ze=(ze-zeijtilde)^2

		*total variance (consistancy check)
		g ts_l=(l-lbar)^2
		g ts_v=(v-vbar)^2
		g ts_s=(s-sbar)^2
		g ts_t=(t-tbar)^2
		
		g ts_n1=(n1-n1bar)^2
		g ts_n2=(n2-n2bar)^2
		g ts_n3=(n3-n3bar)^2
		g ts_n4=(n4-n4bar)^2
		
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_l=(l-lk)^2
		g corr_bi_v=(v-vk)^2
		g corr_bi_s=(s-sk)^2
		g corr_bi_t=(t-tk)^2
		
		g corr_bi_n1=(n1-n1k)^2
		g corr_bi_n2=(n2-n2k)^2
		g corr_bi_n3=(n3-n3k)^2
		g corr_bi_n4=(n4-n4k)^2
		
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* tt* ta* ts* lijtilde vijtilde sijtilde tijtilde n1ijtilde n2ijtilde n3ijtilde n4ijtilde cijtilde nijtilde eijtilde zeijtilde lijres vijres sijres tijres n1ijres n2ijres n3ijres n4ijres cijres nijres eijres zeijres l v s t n1 n2 n3 n4 c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 lj vj sj tj n1j n2j n3j n4j cj nj ej zej ljtilde vjtilde sjtilde tjtilde n1jtilde n2jtilde n3jtilde n4jtilde cjtilde njtilde lk vk sk tk n1k n2k n3k n4k ck nk ek zek lnwpredk lnwagek lbar vbar sbar tbar n1bar n2bar n3bar n4bar cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_l=ws_l*thetaj_w*N2j
		g corr_ws_v=ws_v*thetaj_w*N2j
		g corr_ws_s=ws_s*thetaj_w*N2j
		g corr_ws_t=ws_t*thetaj_w*N2j
		
		g corr_ws_n1=ws_n1*thetaj_w*N2j
		g corr_ws_n2=ws_n2*thetaj_w*N2j
		g corr_ws_n3=ws_n3*thetaj_w*N2j
		g corr_ws_n4=ws_n4*thetaj_w*N2j
		
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		* between occ within firm/plant corrected
		g corr_wt_l=wt_l*thetaj_w*N2j
		g corr_wt_v=wt_v*thetaj_w*N2j
		g corr_wt_s=wt_s*thetaj_w*N2j
		g corr_wt_t=wt_t*thetaj_w*N2j
		
		g corr_wt_n1=wt_n1*thetaj_w*N2j
		g corr_wt_n2=wt_n2*thetaj_w*N2j
		g corr_wt_n3=wt_n3*thetaj_w*N2j
		g corr_wt_n4=wt_n4*thetaj_w*N2j
		
		g corr_wt_c=wt_c*thetaj_w*N2j
		g corr_wt_n=wt_n*thetaj_w*N2j
		g corr_wt_e=wt_e*thetaj_w*N2j
		g corr_wt_ze=wt_ze*thetaj_w*N2j

		*within occ within firm/plant corrected
		g corr_wa_l=wa_l*thetaj_w*N2j
		g corr_wa_v=wa_v*thetaj_w*N2j
		g corr_wa_s=wa_s*thetaj_w*N2j
		g corr_wa_t=wa_t*thetaj_w*N2j
		
		g corr_wa_n1=wa_n1*thetaj_w*N2j
		g corr_wa_n2=wa_n2*thetaj_w*N2j
		g corr_wa_n3=wa_n3*thetaj_w*N2j
		g corr_wa_n4=wa_n4*thetaj_w*N2j
		
		g corr_wa_c=wa_c*thetaj_w*N2j
		g corr_wa_n=wa_n*thetaj_w*N2j
		g corr_wa_e=wa_e*thetaj_w*N2j
		g corr_wa_ze=wa_ze*thetaj_w*N2j

		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_l=wat_l*thetaj_w*N2j
		g corr_wat_v=wat_v*thetaj_w*N2j
		g corr_wat_s=wat_s*thetaj_w*N2j
		g corr_wat_t=wat_t*thetaj_w*N2j
		
		g corr_wat_n1=wat_n1*thetaj_w*N2j
		g corr_wat_n2=wat_n2*thetaj_w*N2j
		g corr_wat_n3=wat_n3*thetaj_w*N2j
		g corr_wat_n4=wat_n4*thetaj_w*N2j
		
		g corr_wat_c=wat_c*thetaj_w*N2j
		g corr_wat_n=wat_n*thetaj_w*N2j
		g corr_wat_e=wat_e*thetaj_w*N2j
		g corr_wat_ze=wat_ze*thetaj_w*N2j

		*within firm/plant total variance corrected
		g corr_wtot_l=corr_wt_l+corr_wa_l+2*corr_wat_l
		g corr_wtot_v=corr_wt_v+corr_wa_v+2*corr_wat_v
		g corr_wtot_s=corr_wt_s+corr_wa_s+2*corr_wat_s
		g corr_wtot_t=corr_wt_t+corr_wa_t+2*corr_wat_t
		
		g corr_wtot_n1=corr_wt_n1+corr_wa_n1+2*corr_wat_n1
		g corr_wtot_n2=corr_wt_n2+corr_wa_n2+2*corr_wat_n2
		g corr_wtot_n3=corr_wt_n3+corr_wa_n3+2*corr_wat_n3
		g corr_wtot_n4=corr_wt_n4+corr_wa_n4+2*corr_wat_n4
		
		g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
		g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
		g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e
		g corr_wtot_ze=corr_wt_ze+corr_wa_ze+2*corr_wat_ze

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_l=N2j*(bs_l-thetaj_b*ws_l)
		g corr_bs_v=N2j*(bs_v-thetaj_b*ws_v)
		g corr_bs_s=N2j*(bs_s-thetaj_b*ws_s)
		g corr_bs_t=N2j*(bs_t-thetaj_b*ws_t)
		
		g corr_bs_n1=N2j*(bs_n1-thetaj_b*ws_n1)
		g corr_bs_n2=N2j*(bs_n2-thetaj_b*ws_n2)
		g corr_bs_n3=N2j*(bs_n3-thetaj_b*ws_n3)
		g corr_bs_n4=N2j*(bs_n4-thetaj_b*ws_n4)
		
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*between occ between firm/plant corrected
		g corr_bt_l=N2j*(bt_l-thetaj_b*wt_l)
		g corr_bt_v=N2j*(bt_v-thetaj_b*wt_v)
		g corr_bt_s=N2j*(bt_s-thetaj_b*wt_s)
		g corr_bt_t=N2j*(bt_t-thetaj_b*wt_t)
		
		g corr_bt_n1=N2j*(bt_n1-thetaj_b*wt_n1)
		g corr_bt_n2=N2j*(bt_n2-thetaj_b*wt_n2)
		g corr_bt_n3=N2j*(bt_n3-thetaj_b*wt_n3)
		g corr_bt_n4=N2j*(bt_n4-thetaj_b*wt_n4)
		
		g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
		g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
		g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)
		g corr_bt_ze=N2j*(bt_ze-thetaj_b*wt_ze)

		*within occ between firm/plant corrected
		g corr_ba_l=N2j*(ba_l-thetaj_b*wa_l)
		g corr_ba_v=N2j*(ba_v-thetaj_b*wa_v)
		g corr_ba_s=N2j*(ba_s-thetaj_b*wa_s)
		g corr_ba_t=N2j*(ba_t-thetaj_b*wa_t)
		
		g corr_ba_n1=N2j*(ba_n1-thetaj_b*wa_n1)
		g corr_ba_n2=N2j*(ba_n2-thetaj_b*wa_n2)
		g corr_ba_n3=N2j*(ba_n3-thetaj_b*wa_n3)
		g corr_ba_n4=N2j*(ba_n4-thetaj_b*wa_n4)
		
		g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
		g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
		g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)
		g corr_ba_ze=N2j*(ba_ze-thetaj_b*wa_ze)

		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_l=N2j*(bat_l-thetaj_b*wat_l)
		g corr_bat_v=N2j*(bat_v-thetaj_b*wat_v)
		g corr_bat_s=N2j*(bat_s-thetaj_b*wat_s)
		g corr_bat_t=N2j*(bat_t-thetaj_b*wat_t)
		
		g corr_bat_n1=N2j*(bat_n1-thetaj_b*wat_n1)
		g corr_bat_n2=N2j*(bat_n2-thetaj_b*wat_n2)
		g corr_bat_n3=N2j*(bat_n3-thetaj_b*wat_n3)
		g corr_bat_n4=N2j*(bat_n4-thetaj_b*wat_n4)
		
		g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
		g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
		g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)
		g corr_bat_ze=N2j*(bat_ze-thetaj_b*wat_ze)

		*between firm/plant total variance corrected
		g corr_btot_l=corr_bt_l+corr_ba_l+2*corr_bat_l
		g corr_btot_v=corr_bt_v+corr_ba_v+2*corr_bat_v
		g corr_btot_s=corr_bt_s+corr_ba_s+2*corr_bat_s
		g corr_btot_t=corr_bt_t+corr_ba_t+2*corr_bat_t
		
		g corr_btot_n1=corr_bt_n1+corr_ba_n1+2*corr_bat_n1
		g corr_btot_n2=corr_bt_n2+corr_ba_n2+2*corr_bat_n2
		g corr_btot_n3=corr_bt_n3+corr_ba_n3+2*corr_bat_n3
		g corr_btot_n4=corr_bt_n4+corr_ba_n4+2*corr_bat_n4
		
		g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
		g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
		g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e
		g corr_btot_ze=corr_bt_ze+corr_ba_ze+2*corr_bat_ze

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_l=bt_l*N2j
		replace bt_v=bt_v*N2j
		replace bt_s=bt_s*N2j
		replace bt_t=bt_t*N2j
		
		replace bt_n1=bt_n1*N2j
		replace bt_n2=bt_n2*N2j
		replace bt_n3=bt_n3*N2j
		replace bt_n4=bt_n4*N2j
		
		replace bt_c=bt_c*N2j
		replace bt_n=bt_n*N2j
		replace bt_e=bt_e*N2j
		replace bt_ze=bt_ze*N2j

		* within occupation between firm/plant
		replace ba_l=ba_l*N2j
		replace ba_v=ba_v*N2j
		replace ba_s=ba_s*N2j
		replace ba_t=ba_t*N2j
		
		replace ba_n1=ba_n1*N2j
		replace ba_n2=ba_n2*N2j
		replace ba_n3=ba_n3*N2j
		replace ba_n4=ba_n4*N2j
		
		replace ba_c=ba_c*N2j
		replace ba_n=ba_n*N2j
		replace ba_e=ba_e*N2j
		replace ba_ze=ba_ze*N2j

		*between firm/plant covariance (between and within occupation)
		replace bat_l=bat_l*N2j
		replace bat_v=bat_v*N2j
		replace bat_s=bat_s*N2j
		replace bat_t=bat_t*N2j
		
		replace bat_n1=bat_n1*N2j
		replace bat_n2=bat_n2*N2j
		replace bat_n3=bat_n3*N2j
		replace bat_n4=bat_n4*N2j
		
		replace bat_c=bat_c*N2j
		replace bat_n=bat_n*N2j
		replace bat_e=bat_e*N2j
		replace bat_ze=bat_ze*N2j

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_l=bs_l*N2j
		replace bs_v=bs_v*N2j
		replace bs_s=bs_s*N2j
		replace bs_t=bs_t*N2j
		
		replace bs_n1=bs_n1*N2j
		replace bs_n2=bs_n2*N2j
		replace bs_n3=bs_n3*N2j
		replace bs_n4=bs_n4*N2j
		
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*between firm/plant total variance
		replace btot_l=btot_l*N2j
		replace btot_v=btot_v*N2j
		replace btot_s=btot_s*N2j
		replace btot_t=btot_t*N2j
		
		replace btot_n1=btot_n1*N2j
		replace btot_n2=btot_n2*N2j
		replace btot_n3=btot_n3*N2j
		replace btot_n4=btot_n4*N2j
		
		replace btot_c=btot_c*N2j
		replace btot_n=btot_n*N2j
		replace btot_e=btot_e*N2j
		replace btot_ze=btot_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)

		*** 4. Overall collapse

		collapse (sum) w* b* tt* ta* ts* corr* N=Nj (mean) lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*final uncorrected variances 

		*between occupation within firm/plant
		replace wt_l=wt_l*1/N2
		replace wt_v=wt_v*1/N2
		replace wt_s=wt_s*1/N2
		replace wt_t=wt_t*1/N2
		
		replace wt_n1=wt_n1*1/N2
		replace wt_n2=wt_n2*1/N2
		replace wt_n3=wt_n3*1/N2
		replace wt_n4=wt_n4*1/N2
		
		replace wt_c=wt_c*1/N2
		replace wt_n=wt_n*1/N2
		replace wt_e=wt_e*1/N2
		replace wt_ze=wt_ze*1/N2

		*within occupation within firm/plant
		replace wa_l=wa_l*1/N2
		replace wa_s=wa_s*1/N2
		replace wa_v=wa_v*1/N2
		replace wa_t=wa_t*1/N2
		
		replace wa_n1=wa_n1*1/N2
		replace wa_n2=wa_n2*1/N2
		replace wa_n3=wa_n3*1/N2
		replace wa_n4=wa_n4*1/N2
		
		replace wa_c=wa_c*1/N2
		replace wa_n=wa_n*1/N2
		replace wa_e=wa_e*1/N2
		replace wa_ze=wa_ze*1/N2

		*within firm/plant covariance (between and within occ)  
		replace wat_l=wat_l*2/N2
		replace wat_v=wat_v*2/N2
		replace wat_s=wat_s*2/N2
		replace wat_t=wat_t*2/N2
		
		replace wat_n1=wat_n1*2/N2
		replace wat_n2=wat_n2*2/N2
		replace wat_n3=wat_n3*2/N2
		replace wat_n4=wat_n4*2/N2
		
		replace wat_c=wat_c*2/N2
		replace wat_n=wat_n*2/N2
		replace wat_e=wat_e*2/N2
		replace wat_ze=wat_ze*2/N2

		*within firm/plant total variance
		replace wtot_l=wtot_l*1/N2
		replace wtot_v=wtot_v*1/N2
		replace wtot_s=wtot_s*1/N2
		replace wtot_t=wtot_t*1/N2
		
		replace wtot_n1=wtot_n1*1/N2
		replace wtot_n2=wtot_n2*1/N2
		replace wtot_n3=wtot_n3*1/N2
		replace wtot_n4=wtot_n4*1/N2
		
		replace wtot_c=wtot_c*1/N2
		replace wtot_n=wtot_n*1/N2
		replace wtot_e=wtot_e*1/N2
		replace wtot_ze=wtot_ze*1/N2

		*within firm/plant total variance (consistancy)
		replace ws_l=ws_l*1/N2
		replace ws_v=ws_v*1/N2
		replace ws_s=ws_s*1/N2
		replace ws_t=ws_t*1/N2
		
		replace ws_n1=ws_n1*1/N2
		replace ws_n2=ws_n2*1/N2
		replace ws_n3=ws_n3*1/N2
		replace ws_n4=ws_n4*1/N2
		
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between occupation between firm
		replace bt_l=bt_l*1/N2
		replace bt_v=bt_v*1/N2
		replace bt_s=bt_s*1/N2
		replace bt_t=bt_t*1/N2
		
		replace bt_n1=bt_n1*1/N2
		replace bt_n2=bt_n2*1/N2
		replace bt_n3=bt_n3*1/N2
		replace bt_n4=bt_n4*1/N2
		
		replace bt_c=bt_c*1/N2
		replace bt_n=bt_n*1/N2
		replace bt_e=bt_e*1/N2
		replace bt_ze=bt_ze*1/N2

		*within occupation between firm/plant 
		replace ba_l=ba_l*1/N2
		replace ba_v=ba_v*1/N2
		replace ba_s=ba_s*1/N2
		replace ba_t=ba_t*1/N2
		
		replace ba_n1=ba_n1*1/N2
		replace ba_n2=ba_n2*1/N2
		replace ba_n3=ba_n3*1/N2
		replace ba_n4=ba_n4*1/N2
		
		replace ba_c=ba_c*1/N2
		replace ba_n=ba_n*1/N2
		replace ba_e=ba_e*1/N2
		replace ba_ze=ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace bat_l=bat_l*2/N2
		replace bat_v=bat_v*2/N2
		replace bat_s=bat_s*2/N2
		replace bat_t=bat_t*2/N2
		
		replace bat_n1=bat_n1*2/N2
		replace bat_n2=bat_n2*2/N2
		replace bat_n3=bat_n3*2/N2
		replace bat_n4=bat_n4*2/N2
		
		replace bat_c=bat_c*2/N2
		replace bat_n=bat_n*2/N2
		replace bat_e=bat_e*2/N2
		replace bat_ze=bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace bs_l=bs_l*1/N2
		replace bs_v=bs_v*1/N2
		replace bs_s=bs_s*1/N2
		replace bs_t=bs_t*1/N2
		
		replace bs_n1=bs_n1*1/N2
		replace bs_n2=bs_n2*1/N2
		replace bs_n3=bs_n3*1/N2
		replace bs_n4=bs_n4*1/N2
		
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*between firm/plant total variance
		replace btot_l=btot_l*1/N2
		replace btot_v=btot_v*1/N2
		replace btot_s=btot_s*1/N2
		replace btot_t=btot_t*1/N2
		
		replace btot_n1=btot_n1*1/N2
		replace btot_n2=btot_n2*1/N2
		replace btot_n3=btot_n3*1/N2
		replace btot_n4=btot_n4*1/N2
		
		replace btot_c=btot_c*1/N2
		replace btot_n=btot_n*1/N2
		replace btot_e=btot_e*1/N2
		replace btot_ze=btot_ze*1/N2

		*total between occ
		replace tt_l=tt_l*1/N2
		replace tt_v=tt_v*1/N2
		replace tt_s=tt_s*1/N2
		replace tt_t=tt_t*1/N2
		
		replace tt_n1=tt_n1*1/N2
		replace tt_n2=tt_n2*1/N2
		replace tt_n3=tt_n3*1/N2
		replace tt_n4=tt_n4*1/N2
		
		replace tt_c=tt_c*1/N2
		replace tt_n=tt_n*1/N2
		replace tt_e=tt_e*1/N2
		replace tt_ze=tt_ze*1/N2

		*total within occ
		replace ta_l=ta_l*1/N2
		replace ta_v=ta_v*1/N2
		replace ta_s=ta_s*1/N2
		replace ta_t=ta_t*1/N2
		
		replace ta_n1=ta_n1*1/N2
		replace ta_n2=ta_n2*1/N2
		replace ta_n3=ta_n3*1/N2
		replace ta_n4=ta_n4*1/N2
		
		replace ta_c=ta_c*1/N2
		replace ta_n=ta_n*1/N2
		replace ta_e=ta_e*1/N2
		replace ta_ze=ta_ze*1/N2

		*total variance (consistancy)
		replace ts_l=ts_l*1/N2
		replace ts_v=ts_v*1/N2
		replace ts_s=ts_s*1/N2
		replace ts_t=ts_t*1/N2
		
		replace ts_n1=ts_n1*1/N2
		replace ts_n2=ts_n2*1/N2
		replace ts_n3=ts_n3*1/N2
		replace ts_n4=ts_n4*1/N2
		
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*between occ within firm corrected
		replace corr_wt_l=corr_wt_l*1/N2
		replace corr_wt_v=corr_wt_v*1/N2
		replace corr_wt_s=corr_wt_s*1/N2
		replace corr_wt_t=corr_wt_t*1/N2
		
		replace corr_wt_n1=corr_wt_n1*1/N2
		replace corr_wt_n2=corr_wt_n2*1/N2
		replace corr_wt_n3=corr_wt_n3*1/N2
		replace corr_wt_n4=corr_wt_n4*1/N2
		
		replace corr_wt_c=corr_wt_c*1/N2
		replace corr_wt_n=corr_wt_n*1/N2
		replace corr_wt_e=corr_wt_e*1/N2
		replace corr_wt_ze=corr_wt_ze*1/N2

		*within occ within firm corrected
		replace corr_wa_l=corr_wa_l*1/N2
		replace corr_wa_v=corr_wa_v*1/N2
		replace corr_wa_s=corr_wa_s*1/N2
		replace corr_wa_t=corr_wa_t*1/N2
		
		replace corr_wa_n1=corr_wa_n1*1/N2
		replace corr_wa_n2=corr_wa_n2*1/N2
		replace corr_wa_n3=corr_wa_n3*1/N2
		replace corr_wa_n4=corr_wa_n4*1/N2
		
		replace corr_wa_c=corr_wa_c*1/N2
		replace corr_wa_n=corr_wa_n*1/N2
		replace corr_wa_e=corr_wa_e*1/N2
		replace corr_wa_ze=corr_wa_ze*1/N2

		*within firm covariance (between and within occ)  
		replace corr_wat_l=corr_wat_l*2/N2
		replace corr_wat_v=corr_wat_v*2/N2
		replace corr_wat_s=corr_wat_s*2/N2
		replace corr_wat_t=corr_wat_t*2/N2
		
		replace corr_wat_n1=corr_wat_n1*2/N2
		replace corr_wat_n2=corr_wat_n2*2/N2
		replace corr_wat_n3=corr_wat_n3*2/N2
		replace corr_wat_n4=corr_wat_n4*2/N2
		
		replace corr_wat_c=corr_wat_c*2/N2
		replace corr_wat_n=corr_wat_n*2/N2
		replace corr_wat_e=corr_wat_e*2/N2
		replace corr_wat_ze=corr_wat_ze*2/N2

		*within firm/plant total variance corrected
		replace corr_wtot_l=corr_wtot_l*1/N2
		replace corr_wtot_v=corr_wtot_v*1/N2
		replace corr_wtot_s=corr_wtot_s*1/N2
		replace corr_wtot_t=corr_wtot_t*1/N2
		
		replace corr_wtot_n1=corr_wtot_n1*1/N2
		replace corr_wtot_n2=corr_wtot_n2*1/N2
		replace corr_wtot_n3=corr_wtot_n3*1/N2
		replace corr_wtot_n4=corr_wtot_n4*1/N2
		
		replace corr_wtot_c=corr_wtot_c*1/N2
		replace corr_wtot_n=corr_wtot_n*1/N2
		replace corr_wtot_e=corr_wtot_e*1/N2
		replace corr_wtot_ze=corr_wtot_ze*1/N2

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_l=corr_ws_l*1/N2
		replace corr_ws_v=corr_ws_v*1/N2
		replace corr_ws_s=corr_ws_s*1/N2
		replace corr_ws_t=corr_ws_t*1/N2
		
		replace corr_ws_n1=corr_ws_n1*1/N2
		replace corr_ws_n2=corr_ws_n2*1/N2
		replace corr_ws_n3=corr_ws_n3*1/N2
		replace corr_ws_n4=corr_ws_n4*1/N2
		
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between occupation between firm/plant
		replace corr_bt_l=corr_bt_l*1/N2
		replace corr_bt_v=corr_bt_v*1/N2
		replace corr_bt_s=corr_bt_s*1/N2
		replace corr_bt_t=corr_bt_t*1/N2
		
		replace corr_bt_n1=corr_bt_n1*1/N2
		replace corr_bt_n2=corr_bt_n2*1/N2
		replace corr_bt_n3=corr_bt_n3*1/N2
		replace corr_bt_n4=corr_bt_n4*1/N2
		
		replace corr_bt_c=corr_bt_c*1/N2
		replace corr_bt_n=corr_bt_n*1/N2
		replace corr_bt_e=corr_bt_e*1/N2
		replace corr_bt_ze=corr_bt_ze*1/N2

		*within occupation between firm/plant
		replace corr_ba_l=corr_ba_l*1/N2
		replace corr_ba_v=corr_ba_v*1/N2
		replace corr_ba_s=corr_ba_s*1/N2
		replace corr_ba_t=corr_ba_t*1/N2
		
		replace corr_ba_n1=corr_ba_n1*1/N2
		replace corr_ba_n2=corr_ba_n2*1/N2
		replace corr_ba_n3=corr_ba_n3*1/N2
		replace corr_ba_n4=corr_ba_n4*1/N2
		
		replace corr_ba_c=corr_ba_c*1/N2
		replace corr_ba_n=corr_ba_n*1/N2
		replace corr_ba_e=corr_ba_e*1/N2
		replace corr_ba_ze=corr_ba_ze*1/N2

		*between firm/plant covariance (between and within occ)  
		replace corr_bat_l=corr_bat_l*2/N2
		replace corr_bat_v=corr_bat_v*2/N2
		replace corr_bat_s=corr_bat_s*2/N2
		replace corr_bat_t=corr_bat_t*2/N2
		
		replace corr_bat_n1=corr_bat_n1*2/N2
		replace corr_bat_n2=corr_bat_n2*2/N2
		replace corr_bat_n3=corr_bat_n3*2/N2
		replace corr_bat_n4=corr_bat_n4*2/N2
		
		replace corr_bat_c=corr_bat_c*2/N2
		replace corr_bat_n=corr_bat_n*2/N2
		replace corr_bat_e=corr_bat_e*2/N2
		replace corr_bat_ze=corr_bat_ze*2/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_l=corr_bs_l*1/N2
		replace corr_bs_v=corr_bs_v*1/N2
		replace corr_bs_s=corr_bs_s*1/N2
		replace corr_bs_t=corr_bs_t*1/N2
		
		replace corr_bs_n1=corr_bs_n1*1/N2
		replace corr_bs_n2=corr_bs_n2*1/N2
		replace corr_bs_n3=corr_bs_n3*1/N2
		replace corr_bs_n4=corr_bs_n4*1/N2
		
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*between firm/plant total variance
		replace corr_btot_l=corr_btot_l*1/N2
		replace corr_btot_v=corr_btot_v*1/N2
		replace corr_btot_s=corr_btot_s*1/N2
		replace corr_btot_t=corr_btot_t*1/N2
		
		replace corr_btot_n1=corr_btot_n1*1/N2
		replace corr_btot_n2=corr_btot_n2*1/N2
		replace corr_btot_n3=corr_btot_n3*1/N2
		replace corr_btot_n4=corr_btot_n4*1/N2
		
		replace corr_btot_c=corr_btot_c*1/N2
		replace corr_btot_n=corr_btot_n*1/N2
		replace corr_btot_e=corr_btot_e*1/N2
		replace corr_btot_ze=corr_btot_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/detailed_vardecomp_aggregate_`x'_`j'_`i',replace
		}
	}
}

foreach x in ftg {
	foreach j in 10 {
	use temp/detailed_vardecomp_aggregate_`x'_`j'_1985,clear
		forvalues i=1986(1)2009{
		append using temp/detailed_vardecomp_aggregate_`x'_`j'_`i'
		}

	lab var ba_l "Within occupation between firm/plant (logic)"
	lab var bt_l "Between occupation between firm/plant (logic)"
	lab var bat_l "Between firm/plant covariance (logic)"
	lab var bs_l "Between firm/plant total (logic)"
	lab var btot_l "Between firm/plant total (logic)"

	lab var wa_l "Within occupation within firm/plant (logic)"
	lab var wt_l "Between occupation within firm/plant (logic)"
	lab var wat_l "Within firm/plant covariance (logic)"
	lab var ws_l "Within firm/plant total (logic)"
	lab var wtot_l "Within firm/plant total (logic)"

	lab var ta_l "Within occupation total (logic)"
	lab var tt_l "Between occupation total (logic)"
	lab var ts_l "Total (logic)"
	
	lab var ba_v "Within occupation between firm/plant (verbal)"
	lab var bt_v "Between occupation between firm/plant (verbal)"
	lab var bat_v "Between firm/plant covariance (verbal)"
	lab var bs_v "Between firm/plant total (verbal)"
	lab var btot_v "Between firm/plant total (verbal)"

	lab var wa_v "Within occupation within firm/plant (verbal)"
	lab var wt_v "Between occupation within firm/plant (verbal)"
	lab var wat_v "Within firm/plant covariance (verbal)"
	lab var ws_v "Within firm/plant total (verbal)"
	lab var wtot_v "Within firm/plant total (verbal)"

	lab var ta_v "Within occupation total (verbal)"
	lab var tt_v "Between occupation total (verbal)"
	lab var ts_v "Total (verbal)"

	lab var ba_s "Within occupation between firm/plant (spatial)"
	lab var bt_s "Between occupation between firm/plant (spatial)"
	lab var bat_s "Between firm/plant covariance (spatial)"
	lab var bs_s "Between firm/plant total (spatial)"
	lab var btot_s "Between firm/plant total (spatial)"

	lab var wa_s "Within occupation within firm/plant (spatial)"
	lab var wt_s "Between occupation within firm/plant (spatial)"
	lab var wat_s "Within firm/plant covariance (spatial)"
	lab var ws_s "Within firm/plant total (spatial)"
	lab var wtot_s "Within firm/plant total (spatial)"

	lab var ta_s "Within occupation total (spatial)"
	lab var tt_s "Between occupation total (spatial)"
	lab var ts_s "Total (spatial)"
	
	lab var ba_t "Within occupation between firm/plant (technical)"
	lab var bt_t "Between occupation between firm/plant (technical)"
	lab var bat_t "Between firm/plant covariance (technical)"
	lab var bs_t "Between firm/plant total (technical)"
	lab var btot_t "Between firm/plant total (technical)"

	lab var wa_t "Within occupation within firm/plant (technical)"
	lab var wt_t "Between occupation within firm/plant (technical)"
	lab var wat_t "Within firm/plant covariance (technical)"
	lab var ws_t "Within firm/plant total (technical)"
	lab var wtot_t "Within firm/plant total (technical)"

	lab var ta_t "Within occupation total (technical)"
	lab var tt_t "Between occupation total (technical)"
	lab var ts_t "Total (technical)"
	
	lab var ba_n1 "Within occupation between firm/plant (S)"
	lab var bt_n1 "Between occupation between firm/plant (S)"
	lab var bat_n1 "Between firm/plant covariance (S)"
	lab var bs_n1 "Between firm/plant total (S)"
	lab var btot_n1 "Between firm/plant total (S)"

	lab var wa_n1 "Within occupation within firm/plant (S)"
	lab var wt_n1 "Between occupation within firm/plant (S)"
	lab var wat_n1 "Within firm/plant covariance (S)"
	lab var ws_n1 "Within firm/plant total (S)"
	lab var wtot_n1 "Within firm/plant total (S)"

	lab var ta_n1 "Within occupation total (S)"
	lab var tt_n1 "Between occupation total (S)"
	lab var ts_n1 "Total (S)"
	
	lab var ba_n2 "Within occupation between firm/plan (I)"
	lab var bt_n2 "Between occupation between firm/plant (I)"
	lab var bat_n2 "Between firm/plant covariance (I)"
	lab var bs_n2 "Between firm/plant total (I)"
	lab var btot_n2 "Between firm/plant total (I)"

	lab var wa_n2 "Within occupation within firm/plant (I)"
	lab var wt_n2 "Between occupation within firm/plant (I)"
	lab var wat_n2 "Within firm/plant covariance (I)"
	lab var ws_n2 "Within firm/plant total (I)"
	lab var wtot_n2 "Within firm/plant total (I)"

	lab var ta_n2 "Within occupation total (I)"
	lab var tt_n2 "Between occupation total (I)"
	lab var ts_n2 "Total (I)"
	
	lab var ba_n3 "Within occupation between firm/plant"
	lab var bt_n3 "Between occupation between firm/plant"
	lab var bat_n3 "Between firm/plant covariance"
	lab var bs_n3 "Between firm/plant total"
	lab var btot_n3 "Between firm/plant total (consistancy)"

	lab var wa_n3 "Within occupation within firm/plant (P)"
	lab var wt_n3 "Between occupation within firm/plant (P)"
	lab var wat_n3 "Within firm/plant covariance (P)"
	lab var ws_n3 "Within firm/plant total (P)"
	lab var wtot_n3 "Within firm/plant total (P)"

	lab var ta_n3 "Within occupation total (P)"
	lab var tt_n3 "Between occupation total (P)"
	lab var ts_n3 "Total (P)"
	
	lab var ba_n4 "Within occupation between firm/plant (E)"
	lab var bt_n4 "Between occupation between firm/plant (E)"
	lab var bat_n4 "Between firm/plant covariance (E)"
	lab var bs_n4 "Between firm/plant total (E)"
	lab var btot_n4 "Between firm/plant total (E)"

	lab var wa_n4 "Within occupation within firm/plant (E)"
	lab var wt_n4 "Between occupation within firm/plant (E)"
	lab var wat_n4 "Within firm/plant covariance (E)"
	lab var ws_n4 "Within firm/plant total (E)"
	lab var wtot_n4 "Within firm/plant total (E)"

	lab var ta_n4 "Within occupation total (E)"
	lab var tt_n4 "Between occupation total (E)"
	lab var ts_n4 "Total (E)"
	
	lab var ba_c "Within occupation between firm/plant (cog)"
	lab var bt_c "Between occupation between firm/plant (cog)"
	lab var bat_c "Between firm/plant covariance (cog)"
	lab var bs_c "Between firm/plant total (cog)"
	lab var btot_c "Between firm/plant total (cog)"

	lab var wa_c "Within occupation within firm/plant (cog)"
	lab var wt_c "Between occupation within firm/plant (cog)"
	lab var wat_c "Within firm/plant covariance (cog)"
	lab var ws_c "Within firm/plant total (cog)"
	lab var wtot_c "Within firm/plant total (cog)"

	lab var ta_c "Within occupation total (cog)"
	lab var tt_c "Between occupation total (cog)"
	lab var ts_c "Total (cog)"

	lab var ba_n "Within occupation between firm/plant (noncog)"
	lab var bt_n "Between occupation between firm/plant (noncog)"
	lab var bat_n "Between firm/plant covariance (noncog)"
	lab var bs_n "Between firm/plant total (noncog)"
	lab var btot_n "Between firm/plant total (noncog)"

	lab var wa_n "Within occupation within firm/plant (noncog)"
	lab var wt_n "Between occupation within firm/plant (noncog)"
	lab var wat_n "Within firm/plant covariance (noncog)"
	lab var ws_n "Within firm/plant total (noncog)"
	lab var wtot_n "Within firm/plant total (noncog)"

	lab var ta_n "Within occupation total (noncog)"
	lab var tt_n "Between occupation total (noncog)"
	lab var ts_n "Total (noncog)"

	lab var ba_e "Within occupation between firm/plant (edu)"
	lab var bt_e "Between occupation between firm/plant (edu)"
	lab var bat_e "Between firm/plant covariance (edu)"
	lab var bs_e "Between firm/plant total (edu)"
	lab var btot_e "Between firm/plant total (edu)"

	lab var wa_e "Within occupation within firm/plant (edu)"
	lab var wt_e "Between occupation within firm/plant (edu)"
	lab var wat_e "Between firm/plant covariance (edu)"
	lab var ws_e "Within firm/plant total (edu)"
	lab var wtot_e "Within firm/plant total (edu)"

	lab var ta_e "Within occupation total (edu)"
	lab var tt_e "Between occupation total (edu)"
	lab var ts_e "Total (edu)"

	lab var ba_ze "Within occupation between firm/plant (eduz)"
	lab var bt_ze "Between occupation between firm/plant (eduz)"
	lab var bat_ze "Between firm/plant covariance (eduz)"
	lab var bs_ze "Between firm/plant total (eduz)"
	lab var btot_ze "Between firm/plant total (eduz)"

	lab var wa_ze "Within occupation within firm/plant (eduz)"
	lab var wt_ze "Between occupation within firm/plant (eduz)"
	lab var wat_ze "Between firm/plant covariance (eduz)"
	lab var ws_ze "Within firm/plant total (eduz)"
	lab var wtot_ze "Within firm/plant total (eduz)"

	lab var ta_ze "Within occupation total (eduz)"
	lab var tt_ze "Between occupation total (eduz)"
	lab var ts_ze "Total (eduz)"

	lab var corr_ba_l "Within occupation between firm/plant (logic)"
	lab var corr_bt_l "Between occupation between firm/plant (logic)"
	lab var corr_bat_l "Between firm/plant covariance (logic)"
	lab var corr_bs_l "Between firm/plant total (logic)"
	lab var corr_btot_l "Between firm/plant total (logic)"

	lab var corr_wa_l "Within occupation witin firm/plant (logic)"
	lab var corr_wt_l "Between occupation within firm/plant (logic)"
	lab var corr_wat_l "Within firm/plant covariance (logic)"
	lab var corr_ws_l "Within firm/plant total (logic)"
	lab var corr_wtot_l "Within firm/plant total (logic)"
	
	lab var corr_ba_v "Within occupation between firm/plant (verbal)"
	lab var corr_bt_v "Between occupation between firm/plant (verbal)"
	lab var corr_bat_v "Between firm/plant covariance (verbal)"
	lab var corr_bs_v "Between firm/plant total (verbal)"
	lab var corr_btot_v "Between firm/plant total (verbal)"

	lab var corr_wa_v "Within occupation witin firm/plant (verbal)"
	lab var corr_wt_v "Between occupation within firm/plant (verbal)"
	lab var corr_wat_v "Within firm/plant covariance (verbal)"
	lab var corr_ws_v "Within firm/plant total (verbal)"
	lab var corr_wtot_v "Within firm/plant total (verbal)"

	lab var corr_ba_s "Within occupation between firm/plant (spatial)"
	lab var corr_bt_s "Between occupation between firm/plant (spatial)"
	lab var corr_bat_s "Between firm/plant covariance (spatial)"
	lab var corr_bs_s "Between firm/plant total (spatial)"
	lab var corr_btot_s "Between firm/plant total (spatial)"

	lab var corr_wa_s "Within occupation witin firm/plant (spatial)"
	lab var corr_wt_s "Between occupation within firm/plant (spatial)"
	lab var corr_wat_s "Within firm/plant covariance (spatial)"
	lab var corr_ws_s "Within firm/plant total (spatial)"
	lab var corr_wtot_s "Within firm/plant total (spatial)"
	
	lab var corr_ba_t "Within occupation between firm/plant (technical)"
	lab var corr_bt_t "Between occupation between firm/plant (technical)"
	lab var corr_bat_t "Between firm/plant covariance (technical)"
	lab var corr_bs_t "Between firm/plant total (technical)"
	lab var corr_btot_t "Between firm/plant total (technical)"

	lab var corr_wa_t "Within occupation witin firm/plant (technical)"
	lab var corr_wt_t "Between occupation within firm/plant (technical)"
	lab var corr_wat_t "Within firm/plant covariance (technical)"
	lab var corr_ws_t "Within firm/plant total (technical)"
	lab var corr_wtot_t "Within firm/plant total (technical)"

	lab var corr_ba_n1 "Within occupation between firm/plant (S)"
	lab var corr_bt_n1 "Between occupation between firm/plant (S)"
	lab var corr_bat_n1 "Between firm/plant covariance (S)"
	lab var corr_bs_n1 "Between firm/plant total (S)"
	lab var corr_btot_n1 "Between firm/plant total (S)"

	lab var corr_wa_n1 "Within occupation witin firm/plant (S)"
	lab var corr_wt_n1 "Between occupation within firm/plant (S)"
	lab var corr_wat_n1 "Within firm/plant covariance (S)"
	lab var corr_ws_n1 "Within firm/plant total (S)"
	lab var corr_wtot_n1 "Within firm/plant total (S)"

	lab var corr_ba_n2 "Within occupation between firm/plant (I)"
	lab var corr_bt_n2 "Between occupation between firm/plant (I)"
	lab var corr_bat_n2 "Between firm/plant covariance (I)"
	lab var corr_bs_n2 "Between firm/plant total (I)"
	lab var corr_btot_n2 "Between firm/plant total (I)"

	lab var corr_wa_n2 "Within occupation witin firm/plant (I)"
	lab var corr_wt_n2 "Between occupation within firm/plant (I)"
	lab var corr_wat_n2 "Within firm/plant covariance (I)"
	lab var corr_ws_n2 "Within firm/plant total (I)"
	lab var corr_wtot_n2 "Within firm/plant total (I)"
	
	lab var corr_ba_n3 "Within occupation between firm/plant (P)"
	lab var corr_bt_n3 "Between occupation between firm/plant (P)"
	lab var corr_bat_n3 "Between firm/plant covariance (P)"
	lab var corr_bs_n3 "Between firm/plant total (P)"
	lab var corr_btot_n3 "Between firm/plant total (P)"

	lab var corr_wa_n3 "Within occupation witin firm/plant (P)"
	lab var corr_wt_n3 "Between occupation within firm/plant (P)"
	lab var corr_wat_n3 "Within firm/plant covariance (P)"
	lab var corr_ws_n3 "Within firm/plant total (P)"
	lab var corr_wtot_n3 "Within firm/plant total (P)"
	
	lab var corr_ba_n4 "Within occupation between firm/plant (E)"
	lab var corr_bt_n4 "Between occupation between firm/plant (E)"
	lab var corr_bat_n4 "Between firm/plant covariance (E)"
	lab var corr_bs_n4 "Between firm/plant total (E)"
	lab var corr_btot_n4 "Between firm/plant total (E)"

	lab var corr_wa_n4 "Within occupation witin firm/plant (E)"
	lab var corr_wt_n4 "Between occupation within firm/plant (E)"
	lab var corr_wat_n4 "Within firm/plant covariance (E)"
	lab var corr_ws_n4 "Within firm/plant total (E)"
	lab var corr_wtot_n4 "Within firm/plant total (E)"
	
	lab var corr_ba_c "Within occupation between firm/plant (cog)"
	lab var corr_bt_c "Between occupation between firm/plant (cog)"
	lab var corr_bat_c "Between firm/plant covariance (cog)"
	lab var corr_bs_c "Between firm/plant total (cog)"
	lab var corr_btot_c "Between firm/plant total (cog)"

	lab var corr_wa_c "Within occupation witin firm/plant (cog)"
	lab var corr_wt_c "Between occupation within firm/plant (cog)"
	lab var corr_wat_c "Within firm/plant covariance (cog)"
	lab var corr_ws_c "Within firm/plant total (cog)"
	lab var corr_wtot_c "Within firm/plant total (cog)"

	lab var corr_ba_n "Within occupation between firm/plant (noncog)"
	lab var corr_bt_n "Between occupation between firm/plant (noncog)"
	lab var corr_bat_n "Between firm covariance/plant (noncog)"
	lab var corr_bs_n "Between firm total/plant (noncog)"
	lab var corr_btot_n "Between firm/plant total (noncog)"

	lab var corr_wa_n "Within occupation witin firm/plant (noncog)"
	lab var corr_wt_n "Between occupation within firm/plant (noncog)"
	lab var corr_wat_n "Within firm/plant covariance (noncog)"
	lab var corr_ws_n "Within firm/plant total (noncog)"
	lab var corr_wtot_n "Within firm/plant total (noncog)"

	lab var corr_ba_e "Within occupation between firm/plant (edu)"
	lab var corr_bt_e "Between occupation between firm/plant (edu)"
	lab var corr_bat_e "Between firm/plant covariance (edu)"
	lab var corr_bs_e "Between firm/plant total (edu)"
	lab var corr_btot_e "Between firm/plant total (edu)"

	lab var corr_wa_e "Within occupation witin firm/plant (edu)"
	lab var corr_wt_e "Between occupation within firm/plant (edu)"
	lab var corr_wat_e "Within firm/plant covariance (edu)"
	lab var corr_ws_e "Within firm/plant total (edu)"
	lab var corr_wtot_e "Within firm/plant total (edu)"

	lab var corr_ba_ze "Within occupation between firm/plant (eduz)"
	lab var corr_bt_ze "Between occupation between firm/plant (eduz)"
	lab var corr_bat_ze "Between firm/plant covariance (eduz)"
	lab var corr_bs_ze "Between firm/plant total (eduz)"
	lab var corr_btot_ze "Between firm/plant total (eduz)"

	lab var corr_wa_ze "Within occupation witin firm/plant (eduz)"
	lab var corr_wt_ze "Between occupation within firm/plant (eduz)"
	lab var corr_wat_ze "Within firm/plant covariance (eduz)"
	lab var corr_ws_ze "Within firm/plant total (eduz)"
	lab var corr_wtot_ze "Within firm/plant total (eduz)"

	save modified/detailed_vardecomp_aggregate_`x'_`j',replace
	saveold modified/detailed_old_vardecomp_aggregate_`x'_`j',replace
	}
}		

********************************************
*** Sorting based on residualized skills ***
********************************************

clear
foreach x in ftg {
foreach j in 10 {
forvalues i = 1986(1)2008 {
	use lopnr fos fos_detail c n edyr ftgsni* sample* ftgstorl_`x' age sex ftgnr privfirm_`x' `x'nr year using modified/sample`i', clear

	* Drop firms/plants without identifiers
	drop if `x'nr==""
		
	* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
	keep if age>=20 & age~=.
	keep if age<=65 & age~=.
		
	* Generate count variable
	g count=1
		
	* Generate the equivalence of Nj (all employees in sample firms/plants)
	bysort `x'nr: egen Nj=total(count)

	* Keep relevant sample
	keep if sample_3035_`j'_`x'==1
	
	reg c n 
	predict cres, resid
	reg n c
	predict nres, resid
	
	drop c n
	rename cres c 
	rename nres n
	
	*firm
	bysort ftgnr: egen cj=mean(c)
	bysort ftgnr: egen nj=mean(n)

	*sample
	egen cbar=mean(c)
	egen nbar=mean(n)

	bysort ftgnr: egen N2j=total(count) 
	egen N2=total(count) 

	*within firm total simple
	g ws_c=(c-cj)^2
	g ws_n=(n-nj)^2
	
	*between firm total simple
	g bs_c=(cj-cbar)^2
	g bs_n=(nj-cbar)^2

	*total simple
	g ts_c=(c-cbar)^2
	g ts_n=(n-nbar)^2
	
	*2.Collapse to firm level
	collapse (sum) w* t* c n (mean) b* Nj N2j N2 cj nj cbar nbar, by (year ftgnr ftgsni2)

	*sample correction firm level
	g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
	g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances
	*within firm total simple corrected
	g corr_ws_c=ws_c*thetaj_w*N2j
	g corr_ws_n=ws_n*thetaj_w*N2j

	*between firm total simple corrected
	g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
	g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

	*between firm total simple
	replace bs_c=bs_c*N2j
	replace bs_n=bs_n*N2j

*3. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

	*within firm total simple
	replace ws_c=ws_c*1/N2
	replace ws_n=ws_n*1/N2

	*between firm total simple
	replace bs_c=bs_c*1/N2
	replace bs_n=bs_n*1/N2

	*total simple
	replace ts_c=ts_c*1/N2
	replace ts_n=ts_n*1/N2

	*within firm total simple corrected
	replace corr_ws_c=corr_ws_c*1/N2
	replace corr_ws_n=corr_ws_n*1/N2

	*between firm total simple
	replace corr_bs_c=corr_bs_c*1/N2
	replace corr_bs_n=corr_bs_n*1/N2
	
	save temp/residualized_`i'.dta, replace
}
}
}

use temp/residualized_1986.dta, clear

forvalue i=1987(1)2008 {
	append using temp/residualized_`i'.dta
	}

save modified/residualized_skills.dta, replace

********************************************************
*** Sorting on education for men 24-60 and all 24-60 ***
********************************************************

set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
		use lopnr fos fos_detail edyr fos fos_detail zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' privfirm_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds 
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample 
		drop if sex=="2"
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10
		keep if age>=24 & age<=60

		*Observed samples and sizes
		bysort `x'nr: egen N2j=total(count)
		drop if N2j<2
		egen N2=total(count) 

		***Actual skill means
		*industry
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*sample
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*within firm total variance (consistancy check)
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*between firm total variance (consistancy check)
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*total variance (consistancy check)
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* t* c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 cj nj ej zej ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))
		
		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)
		
		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) Nj N2j lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*within firm/plant total variance (consistancy)
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*total variance (consistancy)
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/vardecomp_aggregate_ed2460_`x'_`j'_`i',replace
		}
	}
}

use temp/vardecomp_aggregate_ed2460_ftg_10_1986, clear
forvalues i=1987(1)2008 {
	append using temp/vardecomp_aggregate_ed2460_ftg_10_`i'
}

rename corr_bs_e corr_bs_e_ed2460
rename corr_ws_e corr_ws_e_ed2460
rename corr_bs_ze corr_bs_ze_ed2460
rename corr_ws_ze corr_ws_ze_ed2460
rename N2 N2ed2460
lab var corr_bs_e_ed2460 "Men 24-60"
lab var corr_bs_ze_ed2460 "Men 24-60"
lab var corr_ws_e_ed2460 "Men 24-60"
lab var corr_ws_ze_ed2460 "Men 24-60"
lab var N2ed2460 "Men 24-60"

save modified/vardecomp_aggregate_ed2460.dta, replace

******************************
*** Ed men and women 24-60 ***
******************************
set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
		use lopnr fos fos_detail edyr fos fos_detail zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' privfirm_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds 
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample 
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10
		keep if age>=24 & age<=60

		*Observed samples and sizes
		bysort `x'nr: egen N2j=total(count)
		drop if N2j<2
		egen N2=total(count) 

		***Actual skill means
		*industry
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*sample
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*within firm total variance (consistancy check)
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*between firm total variance (consistancy check)
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*total variance (consistancy check)
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* t* c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 cj nj ej zej ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))
		
		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)
		
		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) Nj N2j lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*within firm/plant total variance (consistancy)
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*total variance (consistancy)
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/vardecomp_aggregate_alled2460_`x'_`j'_`i',replace
		}
	}
}

use temp/vardecomp_aggregate_alled2460_ftg_10_1986, clear
forvalues i=1987(1)2008 {
	append using temp/vardecomp_aggregate_alled2460_ftg_10_`i'
}

rename corr_bs_e corr_bs_e_alled2460
rename corr_ws_e corr_ws_e_alled2460
rename corr_bs_ze corr_bs_ze_alled2460
rename corr_ws_ze corr_ws_ze_alled2460
rename N2 N2alled2460
lab var corr_bs_e_alled2460 "All 24-60"
lab var corr_bs_ze_alled2460 "All 24-60"
lab var corr_ws_e_alled2460 "All 24-60"
lab var corr_ws_ze_alled2460 "All 24-60"
lab var N2alled2460 "All 24-60"

save modified/vardecomp_aggregate_alled2460.dta, replace

*** Figure. Sorting on education for different groups (redundant)
/*
use modified/vardecomp_aggregate.dta, clear
drop if year==1985
drop if year==2009

lab var corr_bs_ze_ftg_10 "Main sample"
lab var corr_bs_ze_ftg_10 "Main sample"
lab var corr_ws_ze_ftg_10 "Main sample"
lab var corr_ws_ze_ftg_10 "Main sample"
lab var N2_ftg_10  "Main sample"

merge 1:1 year using modified/vardecomp_aggregate_ed2460.dta
drop _merge
merge 1:1 year using modified/vardecomp_aggregate_alled2460.dta

graph drop _all
twoway (line corr_bs_ze_ftg_10 corr_bs_ze_ed2460 corr_bs_ze_alled2460 year, yaxis(1) ylabel(0.1(0.05)0.5,axis(1)) ymtick(0.1(0.05)0.5, axis(1))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("A: Between firm") name(figR8a)
graph save figR8a,replace
twoway (line corr_ws_ze_ftg_10 corr_ws_ze_ed2460 corr_ws_ze_alled2460 year, yaxis(1) ylabel(0.4(0.05)0.8,axis(1)) ymtick(0.4(0.05)0.8, axis(1))), scheme(s2mono) graphr(c(white)) legend(cols(1)) subt("B: Within firm") name(figR8b) 
graph save figR8b,replace
grc1leg figR8a figR8b, graphr(c(white)) legendfrom(figR8a)
graph save results/figR8.gph,replace
graph export results/figR8.eps,replace
graph export results/figR8.png,replace
*/


************************************************************
*** Sorting excluding engineers and computer specialists ***
************************************************************

* Dropping engineers and computer scientists
foreach x in ftg {
	forvalues i=1986(1)2008 {
		use modified/sample`i'.dta,clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.

		* Rename non-cog
		rename n nc

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen ssyk2=group(edlevel fos_detail)

		gen engineer=0 if edyr~=. & fos~=.
		replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
		label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"
		gen ba_law=0
		replace ba_law=1 if (fos_detail==38|fos_detail==34) & edyr>=15 
		gen computer=0
		replace computer=1 if fos_detail==48 & edyr>=15
		lab var computer "Computer specialists, at least 3 years of teriary education"
		
		* Drop engeneers and computer specialists
		drop if engineer==1
		drop if computer==1
		
		* Generate count variable
		g count=1

		* Count actual number of observations at different levels
		egen N=total(count)
		lab var N "Total observations"
		bysort ftgnr: egen Nj=total(count)
		lab var Nj "Firm number of observations"
		bysort ssyk2: egen Nh=total(count)
		lab var Nh "Education group number of observations"
		bysort ftgnr ssyk2: egen Njh=total(count)
		lab var Njh "Firm-by-education group number of observations"
		
		* Keep relevant sample
		keep if sample_3035_10_`x'==1

		* Count observations for sample
		bysort ftgnr: egen nj=total(count)
		lab var nj "Firm number of observations"
		drop if nj<2
		egen n2=total(count)
		lab var n2 "Number of sample observations"
		bysort ssyk2: egen nh=total(count)
		lab var nh "Education group number of sample observations"
		bysort ftgnr ssyk2: egen njh=total(count)
		lab var njh "Firm-by-education group number of sample observations"
		
		bysort ftgnr: egen cj=mean(c)
		bysort ftgnr: egen ncj=mean(nc)
		lab var cj "Firm mean cognitive"
		lab var ncj "Firm mean non-cognitive"
		
		* Sample mean skilld
		egen cmean=mean(c)
		egen ncmean=mean(nc)
		
		*** Between firm skill variance and its major components (sample size adjusted)

		* Sample size adjustment parameter (between firm)
		gen theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
		
		* Components for between firm sample size adjustments
		bysort ftgnr: egen wfc=sum((c-cj)^2)
		bysort ftgnr: egen wfnc=sum((nc-ncj)^2)
		
		* Between firm variance: not adjusted
		egen bfc=sum((cj-cmean)^2)
		replace bfc=bfc/n2
		egen bfnc=sum((ncj-ncmean)^2)
		replace bfn=bfn/n2
		
		* Between firm skill variance: adjusted
		egen bfc_adj=sum((cj-cmean)^2 - (theta_bf*wfc))
		replace bfc_adj=bfc_adj/n2
		egen bfnc_adj=sum((ncj-ncmean)^2 - (theta_bf*wfnc))
		replace bfnc_adj=bfnc_adj/n2
		
		* Save these
		keep year bf* n2 nj* N*
		duplicates drop year, force
		save temp/bf_edudecomp_3035_excl_eng_comp_`i'.dta, replace
	
	}
}

* Append into one file
use temp/bf_edudecomp_3035_excl_eng_comp_1986.dta, clear
forvalues i=1987(1)2008 {
	append using temp/bf_edudecomp_3035_excl_eng_comp_`i'
	}
* Insert labels
keep year bfc_adj  bfnc_adj
lab var bfc_adj "Between firm total"
lab var bfnc_adj "Between firm total"
rename bfc_adj bfc_adj_excl_eng_comp 
rename bfnc_adj bfnc_adj_excl_eng_comp 

save modified/bf_edudecomp_3035_excl_eng_comp.dta, replace

* Dropping engineers only

foreach x in ftg {
	forvalues i=1986(1)2008 {
		use modified/sample`i'.dta,clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.

		* Rename non-cog
		rename n nc

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen ssyk2=group(edlevel fos_detail)

		gen engineer=0 if edyr~=. & fos~=.
		replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
		label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"
		gen ba_law=0
		replace ba_law=1 if (fos_detail==38|fos_detail==34) & edyr>=15 
		gen computer=0
		replace computer=1 if fos_detail==48 & edyr>=15
		lab var computer "Computer specialists, at least 3 years of teriary education"
		
		* Drop engeneers and computer specialists
		drop if engineer==1
		*drop if computer==1
		
		* Generate count variable
		g count=1

		* Count actual number of observations at different levels
		egen N=total(count)
		lab var N "Total observations"
		bysort ftgnr: egen Nj=total(count)
		lab var Nj "Firm number of observations"
		bysort ssyk2: egen Nh=total(count)
		lab var Nh "Education group number of observations"
		bysort ftgnr ssyk2: egen Njh=total(count)
		lab var Njh "Firm-by-education group number of observations"
		
		* Keep relevant sample
		keep if sample_3035_10_`x'==1

		* Count observations for sample
		bysort ftgnr: egen nj=total(count)
		lab var nj "Firm number of observations"
		drop if nj<2
		egen n2=total(count)
		lab var n2 "Number of sample observations"
		bysort ssyk2: egen nh=total(count)
		lab var nh "Education group number of sample observations"
		bysort ftgnr ssyk2: egen njh=total(count)
		lab var njh "Firm-by-education group number of sample observations"
		
		bysort ftgnr: egen cj=mean(c)
		bysort ftgnr: egen ncj=mean(nc)
		lab var cj "Firm mean cognitive"
		lab var ncj "Firm mean non-cognitive"

		* Sample mean skilld
		egen cmean=mean(c)
		egen ncmean=mean(nc)
		
		*** Between firm skill variance and its major components (sample size adjusted)

		* Sample size adjustment parameter (between firm)
		gen theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
		
		* Components for between firm sample size adjustments
		bysort ftgnr: egen wfc=sum((c-cj)^2)
		bysort ftgnr: egen wfnc=sum((nc-ncj)^2)
		
		* Between firm variance: not adjusted
		egen bfc=sum((cj-cmean)^2)
		replace bfc=bfc/n2
		egen bfnc=sum((ncj-ncmean)^2)
		replace bfn=bfn/n2
		
		* Between firm skill variance: adjusted
		egen bfc_adj=sum((cj-cmean)^2 - (theta_bf*wfc))
		replace bfc_adj=bfc_adj/n2
		egen bfnc_adj=sum((ncj-ncmean)^2 - (theta_bf*wfnc))
		replace bfnc_adj=bfnc_adj/n2
		
		* Save these
		keep year bf* n2 nj* N*
		duplicates drop year, force
		save temp/bf_edudecomp_3035_excl_eng_`i'.dta, replace
	
	}
}

* Append into one file
use temp/bf_edudecomp_3035_excl_eng_1986.dta, clear
forvalues i=1987(1)2008 {
	append using temp/bf_edudecomp_3035_excl_eng_`i'
	}
* Insert labels
keep year bfc_adj  bfnc_adj
lab var bfc_adj "Between firm total"
lab var bfnc_adj "Between firm total"
rename bfc_adj bfc_adj_excl_eng 
rename bfnc_adj bfnc_adj_excl_eng 

save modified/bf_edudecomp_3035_excl_eng.dta, replace

* Dropping computer specialists only

foreach x in ftg {
	forvalues i=1986(1)2008 {
		use modified/sample`i'.dta,clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.

		* Rename non-cog
		rename n nc

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen ssyk2=group(edlevel fos_detail)

		gen engineer=0 if edyr~=. & fos~=.
		replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
		label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"
		gen ba_law=0
		replace ba_law=1 if (fos_detail==38|fos_detail==34) & edyr>=15 
		gen computer=0
		replace computer=1 if fos_detail==48 & edyr>=15
		lab var computer "Computer specialists, at least 3 years of teriary education"
		
		* Drop engeneers and computer specialists
		*drop if engineer==1
		drop if computer==1
		
		* Generate count variable
		g count=1

		* Count actual number of observations at different levels
		egen N=total(count)
		lab var N "Total observations"
		bysort ftgnr: egen Nj=total(count)
		lab var Nj "Firm number of observations"
		bysort ssyk2: egen Nh=total(count)
		lab var Nh "Education group number of observations"
		bysort ftgnr ssyk2: egen Njh=total(count)
		lab var Njh "Firm-by-education group number of observations"
		
		* Keep relevant sample
		keep if sample_3035_10_`x'==1

		* Count observations for sample
		bysort ftgnr: egen nj=total(count)
		lab var nj "Firm number of observations"
		drop if nj<2
		egen n2=total(count)
		lab var n2 "Number of sample observations"
		bysort ssyk2: egen nh=total(count)
		lab var nh "Education group number of sample observations"
		bysort ftgnr ssyk2: egen njh=total(count)
		lab var njh "Firm-by-education group number of sample observations"
		
		bysort ftgnr: egen cj=mean(c)
		bysort ftgnr: egen ncj=mean(nc)
		lab var cj "Firm mean cognitive"
		lab var ncj "Firm mean non-cognitive"

		* Sample mean skilld
		egen cmean=mean(c)
		egen ncmean=mean(nc)
		
		*** Between firm skill variance and its major components (sample size adjusted)

		* Sample size adjustment parameter (between firm)
		gen theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
		
		* Components for between firm sample size adjustments
		bysort ftgnr: egen wfc=sum((c-cj)^2)
		bysort ftgnr: egen wfnc=sum((nc-ncj)^2)
		
		* Between firm variance: not adjusted
		egen bfc=sum((cj-cmean)^2)
		replace bfc=bfc/n2
		egen bfnc=sum((ncj-ncmean)^2)
		replace bfn=bfn/n2
		
		* Between firm skill variance: adjusted
		egen bfc_adj=sum((cj-cmean)^2 - (theta_bf*wfc))
		replace bfc_adj=bfc_adj/n2
		egen bfnc_adj=sum((ncj-ncmean)^2 - (theta_bf*wfnc))
		replace bfnc_adj=bfnc_adj/n2
		
		* Save these
		keep year bf* n2 nj* N*
		duplicates drop year, force
		save temp/bf_edudecomp_3035_excl_comp_`i'.dta, replace
	
	}
}

* Append into one file
use temp/bf_edudecomp_3035_excl_comp_1986.dta, clear
forvalues i=1987(1)2008 {
	append using temp/bf_edudecomp_3035_excl_comp_`i'
	}
* Insert labels
keep year bfc_adj bfnc_adj
lab var bfc_adj "Between firm total"
lab var bfnc_adj "Between firm total"
rename bfc_adj bfc_adj_excl_comp 
rename bfnc_adj bfnc_adj_excl_comp 

save modified/bf_edudecomp_3035_excl_comp.dta, replace

* Not dropping engeneers and computer specialists

foreach x in ftg {
	forvalues i=1986(1)2008 {
		use modified/sample`i'.dta,clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.

		* Rename non-cog
		rename n nc

		* Generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen ssyk2=group(edlevel fos_detail)

		gen engineer=0 if edyr~=. & fos~=.
		replace engineer=1 if edyr>=16 & (fos_detail==52 | fos_detail==54 | fos_detail==58)
		label var engineer "At least 4 years of tertiary education. Only 'engeneering' tracks"
		gen ba_law=0
		replace ba_law=1 if (fos_detail==38|fos_detail==34) & edyr>=15 
		gen computer=0
		replace computer=1 if fos_detail==48 & edyr>=15
		lab var computer "Computer specialists, at least 3 years of teriary education"
		
		* Drop engeneers and computer specialists
		*drop if engineer==1
		*drop if computer==1
		
		* Generate count variable
		g count=1

		* Count actual number of observations at different levels
		egen N=total(count)
		lab var N "Total observations"
		bysort ftgnr: egen Nj=total(count)
		lab var Nj "Firm number of observations"
		bysort ssyk2: egen Nh=total(count)
		lab var Nh "Education group number of observations"
		bysort ftgnr ssyk2: egen Njh=total(count)
		lab var Njh "Firm-by-education group number of observations"
		
		* Keep relevant sample
		keep if sample_3035_10_`x'==1

		* Count observations for sample
		bysort ftgnr: egen nj=total(count)
		lab var nj "Firm number of observations"
		drop if nj<2
		egen n2=total(count)
		lab var n2 "Number of sample observations"
		bysort ssyk2: egen nh=total(count)
		lab var nh "Education group number of sample observations"
		bysort ftgnr ssyk2: egen njh=total(count)
		lab var njh "Firm-by-education group number of sample observations"
		
		bysort ftgnr: egen cj=mean(c)
		bysort ftgnr: egen ncj=mean(nc)
		lab var cj "Firm mean cognitive"
		lab var ncj "Firm mean non-cognitive"

		* Sample mean skilld
		egen cmean=mean(c)
		egen ncmean=mean(nc)
		
		*** Between firm skill variance and its major components (sample size adjusted)

		* Sample size adjustment parameter (between firm)
		gen theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
		
		* Components for between firm sample size adjustments
		bysort ftgnr: egen wfc=sum((c-cj)^2)
		bysort ftgnr: egen wfnc=sum((nc-ncj)^2)
		
		* Between firm variance: not adjusted
		egen bfc=sum((cj-cmean)^2)
		replace bfc=bfc/n2
		egen bfnc=sum((ncj-ncmean)^2)
		replace bfn=bfn/n2
		
		* Between firm skill variance: adjusted
		egen bfc_adj=sum((cj-cmean)^2 - (theta_bf*wfc))
		replace bfc_adj=bfc_adj/n2
		egen bfnc_adj=sum((ncj-ncmean)^2 - (theta_bf*wfnc))
		replace bfnc_adj=bfnc_adj/n2
		
		* Save these
		keep year bf* n2 nj* N*
		duplicates drop year, force
		save temp/bf_edudecomp_3035_all_`i'.dta, replace
	
	}
}

* Append into one file

use temp/bf_edudecomp_3035_all_1986.dta, clear
forvalues i=1987(1)2008 {
	append using temp/bf_edudecomp_3035_all_`i'
	}
	
* Insert labels
keep year bfc_adj bfnc_adj
lab var bfc_adj "Between firm total"
lab var bfnc_adj "Between firm total"

save modified/bf_edudecomp_3035_all.dta, replace

***************************************************************
*** Wage decompositions for all 20-64, men 20-64, men 30-35 ***
***************************************************************

* Men 24-60
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
		
				* Generate count variable
				g count=1
		
				* Actual firm employees
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if privfirm_`x'==1
				keep if ftgstorl_`x'>=10
				keep if sex=="1"
				rename lnwpred_`x' wage
				* Age group:
				keep if age>=24
				keep if age<=60
				
				* Number of firm level observations 
				bysort `x'nr: egen nj=total(count)
				* Drop if less than two obs per firm (needed for size adjustments)
				drop if nj<2
				
				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(nj-1))
				g theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
				
				* Total number of observations
				egen n2=total(count)
								
				* Mean sample wages
				egen wbar=mean(wage)
				* Mean wages by firm/plant
				bysort `x'nr: egen wj=mean(wage)
				* Wages demeaned by firm
				gen wdm=wage-wj
				
				* Total wage variance: wvar
				egen wvar=sum((wage-wbar)^2)
				replace wvar=wvar/n2
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adj1=sum(wdm^2)
				gen wvarw=adj1/nj
								
				* Within firm variance by firm, sample size adjusted: wvarw_adj 
				gen wvarw_adj=adj1*theta_wf
				
				* Between firm wage variance: wvarb
				egen wvarb=sum((wj-wbar)^2)
				replace wvarb=wvarb/n2

				* Between firm wage variance, sample size adjusted: wvarb_adj
				egen wvarb_adj=sum((wj-wbar)^2 - (theta_bf*adj1))
				replace wvarb_adj=wvarb_adj/n2
				
				* Total within firm: sum unadjusted and adjusted, divide by total number of observations
				egen wvarwtot=sum(wvarw)
				replace wvarwtot=wvarwtot/n2

				egen wvarwtot_adj=sum(wvarw_adj)
				replace wvarwtot_adj=wvarwtot_adj/n2
				
				drop wvarw wvarw_adj
				rename wvarwtot wvarw
				rename wvarwtot_adj wvarw_adj
				keep year wvar wvarw wvarw_adj wvarb wvarb_adj
				duplicates drop year, force
		save temp/wagevardecomposition_2460_`x'_`j'_`i'.dta,replace
		}
	}
}

* Append into one file
use temp/wagevardecomposition_2460_ftg_10_1986.dta
	forvalues i=1987(1)2008 {
	append using temp/wagevardecomposition_2460_ftg_10_`i'.dta
}

rename wvar wvar2460 
rename wvarw wvarw2460
rename wvarw_adj wvarw_adj2460
rename wvarb wvarb2460 
rename wvarb_adj wvarb_adj2460
lab var wvar2460 "Wage variance (24-60)"
lab var wvarb2460 "Between firm (24-60)"
lab var wvarb_adj2460 "Between firm (24-60)"
lab var wvarw2460 "Within firm (24-60)"
lab var wvarw_adj2460 "Within firm (24-60)"

save modified/wagevardecomposition_2460_ftg_10.dta, replace

**** All 20-64
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.
		
				* Generate count variable
				g count=1
		
				* Actual firm employees
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if privfirm_`x'==1
				keep if ftgstorl_`x'>=10
				rename lnwpred_`x' wage
				* Age group:
				
				* Number of firm level observations 
				bysort `x'nr: egen nj=total(count)
				* Drop if less than two obs per firm (needed for size adjustments)
				drop if nj<2
				
				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(nj-1))
				g theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
				
				* Total number of observations
				egen n2=total(count)
								
				* Mean sample wages
				egen wbar=mean(wage)
				* Mean wages by firm/plant
				bysort `x'nr: egen wj=mean(wage)
				* Wages demeaned by firm
				gen wdm=wage-wj
				
				* Total wage variance: wvar
				egen wvar=sum((wage-wbar)^2)
				replace wvar=wvar/n2
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adj1=sum(wdm^2)
				gen wvarw=adj1/nj
								
				* Within firm variance by firm, sample size adjusted: wvarw_adj 
				gen wvarw_adj=adj1*theta_wf
				
				* Between firm wage variance: wvarb
				egen wvarb=sum((wj-wbar)^2)
				replace wvarb=wvarb/n2

				* Between firm wage variance, sample size adjusted: wvarb_adj
				egen wvarb_adj=sum((wj-wbar)^2 - (theta_bf*adj1))
				replace wvarb_adj=wvarb_adj/n2
				
				* Total within firm: sum unadjusted and adjusted, divide by total number of observations
				egen wvarwtot=sum(wvarw)
				replace wvarwtot=wvarwtot/n2

				egen wvarwtot_adj=sum(wvarw_adj)
				replace wvarwtot_adj=wvarwtot_adj/n2
				
				drop wvarw wvarw_adj
				rename wvarwtot wvarw
				rename wvarwtot_adj wvarw_adj
				keep year wvar wvarw wvarw_adj wvarb wvarb_adj
				duplicates drop year, force
		save temp/wagevardecomposition_all_`x'_`j'_`i'.dta,replace
		}
	}
}

* Append into one file
use temp/wagevardecomposition_all_ftg_10_1986.dta
	forvalues i=1987(1)2008 {
	append using temp/wagevardecomposition_all_ftg_10_`i'.dta
}

rename wvar wvarall 
rename wvarw wvarwall
rename wvarw_adj wvarw_adjall
rename wvarb wvarball 
rename wvarb_adj wvarb_adjall
lab var wvarall "Wage variance (all 20-64)"
lab var wvarball "Between firm (all 20-64)"
lab var wvarb_adjall "Between firm (all 20-64)"
lab var wvarwall "Within firm (all 20-64)"
lab var wvarw_adjall "Within firm (all 20-64)"

save modified/wagevardecomposition_all_ftg_10.dta, replace

******************************************************
*** Between-firm wage decomposition, excluding ICT ***
******************************************************

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.

				* Drop IT (72) and telecom (32) 
				drop if `x'sni2==72
				drop if `x'sni2==32
		
				* Generate count variable
				g count=1
		
				* Actual firm employees
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if sample_3035_`j'_`x'==1
				keep if lnwpred_`x'~=.
				rename lnwpred_`x' wage

				* Number of firm level observations 
				bysort `x'nr: egen nj=total(count)
				* Drop if less than two obs per firm (needed for size adjustments)
				drop if nj<2
				
				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(nj-1))
				g theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
				
				* Total number of observations
				egen n2=total(count)
								
				* Mean sample wages
				egen wbar=mean(wage)
				* Mean wages by firm/plant
				bysort `x'nr: egen wj=mean(wage)
				* Wages demeaned by firm
				gen wdm=wage-wj
				
				* Total wage variance: wvar
				egen wvar=sum((wage-wbar)^2)
				replace wvar=wvar/n2
				
				* Within firm wage variance by firm: wvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adj1=sum(wdm^2)
				gen wvarw=adj1/nj
								
				* Within firm variance by firm, sample size adjusted: wvarw_adj 
				gen wvarw_adj=adj1*theta_wf
				
				* Between firm wage variance: wvarb
				egen wvarb=sum((wj-wbar)^2)
				replace wvarb=wvarb/n2

				* Between firm wage variance, sample size adjusted: wvarb_adj
				egen wvarb_adj=sum((wj-wbar)^2 - (theta_bf*adj1))
				replace wvarb_adj=wvarb_adj/n2
				
				* Total within firm: sum unadjusted and adjusted, divide by total number of observations
				egen wvarwtot=sum(wvarw)
				replace wvarwtot=wvarwtot/n2

				egen wvarwtot_adj=sum(wvarw_adj)
				replace wvarwtot_adj=wvarwtot_adj/n2
				
				drop wvarw wvarw_adj
				rename wvarwtot wvarw
				rename wvarwtot_adj wvarw_adj
				keep year wvar wvarw wvarw_adj wvarb wvarb_adj
				duplicates drop year, force
		save temp/wagevardecomposition_ex7232_`x'_`j'_`i'.dta,replace
		}
	}
}

* Append into one file
use temp/wagevardecomposition_ex7232_ftg_10_1986.dta
	forvalues i=1987(1)2008 {
	append using temp/wagevardecomposition_ex7232_ftg_10_`i'.dta
}

rename wvar wvar_exICT
rename wvarb wvarb_exICT
rename wvarw wvarw_exICT
rename wvarb_adj wvarb_adj_exICT
rename wvarw_adj wvarw_adj_exICT

lab var wvar_exICT "Wage variance (excl ICT)"
lab var wvarb_exICT "Between firm (excl ICT)"
lab var wvarb_adj_exICT "Between firm (excl ICT)"
lab var wvarw_exICT "Within firm (excl ICT)"
lab var wvarw_adj_exICT "Within firm (excl ICT)"

save modified/wagevardecomposition_ex7232_ftg_10.dta, replace

*****************************************************************************
*** Factor loadings of cognitive and non-congnitive on AKM person effects ***
*****************************************************************************

* Men 30-35
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1989(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'
				
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
				
		* Keep relevant sample
		keep if sample_3035_`j'_`x'==1
		keep if p~=.
		
		reg p c n
		gen betac=_b[c]
		gen betan=_b[n]
		gen r2=e(r2)
		sum p
		gen pmean=r(mean)
		gen psd=r(sd)
		gen pobs=r(N)
		sum c
		gen cmean=r(mean)
		gen csd=r(sd)
		gen cobs=r(N)
		sum n
		gen nmean=r(mean)
		gen nsd=r(sd)

		keep year betac betan r2 pmean psd cmean csd nmean nsd pobs cobs
		duplicates drop year, force
		save temp/akm_factor_loadings_3035_`i'.dta, replace
}
}
}

use temp/akm_factor_loadings_3035_1989.dta, clear
	forvalues i=1990(1)2005 {
	append using temp/akm_factor_loadings_3035_`i'.dta
	}
lab var betac "Cognitive (30-35)"
lab var betan "Non-cognitive (30-35)"
lab var r2 "R-squared (30-35)"

rename betac betac_3035
rename betan betan_3035
rename r2 r2_3035

save modified/akm_factor_loadings_3035, replace

*** Alternative. Different samples: 1) 1995-2005: ages 30-44 2) 2000-2005: ages 30-49

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1995(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'
				
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
				
		* Keep relevant sample
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10 & ftgstorl_`x'~=.
		keep if p~=.
		keep if c~=.
		keep if n~=.
		keep if age<=44
		keep if age>=30
		
		reg p c n
		gen betac=_b[c]
		gen betan=_b[n]
		gen r2=e(r2)
		sum p
		gen pmean=r(mean)
		gen psd=r(sd)
		gen pobs=r(N)
		sum c
		gen cmean=r(mean)
		gen csd=r(sd)
		gen cobs=r(N)
		sum n
		gen nmean=r(mean)
		gen nsd=r(sd)

		keep year betac betan r2 pmean psd cmean csd nmean nsd pobs cobs
		rename betac betac_3044 
		rename betan betan_3044 
		rename r2 r2_3044 
		rename pmean pmean_3044 
		rename psd psd_3044 
		rename cmean cmean_3044
		rename csd csd_3044 
		rename nmean nmean_3044 
		rename nsd nsd_3044 
		rename pobs pobs_3044 
		rename cobs cobs_3044
		
		duplicates drop year, force
		save temp/akm_factor_loadings_3044_`i'.dta, replace
}
}
}

use temp/akm_factor_loadings_3044_1995.dta, clear
	forvalues i=1996(1)2005 {
	append using temp/akm_factor_loadings_3044_`i'.dta
	}
lab var betac_3044 "Cognitive (30-44)"
lab var betan_3044 "Non-cognitive (30-44)"
lab var r2_3044 "R-squared (30-44)"
save modified/akm_factor_loadings_3044, replace

*** Alternative 2000-2005: ages 30-49

foreach x in ftg {
	foreach j in 10 {
		forvalues i=2000(1)2005 {
		use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x'  privfirm_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		sort lopnr
		merge 1:1 lopnr using modified/akm_rolling_4_2.dta
		drop if _merge==2
		drop _merge
		
		gen p=.
		replace p=p2z`i'
				
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
				
		* Keep relevant sample
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10 & ftgstorl_`x'~=.
		keep if p~=.
		keep if c~=.
		keep if n~=.
		keep if age<=49
		keep if age>=30
		
		reg p c n
		gen betac=_b[c]
		gen betan=_b[n]
		gen r2=e(r2)
		sum p
		gen pmean=r(mean)
		gen psd=r(sd)
		gen pobs=r(N)
		sum c
		gen cmean=r(mean)
		gen csd=r(sd)
		gen cobs=r(N)
		sum n
		gen nmean=r(mean)
		gen nsd=r(sd)

		keep year betac betan r2 pmean psd cmean csd nmean nsd pobs cobs
		rename betac betac_3049 
		rename betan betan_3049 
		rename r2 r2_3049 
		rename pmean pmean_3049 
		rename psd psd_3049 
		rename cmean cmean_3049
		rename csd csd_3049 
		rename nmean nmean_3049 
		rename nsd nsd_3049 
		rename pobs pobs_3049 
		rename cobs cobs_3049
		
		duplicates drop year, force
		save temp/akm_factor_loadings_3049_`i'.dta, replace
}
}
}

use temp/akm_factor_loadings_3049_2000.dta, clear
	forvalues i=2001(1)2005 {
	append using temp/akm_factor_loadings_3049_`i'.dta
	}
lab var betac_3049 "Cognitive (30-49)"
lab var betan_3049 "Non-cognitive (30-49)"
lab var r2_3049 "R-squared (30-49)"
save modified/akm_factor_loadings_3049, replace


END

*************************************************
*** Various additional file preparation below ***
*************************************************

*************************************
*** Updated uniform distributions ***
*** For Table1                    ***
*************************************

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1997(11)2008 {
		use lopnr fos fos_detail edyr zedyr sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear
		merge 1:1 lopnr using temp/alternative_skills,keepus(n_uni c_uni)
		drop if _merge==2
		drop _merge
		rename c_uni c
		rename n_uni n
		
		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample
		keep if sample_3035_`j'_`x'==1
		
		*This part generate occupation proxy by combining field of study and level of education
		gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
		replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
		replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
		replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
		replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
		lab def edlevellab 1 "Compulsory schooling or less"
		lab def edlevellab 2 "2-year secondary",add 
		lab def edlevellab 3 "3-year secondary",add 
		lab def edlevellab 4 "Some tertiary",add 
		lab def edlevellab 5 "At least 3-year tertiary",add 
		lab val edlevel edlevellab
		egen yrke=group(edlevel fos_detail)

		***Actual skill means
		*industry
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 

		*firm/plant
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 

		*firm/plant yrke
		bysort `x'nr yrke: egen chj=mean(c) 
		bysort `x'nr yrke: egen nhj=mean(n) 

		*yrke
		bysort yrke: egen ch=mean(c) 
		bysort yrke: egen nh=mean(n) 

		*sample
		egen cbar=mean(c)
		egen nbar=mean(n)

		*Observed samples and sizes
		* rename ftgstorl_`x' Nj
		bysort `x'nr yrke: egen N2hj=total(count) 
		bysort yrke: egen N2h=total(count) 
		bysort `x'nr: egen N2j=total(count) 
		egen N2=total(count) 

		***Predicted skills
		*individual
		areg c, absorb(yrke)
		predict cijtilde if e(sample),xbd
		predict cijres if e(sample), resid
		areg n, absorb(yrke)
		predict nijtilde if e(sample),xbd
		predict nijres if e(sample), resid

		bysort `x'nr: egen cjres=mean(cijres)
		bysort `x'nr: egen njres=mean(nijres)

		g cjtilde=cj-cjres
		g njtilde=nj-njres

		***Components for (corrected and uncorrected) variances (to be collapsed)

		*between occupation within firm/plant  
		g wt_c=(cijtilde-cjtilde)^2
		g wt_n=(nijtilde-njtilde)^2

		*within occupation within plant 
		g wa_c=((c-cijtilde)-(cj-cjtilde))^2
		g wa_n=((n-nijtilde)-(nj-njtilde))^2

		*within firm total variance (consistancy check)
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2

		*within firm covariance (between and witin occ) 
		g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
		g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))

		*within firm total variance (to check results should after collapsed be equal to ws_X )
		g wtot_c=wt_c+wa_c+2*wat_c
		g wtot_n=wt_n+wa_n+2*wat_n

		* between occupation between firm
		g bt_c=(cjtilde-cbar)^2
		g bt_n=(njtilde-nbar)^2

		*within occupation between firm 
		g ba_c=(cj-cjtilde)^2
		g ba_n=(nj-njtilde)^2

		*between firm total variance (consistancy check)
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2

		*between firm covariance (within andd between occ)
		g bat_c=(cjtilde-cbar)*(cj-cjtilde)
		g bat_n=(njtilde-nbar)*(nj-njtilde)

		*between firm total variance 
		g btot_c=bt_c+ba_c+2*bat_c
		g btot_n=bt_n+ba_n+2*bat_n

		*total between occupation
		g tt_c=(cijtilde-cbar)^2 
		g tt_n=(nijtilde-nbar)^2 

		*total within occupation
		g ta_c=(c-cijtilde)^2
		g ta_n=(n-nijtilde)^2

		*total variance (consistancy check)
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2

		*** B.Collapse to firm/plant level
		collapse (sum) w* t* cijtilde nijtilde cijres nijres c n corr_bi* (mean) b* ftgstorl_`x' Nj N2j N2 cj nj cjtilde njtilde ck nk cbar nbar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j

		* between occ within firm/plant corrected
		g corr_wt_c=wt_c*thetaj_w*N2j
		g corr_wt_n=wt_n*thetaj_w*N2j

		*within occ within firm/plant corrected
		g corr_wa_c=wa_c*thetaj_w*N2j
		g corr_wa_n=wa_n*thetaj_w*N2j

		*within firm/plant covariance (between and within occ) corrected
		g corr_wat_c=wat_c*thetaj_w*N2j
		g corr_wat_n=wat_n*thetaj_w*N2j

		*within firm/plant total variance corrected
		g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
		g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)

		*between occ between firm/plant corrected
		g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
		g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)

		*within occ between firm/plant corrected
		g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
		g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)

		*between firm/plant covariance (between and within occ)  corrected
		g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
		g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)

		*between firm/plant total variance corrected
		g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
		g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*** Components for uncorrected variances
		* between occupation between firm/plant
		replace bt_c=bt_c*N2j
		replace bt_n=bt_n*N2j

		* within occupation between firm/plant
		replace ba_c=ba_c*N2j
		replace ba_n=ba_n*N2j

		*between firm/plant covariance (between and within occupation)
		replace bat_c=bat_c*N2j
		replace bat_n=bat_n*N2j

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j

		*between firm/plant total variance
		replace btot_c=btot_c*N2j
		replace btot_n=btot_n*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)

		*** 4. Overall collapse
		collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

		*final uncorrected variances 

		*between occupation within firm/plant
		replace wt_c=wt_c*1/N2
		replace wt_n=wt_n*1/N2

		*within occupation within firm/plant
		replace wa_c=wa_c*1/N2
		replace wa_n=wa_n*1/N2

		*within firm/plant covariance (between and within occ)  
		replace wat_c=wat_c*2/N2
		replace wat_n=wat_n*2/N2

		*within firm/plant total variance
		replace wtot_c=wtot_c*1/N2
		replace wtot_n=wtot_n*1/N2

		*within firm/plant total variance (consistancy)
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2

		*between occupation between firm
		replace bt_c=bt_c*1/N2
		replace bt_n=bt_n*1/N2

		*within occupation between firm/plant 
		replace ba_c=ba_c*1/N2
		replace ba_n=ba_n*1/N2

		*between firm/plant covariance (between and within occ)  
		replace bat_c=bat_c*2/N2
		replace bat_n=bat_n*2/N2

		*between firm/plant total variance (consistancy)
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2

		*between firm/plant total variance
		replace btot_c=btot_c*1/N2
		replace btot_n=btot_n*1/N2

		*total between occ
		replace tt_c=tt_c*1/N2
		replace tt_n=tt_n*1/N2

		*total within occ
		replace ta_c=ta_c*1/N2
		replace ta_n=ta_n*1/N2

		*total variance (consistancy)
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*between occ within firm corrected
		replace corr_wt_c=corr_wt_c*1/N2
		replace corr_wt_n=corr_wt_n*1/N2

		*within occ within firm corrected
		replace corr_wa_c=corr_wa_c*1/N2
		replace corr_wa_n=corr_wa_n*1/N2

		*within firm covariance (between and within occ)  
		replace corr_wat_c=corr_wat_c*2/N2
		replace corr_wat_n=corr_wat_n*2/N2

		*within firm/plant total variance corrected
		replace corr_wtot_c=corr_wtot_c*1/N2
		replace corr_wtot_n=corr_wtot_n*1/N2

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2

		*between occupation between firm/plant
		replace corr_bt_c=corr_bt_c*1/N2
		replace corr_bt_n=corr_bt_n*1/N2

		*within occupation between firm/plant
		replace corr_ba_c=corr_ba_c*1/N2
		replace corr_ba_n=corr_ba_n*1/N2

		*between firm/plant covariance (between and within occ)  
		replace corr_bat_c=corr_bat_c*2/N2
		replace corr_bat_n=corr_bat_n*2/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2

		*between firm/plant total variance
		replace corr_btot_c=corr_btot_c*1/N2
		replace corr_btot_n=corr_btot_n*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/uniform_vardecomp_`i',replace
		}
	}
}

use temp/uniform_vardecomp_1986, clear
append using temp/uniform_vardecomp_1997
append using temp/uniform_vardecomp_2008

save modified/uniform_vardecomp, replace

****************************************************
* Getting firms that are actually in the sample ****
****************************************************
clear
forvalues i=1985(1)2009{
use modified/sample`i',clear
keep ftgnr year in_sample_3035_50_ftg in_sample_3045_50_ftg in_sample_3035_50f_ftg in_sample_3035_50_ast in_sample_3045_50_ast in_sample_3035_50f_ast ftgstorl_ast  ftgstorl_ftg
collapse in_sample_3035_50_ftg in_sample_3045_50_ftg in_sample_3035_50f_ftg in_sample_3035_50_ast in_sample_3045_50_ast in_sample_3035_50f_ast ftgstorl_ast ftgstorl_ftg, by(ftgnr year)
replace in_sample_3035_50_ast=1 if in_sample_3035_50_ast>0 & in_sample_3035_50_ast~=.
replace in_sample_3045_50_ast=1 if in_sample_3045_50_ast>0 & in_sample_3045_50_ast~=.
replace in_sample_3035_50f_ast=1 if in_sample_3035_50f_ast>0 & in_sample_3035_50f_ast~=.
sort ftgnr year
save temp/prodsample`i',replace
}

clear
use temp/prodsample1985
forvalues i=1986(1)2009{
append using temp/prodsample`i'
}
sort ftgnr year
save temp/prodsample,replace
	

***************************************	
*** Files for sorting analysis  *******
***************************************

forvalues i=1986(1)2008{
use lopnr fos fos_detail edyr zedyr c n sex sample_3035_50 sample_3035_50f ftgsni* ftgstorl age ftgnr year using modified/sample`i', clear

* Main sample (if looping over samples, start here)
keep if sample_3035_50==1

g count=1

*This part generate occupation proxy by combining field of study and level of education
gen edlevel=1 if (edyr==8 | edyr==9) &  edyr~=. & fos~=.
replace edlevel=2 if (edyr==10 | edyr==11)  &  edyr~=. & fos~=.
replace edlevel=3 if edyr==12  &  edyr~=. & fos~=. 
replace edlevel=4 if (edyr==13 | edyr==14)  &  edyr~=. & fos~=.
replace edlevel=5 if edyr>=15  &  edyr~=. & fos~=.
lab def edlevellab 1 "Compulsory schooling or less"
lab def edlevellab 2 "2-year secondary",add 
lab def edlevellab 3 "3-year secondary",add 
lab def edlevellab 4 "Some tertiary",add 
lab def edlevellab 5 "At least 3-year tertiary",add 
lab val edlevel edlevellab
egen yrke=group(edlevel fos_detail)

***Actual skill means
*industry
bysort ftgsni2: egen ck=mean(c) 
bysort ftgsni2: egen nk=mean(n) 
bysort ftgsni2: egen ek=mean(edyr)
bysort ftgsni2: egen zek=mean(zedyr)

*firm
bysort ftgnr: egen cj=mean(c) 
bysort ftgnr: egen nj=mean(n) 
bysort ftgnr: egen ej=mean(edyr)
bysort ftgnr: egen zej=mean(zedyr) 

*firm yrke
bysort ftgnr yrke: egen chj=mean(c) 
bysort ftgnr yrke: egen nhj=mean(n) 
bysort ftgnr yrke: egen ehj=mean(edyr)
bysort ftgnr yrke: egen zehj=mean(zedyr) 

*yrke
bysort yrke: egen ch=mean(c) 
bysort yrke: egen nh=mean(n) 
bysort yrke: egen eh=mean(edyr) 
bysort yrke: egen zeh=mean(zedyr) 

*sample
egen cbar=mean(c)
egen nbar=mean(n)
egen ebar=mean(edyr)
egen zebar=mean(zedyr)

*Observed samples and sizes
rename ftgstorl Nj
bysort ftgnr yrke: egen N2hj=total(count) 
bysort yrke: egen N2h=total(count) 
bysort ftgnr: egen N2j=total(count) 
egen N2=total(count) 

***Predicted skills
*individual
areg c, absorb(yrke)
predict cijtilde if e(sample),xbd
predict cijres if e(sample), resid
areg n, absorb(yrke)
predict nijtilde if e(sample),xbd
predict nijres if e(sample), resid
areg edyr, absorb(yrke)
predict eijtilde if e(sample), xbd
predict eijres if e(sample), resid
areg zedyr, absorb(yrke)
predict zeijtilde if e(sample), xbd
predict zeijres if e(sample), resid

bysort ftgnr: egen cjres=mean(cijres)
bysort ftgnr: egen njres=mean(nijres)
bysort ftgnr: egen ejres=mean(eijres)
bysort ftgnr: egen zejres=mean(zeijres)

g cjtilde=cj-cjres
g njtilde=nj-njres
g ejtilde=ej-ejres
g zejtilde=zej-zejres

rename edyr e
rename zedyr ze

***Components for (corrected and uncorrected) variances (to be collapsed)

*between occupation within firm  
g wt_c=(cijtilde-cjtilde)^2
g wt_n=(nijtilde-njtilde)^2
g wt_e=(eijtilde-ejtilde)^2
g wt_ze=(zeijtilde-zejtilde)^2

*within occupation within firm 
g wa_c=((c-cijtilde)-(cj-cjtilde))^2
g wa_n=((n-nijtilde)-(nj-njtilde))^2
g wa_e=((e-eijtilde)-(ej-ejtilde))^2
g wa_ze=((ze-zeijtilde)-(zej-zejtilde))^2

*within firm total variance (consistancy check)
g ws_c=(c-cj)^2
g ws_n=(n-nj)^2
g ws_e=(e-ej)^2
g ws_ze=(ze-zej)^2

*within firm covariance (between and witin occ) 
g wat_c=(cijtilde-cjtilde)*((c-cijtilde)-(cj-cjtilde))
g wat_n=(nijtilde-njtilde)*((n-nijtilde)-(nj-njtilde))
g wat_e=(eijtilde-ejtilde)*((e-eijtilde)-(ej-ejtilde))
g wat_ze=(zeijtilde-zejtilde)*((ze-zeijtilde)-(zej-zejtilde))

*within firm total variance (to check results should after collapsed be equal to ws_X )
g wtot_c=wt_c+wa_c+2*wat_c
g wtot_n=wt_n+wa_n+2*wat_n
g wtot_e=wt_e+wa_e+2*wat_e
g wtot_ze=wt_ze+wa_ze+2*wat_ze

* between occupation between firm
g bt_c=(cjtilde-cbar)^2
g bt_n=(njtilde-nbar)^2
g bt_e=(ejtilde-ebar)^2
g bt_ze=(zejtilde-zebar)^2

*within occupation between firm 
g ba_c=(cj-cjtilde)^2
g ba_n=(nj-njtilde)^2
g ba_e=(ej-ejtilde)^2
g ba_ze=(zej-zejtilde)^2

*between firm total variance (consistancy check)
g bs_c=(cj-cbar)^2
g bs_n=(nj-nbar)^2
g bs_e=(ej-ebar)^2
g bs_ze=(zej-zebar)^2

*between firm covariance (within andd between occ)
g bat_c=(cjtilde-cbar)*(cj-cjtilde)
g bat_n=(njtilde-nbar)*(nj-njtilde)
g bat_e=(ejtilde-ebar)*(ej-ejtilde)
g bat_ze=(zejtilde-zebar)*(zej-zejtilde)

*between firm total variance 
g btot_c=bt_c+ba_c+2*bat_c
g btot_n=bt_n+ba_n+2*bat_n
g btot_e=bt_e+ba_e+2*bat_e
g btot_ze=bt_ze+ba_ze+2*bat_ze

*total between occupation
g tt_c=(cijtilde-cbar)^2 
g tt_n=(nijtilde-nbar)^2 
g tt_e=(eijtilde-ebar)^2 
g tt_ze=(zeijtilde-zebar)^2 

*total within occupation
g ta_c=(c-cijtilde)^2
g ta_n=(n-nijtilde)^2
g ta_e=(e-eijtilde)^2
g ta_ze=(ze-zeijtilde)^2

*total variance (consistancy check)
g ts_c=(c-cbar)^2
g ts_n=(n-nbar)^2
g ts_e=(e-ebar)^2
g ts_ze=(ze-zebar)^2
	
*covariance CS NCS
g wcov=(c-cj)*(n-nj)	

*component for corr_between industry (this goes into the industry matrix)
g corr_bi_c=(c-ck)^2
g corr_bi_n=(n-nk)^2
g corr_bi_e=(e-ek)^2
g corr_bi_ze=(ze-zek)^2

*** 2.Collapse to firm level
collapse (sum) w* t* cijtilde nijtilde eijtilde zeijtilde cijres nijres eijres zeijres c n e ze corr_bi* (mean) wpred=wpred lwage=lwage b* Nj N2j N2 cj nj ej zej cjtilde njtilde ck nk ek zek cbar nbar ebar zebar, by (year ftgnr ftgsni2)

*sample correction firm level
g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))

*components for corrected variances

*within firm total variance corrected 
g corr_ws_c=ws_c*thetaj_w*N2j
g corr_ws_n=ws_n*thetaj_w*N2j
g corr_ws_e=ws_e*thetaj_w*N2j
g corr_ws_ze=ws_ze*thetaj_w*N2j

* between occ within firm corrected
g corr_wt_c=wt_c*thetaj_w*N2j
g corr_wt_n=wt_n*thetaj_w*N2j
g corr_wt_e=wt_e*thetaj_w*N2j
g corr_wt_ze=wt_ze*thetaj_w*N2j

*within occ within firm corrected
g corr_wa_c=wa_c*thetaj_w*N2j
g corr_wa_n=wa_n*thetaj_w*N2j
g corr_wa_e=wa_e*thetaj_w*N2j
g corr_wa_ze=wa_ze*thetaj_w*N2j

*within firm covariance (between and within occ) corrected
g corr_wat_c=wat_c*thetaj_w*N2j
g corr_wat_n=wat_n*thetaj_w*N2j
g corr_wat_e=wat_e*thetaj_w*N2j
g corr_wat_ze=wat_ze*thetaj_w*N2j

*within firm total variance corrected
g corr_wtot_c=corr_wt_c+corr_wa_c+2*corr_wat_c
g corr_wtot_n=corr_wt_n+corr_wa_n+2*corr_wat_n
g corr_wtot_e=corr_wt_e+corr_wa_e+2*corr_wat_e
g corr_wtot_ze=corr_wt_ze+corr_wa_ze+2*corr_wat_ze

*between firm total variance corrected (consistancy check)
g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

*between occ between firm corrected
g corr_bt_c=N2j*(bt_c-thetaj_b*wt_c)
g corr_bt_n=N2j*(bt_n-thetaj_b*wt_n)
g corr_bt_e=N2j*(bt_e-thetaj_b*wt_e)
g corr_bt_ze=N2j*(bt_ze-thetaj_b*wt_ze)

*within occ between firm corrected
g corr_ba_c=N2j*(ba_c-thetaj_b*wa_c)
g corr_ba_n=N2j*(ba_n-thetaj_b*wa_n)
g corr_ba_e=N2j*(ba_e-thetaj_b*wa_e)
g corr_ba_ze=N2j*(ba_ze-thetaj_b*wa_ze)

*between firm covariance (between and within occ)  corrected
g corr_bat_c=N2j*(bat_c-thetaj_b*wat_c)
g corr_bat_n=N2j*(bat_n-thetaj_b*wat_n)
g corr_bat_e=N2j*(bat_e-thetaj_b*wat_e)
g corr_bat_ze=N2j*(bat_ze-thetaj_b*wat_ze)

*between firm total variance corrected
g corr_btot_c=corr_bt_c+corr_ba_c+2*corr_bat_c
g corr_btot_n=corr_bt_n+corr_ba_n+2*corr_bat_n
g corr_btot_e=corr_bt_e+corr_ba_e+2*corr_bat_e
g corr_btot_ze=corr_bt_ze+corr_ba_ze+2*corr_bat_ze

*covariance CS NCS corrected
g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
g corr_wcov=N2j*thetaj_w*wcov

*** Firmlevel data set for use in regressions. Note: this should only be done for main sample if looping.
*if `j'==main {
preserve
keep corr* b* w* t* cjtilde njtilde cj nj ej zej cbar nbar ebar zebar N2j N2 ftgnr year ftgsni2
save temp/decomp_occupation_matrix_firm_v2_`i',replace
restore
*}

*** Components for uncorrected variances

* between occupation between firm
replace bt_c=bt_c*N2j
replace bt_n=bt_n*N2j
replace bt_e=bt_e*N2j
replace bt_ze=bt_ze*N2j

* within occupation between firm
replace ba_c=ba_c*N2j
replace ba_n=ba_n*N2j
replace ba_e=ba_e*N2j
replace ba_ze=ba_ze*N2j

*between firm covariance (between and within occupation)
replace bat_c=bat_c*N2j
replace bat_n=bat_n*N2j
replace bat_e=bat_e*N2j
replace bat_ze=bat_ze*N2j

*between firm total variance (consistancy check of total variance demcomp)
replace bs_c=bs_c*N2j
replace bs_n=bs_n*N2j
replace bs_e=bs_e*N2j
replace bs_ze=bs_ze*N2j

*between firm total variance
replace btot_c=btot_c*N2j
replace btot_n=btot_n*N2j
replace btot_e=btot_e*N2j
replace btot_ze=btot_ze*N2j

*covariance CS NCS
g bcov=N2j*(cj-cbar)*(nj-nbar)

*** 3. Collapse to industry level for use in regressions. Note: This should only be done for main sample if looping

*if  `j'==main {
preserve
*components for between-firm within-industry variance
g bfwi_c=N2j*(cj-ck)^2
g bfwi_n=N2j*(nj-nk)^2
g bfwi_e=N2j*(ej-ek)^2
g bfwi_ze=N2j*(zej-zek)^2

collapse (sum) w* b* t* corr* cktilde=cijtilde nktilde=nijtilde ektilde=eijtilde zektilde=zeijtilde ckres=cijres nkres=nijres ekres=eijres zekres=zeijres Nk=Nj N2k=N2j (mean) N2 ck nk ek zek cbar nbar ebar zebar, by(year ftgsni2)

*sample correction industry level
g thetak=((Nk-N2k)/(N2k*Nk))*(1/(N2k-1))

*components for bfwi variance and bi variance
replace corr_bi_c=N2k*((ck-cbar)^2-thetak*corr_bi_c)
replace corr_bi_n=N2k*((nk-nbar)^2-thetak*corr_bi_n)
replace corr_bi_e=N2k*((ek-ebar)^2-thetak*corr_bi_e)
replace corr_bi_ze=N2k*((zek-zebar)^2-thetak*corr_bi_ze)

g bi_c=N2k*(ck-cbar)^2
g bi_n=N2k*(nk-nbar)^2
g bi_e=N2k*(ek-ebar)^2
g bi_ze=N2k*(zek-zebar)^2

save temp/decomp_bfwi_bi_v2_`i',replace
drop bi* bfwi* corr_bi* 

*note: predicted skills have been summed up from individual level => divide by N2K to get average industry skill
replace cktilde=cktilde/N2k
replace nktilde=nktilde/N2k
replace ektilde=ektilde/N2k
replace zektilde=zektilde/N2k

replace ckres=ckres/N2k
replace nkres=nkres/N2k
replace ekres=ekres/N2k
replace zekres=zekres/N2k

***final industry level uncorrected variances

* between occupation within firm
replace wt_c=wt_c*1/N2k
replace wt_n=wt_n*1/N2k
replace wt_e=wt_e*1/N2k
replace wt_ze=wt_ze*1/N2k

* within occupation within firm
replace wa_c=wa_c*1/N2k
replace wa_n=wa_n*1/N2k
replace wa_e=wa_e*1/N2k
replace wa_ze=wa_ze*1/N2k

*within firm covariance (between and within occupation)
replace wat_c=wat_c*2/N2k
replace wat_n=wat_n*2/N2k
replace wat_e=wat_e*2/N2k
replace wat_ze=wat_ze*2/N2k

*within firm total variance 
replace wtot_c=wtot_c*1/N2k
replace wtot_n=wtot_n*1/N2k
replace wtot_e=wtot_e*1/N2k
replace wtot_ze=wtot_ze*1/N2k

*within firm total (consistancy check of above)
replace ws_c=ws_c*1/N2k
replace ws_n=ws_n*1/N2k
replace ws_e=ws_e*1/N2k
replace ws_ze=ws_ze*1/N2k

*between occupation between firm
replace bt_c=bt_c*1/N2k
replace bt_n=bt_n*1/N2k
replace bt_e=bt_e*1/N2k
replace bt_ze=bt_ze*1/N2k

*within occupation between firm
replace ba_c=ba_c*1/N2k
replace ba_n=ba_n*1/N2k
replace ba_e=ba_e*1/N2k
replace ba_ze=ba_ze*1/N2k

*between firm covariance (between and within occ) 
replace bat_c=bat_c*2/N2k
replace bat_n=bat_n*2/N2k
replace bat_e=bat_e*2/N2k
replace bat_ze=bat_ze*2/N2k

*between firm total variance (consistancy check)
replace bs_c=bs_c*1/N2k
replace bs_n=bs_n*1/N2k
replace bs_e=bs_e*1/N2k
replace bs_ze=bs_ze*1/N2k

*between firm total variance
replace btot_c=btot_c*1/N2k
replace btot_n=btot_n*1/N2k
replace btot_e=btot_e*1/N2k
replace btot_ze=btot_ze*1/N2k

*total between occupation
replace tt_c=tt_c*1/N2k
replace tt_n=tt_n*1/N2k
replace tt_e=tt_e*1/N2k
replace tt_ze=tt_ze*1/N2k

*total within occupation
replace ta_c=ta_c*1/N2k
replace ta_n=ta_n*1/N2k
replace ta_e=ta_e*1/N2k
replace ta_ze=ta_ze*1/N2k

*total variance (consistancy)
replace ts_c=ts_c*1/N2k
replace ts_n=ts_n*1/N2k
replace ts_e=ts_e*1/N2k
replace ts_ze=ts_ze*1/N2k

*** Final industry level sample corrected variances 

*between occupation within firm corrected
replace corr_wt_c=corr_wt_c*1/N2k
replace corr_wt_n=corr_wt_n*1/N2k
replace corr_wt_e=corr_wt_e*1/N2k
replace corr_wt_ze=corr_wt_ze*1/N2k

*within occupation within firm corrected
replace corr_wa_c=corr_wa_c*1/N2k
replace corr_wa_n=corr_wa_n*1/N2k
replace corr_wa_e=corr_wa_e*1/N2k
replace corr_wa_ze=corr_wa_ze*1/N2k

*within firm covariance (between and within occ)  
replace corr_wat_c=corr_wat_c*2/N2k
replace corr_wat_n=corr_wat_n*2/N2k
replace corr_wat_e=corr_wat_e*2/N2k
replace corr_wat_ze=corr_wat_ze*2/N2k

*within firm total varinace corrected
replace corr_wtot_c=corr_wtot_c*1/N2k
replace corr_wtot_n=corr_wtot_n*1/N2k
replace corr_wtot_e=corr_wtot_e*1/N2k
replace corr_wtot_ze=corr_wtot_ze*1/N2k

*within firm total variance corrected (consistancy)
replace corr_ws_c=corr_ws_c*1/N2k
replace corr_ws_n=corr_ws_n*1/N2k
replace corr_ws_e=corr_ws_e*1/N2k
replace corr_ws_ze=corr_ws_ze*1/N2k

*between occupation between firm
replace corr_bt_c=corr_bt_c*1/N2k
replace corr_bt_n=corr_bt_n*1/N2k
replace corr_bt_e=corr_bt_e*1/N2k
replace corr_bt_ze=corr_bt_ze*1/N2k

*within occupation between firm
replace corr_ba_c=corr_ba_c*1/N2k
replace corr_ba_n=corr_ba_n*1/N2k
replace corr_ba_e=corr_ba_e*1/N2k
replace corr_ba_ze=corr_ba_ze*1/N2k

*between firm covariance (between and  within occ)  
replace corr_bat_c=corr_bat_c*2/N2k
replace corr_bat_n=corr_bat_n*2/N2k
replace corr_bat_e=corr_bat_e*2/N2k
replace corr_bat_ze=corr_bat_ze*2/N2k

*between firm total variance (consistancy)
replace corr_bs_c=corr_bs_c*1/N2k
replace corr_bs_n=corr_bs_n*1/N2k
replace corr_bs_e=corr_bs_e*1/N2k
replace corr_bs_ze=corr_bs_ze*1/N2k

*between firm total variance
replace corr_btot_c=corr_btot_c*1/N2k
replace corr_btot_n=corr_btot_n*1/N2k
replace corr_btot_e=corr_btot_e*1/N2k
replace corr_btot_ze=corr_btot_ze*1/N2k

save temp/decomp_occupation_matrix_industry_v2_`i',replace

restore
*}

*** 4. Overall collapse

collapse (sum) w* b* t* corr* N=Nj (mean) N2, by(year)

*final uncorrected variances 

*between occupation within firm
replace wt_c=wt_c*1/N2
replace wt_n=wt_n*1/N2
replace wt_e=wt_e*1/N2
replace wt_ze=wt_ze*1/N2

*within occupation within firm
replace wa_c=wa_c*1/N2
replace wa_n=wa_n*1/N2
replace wa_e=wa_e*1/N2
replace wa_ze=wa_ze*1/N2

*within firm covariance (between and within occ)  
replace wat_c=wat_c*2/N2
replace wat_n=wat_n*2/N2
replace wat_e=wat_e*2/N2
replace wat_ze=wat_ze*2/N2

*within firm total variance
replace wtot_c=wtot_c*1/N2
replace wtot_n=wtot_n*1/N2
replace wtot_e=wtot_e*1/N2
replace wtot_ze=wtot_ze*1/N2

*within firm total variance (consistancy)
replace ws_c=ws_c*1/N2
replace ws_n=ws_n*1/N2
replace ws_e=ws_e*1/N2
replace ws_ze=ws_ze*1/N2

*between occupation between firm
replace bt_c=bt_c*1/N2
replace bt_n=bt_n*1/N2
replace bt_e=bt_e*1/N2
replace bt_ze=bt_ze*1/N2

*within occupation between firm 
replace ba_c=ba_c*1/N2
replace ba_n=ba_n*1/N2
replace ba_e=ba_e*1/N2
replace ba_ze=ba_ze*1/N2

*between firm covariance (between and within occ)  
replace bat_c=bat_c*2/N2
replace bat_n=bat_n*2/N2
replace bat_e=bat_e*2/N2
replace bat_ze=bat_ze*2/N2

*between firm total variance (consistancy)
replace bs_c=bs_c*1/N2
replace bs_n=bs_n*1/N2
replace bs_e=bs_e*1/N2
replace bs_ze=bs_ze*1/N2

*between firm total variance
replace btot_c=btot_c*1/N2
replace btot_n=btot_n*1/N2
replace btot_e=btot_e*1/N2
replace btot_ze=btot_ze*1/N2

*total between occ
replace tt_c=tt_c*1/N2
replace tt_n=tt_n*1/N2
replace tt_e=tt_e*1/N2
replace tt_ze=tt_ze*1/N2

*total within occ
replace ta_c=ta_c*1/N2
replace ta_n=ta_n*1/N2
replace ta_e=ta_e*1/N2
replace ta_ze=ta_ze*1/N2

*total variance (consistancy)
replace ts_c=ts_c*1/N2
replace ts_n=ts_n*1/N2
replace ts_e=ts_e*1/N2
replace ts_ze=ts_ze*1/N2

*covariances skill
replace bcov=bcov*1/N2
replace wcov=wcov*1/N2

*** Final sample corrected variances 

*between occ within firm corrected
replace corr_wt_c=corr_wt_c*1/N2
replace corr_wt_n=corr_wt_n*1/N2
replace corr_wt_e=corr_wt_e*1/N2
replace corr_wt_ze=corr_wt_ze*1/N2

*within occ within firm corrected
replace corr_wa_c=corr_wa_c*1/N2
replace corr_wa_n=corr_wa_n*1/N2
replace corr_wa_e=corr_wa_e*1/N2
replace corr_wa_ze=corr_wa_ze*1/N2

*within firm covariance (between and within occ)  
replace corr_wat_c=corr_wat_c*2/N2
replace corr_wat_n=corr_wat_n*2/N2
replace corr_wat_e=corr_wat_e*2/N2
replace corr_wat_ze=corr_wat_ze*2/N2

*within firm total variance corrected
replace corr_wtot_c=corr_wtot_c*1/N2
replace corr_wtot_n=corr_wtot_n*1/N2
replace corr_wtot_e=corr_wtot_e*1/N2
replace corr_wtot_ze=corr_wtot_ze*1/N2

*within firm total variance corrected (concistancy)
replace corr_ws_c=corr_ws_c*1/N2
replace corr_ws_n=corr_ws_n*1/N2
replace corr_ws_e=corr_ws_e*1/N2
replace corr_ws_ze=corr_ws_ze*1/N2

*between occupation between firm
replace corr_bt_c=corr_bt_c*1/N2
replace corr_bt_n=corr_bt_n*1/N2
replace corr_bt_e=corr_bt_e*1/N2
replace corr_bt_ze=corr_bt_ze*1/N2

*within occupation between firm
replace corr_ba_c=corr_ba_c*1/N2
replace corr_ba_n=corr_ba_n*1/N2
replace corr_ba_e=corr_ba_e*1/N2
replace corr_ba_ze=corr_ba_ze*1/N2

*between firm covariance (between and within occ)  
replace corr_bat_c=corr_bat_c*2/N2
replace corr_bat_n=corr_bat_n*2/N2
replace corr_bat_e=corr_bat_e*2/N2
replace corr_bat_ze=corr_bat_ze*2/N2

*between firm total variance (consistancy)
replace corr_bs_c=corr_bs_c*1/N2
replace corr_bs_n=corr_bs_n*1/N2
replace corr_bs_e=corr_bs_e*1/N2
replace corr_bs_ze=corr_bs_ze*1/N2

*between firm total variance
replace corr_btot_c=corr_btot_c*1/N2
replace corr_btot_n=corr_btot_n*1/N2
replace corr_btot_e=corr_btot_e*1/N2
replace corr_btot_ze=corr_btot_ze*1/N2

*covariances skill
replace corr_bcov=corr_bcov*1/N2
replace corr_wcov=corr_wcov*1/N2

save temp/decomp_occupation_matrix_v2_`i',replace

}

*** Combine annual files to a main file

clear

use temp/decomp_occupation_matrix_1986
forvalues i=1987(1)2008{
append using temp/decomp_occupation_matrix_v2_`i'
keep b* w* t* corr* year N*
*}

lab var ba_c "Within occupation between firm"
lab var bt_c "Between occupation between firm"
lab var bat_c "Between firm covariance"
lab var bs_c "Between firm total"
lab var btot_c "Between firm total (consistancy)"

lab var wa_c "Within occupation within firm"
lab var wt_c "Between occupation within firm"
lab var wat_c "Within firm covariance"
lab var ws_c "Within firm total"
lab var wtot_c "Within firm total (consistancy)"

lab var ta_c "Within occupation total"
lab var tt_c "Between occupation total"
lab var ts_c "Total"

lab var ba_n "Within occupation between firm"
lab var bt_n "Between occupation between firm"
lab var bat_n "Between firm covariance"
lab var bs_n "Between firm total"
lab var btot_n "Between firm total (consistancy)"

lab var wa_n "Within occupation within firm"
lab var wt_n "Between occupation within firm"
lab var wat_n "Within firm covariance"
lab var ws_n "Within firm total"
lab var wtot_n "Within firm total (consistancy)"

lab var ta_n "Within occupation total"
lab var tt_n "Between occupation total"
lab var ts_n "Total"

lab var ba_e "Within occupation between firm"
lab var bt_e "Between occupation between firm"
lab var bat_e "Between firm covariance"
lab var bs_e "Between firm total"
lab var btot_e "Between firm total (consistancy)"

lab var wa_e "Within occupation within firm"
lab var wt_e "Between occupation within firm"
lab var wat_e "Between firm covariance"
lab var ws_e "Within firm total"
lab var wtot_e "Within firm total (consistancy)"

lab var ta_e "Within occupation total"
lab var tt_e "Between occupation total"
lab var ts_e "Total"

lab var ba_ze "Within occupation between firm"
lab var bt_ze "Between occupation between firm"
lab var bat_ze "Between firm covariance"
lab var bs_ze "Between firm total"
lab var btot_ze "Between firm total (consistancy)"

lab var wa_ze "Within occupation within firm"
lab var wt_ze "Between occupation within firm"
lab var wat_ze "Between firm covariance"
lab var ws_ze "Within firm total"
lab var wtot_ze "Within firm total (consistancy)"

lab var ta_ze "Within occupation total"
lab var tt_ze "Between occupation total"
lab var ts_ze "Total"

lab var corr_ba_c "Within occupation between firm"
lab var corr_bt_c "Between occupation between firm"
lab var corr_bat_c "Between firm covariance"
lab var corr_bs_c "Between firm total"
lab var corr_btot_c "Between firm total (consistancy)"

lab var corr_wa_c "Within occupation witin firm"
lab var corr_wt_c "Between occupation within firm"
lab var corr_wat_c "Within firm covariance"
lab var corr_ws_c "Within firm total"
lab var corr_wtot_c "Within firm total (consistancy)"

lab var corr_ba_n "Within occupation between firm"
lab var corr_bt_n "Between occupation between firm"
lab var corr_bat_n "Between firm covariance"
lab var corr_bs_n "Between firm total"
lab var corr_btot_n "Between firm total (consistancy)"

lab var corr_wa_n "Within occupation witin firm"
lab var corr_wt_n "Between occupation within firm"
lab var corr_wat_n "Within firm covariance"
lab var corr_ws_n "Within firm total"
lab var corr_wtot_n "Within firm total (consistancy)"

lab var corr_ba_e "Within occupation between firm"
lab var corr_bt_e "Between occupation between firm"
lab var corr_bat_e "Between firm covariance"
lab var corr_bs_e "Between firm total"
lab var corr_btot_e "Between firm total (consistancy)"

lab var corr_wa_e "Within occupation witin firm"
lab var corr_wt_e "Between occupation within firm"
lab var corr_wat_e "Within firm covariance"
lab var corr_ws_e "Within firm total"
lab var corr_wtot_e "Within firm total (consistancy)"

lab var corr_ba_ze "Within occupation between firm"
lab var corr_bt_ze "Between occupation between firm"
lab var corr_bat_ze "Between firm covariance"
lab var corr_bs_ze "Between firm total"
lab var corr_btot_ze "Between firm total (consistancy)"

lab var corr_wa_ze "Within occupation witin firm"
lab var corr_wt_ze "Between occupation within firm"
lab var corr_wat_ze "Within firm covariance"
lab var corr_ws_ze "Within firm total"
lab var corr_wtot_ze "Within firm total (consistancy)"

save modified/decomp_occupation_matrix_v2,replace
}

*** Append annual industry files
clear
use temp/decomp_occupation_matrix_industry_v2_1986
forvalues i=1987(1)2008{
append using temp/decomp_occupation_matrix_industry_v2_`i'
}
keep b* w* t* c* n* e* z* corr* year N*
save modified/decomp_occupation_matrix_industry_v2,replace

*** Append annual firm files
use temp/decomp_occupation_matrix_firm_v2_1986,clear
forvalues i=1987(1)2008{
append using temp/decomp_occupation_matrix_firm_v2_`i'
}
keep b* w* t* c* n* e* z* corr* year N*
save modified/decomp_occupation_matrix_firm_v2,replace

*** Collect and finalize variance bfwi and bi (only for main sample)
clear
use temp/decomp_bfwi_bi_v2_1986
forvalues i=1987(1)2008{
append using temp/decomp_bfwi_bi_v2_`i'
}
keep bi* btot* bfwi* corr_bi* corr_btot* year N2
collapse (sum) btot* bfwi* corr_bi* corr_btot* bi* (mean) N2, by (year)

replace btot_c=btot_c/N2
replace bfwi_c=bfwi_c/N2
replace bi_c=bi_c/N2
replace corr_btot_c=corr_btot_c/N2
replace corr_bi_c=corr_bi_c/N2

replace btot_n=btot_n/N2
replace bfwi_n=bfwi_n/N2
replace bi_n=bi_n/N2
replace corr_btot_n=corr_btot_n/N2
replace corr_bi_n=corr_bi_n/N2

replace btot_e=btot_e/N2
replace bfwi_e=bfwi_e/N2
replace bi_e=bi_e/N2
replace corr_btot_e=corr_btot_e/N2
replace corr_bi_e=corr_bi_e/N2

g corr_bfwi_c=corr_btot_c-corr_bi_c
g corr_bfwi_n=corr_btot_n-corr_bi_n
g corr_bfwi_e=corr_btot_e-corr_bi_e

save modified/decomp_bfwi_bi_v2,replace


**************************************************
*** Sorting by education for different samples ***
**************************************************

******************
*** Men 24-60 ****
*****************

set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
		use lopnr fos fos_detail edyr fos fos_detail zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' privfirm_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds 
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample 
		drop if sex=="2"
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10
		keep if age>=24 & age<=60

		*Observed samples and sizes
		bysort `x'nr: egen N2j=total(count)
		drop if N2j<2
		egen N2=total(count) 

		***Actual skill means
		*industry
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*sample
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*within firm total variance (consistancy check)
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*between firm total variance (consistancy check)
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*total variance (consistancy check)
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* t* c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 cj nj ej zej ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))
		
		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)
		
		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) Nj N2j lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*within firm/plant total variance (consistancy)
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*total variance (consistancy)
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/vardecomp_aggregate_ed2460_`x'_`j'_`i',replace
		}
	}
}

use temp/vardecomp_aggregate_ed2460_ftg_10_1986, clear
forvalues i=1987(1)2008 {
	append using temp/vardecomp_aggregate_ed2460_ftg_10_`i'
}

rename corr_bs_e corr_bs_e_ed2460
rename corr_ws_e corr_ws_e_ed2460
rename corr_bs_ze corr_bs_ze_ed2460
rename corr_ws_ze corr_ws_ze_ed2460
rename N2 N2ed2460
lab var corr_bs_e_ed2460 "Men 24-60"
lab var corr_bs_ze_ed2460 "Men 24-60"
lab var corr_ws_e_ed2460 "Men 24-60"
lab var corr_ws_ze_ed2460 "Men 24-60"
lab var N2ed2460 "Men 24-60"

save modified/vardecomp_aggregate_ed2460.dta, replace

***************************
*** Men and women 24-60 ***
***************************

set more off
foreach x in ftg {
	foreach j in 10 {
		forvalues i=1986(1)2008 {
		use lopnr fos fos_detail edyr fos fos_detail zedyr c n sex age lnwpred_`x' lnwage_`x' sample_3035_`j'_`x' in_sample_3035_`j'_`x' privfirm_`x' ftgstorl_`x' `x'nr ast_ftg `x'sni* year using modified/sample`i', clear

		* Drop firms/plants without identifiers
		drop if `x'nr==""
		
		* Keep 20-65 year olds 
		keep if age>=20 & age~=.
		keep if age<=65 & age~=.
		
		* Generate count variable
		g count=1
		
		* Generate the equivalence of Nj (all employees in sample firms/plants)
		bysort `x'nr: egen Nj=total(count)
		
		* Keep relevant sample 
		keep if privfirm_`x'==1
		keep if ftgstorl_`x'>=10
		keep if age>=24 & age<=60

		*Observed samples and sizes
		bysort `x'nr: egen N2j=total(count)
		drop if N2j<2
		egen N2=total(count) 

		***Actual skill means
		*industry
		bysort `x'sni2: egen ck=mean(c) 
		bysort `x'sni2: egen nk=mean(n) 
		bysort `x'sni2: egen ek=mean(edyr)
		bysort `x'sni2: egen zek=mean(zedyr)
		bysort `x'sni2: egen lnwpredk=mean(lnwpred_`x')
		bysort `x'sni2: egen lnwagek=mean(lnwage_`x')

		*firm/plant
		bysort `x'nr: egen cj=mean(c) 
		bysort `x'nr: egen nj=mean(n) 
		bysort `x'nr: egen ej=mean(edyr)
		bysort `x'nr: egen zej=mean(zedyr) 
		bysort `x'nr: egen lnwpredj=mean(lnwpred_`x')
		bysort `x'nr: egen lnwagej=mean(lnwage_`x')

		*sample
		egen cbar=mean(c)
		egen nbar=mean(n)
		egen ebar=mean(edyr)
		egen zebar=mean(zedyr)
		egen lnwpredbar=mean(lnwpred_`x')
		egen lnwagebar=mean(lnwage_`x')

		rename edyr e
		rename zedyr ze
			
		***Components for (corrected and uncorrected) variances (to be collapsed)

		*within firm total variance (consistancy check)
		g ws_c=(c-cj)^2
		g ws_n=(n-nj)^2
		g ws_e=(e-ej)^2
		g ws_ze=(ze-zej)^2

		*between firm total variance (consistancy check)
		g bs_c=(cj-cbar)^2
		g bs_n=(nj-nbar)^2
		g bs_e=(ej-ebar)^2
		g bs_ze=(zej-zebar)^2

		*total variance (consistancy check)
		g ts_c=(c-cbar)^2
		g ts_n=(n-nbar)^2
		g ts_e=(e-ebar)^2
		g ts_ze=(ze-zebar)^2
	
		*covariance CS NCS
		g wcov=(c-cj)*(n-nj)	

		*component for corr_between industry (this goes into the industry matrix)
		g corr_bi_c=(c-ck)^2
		g corr_bi_n=(n-nk)^2
		g corr_bi_e=(e-ek)^2
		g corr_bi_ze=(ze-zek)^2

		*** B.Collapse to firm/plant level (Note 2018-05-22: ast_ftg removed from collapse)
		
		collapse (sum) w* t* c n e ze corr_bi* (mean) lnwpredj lnwagej b* ftgstorl_`x' Nj N2j N2 cj nj ej zej ck nk ek zek lnwpredk lnwagek cbar nbar ebar zebar lnwpredbar lnwagebar, by (year `x'nr `x'sni2)

		*sample correction firm/plant level
		g thetaj_w=((Nj-1)/Nj)*(1/(N2j-1))
		g thetaj_b=((Nj-N2j)/(Nj*N2j))*(1/(N2j-1))
		
		*components for corrected variances

		*within firm/plant total variance corrected 
		g corr_ws_c=ws_c*thetaj_w*N2j
		g corr_ws_n=ws_n*thetaj_w*N2j
		g corr_ws_e=ws_e*thetaj_w*N2j
		g corr_ws_ze=ws_ze*thetaj_w*N2j

		*between firm/plant total variance corrected (consistancy check)
		g corr_bs_c=N2j*(bs_c-thetaj_b*ws_c)
		g corr_bs_n=N2j*(bs_n-thetaj_b*ws_n)
		g corr_bs_e=N2j*(bs_e-thetaj_b*ws_e)
		g corr_bs_ze=N2j*(bs_ze-thetaj_b*ws_ze)

		*covariance CS NCS corrected
		g corr_bcov=N2j*((cj-cbar)*(nj-nbar)-thetaj_b*wcov)
		g corr_wcov=N2j*thetaj_w*wcov

		*between firm/plant total variance (consistancy check of total variance demcomp)
		replace bs_c=bs_c*N2j
		replace bs_n=bs_n*N2j
		replace bs_e=bs_e*N2j
		replace bs_ze=bs_ze*N2j

		*covariance CS NCS
		g bcov=N2j*(cj-cbar)*(nj-nbar)
		
		*** 4. Overall collapse

		collapse (sum) w* b* t* corr* N=Nj (mean) Nj N2j lnwpred=lnwpredbar lnwage=lnwagebar N2, by(year)

		*within firm/plant total variance (consistancy)
		replace ws_c=ws_c*1/N2
		replace ws_n=ws_n*1/N2
		replace ws_e=ws_e*1/N2
		replace ws_ze=ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace bs_c=bs_c*1/N2
		replace bs_n=bs_n*1/N2
		replace bs_e=bs_e*1/N2
		replace bs_ze=bs_ze*1/N2

		*total variance (consistancy)
		replace ts_c=ts_c*1/N2
		replace ts_n=ts_n*1/N2
		replace ts_e=ts_e*1/N2
		replace ts_ze=ts_ze*1/N2

		*covariances skill
		replace bcov=bcov*1/N2
		replace wcov=wcov*1/N2

		*** Final sample corrected variances 

		*within firm/plant total variance corrected (concistancy)
		replace corr_ws_c=corr_ws_c*1/N2
		replace corr_ws_n=corr_ws_n*1/N2
		replace corr_ws_e=corr_ws_e*1/N2
		replace corr_ws_ze=corr_ws_ze*1/N2

		*between firm/plant total variance (consistancy)
		replace corr_bs_c=corr_bs_c*1/N2
		replace corr_bs_n=corr_bs_n*1/N2
		replace corr_bs_e=corr_bs_e*1/N2
		replace corr_bs_ze=corr_bs_ze*1/N2

		*covariances skill
		replace corr_bcov=corr_bcov*1/N2
		replace corr_wcov=corr_wcov*1/N2

		save temp/vardecomp_aggregate_alled2460_`x'_`j'_`i',replace
		}
	}
}

use temp/vardecomp_aggregate_alled2460_ftg_10_1986, clear
forvalues i=1987(1)2008 {
	append using temp/vardecomp_aggregate_alled2460_ftg_10_`i'
}

rename corr_bs_e corr_bs_e_alled2460
rename corr_ws_e corr_ws_e_alled2460
rename corr_bs_ze corr_bs_ze_alled2460
rename corr_ws_ze corr_ws_ze_alled2460
rename N2 N2alled2460
lab var corr_bs_e_alled2460 "All 24-60"
lab var corr_bs_ze_alled2460 "All 24-60"
lab var corr_ws_e_alled2460 "All 24-60"
lab var corr_ws_ze_alled2460 "All 24-60"
lab var N2alled2460 "All 24-60"

save modified/vardecomp_aggregate_alled2460.dta, replace

*********************************
*** AKM sorting excluding ICT ***
*********************************

foreach x in ftg {
	foreach j in 10 {
		forvalues i=1989(1)2005 {
			use lopnr fos fos_detail edyr zedyr c n sex age lnwpred_`x'  sample_3035_`j'_`x' in_sample_3035_`j'_`x' ftgstorl_`x' privfirm_`x' ftgnr ftg_ast astnr ast_ftg `x'sni* year using modified/sample`i', clear
				drop if `x'nr==""	
				sort lopnr
				merge 1:1 lopnr using modified/akm_rolling_4_2.dta
				drop if _merge==2
				drop _merge
		
				gen p=.
				replace p=p2z`i'
				
				* Keep 20-65 year olds (same restriction as in wage dispersion analysis)
				keep if age>=20 & age~=.
				keep if age<=65 & age~=.

				* Drop IT (72) and telecom (32) 
				drop if `x'sni2==72
				drop if `x'sni2==32
		
				* Generate count variable
				g count=1
		
				* Actual firm employees
				bysort `x'nr: egen Nj=total(count)
				
				* Keep relevant sample
				keep if sample_3035_`j'_`x'==1
				keep if p~=.

				* Number of firm level observations 
				bysort `x'nr: egen nj=total(count)
				* Drop if less than two obs per firm (needed for size adjustments)
				drop if nj<2
				
				* Sample size correction terms 
				g theta_wf=((Nj-1)/Nj)*(1/(nj-1))
				g theta_bf=((Nj-nj)/(Nj*nj))*(1/(nj-1))
				
				* Total number of observations
				egen n2=total(count)
								
				* Mean sample skills
				egen pbar=mean(p)
				* Mean skills by firm/plant
				bysort `x'nr: egen pj=mean(p)
				* Skills demeaned by firm
				gen pdm=p-pj
				
				* Total skill variance: pvar
				egen pvar=sum((p-pbar)^2)
				replace pvar=pvar/n2
				
				* Within firm skill variance by firm: pvarw (adj1 is the correction term for bf variance)
				bysort `x'nr: egen adj1=sum(pdm^2)
				gen pvarw=adj1/nj
								
				* Within firm variance by firm, sample size adjusted: pvarw_adj 
				gen pvarw_adj=adj1*theta_wf
				
				* Between firm skill variance: pvarb
				egen pvarb=sum((pj-pbar)^2)
				replace pvarb=pvarb/n2

				* Between firm skill variance, sample size adjusted: pvarb_adj
				egen pvarb_adj=sum((pj-pbar)^2 - (theta_bf*adj1))
				replace pvarb_adj=pvarb_adj/n2
				
				* Total within firm: sum unadjusted and adjusted, divide by total number of observations
				egen pvarwtot=sum(pvarw)
				replace pvarwtot=pvarwtot/n2

				egen pvarwtot_adj=sum(pvarw_adj)
				replace pvarwtot_adj=pvarwtot_adj/n2
				
				drop pvarw pvarw_adj
				rename pvarwtot pvarw
				rename pvarwtot_adj pvarw_adj
				keep year pvar pvarw pvarw_adj pvarb pvarb_adj
				duplicates drop year, force
		save temp/AKMvardecomposition_exICT_`x'_`j'_`i'.dta,replace
		}
	}
}

* Combine into one file
use temp/AKMvardecomposition_exICT_ftg_10_1989
forvalues i=1990(1)2005 {
	append using temp/AKMvardecomposition_exICT_ftg_10_`i'
}
save modified/akm_vardecomp_3035_exICT, replace


*************************
*** Firm level data  ****
*************************
use modified/prodfcn_data_3035, clear

keep oms ftgnr ftgsni2 ant_anst fv kma Km Kb year foradlingsvarde omsattning trim_kma 
drop if year==1985

* Trimming capital intensity based on top and bottom percentile of firm capital intensities
replace kma=. if trim_kma==0	
replace Km=. if trim_kma==0

gen kmaj=Km/ant_anst
gen lnsizej=ln(ant_anst)
gen lncapintj=ln(kma)
rename ant_anst sizej
rename fv vaj
rename Km Kmj
rename Kb Kbj

lab var kmaj "Mean capital (machinery) intensiy"
lab var sizej "Employees"
lab var vaj "Value added"
lab var Kmj "Capital: machinery"
lab var Kbj "Capital: buildings"
lab var lnsizej "Log no of employees"
lab var lncapintj "Log capital (machinery) intensity"

sort ftgnr year
save temp/firmdata.dta, replace

**********************************
*** Firm level wage dispersion ***
**********************************
* wpred is (log) imputed wages based on sws
* lwage is (log) earnings, converted to monthly equavalents

* wa1: all based on wpred
* wa2: men based on wpred
* wa3: men 30-35 based on wpred ithout adjustments: THIS IS THE MAIN WAGE MEASURE USED!
* wa4: all based on lwage
* wa5: men based on lwage
* wa6: men 30-35 based on lwage

use lopnr fos fos_detail edyr zedyr c n sex sample_3035_50 sample_3045_50 sample_3035_50f in_sample_3035_50 in_sample_3045_50 in_sample_3035_50f ftgsni* astsni* ftgstorl age ftgnr wpred lwage year using modified/sample1986, clear
forvalues i=1987(1)2008{
	append using modified/sample`i', keep(lopnr fos fos_detail edyr zedyr c n sex sample_3035_50 sample_3045_50 sample_3035_50f in_sample_3035_50 in_sample_3045_50 in_sample_3035_50f ftgsni* astsni* ftgstorl age ftgnr wpred lwage year)
}

*retain only individuals in sample firms
keep if in_sample_3035_50==1
destring sex, replace

* Mean sample wages
bysort year: egen wa1m=mean(wpred)
bysort year: egen wa2m=mean(wpred) if sex==1
bysort year: egen wa3m=mean(wpred) if sample_3035_50==1
bysort year: egen wa4m=mean(lwage)
bysort year: egen wa5m=mean(lwage) if sex==1
bysort year: egen wa6m=mean(lwage) if sample_3035_50==1

* Mean by firm
bysort ftgnr year: egen wa1j=mean(wpred)
bysort ftgnr year: egen wa2j=mean(wpred) if sex==1
bysort ftgnr year: egen wa3j=mean(wpred) if sample_3035_50==1
bysort ftgnr year: egen wa4j=mean(lwage)
bysort ftgnr year: egen wa5j=mean(lwage) if sex==1
bysort ftgnr year: egen wa6j=mean(lwage) if sample_3035_50==1

* Mean sample skills (among 30-35 year old men)
bysort year: egen cm=mean(c) if sample_3035_50==1
bysort year: egen nm=mean(n) if sample_3035_50==1
bysort year: egen edyrm_3035=mean(edyr) if sample_3035_50==1
bysort year: egen edyrm=mean(edyr)
bysort year: egen zedyrm_3035=mean(zedyr) if sample_3035_50==1
bysort year: egen zedyrm=mean(zedyr)

* Mean skills by firm(among 30-35 year old men)
bysort ftgnr year: egen cj=mean(c) if sample_3035_50==1
bysort ftgnr year: egen nj=mean(n) if sample_3035_50==1
bysort ftgnr year: egen edyrj_3035=mean(edyr) if sample_3035_50==1
bysort ftgnr year: egen edyrj=mean(edyr)
bysort ftgnr year: egen zedyrj_3035=mean(zedyr) if sample_3035_50==1
bysort ftgnr year: egen zedyrj=mean(zedyr)

* Number of observations by year
bysort year: egen nobs1=count(wpred)
bysort year: egen nobs2=count(wpred) if sex==1
bysort year: egen nobs3=count(wpred) if sample_3035_50==1
bysort year: egen nobs4=count(lwage)
bysort year: egen nobs5=count(lwage) if sex==1
bysort year: egen nobs6=count(lwage) if sample_3035_50==1

* Number of observations by firm-year
bysort ftgnr year: egen nobs1j=count(wpred)
bysort ftgnr year: egen nobs2j=count(wpred) if sex==1
bysort ftgnr year: egen nobs3j=count(wpred) if sample_3035_50==1
bysort ftgnr year: egen nobs4j=count(lwage)
bysort ftgnr year: egen nobs5j=count(lwage) if sex==1
bysort ftgnr year: egen nobs6j=count(lwage) if sample_3035_50==1

* Total wage variance by year
bysort year: egen w1sd=sd(wpred)
bysort year: gen w1var=w1sd*w1sd
bysort year: egen w2sd=sd(wpred) if sex==1
bysort year: gen w2var=w2sd*w2sd if sex==1
bysort year: egen w3sd=sd(wpred) if sample_3035_50==1
bysort year: gen w3var=w3sd*w3sd if sample_3035_50==1
bysort year: egen w4sd=sd(lwage)
bysort year: gen w4var=w4sd*w4sd
bysort year: egen w5sd=sd(lwage) if sex==1
bysort year: gen w5var=w5sd*w5sd if sex==1
bysort year: egen w6sd=sd(lwage) if sample_3035_50==1
bysort year: gen w6var=w6sd*w6sd if sample_3035_50==1

* Collapse to firm-year level
sort ftgnr year
collapse w1var w2var w3var w4var w5var w6var wa1m wa2m wa3m wa4m wa5m wa6m wa1j wa2j wa3j wa4j wa5j wa6j cm nm edyrm zedyrm edyrm_3035 zedyrm_3035 cj nj edyrj zedyrj edyrj_3035 zedyrj_3035 ftgstorl nobs1 nobs2 nobs3 nobs4 nobs5 nobs6 nobs1j nobs2j nobs3j nobs4j nobs5j nobs6j, by(ftgnr year)

*** Between firm variance 
bysort year: egen BFt1=sum(nobs1j*((wa1j-wa1m)*(wa1j-wa1m)))
replace BFt1=BFt1/nobs1
bysort year: egen BFt2=sum(nobs2j*((wa2j-wa2m)*(wa2j-wa2m)))
replace BFt2=BFt2/nobs2
bysort year: egen BFt3=sum(nobs3j*((wa3j-wa3m)*(wa3j-wa3m)))
replace BFt3=BFt3/nobs3
bysort year: egen BFt4=sum(nobs4j*((wa4j-wa4m)*(wa4j-wa4m)))
replace BFt4=BFt4/nobs4
bysort year: egen BFt5=sum(nobs5j*((wa5j-wa5m)*(wa5j-wa5m)))
replace BFt5=BFt5/nobs5
bysort year: egen BFt6=sum(nobs6j*((wa6j-wa6m)*(wa6j-wa6m)))
replace BFt6=BFt6/nobs6

lab var wa1m "Mean monthly wages, all"
lab var wa2m "Mean monthly wages, men"
lab var wa3m "Mean monthly wages, men 30-35"
lab var wa4m "Mean monthly earnings, all"
lab var wa5m "Mean monthly earnings, men"
lab var wa6m "Mean monthly earnings, men 30-35"

lab var wa1j "Firm monthly wages, all"
lab var wa2j "Firm monthly wages, men"
lab var wa3j "Firm monthly wages, men 30-35"
lab var wa4j "Firm monthly earnings, all"
lab var wa5j "Firm monthly earnings, men"
lab var wa6j "Firm monthly earnings, men 30-35"

lab var nobs1 "Total number of observations, all"
lab var nobs2 "Total number of observations, men"
lab var nobs3 "Total number of observations, men 30-35"
lab var nobs4 "Total number of observations, all"
lab var nobs5 "Total number of observations, men"
lab var nobs6 "Total number of observations, men 30-35"

lab var ftgstorl "Firm number of employees (RAMS)"
lab var nobs1j "Firm number of observations, all"
lab var nobs2j "Firm number of observations, men"
lab var nobs3j "Firm number of observations, men 30-35"
lab var nobs4j "Firm number of observations, all"
lab var nobs5j "Firm number of observations, men"
lab var nobs6j "Firm number of observations, men 30-35"

lab var cm "Mean cognitive, men 30-35"
lab var nm "Mean non-cognitive, men 30-35"
lab var edyrm "Mean edyr, all"
lab var edyrm_3035 "Mean edyr, men 30-35"
lab var zedyrm "Mean zedyr, all"
lab var zedyrm_3035 "Mean zedyr, men 30-35"

lab var cj "Firm cognitive, men 30-35"
lab var nj "Firm non-cognitive, men 30-35"
lab var edyrj "Firm edyr, all"
lab var edyrj_3035 "Firm edyr, men 30-35"
lab var zedyrj "Firm zedyr, all"
lab var zedyrj_3035 "Firm zedyr, men 30-35"

lab var w1var "Total wage variance, all"
lab var w2var "Total wage variance, men"
lab var w3var "Total wage variance, men 30-35"
lab var w4var "Total earnings variance, all"
lab var w5var "Total earnings variance, men"
lab var w6var "Total earnings variance, men 30-35"

lab var BFt1 "Between firm wage variance, all"
lab var BFt2 "Between firm wage variance, men"
lab var BFt3 "Between firm wage variance, men 30-35"
lab var BFt4 "Between firm earnings variance, all"
lab var BFt5 "Between firm earnings variance, men"
lab var BFt6 "Between firm earnings variance, men 30-35"

save modified/wage_dispersion_firm.dta, replace

*********************************
*** Aggregate wage dispersion ***
*********************************

use modified/wage_dispersion_firm.dta, clear

collapse wa1m wa2m wa3m wa4m wa5m wa6m w1var w2var w3var w4var w5var w6var BF* nobs*, by(year)

gen WFt1=w1var-BFt1
gen WFt2=w2var-BFt2
gen WFt3=w3var-BFt3
gen WFt4=w4var-BFt4
gen WFt5=w5var-BFt5
gen WFt6=w6var-BFt6

lab var wa1m "Mean monthly wages, all"
lab var wa2m "Mean monthly wages, men"
lab var wa3m "Mean monthly wages, men 30-35"
lab var wa4m "Mean monthly earnings, all"
lab var wa5m "Mean monthly earnings, men"
lab var wa6m "Mean monthly earnings, men 30-35"

lab var w1var "Total wage variance, all"
lab var w2var "Total wage variance, men"
lab var w3var "Total wage variance, men 30-35"
lab var w4var "Total earnings variance, all"
lab var w5var "Total earnings variance, men"
lab var w6var "Total earnings variance, men 30-35"

lab var WFt1 "Within firm wage variance, all"
lab var WFt2 "Within firm wage variance, men"
lab var WFt3 "Within firm wage variance, men 30-35"
lab var WFt4 "Within firm earnings variance, all"
lab var WFt5 "Within firm earnings variance, men"
lab var WFt6 "Within firm earnings variance, men 30-35"

lab var BFt1 "Between firm wage variance, all"
lab var BFt2 "Between firm wage variance, men"
lab var BFt3 "Between firm wage variance, men 30-35"
lab var BFt4 "Between firm earnings variance, all"
lab var BFt5 "Between firm earnings variance, men"
lab var BFt6 "Between firm earnings variance, men 30-35"

save modified/wage_dispersion_agg_firm.dta, replace

